import { encode as encode$4, decode as decode$5 } from 'universal-base64url';
import { KeyType, Checksum256, Bytes, PrivateKey, PublicKey, Name, Serializer, APIClient, FetchProvider, Action, Transaction, SignedTransaction, ABI } from '@wharfkit/antelope';
import rb from '@consento/sync-randombytes';
import Debug from 'debug';
import { getResolver } from '@tonomy/antelope-did-resolver';
import { getDidKeyResolver } from '@veramo/did-provider-key';
import { SigningKey, Wallet } from 'ethers';
import fetch from 'cross-fetch';
import Decimal from 'decimal.js';
import { io } from 'socket.io-client';
import { createAgent } from '@veramo/core';
import { DIDManager } from '@veramo/did-manager';
import { EthrDIDProvider } from '@veramo/did-provider-ethr';
import { KeyManager } from '@veramo/key-manager';
import { KeyManagementSystem, SecretBox } from '@veramo/kms-local';
import { CredentialPlugin } from '@veramo/credential-w3c';
import { DIDResolverPlugin } from '@veramo/did-resolver';
import { getResolver as getResolver$1 } from 'ethr-did-resolver';
import { getResolver as getResolver$2 } from 'web-did-resolver';
import { KeyStore, PrivateKeyStore, migrations, Entities, DIDStore } from '@veramo/data-store';
import { DataSource } from 'typeorm';

function _arrayLikeToArray(r, a) {
  (null == a || a > r.length) && (a = r.length);
  for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e];
  return n;
}
function _construct(t, e, r) {
  if (_isNativeReflectConstruct()) return Reflect.construct.apply(null, arguments);
  var o = [null];
  o.push.apply(o, e);
  var p = new (t.bind.apply(t, o))();
  return r && _setPrototypeOf(p, r.prototype), p;
}
function _defineProperties(e, r) {
  for (var t = 0; t < r.length; t++) {
    var o = r[t];
    o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o);
  }
}
function _createClass(e, r, t) {
  return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", {
    writable: !1
  }), e;
}
function _createForOfIteratorHelperLoose(r, e) {
  var t = "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"];
  if (t) return (t = t.call(r)).next.bind(t);
  if (Array.isArray(r) || (t = _unsupportedIterableToArray(r)) || e && r && "number" == typeof r.length) {
    t && (r = t);
    var o = 0;
    return function () {
      return o >= r.length ? {
        done: !0
      } : {
        done: !1,
        value: r[o++]
      };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function (n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
function _getPrototypeOf(t) {
  return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) {
    return t.__proto__ || Object.getPrototypeOf(t);
  }, _getPrototypeOf(t);
}
function _inheritsLoose(t, o) {
  t.prototype = Object.create(o.prototype), t.prototype.constructor = t, _setPrototypeOf(t, o);
}
function _isNativeFunction(t) {
  try {
    return -1 !== Function.toString.call(t).indexOf("[native code]");
  } catch (n) {
    return "function" == typeof t;
  }
}
function _isNativeReflectConstruct() {
  try {
    var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
  } catch (t) {}
  return (_isNativeReflectConstruct = function () {
    return !!t;
  })();
}
function _setPrototypeOf(t, e) {
  return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) {
    return t.__proto__ = e, t;
  }, _setPrototypeOf(t, e);
}
function _toPrimitive(t, r) {
  if ("object" != typeof t || !t) return t;
  var e = t[Symbol.toPrimitive];
  if (void 0 !== e) {
    var i = e.call(t, r || "default");
    if ("object" != typeof i) return i;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r ? String : Number)(t);
}
function _toPropertyKey(t) {
  var i = _toPrimitive(t, "string");
  return "symbol" == typeof i ? i : i + "";
}
function _unsupportedIterableToArray(r, a) {
  if (r) {
    if ("string" == typeof r) return _arrayLikeToArray(r, a);
    var t = {}.toString.call(r).slice(8, -1);
    return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0;
  }
}
function _wrapNativeSuper(t) {
  var r = "function" == typeof Map ? new Map() : void 0;
  return _wrapNativeSuper = function (t) {
    if (null === t || !_isNativeFunction(t)) return t;
    if ("function" != typeof t) throw new TypeError("Super expression must either be null or a function");
    if (void 0 !== r) {
      if (r.has(t)) return r.get(t);
      r.set(t, Wrapper);
    }
    function Wrapper() {
      return _construct(t, arguments, _getPrototypeOf(this).constructor);
    }
    return Wrapper.prototype = Object.create(t.prototype, {
      constructor: {
        value: Wrapper,
        enumerable: !1,
        writable: !0,
        configurable: !0
      }
    }), _setPrototypeOf(Wrapper, t);
  }, _wrapNativeSuper(t);
}

/**
 * Utility function that works like `Object.apply`, but copies getters and setters properly as well.  Additionally gives
 * the option to exclude properties by name.
 */
const copyProps = (dest, src, exclude = []) => {
    const props = Object.getOwnPropertyDescriptors(src);
    for (let prop of exclude)
        delete props[prop];
    Object.defineProperties(dest, props);
};
/**
 * Returns the full chain of prototypes up until Object.prototype given a starting object.  The order of prototypes will
 * be closest to farthest in the chain.
 */
const protoChain = (obj, currentChain = [obj]) => {
    const proto = Object.getPrototypeOf(obj);
    if (proto === null)
        return currentChain;
    return protoChain(proto, [...currentChain, proto]);
};
/**
 * Identifies the nearest ancestor common to all the given objects in their prototype chains.  For most unrelated
 * objects, this function should return Object.prototype.
 */
const nearestCommonProto = (...objs) => {
    if (objs.length === 0)
        return undefined;
    let commonProto = undefined;
    const protoChains = objs.map(obj => protoChain(obj));
    while (protoChains.every(protoChain => protoChain.length > 0)) {
        const protos = protoChains.map(protoChain => protoChain.pop());
        const potentialCommonProto = protos[0];
        if (protos.every(proto => proto === potentialCommonProto))
            commonProto = potentialCommonProto;
        else
            break;
    }
    return commonProto;
};
/**
 * Creates a new prototype object that is a mixture of the given prototypes.  The mixing is achieved by first
 * identifying the nearest common ancestor and using it as the prototype for a new object.  Then all properties/methods
 * downstream of this prototype (ONLY downstream) are copied into the new object.
 *
 * The resulting prototype is more performant than softMixProtos(...), as well as ES5 compatible.  However, it's not as
 * flexible as updates to the source prototypes aren't captured by the mixed result.  See softMixProtos for why you may
 * want to use that instead.
 */
const hardMixProtos = (ingredients, constructor, exclude = []) => {
    var _a;
    const base = (_a = nearestCommonProto(...ingredients)) !== null && _a !== void 0 ? _a : Object.prototype;
    const mixedProto = Object.create(base);
    // Keeps track of prototypes we've already visited to avoid copying the same properties multiple times.  We init the
    // list with the proto chain below the nearest common ancestor because we don't want any of those methods mixed in
    // when they will already be accessible via prototype access.
    const visitedProtos = protoChain(base);
    for (let prototype of ingredients) {
        let protos = protoChain(prototype);
        // Apply the prototype chain in reverse order so that old methods don't override newer ones.
        for (let i = protos.length - 1; i >= 0; i--) {
            let newProto = protos[i];
            if (visitedProtos.indexOf(newProto) === -1) {
                copyProps(mixedProto, newProto, ['constructor', ...exclude]);
                visitedProtos.push(newProto);
            }
        }
    }
    mixedProto.constructor = constructor;
    return mixedProto;
};
const unique = (arr) => arr.filter((e, i) => arr.indexOf(e) == i);

// Keeps track of constituent classes for every mixin class created by ts-mixer.
const mixins = new WeakMap();
const getMixinsForClass = (clazz) => mixins.get(clazz);
const registerMixins = (mixedClass, constituents) => mixins.set(mixedClass, constituents);

const mergeObjectsOfDecorators = (o1, o2) => {
    var _a, _b;
    const allKeys = unique([...Object.getOwnPropertyNames(o1), ...Object.getOwnPropertyNames(o2)]);
    const mergedObject = {};
    for (let key of allKeys)
        mergedObject[key] = unique([...((_a = o1 === null || o1 === void 0 ? void 0 : o1[key]) !== null && _a !== void 0 ? _a : []), ...((_b = o2 === null || o2 === void 0 ? void 0 : o2[key]) !== null && _b !== void 0 ? _b : [])]);
    return mergedObject;
};
const mergePropertyAndMethodDecorators = (d1, d2) => {
    var _a, _b, _c, _d;
    return ({
        property: mergeObjectsOfDecorators((_a = d1 === null || d1 === void 0 ? void 0 : d1.property) !== null && _a !== void 0 ? _a : {}, (_b = d2 === null || d2 === void 0 ? void 0 : d2.property) !== null && _b !== void 0 ? _b : {}),
        method: mergeObjectsOfDecorators((_c = d1 === null || d1 === void 0 ? void 0 : d1.method) !== null && _c !== void 0 ? _c : {}, (_d = d2 === null || d2 === void 0 ? void 0 : d2.method) !== null && _d !== void 0 ? _d : {}),
    });
};
const mergeDecorators = (d1, d2) => {
    var _a, _b, _c, _d, _e, _f;
    return ({
        class: unique([...(_a = d1 === null || d1 === void 0 ? void 0 : d1.class) !== null && _a !== void 0 ? _a : [], ...(_b = d2 === null || d2 === void 0 ? void 0 : d2.class) !== null && _b !== void 0 ? _b : []]),
        static: mergePropertyAndMethodDecorators((_c = d1 === null || d1 === void 0 ? void 0 : d1.static) !== null && _c !== void 0 ? _c : {}, (_d = d2 === null || d2 === void 0 ? void 0 : d2.static) !== null && _d !== void 0 ? _d : {}),
        instance: mergePropertyAndMethodDecorators((_e = d1 === null || d1 === void 0 ? void 0 : d1.instance) !== null && _e !== void 0 ? _e : {}, (_f = d2 === null || d2 === void 0 ? void 0 : d2.instance) !== null && _f !== void 0 ? _f : {}),
    });
};
const decorators = new Map();
const findAllConstituentClasses = (...classes) => {
    var _a;
    const allClasses = new Set();
    const frontier = new Set([...classes]);
    while (frontier.size > 0) {
        for (let clazz of frontier) {
            const protoChainClasses = protoChain(clazz.prototype).map(proto => proto.constructor);
            const mixinClasses = (_a = getMixinsForClass(clazz)) !== null && _a !== void 0 ? _a : [];
            const potentiallyNewClasses = [...protoChainClasses, ...mixinClasses];
            const newClasses = potentiallyNewClasses.filter(c => !allClasses.has(c));
            for (let newClass of newClasses)
                frontier.add(newClass);
            allClasses.add(clazz);
            frontier.delete(clazz);
        }
    }
    return [...allClasses];
};
const deepDecoratorSearch = (...classes) => {
    const decoratorsForClassChain = findAllConstituentClasses(...classes)
        .map(clazz => decorators.get(clazz))
        .filter(decorators => !!decorators);
    if (decoratorsForClassChain.length == 0)
        return {};
    if (decoratorsForClassChain.length == 1)
        return decoratorsForClassChain[0];
    return decoratorsForClassChain.reduce((d1, d2) => mergeDecorators(d1, d2));
};

function Mixin(...constructors) {
    var _a, _b, _c;
    const prototypes = constructors.map(constructor => constructor.prototype);
    function MixedClass(...args) {
        for (const constructor of constructors)
            // @ts-ignore: potentially abstract class
            copyProps(this, new constructor(...args));
    }
    MixedClass.prototype = hardMixProtos(prototypes, MixedClass)
        ;
    Object.setPrototypeOf(MixedClass, hardMixProtos(constructors, null, ['prototype'])
        );
    let DecoratedMixedClass = MixedClass;
    {
        const classDecorators = deepDecoratorSearch(...constructors)
            ;
        for (let decorator of (_a = classDecorators === null || classDecorators === void 0 ? void 0 : classDecorators.class) !== null && _a !== void 0 ? _a : []) {
            const result = decorator(DecoratedMixedClass);
            if (result) {
                DecoratedMixedClass = result;
            }
        }
        applyPropAndMethodDecorators((_b = classDecorators === null || classDecorators === void 0 ? void 0 : classDecorators.static) !== null && _b !== void 0 ? _b : {}, DecoratedMixedClass);
        applyPropAndMethodDecorators((_c = classDecorators === null || classDecorators === void 0 ? void 0 : classDecorators.instance) !== null && _c !== void 0 ? _c : {}, DecoratedMixedClass.prototype);
    }
    registerMixins(DecoratedMixedClass, constructors);
    return DecoratedMixedClass;
}
const applyPropAndMethodDecorators = (propAndMethodDecorators, target) => {
    const propDecorators = propAndMethodDecorators.property;
    const methodDecorators = propAndMethodDecorators.method;
    if (propDecorators)
        for (let key in propDecorators)
            for (let decorator of propDecorators[key])
                decorator(target, key);
    if (methodDecorators)
        for (let key in methodDecorators)
            for (let decorator of methodDecorators[key])
                decorator(target, key, Object.getOwnPropertyDescriptor(target, key));
};

// From utf8 to base64url and visa versa
function objToBase64Url(obj) {
  return encode$4(JSON.stringify(obj));
}
function base64UrlToObj(str) {
  return JSON.parse(decode$5(str));
}

var HttpError = /*#__PURE__*/function (_Error) {
  function HttpError(httpError) {
    var _this;
    _this = _Error.call(this, 'HTTP Error') || this;
    // Ensure the name of this error is the same as the class name
    _this.path = void 0;
    _this.response = void 0;
    _this.code = void 0;
    _this.line = void 0;
    _this.column = void 0;
    _this.sourceURL = void 0;
    _this.name = _this.constructor.name;
    // This clips the constructor invocation from the stack trace.
    // It's not absolutely essential, but it does make the stack trace a little nicer.
    //  @see Node.js reference (bottom)
    if (Error.captureStackTrace) {
      Error.captureStackTrace(_this, _this.constructor);
    }
    _this.stack = new Error().stack;
    _this.path = httpError.path;
    _this.response = httpError.response;
    if (httpError.line) _this.line = httpError.line;
    if (httpError.column) _this.line = httpError.column;
    if (httpError.sourceURL) _this.sourceURL = httpError.sourceURL;
    if (httpError.code) _this.code = httpError.code;
    return _this;
  }
  _inheritsLoose(HttpError, _Error);
  return HttpError;
}( /*#__PURE__*/_wrapNativeSuper(Error));
var CommunicationError = /*#__PURE__*/function (_Error2) {
  function CommunicationError(communicationError) {
    var _this2;
    _this2 = _Error2.call(this, 'Communication Error') || this;
    _this2.exception = void 0;
    _this2.name = 'CommunicationError';
    _this2.message = communicationError.exception.message;
    _this2.exception = communicationError.exception;
    // This clips the constructor invocation from the stack trace.
    // It's not absolutely essential, but it does make the stack trace a little nicer.
    //  @see Node.js reference (bottom)
    if (Error.captureStackTrace) {
      Error.captureStackTrace(_this2, _this2.constructor);
    } else {
      _this2.stack = new Error().stack;
    }
    return _this2;
  }
  _inheritsLoose(CommunicationError, _Error2);
  return CommunicationError;
}( /*#__PURE__*/_wrapNativeSuper(Error));
var SdkError = /*#__PURE__*/function (_Error3) {
  function SdkError(message) {
    var _this3;
    _this3 = _Error3.call(this, message) || this;
    // Ensure the name of this error is the same as the class name
    _this3.code = void 0;
    _this3.name = _this3.constructor.name;
    // This clips the constructor invocation from the stack trace.
    // It's not absolutely essential, but it does make the stack trace a little nicer.
    if (Error.captureStackTrace) {
      Error.captureStackTrace(_this3, _this3.constructor);
    } else {
      _this3.stack = new Error().stack;
    }
    return _this3;
  }
  _inheritsLoose(SdkError, _Error3);
  return SdkError;
}( /*#__PURE__*/_wrapNativeSuper(Error));
function createSdkError(message, code) {
  var error = new SdkError(message);
  if (code) {
    error = new SdkError(code + ': ' + message);
    error.code = code;
  }
  return error;
}
// using never to suppress error https://bobbyhadz.com/blog/typescript-function-that-throws-error#:~:text=To%20declare%20a%20function%20that,terminate%20execution%20of%20the%20program.
function throwError(message, code) {
  throw createSdkError(message, code);
}
var SdkErrors;
(function (SdkErrors) {
  SdkErrors["AccountDoesntExist"] = "AccountDoesntExist";
  SdkErrors["AccountNotFound"] = "AccountNotFound";
  SdkErrors["AccountServiceError"] = "AccountServiceError";
  SdkErrors["CommunicationNotConnected"] = "CommunicationNotConnected";
  SdkErrors["CommunicationNotLoggedIn"] = "CommunicationNotLoggedIn";
  SdkErrors["CommunicationTimeout"] = "CommunicationTimeout";
  SdkErrors["CouldntCreateApi"] = "CouldntCreateApi";
  SdkErrors["DataQueryNoRowDataFound"] = "DataQueryNoRowDataFound";
  SdkErrors["InvalidLinkAuthRequest"] = "InvalidLinkAuthRequest";
  SdkErrors["InvalidChallenge"] = "InvalidChallenge";
  SdkErrors["InvalidData"] = "InvalidData";
  SdkErrors["InvalidKey"] = "InvalidKey";
  SdkErrors["InvalidArgumentType"] = "InvalidArgumentType";
  SdkErrors["InvalidKeyLevel"] = "InvalidKeyLevel";
  SdkErrors["InvalidQrCode"] = "InvalidQrCode";
  SdkErrors["InvalidUsername"] = "InvalidUsername";
  SdkErrors["InvalidRequestType"] = "InvalidRequestType";
  SdkErrors["InvalidRequestResponseType"] = "InvalidRequestResponseType";
  SdkErrors["JwtNotValid"] = "JwtNotValid";
  SdkErrors["KeyNotFound"] = "KeyNotFound";
  SdkErrors["LinkAuthFailed"] = "LinkAuthFailed";
  SdkErrors["MessageSendError"] = "MessageSendError";
  SdkErrors["MissingChallenge"] = "MissingChallenge";
  SdkErrors["MissingParams"] = "MissingParams";
  SdkErrors["OriginNotFound"] = "OriginNotFound";
  SdkErrors["OriginMismatch"] = "OriginMismatch";
  SdkErrors["PasswordFormatInvalid"] = "PasswordFormatInvalid";
  SdkErrors["PasswordInvalid"] = "PasswordInvalid";
  SdkErrors["RequestsNotFound"] = "RequestsNotFound";
  SdkErrors["ResponsesNotFound"] = "ResponsesNotFound";
  SdkErrors["PasswordTooCommon"] = "PasswordTooCommon";
  SdkErrors["PinInvalid"] = "PinInvalid";
  SdkErrors["ReferrerEmpty"] = "ReferrerEmpty";
  SdkErrors["SenderNotAuthorized"] = "SenderNotAuthorized";
  SdkErrors["SettingsNotInitialized"] = "SettingsNotInitialized";
  SdkErrors["UpdateKeysTransactionNoKeys"] = "UpdateKeysTransactionNoKeys";
  SdkErrors["UserDeactivated"] = "UserDeactivated";
  SdkErrors["UsernameNotFound"] = "UsernameNotFound";
  SdkErrors["UsernameTaken"] = "UsernameTaken";
  SdkErrors["UsernameNotDefined"] = "UsernameNotDefined";
  SdkErrors["UserNotLoggedIn"] = "UserNotLoggedIn";
  SdkErrors["UserNotLoggedInWithThisApp"] = "UserNotLoggedInWithThisApp";
  SdkErrors["UserRefreshed"] = "UserRefreshed";
  SdkErrors["WrongOrigin"] = "WrongOrigin";
  SdkErrors["UserCancelled"] = "UserCancelled";
  SdkErrors["UserLogout"] = "UserLogout";
})(SdkErrors || (SdkErrors = {}));
// eslint-disable-next-line @typescript-eslint/no-namespace
(function (SdkErrors) {
  /*
   * Returns the index of the enum value
   *
   * @param value The value to get the index of
   */
  function indexFor(value) {
    return Object.keys(SdkErrors).indexOf(value);
  }
  SdkErrors.indexFor = indexFor;
  /*
   * Creates an SdkErrors from a string or index of the level
   *
   * @param value The string or index
   */
  function from(value) {
    var index;
    if (typeof value !== 'number') {
      index = SdkErrors.indexFor(value);
    } else {
      index = value;
    }
    return Object.values(SdkErrors)[index];
  }
  SdkErrors.from = from;
})(SdkErrors || (SdkErrors = {}));

function asUint8Array(buf) {
  if (globalThis.Buffer != null) {
    return new Uint8Array(buf.buffer, buf.byteOffset, buf.byteLength);
  }
  return buf;
}

function allocUnsafe(size = 0) {
  if (globalThis.Buffer != null && globalThis.Buffer.allocUnsafe != null) {
    return asUint8Array(globalThis.Buffer.allocUnsafe(size));
  }
  return new Uint8Array(size);
}

function concat$1(arrays, length) {
  if (!length) {
    length = arrays.reduce((acc, curr) => acc + curr.length, 0);
  }
  const output = allocUnsafe(length);
  let offset = 0;
  for (const arr of arrays) {
    output.set(arr, offset);
    offset += arr.length;
  }
  return asUint8Array(output);
}

function base$2(ALPHABET, name) {
  if (ALPHABET.length >= 255) {
    throw new TypeError('Alphabet too long');
  }
  var BASE_MAP = new Uint8Array(256);
  for (var j = 0; j < BASE_MAP.length; j++) {
    BASE_MAP[j] = 255;
  }
  for (var i = 0; i < ALPHABET.length; i++) {
    var x = ALPHABET.charAt(i);
    var xc = x.charCodeAt(0);
    if (BASE_MAP[xc] !== 255) {
      throw new TypeError(x + ' is ambiguous');
    }
    BASE_MAP[xc] = i;
  }
  var BASE = ALPHABET.length;
  var LEADER = ALPHABET.charAt(0);
  var FACTOR = Math.log(BASE) / Math.log(256);
  var iFACTOR = Math.log(256) / Math.log(BASE);
  function encode(source) {
    if (source instanceof Uint8Array);
    else if (ArrayBuffer.isView(source)) {
      source = new Uint8Array(source.buffer, source.byteOffset, source.byteLength);
    } else if (Array.isArray(source)) {
      source = Uint8Array.from(source);
    }
    if (!(source instanceof Uint8Array)) {
      throw new TypeError('Expected Uint8Array');
    }
    if (source.length === 0) {
      return '';
    }
    var zeroes = 0;
    var length = 0;
    var pbegin = 0;
    var pend = source.length;
    while (pbegin !== pend && source[pbegin] === 0) {
      pbegin++;
      zeroes++;
    }
    var size = (pend - pbegin) * iFACTOR + 1 >>> 0;
    var b58 = new Uint8Array(size);
    while (pbegin !== pend) {
      var carry = source[pbegin];
      var i = 0;
      for (var it1 = size - 1; (carry !== 0 || i < length) && it1 !== -1; it1--, i++) {
        carry += 256 * b58[it1] >>> 0;
        b58[it1] = carry % BASE >>> 0;
        carry = carry / BASE >>> 0;
      }
      if (carry !== 0) {
        throw new Error('Non-zero carry');
      }
      length = i;
      pbegin++;
    }
    var it2 = size - length;
    while (it2 !== size && b58[it2] === 0) {
      it2++;
    }
    var str = LEADER.repeat(zeroes);
    for (; it2 < size; ++it2) {
      str += ALPHABET.charAt(b58[it2]);
    }
    return str;
  }
  function decodeUnsafe(source) {
    if (typeof source !== 'string') {
      throw new TypeError('Expected String');
    }
    if (source.length === 0) {
      return new Uint8Array();
    }
    var psz = 0;
    if (source[psz] === ' ') {
      return;
    }
    var zeroes = 0;
    var length = 0;
    while (source[psz] === LEADER) {
      zeroes++;
      psz++;
    }
    var size = (source.length - psz) * FACTOR + 1 >>> 0;
    var b256 = new Uint8Array(size);
    while (source[psz]) {
      var carry = BASE_MAP[source.charCodeAt(psz)];
      if (carry === 255) {
        return;
      }
      var i = 0;
      for (var it3 = size - 1; (carry !== 0 || i < length) && it3 !== -1; it3--, i++) {
        carry += BASE * b256[it3] >>> 0;
        b256[it3] = carry % 256 >>> 0;
        carry = carry / 256 >>> 0;
      }
      if (carry !== 0) {
        throw new Error('Non-zero carry');
      }
      length = i;
      psz++;
    }
    if (source[psz] === ' ') {
      return;
    }
    var it4 = size - length;
    while (it4 !== size && b256[it4] === 0) {
      it4++;
    }
    var vch = new Uint8Array(zeroes + (size - it4));
    var j = zeroes;
    while (it4 !== size) {
      vch[j++] = b256[it4++];
    }
    return vch;
  }
  function decode(string) {
    var buffer = decodeUnsafe(string);
    if (buffer) {
      return buffer;
    }
    throw new Error(`Non-${ name } character`);
  }
  return {
    encode: encode,
    decodeUnsafe: decodeUnsafe,
    decode: decode
  };
}
var src$2 = base$2;
var _brrp__multiformats_scope_baseX = src$2;

const coerce = o => {
  if (o instanceof Uint8Array && o.constructor.name === 'Uint8Array')
    return o;
  if (o instanceof ArrayBuffer)
    return new Uint8Array(o);
  if (ArrayBuffer.isView(o)) {
    return new Uint8Array(o.buffer, o.byteOffset, o.byteLength);
  }
  throw new Error('Unknown type, must be binary type');
};
const fromString$1 = str => new TextEncoder().encode(str);
const toString$1 = b => new TextDecoder().decode(b);

class Encoder {
  constructor(name, prefix, baseEncode) {
    this.name = name;
    this.prefix = prefix;
    this.baseEncode = baseEncode;
  }
  encode(bytes) {
    if (bytes instanceof Uint8Array) {
      return `${ this.prefix }${ this.baseEncode(bytes) }`;
    } else {
      throw Error('Unknown type, must be binary type');
    }
  }
}
class Decoder {
  constructor(name, prefix, baseDecode) {
    this.name = name;
    this.prefix = prefix;
    if (prefix.codePointAt(0) === undefined) {
      throw new Error('Invalid prefix character');
    }
    this.prefixCodePoint = prefix.codePointAt(0);
    this.baseDecode = baseDecode;
  }
  decode(text) {
    if (typeof text === 'string') {
      if (text.codePointAt(0) !== this.prefixCodePoint) {
        throw Error(`Unable to decode multibase string ${ JSON.stringify(text) }, ${ this.name } decoder only supports inputs prefixed with ${ this.prefix }`);
      }
      return this.baseDecode(text.slice(this.prefix.length));
    } else {
      throw Error('Can only multibase decode strings');
    }
  }
  or(decoder) {
    return or(this, decoder);
  }
}
class ComposedDecoder {
  constructor(decoders) {
    this.decoders = decoders;
  }
  or(decoder) {
    return or(this, decoder);
  }
  decode(input) {
    const prefix = input[0];
    const decoder = this.decoders[prefix];
    if (decoder) {
      return decoder.decode(input);
    } else {
      throw RangeError(`Unable to decode multibase string ${ JSON.stringify(input) }, only inputs prefixed with ${ Object.keys(this.decoders) } are supported`);
    }
  }
}
const or = (left, right) => new ComposedDecoder({
  ...left.decoders || { [left.prefix]: left },
  ...right.decoders || { [right.prefix]: right }
});
class Codec {
  constructor(name, prefix, baseEncode, baseDecode) {
    this.name = name;
    this.prefix = prefix;
    this.baseEncode = baseEncode;
    this.baseDecode = baseDecode;
    this.encoder = new Encoder(name, prefix, baseEncode);
    this.decoder = new Decoder(name, prefix, baseDecode);
  }
  encode(input) {
    return this.encoder.encode(input);
  }
  decode(input) {
    return this.decoder.decode(input);
  }
}
const from = ({name, prefix, encode, decode}) => new Codec(name, prefix, encode, decode);
const baseX = ({prefix, name, alphabet}) => {
  const {encode, decode} = _brrp__multiformats_scope_baseX(alphabet, name);
  return from({
    prefix,
    name,
    encode,
    decode: text => coerce(decode(text))
  });
};
const decode$4 = (string, alphabet, bitsPerChar, name) => {
  const codes = {};
  for (let i = 0; i < alphabet.length; ++i) {
    codes[alphabet[i]] = i;
  }
  let end = string.length;
  while (string[end - 1] === '=') {
    --end;
  }
  const out = new Uint8Array(end * bitsPerChar / 8 | 0);
  let bits = 0;
  let buffer = 0;
  let written = 0;
  for (let i = 0; i < end; ++i) {
    const value = codes[string[i]];
    if (value === undefined) {
      throw new SyntaxError(`Non-${ name } character`);
    }
    buffer = buffer << bitsPerChar | value;
    bits += bitsPerChar;
    if (bits >= 8) {
      bits -= 8;
      out[written++] = 255 & buffer >> bits;
    }
  }
  if (bits >= bitsPerChar || 255 & buffer << 8 - bits) {
    throw new SyntaxError('Unexpected end of data');
  }
  return out;
};
const encode$3 = (data, alphabet, bitsPerChar) => {
  const pad = alphabet[alphabet.length - 1] === '=';
  const mask = (1 << bitsPerChar) - 1;
  let out = '';
  let bits = 0;
  let buffer = 0;
  for (let i = 0; i < data.length; ++i) {
    buffer = buffer << 8 | data[i];
    bits += 8;
    while (bits > bitsPerChar) {
      bits -= bitsPerChar;
      out += alphabet[mask & buffer >> bits];
    }
  }
  if (bits) {
    out += alphabet[mask & buffer << bitsPerChar - bits];
  }
  if (pad) {
    while (out.length * bitsPerChar & 7) {
      out += '=';
    }
  }
  return out;
};
const rfc4648$2 = ({name, prefix, bitsPerChar, alphabet}) => {
  return from({
    prefix,
    name,
    encode(input) {
      return encode$3(input, alphabet, bitsPerChar);
    },
    decode(input) {
      return decode$4(input, alphabet, bitsPerChar, name);
    }
  });
};

const identity$1 = from({
  prefix: '\0',
  name: 'identity',
  encode: buf => toString$1(buf),
  decode: str => fromString$1(str)
});

var identityBase = {
  __proto__: null,
  identity: identity$1
};

const base2 = rfc4648$2({
  prefix: '0',
  name: 'base2',
  alphabet: '01',
  bitsPerChar: 1
});

var base2$1 = {
  __proto__: null,
  base2: base2
};

const base8 = rfc4648$2({
  prefix: '7',
  name: 'base8',
  alphabet: '01234567',
  bitsPerChar: 3
});

var base8$1 = {
  __proto__: null,
  base8: base8
};

const base10 = baseX({
  prefix: '9',
  name: 'base10',
  alphabet: '0123456789'
});

var base10$1 = {
  __proto__: null,
  base10: base10
};

const base16 = rfc4648$2({
  prefix: 'f',
  name: 'base16',
  alphabet: '0123456789abcdef',
  bitsPerChar: 4
});
const base16upper = rfc4648$2({
  prefix: 'F',
  name: 'base16upper',
  alphabet: '0123456789ABCDEF',
  bitsPerChar: 4
});

var base16$1 = {
  __proto__: null,
  base16: base16,
  base16upper: base16upper
};

const base32 = rfc4648$2({
  prefix: 'b',
  name: 'base32',
  alphabet: 'abcdefghijklmnopqrstuvwxyz234567',
  bitsPerChar: 5
});
const base32upper = rfc4648$2({
  prefix: 'B',
  name: 'base32upper',
  alphabet: 'ABCDEFGHIJKLMNOPQRSTUVWXYZ234567',
  bitsPerChar: 5
});
const base32pad = rfc4648$2({
  prefix: 'c',
  name: 'base32pad',
  alphabet: 'abcdefghijklmnopqrstuvwxyz234567=',
  bitsPerChar: 5
});
const base32padupper = rfc4648$2({
  prefix: 'C',
  name: 'base32padupper',
  alphabet: 'ABCDEFGHIJKLMNOPQRSTUVWXYZ234567=',
  bitsPerChar: 5
});
const base32hex = rfc4648$2({
  prefix: 'v',
  name: 'base32hex',
  alphabet: '0123456789abcdefghijklmnopqrstuv',
  bitsPerChar: 5
});
const base32hexupper = rfc4648$2({
  prefix: 'V',
  name: 'base32hexupper',
  alphabet: '0123456789ABCDEFGHIJKLMNOPQRSTUV',
  bitsPerChar: 5
});
const base32hexpad = rfc4648$2({
  prefix: 't',
  name: 'base32hexpad',
  alphabet: '0123456789abcdefghijklmnopqrstuv=',
  bitsPerChar: 5
});
const base32hexpadupper = rfc4648$2({
  prefix: 'T',
  name: 'base32hexpadupper',
  alphabet: '0123456789ABCDEFGHIJKLMNOPQRSTUV=',
  bitsPerChar: 5
});
const base32z = rfc4648$2({
  prefix: 'h',
  name: 'base32z',
  alphabet: 'ybndrfg8ejkmcpqxot1uwisza345h769',
  bitsPerChar: 5
});

var base32$1 = {
  __proto__: null,
  base32: base32,
  base32upper: base32upper,
  base32pad: base32pad,
  base32padupper: base32padupper,
  base32hex: base32hex,
  base32hexupper: base32hexupper,
  base32hexpad: base32hexpad,
  base32hexpadupper: base32hexpadupper,
  base32z: base32z
};

const base36 = baseX({
  prefix: 'k',
  name: 'base36',
  alphabet: '0123456789abcdefghijklmnopqrstuvwxyz'
});
const base36upper = baseX({
  prefix: 'K',
  name: 'base36upper',
  alphabet: '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'
});

var base36$1 = {
  __proto__: null,
  base36: base36,
  base36upper: base36upper
};

const base58btc = baseX({
  name: 'base58btc',
  prefix: 'z',
  alphabet: '123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz'
});
const base58flickr = baseX({
  name: 'base58flickr',
  prefix: 'Z',
  alphabet: '123456789abcdefghijkmnopqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ'
});

var base58 = {
  __proto__: null,
  base58btc: base58btc,
  base58flickr: base58flickr
};

const base64 = rfc4648$2({
  prefix: 'm',
  name: 'base64',
  alphabet: 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/',
  bitsPerChar: 6
});
const base64pad = rfc4648$2({
  prefix: 'M',
  name: 'base64pad',
  alphabet: 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=',
  bitsPerChar: 6
});
const base64url = rfc4648$2({
  prefix: 'u',
  name: 'base64url',
  alphabet: 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_',
  bitsPerChar: 6
});
const base64urlpad = rfc4648$2({
  prefix: 'U',
  name: 'base64urlpad',
  alphabet: 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_=',
  bitsPerChar: 6
});

var base64$1 = {
  __proto__: null,
  base64: base64,
  base64pad: base64pad,
  base64url: base64url,
  base64urlpad: base64urlpad
};

const alphabet$1 = Array.from('\uD83D\uDE80\uD83E\uDE90\u2604\uD83D\uDEF0\uD83C\uDF0C\uD83C\uDF11\uD83C\uDF12\uD83C\uDF13\uD83C\uDF14\uD83C\uDF15\uD83C\uDF16\uD83C\uDF17\uD83C\uDF18\uD83C\uDF0D\uD83C\uDF0F\uD83C\uDF0E\uD83D\uDC09\u2600\uD83D\uDCBB\uD83D\uDDA5\uD83D\uDCBE\uD83D\uDCBF\uD83D\uDE02\u2764\uD83D\uDE0D\uD83E\uDD23\uD83D\uDE0A\uD83D\uDE4F\uD83D\uDC95\uD83D\uDE2D\uD83D\uDE18\uD83D\uDC4D\uD83D\uDE05\uD83D\uDC4F\uD83D\uDE01\uD83D\uDD25\uD83E\uDD70\uD83D\uDC94\uD83D\uDC96\uD83D\uDC99\uD83D\uDE22\uD83E\uDD14\uD83D\uDE06\uD83D\uDE44\uD83D\uDCAA\uD83D\uDE09\u263A\uD83D\uDC4C\uD83E\uDD17\uD83D\uDC9C\uD83D\uDE14\uD83D\uDE0E\uD83D\uDE07\uD83C\uDF39\uD83E\uDD26\uD83C\uDF89\uD83D\uDC9E\u270C\u2728\uD83E\uDD37\uD83D\uDE31\uD83D\uDE0C\uD83C\uDF38\uD83D\uDE4C\uD83D\uDE0B\uD83D\uDC97\uD83D\uDC9A\uD83D\uDE0F\uD83D\uDC9B\uD83D\uDE42\uD83D\uDC93\uD83E\uDD29\uD83D\uDE04\uD83D\uDE00\uD83D\uDDA4\uD83D\uDE03\uD83D\uDCAF\uD83D\uDE48\uD83D\uDC47\uD83C\uDFB6\uD83D\uDE12\uD83E\uDD2D\u2763\uD83D\uDE1C\uD83D\uDC8B\uD83D\uDC40\uD83D\uDE2A\uD83D\uDE11\uD83D\uDCA5\uD83D\uDE4B\uD83D\uDE1E\uD83D\uDE29\uD83D\uDE21\uD83E\uDD2A\uD83D\uDC4A\uD83E\uDD73\uD83D\uDE25\uD83E\uDD24\uD83D\uDC49\uD83D\uDC83\uD83D\uDE33\u270B\uD83D\uDE1A\uD83D\uDE1D\uD83D\uDE34\uD83C\uDF1F\uD83D\uDE2C\uD83D\uDE43\uD83C\uDF40\uD83C\uDF37\uD83D\uDE3B\uD83D\uDE13\u2B50\u2705\uD83E\uDD7A\uD83C\uDF08\uD83D\uDE08\uD83E\uDD18\uD83D\uDCA6\u2714\uD83D\uDE23\uD83C\uDFC3\uD83D\uDC90\u2639\uD83C\uDF8A\uD83D\uDC98\uD83D\uDE20\u261D\uD83D\uDE15\uD83C\uDF3A\uD83C\uDF82\uD83C\uDF3B\uD83D\uDE10\uD83D\uDD95\uD83D\uDC9D\uD83D\uDE4A\uD83D\uDE39\uD83D\uDDE3\uD83D\uDCAB\uD83D\uDC80\uD83D\uDC51\uD83C\uDFB5\uD83E\uDD1E\uD83D\uDE1B\uD83D\uDD34\uD83D\uDE24\uD83C\uDF3C\uD83D\uDE2B\u26BD\uD83E\uDD19\u2615\uD83C\uDFC6\uD83E\uDD2B\uD83D\uDC48\uD83D\uDE2E\uD83D\uDE46\uD83C\uDF7B\uD83C\uDF43\uD83D\uDC36\uD83D\uDC81\uD83D\uDE32\uD83C\uDF3F\uD83E\uDDE1\uD83C\uDF81\u26A1\uD83C\uDF1E\uD83C\uDF88\u274C\u270A\uD83D\uDC4B\uD83D\uDE30\uD83E\uDD28\uD83D\uDE36\uD83E\uDD1D\uD83D\uDEB6\uD83D\uDCB0\uD83C\uDF53\uD83D\uDCA2\uD83E\uDD1F\uD83D\uDE41\uD83D\uDEA8\uD83D\uDCA8\uD83E\uDD2C\u2708\uD83C\uDF80\uD83C\uDF7A\uD83E\uDD13\uD83D\uDE19\uD83D\uDC9F\uD83C\uDF31\uD83D\uDE16\uD83D\uDC76\uD83E\uDD74\u25B6\u27A1\u2753\uD83D\uDC8E\uD83D\uDCB8\u2B07\uD83D\uDE28\uD83C\uDF1A\uD83E\uDD8B\uD83D\uDE37\uD83D\uDD7A\u26A0\uD83D\uDE45\uD83D\uDE1F\uD83D\uDE35\uD83D\uDC4E\uD83E\uDD32\uD83E\uDD20\uD83E\uDD27\uD83D\uDCCC\uD83D\uDD35\uD83D\uDC85\uD83E\uDDD0\uD83D\uDC3E\uD83C\uDF52\uD83D\uDE17\uD83E\uDD11\uD83C\uDF0A\uD83E\uDD2F\uD83D\uDC37\u260E\uD83D\uDCA7\uD83D\uDE2F\uD83D\uDC86\uD83D\uDC46\uD83C\uDFA4\uD83D\uDE47\uD83C\uDF51\u2744\uD83C\uDF34\uD83D\uDCA3\uD83D\uDC38\uD83D\uDC8C\uD83D\uDCCD\uD83E\uDD40\uD83E\uDD22\uD83D\uDC45\uD83D\uDCA1\uD83D\uDCA9\uD83D\uDC50\uD83D\uDCF8\uD83D\uDC7B\uD83E\uDD10\uD83E\uDD2E\uD83C\uDFBC\uD83E\uDD75\uD83D\uDEA9\uD83C\uDF4E\uD83C\uDF4A\uD83D\uDC7C\uD83D\uDC8D\uD83D\uDCE3\uD83E\uDD42');
const alphabetBytesToChars = alphabet$1.reduce((p, c, i) => {
  p[i] = c;
  return p;
}, []);
const alphabetCharsToBytes = alphabet$1.reduce((p, c, i) => {
  p[c.codePointAt(0)] = i;
  return p;
}, []);
function encode$2(data) {
  return data.reduce((p, c) => {
    p += alphabetBytesToChars[c];
    return p;
  }, '');
}
function decode$3(str) {
  const byts = [];
  for (const char of str) {
    const byt = alphabetCharsToBytes[char.codePointAt(0)];
    if (byt === undefined) {
      throw new Error(`Non-base256emoji character: ${ char }`);
    }
    byts.push(byt);
  }
  return new Uint8Array(byts);
}
const base256emoji = from({
  prefix: '\uD83D\uDE80',
  name: 'base256emoji',
  encode: encode$2,
  decode: decode$3
});

var base256emoji$1 = {
  __proto__: null,
  base256emoji: base256emoji
};

var encode_1 = encode$1;
var MSB = 128, REST = 127, MSBALL = ~REST, INT = Math.pow(2, 31);
function encode$1(num, out, offset) {
  out = out || [];
  offset = offset || 0;
  var oldOffset = offset;
  while (num >= INT) {
    out[offset++] = num & 255 | MSB;
    num /= 128;
  }
  while (num & MSBALL) {
    out[offset++] = num & 255 | MSB;
    num >>>= 7;
  }
  out[offset] = num | 0;
  encode$1.bytes = offset - oldOffset + 1;
  return out;
}
var decode$2 = read;
var MSB$1 = 128, REST$1 = 127;
function read(buf, offset) {
  var res = 0, offset = offset || 0, shift = 0, counter = offset, b, l = buf.length;
  do {
    if (counter >= l) {
      read.bytes = 0;
      throw new RangeError('Could not decode varint');
    }
    b = buf[counter++];
    res += shift < 28 ? (b & REST$1) << shift : (b & REST$1) * Math.pow(2, shift);
    shift += 7;
  } while (b >= MSB$1);
  read.bytes = counter - offset;
  return res;
}
var N1 = Math.pow(2, 7);
var N2 = Math.pow(2, 14);
var N3 = Math.pow(2, 21);
var N4 = Math.pow(2, 28);
var N5 = Math.pow(2, 35);
var N6 = Math.pow(2, 42);
var N7 = Math.pow(2, 49);
var N8 = Math.pow(2, 56);
var N9 = Math.pow(2, 63);
var length = function (value) {
  return value < N1 ? 1 : value < N2 ? 2 : value < N3 ? 3 : value < N4 ? 4 : value < N5 ? 5 : value < N6 ? 6 : value < N7 ? 7 : value < N8 ? 8 : value < N9 ? 9 : 10;
};
var varint = {
  encode: encode_1,
  decode: decode$2,
  encodingLength: length
};
var _brrp_varint = varint;

const decode$1 = (data, offset = 0) => {
  const code = _brrp_varint.decode(data, offset);
  return [
    code,
    _brrp_varint.decode.bytes
  ];
};
const encodeTo = (int, target, offset = 0) => {
  _brrp_varint.encode(int, target, offset);
  return target;
};
const encodingLength = int => {
  return _brrp_varint.encodingLength(int);
};

new TextEncoder();
new TextDecoder();

const bases = {
  ...identityBase,
  ...base2$1,
  ...base8$1,
  ...base10$1,
  ...base16$1,
  ...base32$1,
  ...base36$1,
  ...base58,
  ...base64$1,
  ...base256emoji$1
};

function createCodec(name, prefix, encode, decode) {
  return {
    name,
    prefix,
    encoder: {
      name,
      prefix,
      encode
    },
    decoder: { decode }
  };
}
const string = createCodec('utf8', 'u', buf => {
  const decoder = new TextDecoder('utf8');
  return 'u' + decoder.decode(buf);
}, str => {
  const encoder = new TextEncoder();
  return encoder.encode(str.substring(1));
});
const ascii = createCodec('ascii', 'a', buf => {
  let string = 'a';
  for (let i = 0; i < buf.length; i++) {
    string += String.fromCharCode(buf[i]);
  }
  return string;
}, str => {
  str = str.substring(1);
  const buf = allocUnsafe(str.length);
  for (let i = 0; i < str.length; i++) {
    buf[i] = str.charCodeAt(i);
  }
  return buf;
});
const BASES = {
  utf8: string,
  'utf-8': string,
  hex: bases.base16,
  latin1: ascii,
  ascii: ascii,
  binary: ascii,
  ...bases
};

function fromString(string, encoding = 'utf8') {
  const base = BASES[encoding];
  if (!base) {
    throw new Error(`Unsupported encoding "${ encoding }"`);
  }
  if ((encoding === 'utf8' || encoding === 'utf-8') && globalThis.Buffer != null && globalThis.Buffer.from != null) {
    return asUint8Array(globalThis.Buffer.from(string, 'utf-8'));
  }
  return base.decoder.decode(`${ base.prefix }${ string }`);
}

function toString(array, encoding = 'utf8') {
  const base = BASES[encoding];
  if (!base) {
    throw new Error(`Unsupported encoding "${ encoding }"`);
  }
  if ((encoding === 'utf8' || encoding === 'utf-8') && globalThis.Buffer != null && globalThis.Buffer.from != null) {
    return globalThis.Buffer.from(array.buffer, array.byteOffset, array.byteLength).toString('utf8');
  }
  return base.encoder.encode(array).substring(1);
}

function number(n) {
    if (!Number.isSafeInteger(n) || n < 0)
        throw new Error(`positive integer expected, not ${n}`);
}
// copied from utils
function isBytes$2(a) {
    return (a instanceof Uint8Array ||
        (a != null && typeof a === 'object' && a.constructor.name === 'Uint8Array'));
}
function bytes(b, ...lengths) {
    if (!isBytes$2(b))
        throw new Error('Uint8Array expected');
    if (lengths.length > 0 && !lengths.includes(b.length))
        throw new Error(`Uint8Array expected of length ${lengths}, not of length=${b.length}`);
}
function hash(h) {
    if (typeof h !== 'function' || typeof h.create !== 'function')
        throw new Error('Hash should be wrapped by utils.wrapConstructor');
    number(h.outputLen);
    number(h.blockLen);
}
function exists(instance, checkFinished = true) {
    if (instance.destroyed)
        throw new Error('Hash instance has been destroyed');
    if (checkFinished && instance.finished)
        throw new Error('Hash#digest() has already been called');
}
function output(out, instance) {
    bytes(out);
    const min = instance.outputLen;
    if (out.length < min) {
        throw new Error(`digestInto() expects output buffer of length at least ${min}`);
    }
}

const crypto = typeof globalThis === 'object' && 'crypto' in globalThis ? globalThis.crypto : undefined;

/*! noble-hashes - MIT License (c) 2022 Paul Miller (paulmillr.com) */
const u32 = (arr) => new Uint32Array(arr.buffer, arr.byteOffset, Math.floor(arr.byteLength / 4));
// Cast array to view
const createView = (arr) => new DataView(arr.buffer, arr.byteOffset, arr.byteLength);
// The rotate right (circular right shift) operation for uint32
const rotr = (word, shift) => (word << (32 - shift)) | (word >>> shift);
// The rotate left (circular left shift) operation for uint32
const rotl = (word, shift) => (word << shift) | ((word >>> (32 - shift)) >>> 0);
const isLE = new Uint8Array(new Uint32Array([0x11223344]).buffer)[0] === 0x44;
// The byte swap operation for uint32
const byteSwap = (word) => ((word << 24) & 0xff000000) |
    ((word << 8) & 0xff0000) |
    ((word >>> 8) & 0xff00) |
    ((word >>> 24) & 0xff);
// In place byte swap for Uint32Array
function byteSwap32(arr) {
    for (let i = 0; i < arr.length; i++) {
        arr[i] = byteSwap(arr[i]);
    }
}
/**
 * @example utf8ToBytes('abc') // new Uint8Array([97, 98, 99])
 */
function utf8ToBytes$1(str) {
    if (typeof str !== 'string')
        throw new Error(`utf8ToBytes expected string, got ${typeof str}`);
    return new Uint8Array(new TextEncoder().encode(str)); // https://bugzil.la/1681809
}
/**
 * Normalizes (non-hex) string or Uint8Array to Uint8Array.
 * Warning: when Uint8Array is passed, it would NOT get copied.
 * Keep in mind for future mutable operations.
 */
function toBytes(data) {
    if (typeof data === 'string')
        data = utf8ToBytes$1(data);
    bytes(data);
    return data;
}
/**
 * Copies several Uint8Arrays into one.
 */
function concatBytes$1(...arrays) {
    let sum = 0;
    for (let i = 0; i < arrays.length; i++) {
        const a = arrays[i];
        bytes(a);
        sum += a.length;
    }
    const res = new Uint8Array(sum);
    for (let i = 0, pad = 0; i < arrays.length; i++) {
        const a = arrays[i];
        res.set(a, pad);
        pad += a.length;
    }
    return res;
}
// For runtime check if class implements interface
class Hash {
    // Safe version that clones internal state
    clone() {
        return this._cloneInto();
    }
}
function wrapConstructor(hashCons) {
    const hashC = (msg) => hashCons().update(toBytes(msg)).digest();
    const tmp = hashCons();
    hashC.outputLen = tmp.outputLen;
    hashC.blockLen = tmp.blockLen;
    hashC.create = () => hashCons();
    return hashC;
}
/**
 * Secure PRNG. Uses `crypto.getRandomValues`, which defers to OS.
 */
function randomBytes$1(bytesLength = 32) {
    if (crypto && typeof crypto.getRandomValues === 'function') {
        return crypto.getRandomValues(new Uint8Array(bytesLength));
    }
    throw new Error('crypto.getRandomValues must be defined');
}

// Polyfill for Safari 14
function setBigUint64(view, byteOffset, value, isLE) {
    if (typeof view.setBigUint64 === 'function')
        return view.setBigUint64(byteOffset, value, isLE);
    const _32n = BigInt(32);
    const _u32_max = BigInt(0xffffffff);
    const wh = Number((value >> _32n) & _u32_max);
    const wl = Number(value & _u32_max);
    const h = isLE ? 4 : 0;
    const l = isLE ? 0 : 4;
    view.setUint32(byteOffset + h, wh, isLE);
    view.setUint32(byteOffset + l, wl, isLE);
}
// Choice: a ? b : c
const Chi = (a, b, c) => (a & b) ^ (~a & c);
// Majority function, true if any two inpust is true
const Maj = (a, b, c) => (a & b) ^ (a & c) ^ (b & c);
/**
 * Merkle-Damgard hash construction base class.
 * Could be used to create MD5, RIPEMD, SHA1, SHA2.
 */
class HashMD extends Hash {
    constructor(blockLen, outputLen, padOffset, isLE) {
        super();
        this.blockLen = blockLen;
        this.outputLen = outputLen;
        this.padOffset = padOffset;
        this.isLE = isLE;
        this.finished = false;
        this.length = 0;
        this.pos = 0;
        this.destroyed = false;
        this.buffer = new Uint8Array(blockLen);
        this.view = createView(this.buffer);
    }
    update(data) {
        exists(this);
        const { view, buffer, blockLen } = this;
        data = toBytes(data);
        const len = data.length;
        for (let pos = 0; pos < len;) {
            const take = Math.min(blockLen - this.pos, len - pos);
            // Fast path: we have at least one block in input, cast it to view and process
            if (take === blockLen) {
                const dataView = createView(data);
                for (; blockLen <= len - pos; pos += blockLen)
                    this.process(dataView, pos);
                continue;
            }
            buffer.set(data.subarray(pos, pos + take), this.pos);
            this.pos += take;
            pos += take;
            if (this.pos === blockLen) {
                this.process(view, 0);
                this.pos = 0;
            }
        }
        this.length += data.length;
        this.roundClean();
        return this;
    }
    digestInto(out) {
        exists(this);
        output(out, this);
        this.finished = true;
        // Padding
        // We can avoid allocation of buffer for padding completely if it
        // was previously not allocated here. But it won't change performance.
        const { buffer, view, blockLen, isLE } = this;
        let { pos } = this;
        // append the bit '1' to the message
        buffer[pos++] = 0b10000000;
        this.buffer.subarray(pos).fill(0);
        // we have less than padOffset left in buffer, so we cannot put length in
        // current block, need process it and pad again
        if (this.padOffset > blockLen - pos) {
            this.process(view, 0);
            pos = 0;
        }
        // Pad until full block byte with zeros
        for (let i = pos; i < blockLen; i++)
            buffer[i] = 0;
        // Note: sha512 requires length to be 128bit integer, but length in JS will overflow before that
        // You need to write around 2 exabytes (u64_max / 8 / (1024**6)) for this to happen.
        // So we just write lowest 64 bits of that value.
        setBigUint64(view, blockLen - 8, BigInt(this.length * 8), isLE);
        this.process(view, 0);
        const oview = createView(out);
        const len = this.outputLen;
        // NOTE: we do division by 4 later, which should be fused in single op with modulo by JIT
        if (len % 4)
            throw new Error('_sha2: outputLen should be aligned to 32bit');
        const outLen = len / 4;
        const state = this.get();
        if (outLen > state.length)
            throw new Error('_sha2: outputLen bigger than state');
        for (let i = 0; i < outLen; i++)
            oview.setUint32(4 * i, state[i], isLE);
    }
    digest() {
        const { buffer, outputLen } = this;
        this.digestInto(buffer);
        const res = buffer.slice(0, outputLen);
        this.destroy();
        return res;
    }
    _cloneInto(to) {
        to || (to = new this.constructor());
        to.set(...this.get());
        const { blockLen, buffer, length, finished, destroyed, pos } = this;
        to.length = length;
        to.pos = pos;
        to.finished = finished;
        to.destroyed = destroyed;
        if (length % blockLen)
            to.buffer.set(buffer);
        return to;
    }
}

const U32_MASK64 = /* @__PURE__ */ BigInt(2 ** 32 - 1);
const _32n = /* @__PURE__ */ BigInt(32);
// We are not using BigUint64Array, because they are extremely slow as per 2022
function fromBig(n, le = false) {
    if (le)
        return { h: Number(n & U32_MASK64), l: Number((n >> _32n) & U32_MASK64) };
    return { h: Number((n >> _32n) & U32_MASK64) | 0, l: Number(n & U32_MASK64) | 0 };
}
function split(lst, le = false) {
    let Ah = new Uint32Array(lst.length);
    let Al = new Uint32Array(lst.length);
    for (let i = 0; i < lst.length; i++) {
        const { h, l } = fromBig(lst[i], le);
        [Ah[i], Al[i]] = [h, l];
    }
    return [Ah, Al];
}
const toBig = (h, l) => (BigInt(h >>> 0) << _32n) | BigInt(l >>> 0);
// for Shift in [0, 32)
const shrSH = (h, _l, s) => h >>> s;
const shrSL = (h, l, s) => (h << (32 - s)) | (l >>> s);
// Right rotate for Shift in [1, 32)
const rotrSH = (h, l, s) => (h >>> s) | (l << (32 - s));
const rotrSL = (h, l, s) => (h << (32 - s)) | (l >>> s);
// Right rotate for Shift in (32, 64), NOTE: 32 is special case.
const rotrBH = (h, l, s) => (h << (64 - s)) | (l >>> (s - 32));
const rotrBL = (h, l, s) => (h >>> (s - 32)) | (l << (64 - s));
// Right rotate for shift===32 (just swaps l&h)
const rotr32H = (_h, l) => l;
const rotr32L = (h, _l) => h;
// Left rotate for Shift in [1, 32)
const rotlSH = (h, l, s) => (h << s) | (l >>> (32 - s));
const rotlSL = (h, l, s) => (l << s) | (h >>> (32 - s));
// Left rotate for Shift in (32, 64), NOTE: 32 is special case.
const rotlBH = (h, l, s) => (l << (s - 32)) | (h >>> (64 - s));
const rotlBL = (h, l, s) => (h << (s - 32)) | (l >>> (64 - s));
// JS uses 32-bit signed integers for bitwise operations which means we cannot
// simple take carry out of low bit sum by shift, we need to use division.
function add(Ah, Al, Bh, Bl) {
    const l = (Al >>> 0) + (Bl >>> 0);
    return { h: (Ah + Bh + ((l / 2 ** 32) | 0)) | 0, l: l | 0 };
}
// Addition with more than 2 elements
const add3L = (Al, Bl, Cl) => (Al >>> 0) + (Bl >>> 0) + (Cl >>> 0);
const add3H = (low, Ah, Bh, Ch) => (Ah + Bh + Ch + ((low / 2 ** 32) | 0)) | 0;
const add4L = (Al, Bl, Cl, Dl) => (Al >>> 0) + (Bl >>> 0) + (Cl >>> 0) + (Dl >>> 0);
const add4H = (low, Ah, Bh, Ch, Dh) => (Ah + Bh + Ch + Dh + ((low / 2 ** 32) | 0)) | 0;
const add5L = (Al, Bl, Cl, Dl, El) => (Al >>> 0) + (Bl >>> 0) + (Cl >>> 0) + (Dl >>> 0) + (El >>> 0);
const add5H = (low, Ah, Bh, Ch, Dh, Eh) => (Ah + Bh + Ch + Dh + Eh + ((low / 2 ** 32) | 0)) | 0;
// prettier-ignore
const u64 = {
    fromBig, split, toBig,
    shrSH, shrSL,
    rotrSH, rotrSL, rotrBH, rotrBL,
    rotr32H, rotr32L,
    rotlSH, rotlSL, rotlBH, rotlBL,
    add, add3L, add3H, add4L, add4H, add5H, add5L,
};

// Round contants (first 32 bits of the fractional parts of the cube roots of the first 80 primes 2..409):
// prettier-ignore
const [SHA512_Kh, SHA512_Kl] = /* @__PURE__ */ (() => u64.split([
    '0x428a2f98d728ae22', '0x7137449123ef65cd', '0xb5c0fbcfec4d3b2f', '0xe9b5dba58189dbbc',
    '0x3956c25bf348b538', '0x59f111f1b605d019', '0x923f82a4af194f9b', '0xab1c5ed5da6d8118',
    '0xd807aa98a3030242', '0x12835b0145706fbe', '0x243185be4ee4b28c', '0x550c7dc3d5ffb4e2',
    '0x72be5d74f27b896f', '0x80deb1fe3b1696b1', '0x9bdc06a725c71235', '0xc19bf174cf692694',
    '0xe49b69c19ef14ad2', '0xefbe4786384f25e3', '0x0fc19dc68b8cd5b5', '0x240ca1cc77ac9c65',
    '0x2de92c6f592b0275', '0x4a7484aa6ea6e483', '0x5cb0a9dcbd41fbd4', '0x76f988da831153b5',
    '0x983e5152ee66dfab', '0xa831c66d2db43210', '0xb00327c898fb213f', '0xbf597fc7beef0ee4',
    '0xc6e00bf33da88fc2', '0xd5a79147930aa725', '0x06ca6351e003826f', '0x142929670a0e6e70',
    '0x27b70a8546d22ffc', '0x2e1b21385c26c926', '0x4d2c6dfc5ac42aed', '0x53380d139d95b3df',
    '0x650a73548baf63de', '0x766a0abb3c77b2a8', '0x81c2c92e47edaee6', '0x92722c851482353b',
    '0xa2bfe8a14cf10364', '0xa81a664bbc423001', '0xc24b8b70d0f89791', '0xc76c51a30654be30',
    '0xd192e819d6ef5218', '0xd69906245565a910', '0xf40e35855771202a', '0x106aa07032bbd1b8',
    '0x19a4c116b8d2d0c8', '0x1e376c085141ab53', '0x2748774cdf8eeb99', '0x34b0bcb5e19b48a8',
    '0x391c0cb3c5c95a63', '0x4ed8aa4ae3418acb', '0x5b9cca4f7763e373', '0x682e6ff3d6b2b8a3',
    '0x748f82ee5defb2fc', '0x78a5636f43172f60', '0x84c87814a1f0ab72', '0x8cc702081a6439ec',
    '0x90befffa23631e28', '0xa4506cebde82bde9', '0xbef9a3f7b2c67915', '0xc67178f2e372532b',
    '0xca273eceea26619c', '0xd186b8c721c0c207', '0xeada7dd6cde0eb1e', '0xf57d4f7fee6ed178',
    '0x06f067aa72176fba', '0x0a637dc5a2c898a6', '0x113f9804bef90dae', '0x1b710b35131c471b',
    '0x28db77f523047d84', '0x32caab7b40c72493', '0x3c9ebe0a15c9bebc', '0x431d67c49c100d4c',
    '0x4cc5d4becb3e42b6', '0x597f299cfc657e2a', '0x5fcb6fab3ad6faec', '0x6c44198c4a475817'
].map(n => BigInt(n))))();
// Temporary buffer, not used to store anything between runs
const SHA512_W_H = /* @__PURE__ */ new Uint32Array(80);
const SHA512_W_L = /* @__PURE__ */ new Uint32Array(80);
class SHA512 extends HashMD {
    constructor() {
        super(128, 64, 16, false);
        // We cannot use array here since array allows indexing by variable which means optimizer/compiler cannot use registers.
        // Also looks cleaner and easier to verify with spec.
        // Initial state (first 32 bits of the fractional parts of the square roots of the first 8 primes 2..19):
        // h -- high 32 bits, l -- low 32 bits
        this.Ah = 0x6a09e667 | 0;
        this.Al = 0xf3bcc908 | 0;
        this.Bh = 0xbb67ae85 | 0;
        this.Bl = 0x84caa73b | 0;
        this.Ch = 0x3c6ef372 | 0;
        this.Cl = 0xfe94f82b | 0;
        this.Dh = 0xa54ff53a | 0;
        this.Dl = 0x5f1d36f1 | 0;
        this.Eh = 0x510e527f | 0;
        this.El = 0xade682d1 | 0;
        this.Fh = 0x9b05688c | 0;
        this.Fl = 0x2b3e6c1f | 0;
        this.Gh = 0x1f83d9ab | 0;
        this.Gl = 0xfb41bd6b | 0;
        this.Hh = 0x5be0cd19 | 0;
        this.Hl = 0x137e2179 | 0;
    }
    // prettier-ignore
    get() {
        const { Ah, Al, Bh, Bl, Ch, Cl, Dh, Dl, Eh, El, Fh, Fl, Gh, Gl, Hh, Hl } = this;
        return [Ah, Al, Bh, Bl, Ch, Cl, Dh, Dl, Eh, El, Fh, Fl, Gh, Gl, Hh, Hl];
    }
    // prettier-ignore
    set(Ah, Al, Bh, Bl, Ch, Cl, Dh, Dl, Eh, El, Fh, Fl, Gh, Gl, Hh, Hl) {
        this.Ah = Ah | 0;
        this.Al = Al | 0;
        this.Bh = Bh | 0;
        this.Bl = Bl | 0;
        this.Ch = Ch | 0;
        this.Cl = Cl | 0;
        this.Dh = Dh | 0;
        this.Dl = Dl | 0;
        this.Eh = Eh | 0;
        this.El = El | 0;
        this.Fh = Fh | 0;
        this.Fl = Fl | 0;
        this.Gh = Gh | 0;
        this.Gl = Gl | 0;
        this.Hh = Hh | 0;
        this.Hl = Hl | 0;
    }
    process(view, offset) {
        // Extend the first 16 words into the remaining 64 words w[16..79] of the message schedule array
        for (let i = 0; i < 16; i++, offset += 4) {
            SHA512_W_H[i] = view.getUint32(offset);
            SHA512_W_L[i] = view.getUint32((offset += 4));
        }
        for (let i = 16; i < 80; i++) {
            // s0 := (w[i-15] rightrotate 1) xor (w[i-15] rightrotate 8) xor (w[i-15] rightshift 7)
            const W15h = SHA512_W_H[i - 15] | 0;
            const W15l = SHA512_W_L[i - 15] | 0;
            const s0h = u64.rotrSH(W15h, W15l, 1) ^ u64.rotrSH(W15h, W15l, 8) ^ u64.shrSH(W15h, W15l, 7);
            const s0l = u64.rotrSL(W15h, W15l, 1) ^ u64.rotrSL(W15h, W15l, 8) ^ u64.shrSL(W15h, W15l, 7);
            // s1 := (w[i-2] rightrotate 19) xor (w[i-2] rightrotate 61) xor (w[i-2] rightshift 6)
            const W2h = SHA512_W_H[i - 2] | 0;
            const W2l = SHA512_W_L[i - 2] | 0;
            const s1h = u64.rotrSH(W2h, W2l, 19) ^ u64.rotrBH(W2h, W2l, 61) ^ u64.shrSH(W2h, W2l, 6);
            const s1l = u64.rotrSL(W2h, W2l, 19) ^ u64.rotrBL(W2h, W2l, 61) ^ u64.shrSL(W2h, W2l, 6);
            // SHA256_W[i] = s0 + s1 + SHA256_W[i - 7] + SHA256_W[i - 16];
            const SUMl = u64.add4L(s0l, s1l, SHA512_W_L[i - 7], SHA512_W_L[i - 16]);
            const SUMh = u64.add4H(SUMl, s0h, s1h, SHA512_W_H[i - 7], SHA512_W_H[i - 16]);
            SHA512_W_H[i] = SUMh | 0;
            SHA512_W_L[i] = SUMl | 0;
        }
        let { Ah, Al, Bh, Bl, Ch, Cl, Dh, Dl, Eh, El, Fh, Fl, Gh, Gl, Hh, Hl } = this;
        // Compression function main loop, 80 rounds
        for (let i = 0; i < 80; i++) {
            // S1 := (e rightrotate 14) xor (e rightrotate 18) xor (e rightrotate 41)
            const sigma1h = u64.rotrSH(Eh, El, 14) ^ u64.rotrSH(Eh, El, 18) ^ u64.rotrBH(Eh, El, 41);
            const sigma1l = u64.rotrSL(Eh, El, 14) ^ u64.rotrSL(Eh, El, 18) ^ u64.rotrBL(Eh, El, 41);
            //const T1 = (H + sigma1 + Chi(E, F, G) + SHA256_K[i] + SHA256_W[i]) | 0;
            const CHIh = (Eh & Fh) ^ (~Eh & Gh);
            const CHIl = (El & Fl) ^ (~El & Gl);
            // T1 = H + sigma1 + Chi(E, F, G) + SHA512_K[i] + SHA512_W[i]
            // prettier-ignore
            const T1ll = u64.add5L(Hl, sigma1l, CHIl, SHA512_Kl[i], SHA512_W_L[i]);
            const T1h = u64.add5H(T1ll, Hh, sigma1h, CHIh, SHA512_Kh[i], SHA512_W_H[i]);
            const T1l = T1ll | 0;
            // S0 := (a rightrotate 28) xor (a rightrotate 34) xor (a rightrotate 39)
            const sigma0h = u64.rotrSH(Ah, Al, 28) ^ u64.rotrBH(Ah, Al, 34) ^ u64.rotrBH(Ah, Al, 39);
            const sigma0l = u64.rotrSL(Ah, Al, 28) ^ u64.rotrBL(Ah, Al, 34) ^ u64.rotrBL(Ah, Al, 39);
            const MAJh = (Ah & Bh) ^ (Ah & Ch) ^ (Bh & Ch);
            const MAJl = (Al & Bl) ^ (Al & Cl) ^ (Bl & Cl);
            Hh = Gh | 0;
            Hl = Gl | 0;
            Gh = Fh | 0;
            Gl = Fl | 0;
            Fh = Eh | 0;
            Fl = El | 0;
            ({ h: Eh, l: El } = u64.add(Dh | 0, Dl | 0, T1h | 0, T1l | 0));
            Dh = Ch | 0;
            Dl = Cl | 0;
            Ch = Bh | 0;
            Cl = Bl | 0;
            Bh = Ah | 0;
            Bl = Al | 0;
            const All = u64.add3L(T1l, sigma0l, MAJl);
            Ah = u64.add3H(All, T1h, sigma0h, MAJh);
            Al = All | 0;
        }
        // Add the compressed chunk to the current hash value
        ({ h: Ah, l: Al } = u64.add(this.Ah | 0, this.Al | 0, Ah | 0, Al | 0));
        ({ h: Bh, l: Bl } = u64.add(this.Bh | 0, this.Bl | 0, Bh | 0, Bl | 0));
        ({ h: Ch, l: Cl } = u64.add(this.Ch | 0, this.Cl | 0, Ch | 0, Cl | 0));
        ({ h: Dh, l: Dl } = u64.add(this.Dh | 0, this.Dl | 0, Dh | 0, Dl | 0));
        ({ h: Eh, l: El } = u64.add(this.Eh | 0, this.El | 0, Eh | 0, El | 0));
        ({ h: Fh, l: Fl } = u64.add(this.Fh | 0, this.Fl | 0, Fh | 0, Fl | 0));
        ({ h: Gh, l: Gl } = u64.add(this.Gh | 0, this.Gl | 0, Gh | 0, Gl | 0));
        ({ h: Hh, l: Hl } = u64.add(this.Hh | 0, this.Hl | 0, Hh | 0, Hl | 0));
        this.set(Ah, Al, Bh, Bl, Ch, Cl, Dh, Dl, Eh, El, Fh, Fl, Gh, Gl, Hh, Hl);
    }
    roundClean() {
        SHA512_W_H.fill(0);
        SHA512_W_L.fill(0);
    }
    destroy() {
        this.buffer.fill(0);
        this.set(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
    }
}
const sha512 = /* @__PURE__ */ wrapConstructor(() => new SHA512());

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
// 100 lines of code in the file are duplicated from noble-hashes (utils).
// This is OK: `abstract` directory does not use noble-hashes.
// User may opt-in into using different hashing library. This way, noble-hashes
// won't be included into their bundle.
const _0n$5 = /* @__PURE__ */ BigInt(0);
const _1n$7 = /* @__PURE__ */ BigInt(1);
const _2n$5 = /* @__PURE__ */ BigInt(2);
function isBytes$1(a) {
    return (a instanceof Uint8Array ||
        (a != null && typeof a === 'object' && a.constructor.name === 'Uint8Array'));
}
function abytes(item) {
    if (!isBytes$1(item))
        throw new Error('Uint8Array expected');
}
// Array where index 0xf0 (240) is mapped to string 'f0'
const hexes = /* @__PURE__ */ Array.from({ length: 256 }, (_, i) => i.toString(16).padStart(2, '0'));
/**
 * @example bytesToHex(Uint8Array.from([0xca, 0xfe, 0x01, 0x23])) // 'cafe0123'
 */
function bytesToHex$1(bytes) {
    abytes(bytes);
    // pre-caching improves the speed 6x
    let hex = '';
    for (let i = 0; i < bytes.length; i++) {
        hex += hexes[bytes[i]];
    }
    return hex;
}
function numberToHexUnpadded(num) {
    const hex = num.toString(16);
    return hex.length & 1 ? `0${hex}` : hex;
}
function hexToNumber(hex) {
    if (typeof hex !== 'string')
        throw new Error('hex string expected, got ' + typeof hex);
    // Big Endian
    return BigInt(hex === '' ? '0' : `0x${hex}`);
}
// We use optimized technique to convert hex string to byte array
const asciis = { _0: 48, _9: 57, _A: 65, _F: 70, _a: 97, _f: 102 };
function asciiToBase16(char) {
    if (char >= asciis._0 && char <= asciis._9)
        return char - asciis._0;
    if (char >= asciis._A && char <= asciis._F)
        return char - (asciis._A - 10);
    if (char >= asciis._a && char <= asciis._f)
        return char - (asciis._a - 10);
    return;
}
/**
 * @example hexToBytes('cafe0123') // Uint8Array.from([0xca, 0xfe, 0x01, 0x23])
 */
function hexToBytes$1(hex) {
    if (typeof hex !== 'string')
        throw new Error('hex string expected, got ' + typeof hex);
    const hl = hex.length;
    const al = hl / 2;
    if (hl % 2)
        throw new Error('padded hex string expected, got unpadded hex of length ' + hl);
    const array = new Uint8Array(al);
    for (let ai = 0, hi = 0; ai < al; ai++, hi += 2) {
        const n1 = asciiToBase16(hex.charCodeAt(hi));
        const n2 = asciiToBase16(hex.charCodeAt(hi + 1));
        if (n1 === undefined || n2 === undefined) {
            const char = hex[hi] + hex[hi + 1];
            throw new Error('hex string expected, got non-hex character "' + char + '" at index ' + hi);
        }
        array[ai] = n1 * 16 + n2;
    }
    return array;
}
// BE: Big Endian, LE: Little Endian
function bytesToNumberBE(bytes) {
    return hexToNumber(bytesToHex$1(bytes));
}
function bytesToNumberLE(bytes) {
    abytes(bytes);
    return hexToNumber(bytesToHex$1(Uint8Array.from(bytes).reverse()));
}
function numberToBytesBE(n, len) {
    return hexToBytes$1(n.toString(16).padStart(len * 2, '0'));
}
function numberToBytesLE(n, len) {
    return numberToBytesBE(n, len).reverse();
}
// Unpadded, rarely used
function numberToVarBytesBE(n) {
    return hexToBytes$1(numberToHexUnpadded(n));
}
/**
 * Takes hex string or Uint8Array, converts to Uint8Array.
 * Validates output length.
 * Will throw error for other types.
 * @param title descriptive title for an error e.g. 'private key'
 * @param hex hex string or Uint8Array
 * @param expectedLength optional, will compare to result array's length
 * @returns
 */
function ensureBytes(title, hex, expectedLength) {
    let res;
    if (typeof hex === 'string') {
        try {
            res = hexToBytes$1(hex);
        }
        catch (e) {
            throw new Error(`${title} must be valid hex string, got "${hex}". Cause: ${e}`);
        }
    }
    else if (isBytes$1(hex)) {
        // Uint8Array.from() instead of hash.slice() because node.js Buffer
        // is instance of Uint8Array, and its slice() creates **mutable** copy
        res = Uint8Array.from(hex);
    }
    else {
        throw new Error(`${title} must be hex string or Uint8Array`);
    }
    const len = res.length;
    if (typeof expectedLength === 'number' && len !== expectedLength)
        throw new Error(`${title} expected ${expectedLength} bytes, got ${len}`);
    return res;
}
/**
 * Copies several Uint8Arrays into one.
 */
function concatBytes(...arrays) {
    let sum = 0;
    for (let i = 0; i < arrays.length; i++) {
        const a = arrays[i];
        abytes(a);
        sum += a.length;
    }
    const res = new Uint8Array(sum);
    for (let i = 0, pad = 0; i < arrays.length; i++) {
        const a = arrays[i];
        res.set(a, pad);
        pad += a.length;
    }
    return res;
}
// Compares 2 u8a-s in kinda constant time
function equalBytes(a, b) {
    if (a.length !== b.length)
        return false;
    let diff = 0;
    for (let i = 0; i < a.length; i++)
        diff |= a[i] ^ b[i];
    return diff === 0;
}
/**
 * @example utf8ToBytes('abc') // new Uint8Array([97, 98, 99])
 */
function utf8ToBytes(str) {
    if (typeof str !== 'string')
        throw new Error(`utf8ToBytes expected string, got ${typeof str}`);
    return new Uint8Array(new TextEncoder().encode(str)); // https://bugzil.la/1681809
}
// Bit operations
/**
 * Calculates amount of bits in a bigint.
 * Same as `n.toString(2).length`
 */
function bitLen(n) {
    let len;
    for (len = 0; n > _0n$5; n >>= _1n$7, len += 1)
        ;
    return len;
}
/**
 * Gets single bit at position.
 * NOTE: first bit position is 0 (same as arrays)
 * Same as `!!+Array.from(n.toString(2)).reverse()[pos]`
 */
function bitGet(n, pos) {
    return (n >> BigInt(pos)) & _1n$7;
}
/**
 * Sets single bit at position.
 */
function bitSet(n, pos, value) {
    return n | ((value ? _1n$7 : _0n$5) << BigInt(pos));
}
/**
 * Calculate mask for N bits. Not using ** operator with bigints because of old engines.
 * Same as BigInt(`0b${Array(i).fill('1').join('')}`)
 */
const bitMask = (n) => (_2n$5 << BigInt(n - 1)) - _1n$7;
// DRBG
const u8n = (data) => new Uint8Array(data); // creates Uint8Array
const u8fr = (arr) => Uint8Array.from(arr); // another shortcut
/**
 * Minimal HMAC-DRBG from NIST 800-90 for RFC6979 sigs.
 * @returns function that will call DRBG until 2nd arg returns something meaningful
 * @example
 *   const drbg = createHmacDRBG<Key>(32, 32, hmac);
 *   drbg(seed, bytesToKey); // bytesToKey must return Key or undefined
 */
function createHmacDrbg(hashLen, qByteLen, hmacFn) {
    if (typeof hashLen !== 'number' || hashLen < 2)
        throw new Error('hashLen must be a number');
    if (typeof qByteLen !== 'number' || qByteLen < 2)
        throw new Error('qByteLen must be a number');
    if (typeof hmacFn !== 'function')
        throw new Error('hmacFn must be a function');
    // Step B, Step C: set hashLen to 8*ceil(hlen/8)
    let v = u8n(hashLen); // Minimal non-full-spec HMAC-DRBG from NIST 800-90 for RFC6979 sigs.
    let k = u8n(hashLen); // Steps B and C of RFC6979 3.2: set hashLen, in our case always same
    let i = 0; // Iterations counter, will throw when over 1000
    const reset = () => {
        v.fill(1);
        k.fill(0);
        i = 0;
    };
    const h = (...b) => hmacFn(k, v, ...b); // hmac(k)(v, ...values)
    const reseed = (seed = u8n()) => {
        // HMAC-DRBG reseed() function. Steps D-G
        k = h(u8fr([0x00]), seed); // k = hmac(k || v || 0x00 || seed)
        v = h(); // v = hmac(k || v)
        if (seed.length === 0)
            return;
        k = h(u8fr([0x01]), seed); // k = hmac(k || v || 0x01 || seed)
        v = h(); // v = hmac(k || v)
    };
    const gen = () => {
        // HMAC-DRBG generate() function
        if (i++ >= 1000)
            throw new Error('drbg: tried 1000 values');
        let len = 0;
        const out = [];
        while (len < qByteLen) {
            v = h();
            const sl = v.slice();
            out.push(sl);
            len += v.length;
        }
        return concatBytes(...out);
    };
    const genUntil = (seed, pred) => {
        reset();
        reseed(seed); // Steps D-G
        let res = undefined; // Step H: grind until k is in [1..n-1]
        while (!(res = pred(gen())))
            reseed();
        reset();
        return res;
    };
    return genUntil;
}
// Validating curves and fields
const validatorFns = {
    bigint: (val) => typeof val === 'bigint',
    function: (val) => typeof val === 'function',
    boolean: (val) => typeof val === 'boolean',
    string: (val) => typeof val === 'string',
    stringOrUint8Array: (val) => typeof val === 'string' || isBytes$1(val),
    isSafeInteger: (val) => Number.isSafeInteger(val),
    array: (val) => Array.isArray(val),
    field: (val, object) => object.Fp.isValid(val),
    hash: (val) => typeof val === 'function' && Number.isSafeInteger(val.outputLen),
};
// type Record<K extends string | number | symbol, T> = { [P in K]: T; }
function validateObject(object, validators, optValidators = {}) {
    const checkField = (fieldName, type, isOptional) => {
        const checkVal = validatorFns[type];
        if (typeof checkVal !== 'function')
            throw new Error(`Invalid validator "${type}", expected function`);
        const val = object[fieldName];
        if (isOptional && val === undefined)
            return;
        if (!checkVal(val, object)) {
            throw new Error(`Invalid param ${String(fieldName)}=${val} (${typeof val}), expected ${type}`);
        }
    };
    for (const [fieldName, type] of Object.entries(validators))
        checkField(fieldName, type, false);
    for (const [fieldName, type] of Object.entries(optValidators))
        checkField(fieldName, type, true);
    return object;
}
// validate type tests
// const o: { a: number; b: number; c: number } = { a: 1, b: 5, c: 6 };
// const z0 = validateObject(o, { a: 'isSafeInteger' }, { c: 'bigint' }); // Ok!
// // Should fail type-check
// const z1 = validateObject(o, { a: 'tmp' }, { c: 'zz' });
// const z2 = validateObject(o, { a: 'isSafeInteger' }, { c: 'zz' });
// const z3 = validateObject(o, { test: 'boolean', z: 'bug' });
// const z4 = validateObject(o, { a: 'boolean', z: 'bug' });

var ut = {
  __proto__: null,
  isBytes: isBytes$1,
  abytes: abytes,
  bytesToHex: bytesToHex$1,
  numberToHexUnpadded: numberToHexUnpadded,
  hexToNumber: hexToNumber,
  hexToBytes: hexToBytes$1,
  bytesToNumberBE: bytesToNumberBE,
  bytesToNumberLE: bytesToNumberLE,
  numberToBytesBE: numberToBytesBE,
  numberToBytesLE: numberToBytesLE,
  numberToVarBytesBE: numberToVarBytesBE,
  ensureBytes: ensureBytes,
  concatBytes: concatBytes,
  equalBytes: equalBytes,
  utf8ToBytes: utf8ToBytes,
  bitLen: bitLen,
  bitGet: bitGet,
  bitSet: bitSet,
  bitMask: bitMask,
  createHmacDrbg: createHmacDrbg,
  validateObject: validateObject
};

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
// prettier-ignore
const _0n$4 = BigInt(0), _1n$6 = BigInt(1), _2n$4 = BigInt(2), _3n$1 = BigInt(3);
// prettier-ignore
const _4n = BigInt(4), _5n$1 = BigInt(5), _8n$2 = BigInt(8);
// prettier-ignore
BigInt(9); BigInt(16);
// Calculates a modulo b
function mod(a, b) {
    const result = a % b;
    return result >= _0n$4 ? result : b + result;
}
/**
 * Efficiently raise num to power and do modular division.
 * Unsafe in some contexts: uses ladder, so can expose bigint bits.
 * @example
 * pow(2n, 6n, 11n) // 64n % 11n == 9n
 */
// TODO: use field version && remove
function pow(num, power, modulo) {
    if (modulo <= _0n$4 || power < _0n$4)
        throw new Error('Expected power/modulo > 0');
    if (modulo === _1n$6)
        return _0n$4;
    let res = _1n$6;
    while (power > _0n$4) {
        if (power & _1n$6)
            res = (res * num) % modulo;
        num = (num * num) % modulo;
        power >>= _1n$6;
    }
    return res;
}
// Does x ^ (2 ^ power) mod p. pow2(30, 4) == 30 ^ (2 ^ 4)
function pow2(x, power, modulo) {
    let res = x;
    while (power-- > _0n$4) {
        res *= res;
        res %= modulo;
    }
    return res;
}
// Inverses number over modulo
function invert(number, modulo) {
    if (number === _0n$4 || modulo <= _0n$4) {
        throw new Error(`invert: expected positive integers, got n=${number} mod=${modulo}`);
    }
    // Euclidean GCD https://brilliant.org/wiki/extended-euclidean-algorithm/
    // Fermat's little theorem "CT-like" version inv(n) = n^(m-2) mod m is 30x slower.
    let a = mod(number, modulo);
    let b = modulo;
    // prettier-ignore
    let x = _0n$4, u = _1n$6;
    while (a !== _0n$4) {
        // JIT applies optimization if those two lines follow each other
        const q = b / a;
        const r = b % a;
        const m = x - u * q;
        // prettier-ignore
        b = a, a = r, x = u, u = m;
    }
    const gcd = b;
    if (gcd !== _1n$6)
        throw new Error('invert: does not exist');
    return mod(x, modulo);
}
/**
 * Tonelli-Shanks square root search algorithm.
 * 1. https://eprint.iacr.org/2012/685.pdf (page 12)
 * 2. Square Roots from 1; 24, 51, 10 to Dan Shanks
 * Will start an infinite loop if field order P is not prime.
 * @param P field order
 * @returns function that takes field Fp (created from P) and number n
 */
function tonelliShanks(P) {
    // Legendre constant: used to calculate Legendre symbol (a | p),
    // which denotes the value of a^((p-1)/2) (mod p).
    // (a | p) ≡ 1    if a is a square (mod p)
    // (a | p) ≡ -1   if a is not a square (mod p)
    // (a | p) ≡ 0    if a ≡ 0 (mod p)
    const legendreC = (P - _1n$6) / _2n$4;
    let Q, S, Z;
    // Step 1: By factoring out powers of 2 from p - 1,
    // find q and s such that p - 1 = q*(2^s) with q odd
    for (Q = P - _1n$6, S = 0; Q % _2n$4 === _0n$4; Q /= _2n$4, S++)
        ;
    // Step 2: Select a non-square z such that (z | p) ≡ -1 and set c ≡ zq
    for (Z = _2n$4; Z < P && pow(Z, legendreC, P) !== P - _1n$6; Z++)
        ;
    // Fast-path
    if (S === 1) {
        const p1div4 = (P + _1n$6) / _4n;
        return function tonelliFast(Fp, n) {
            const root = Fp.pow(n, p1div4);
            if (!Fp.eql(Fp.sqr(root), n))
                throw new Error('Cannot find square root');
            return root;
        };
    }
    // Slow-path
    const Q1div2 = (Q + _1n$6) / _2n$4;
    return function tonelliSlow(Fp, n) {
        // Step 0: Check that n is indeed a square: (n | p) should not be ≡ -1
        if (Fp.pow(n, legendreC) === Fp.neg(Fp.ONE))
            throw new Error('Cannot find square root');
        let r = S;
        // TODO: will fail at Fp2/etc
        let g = Fp.pow(Fp.mul(Fp.ONE, Z), Q); // will update both x and b
        let x = Fp.pow(n, Q1div2); // first guess at the square root
        let b = Fp.pow(n, Q); // first guess at the fudge factor
        while (!Fp.eql(b, Fp.ONE)) {
            if (Fp.eql(b, Fp.ZERO))
                return Fp.ZERO; // https://en.wikipedia.org/wiki/Tonelli%E2%80%93Shanks_algorithm (4. If t = 0, return r = 0)
            // Find m such b^(2^m)==1
            let m = 1;
            for (let t2 = Fp.sqr(b); m < r; m++) {
                if (Fp.eql(t2, Fp.ONE))
                    break;
                t2 = Fp.sqr(t2); // t2 *= t2
            }
            // NOTE: r-m-1 can be bigger than 32, need to convert to bigint before shift, otherwise there will be overflow
            const ge = Fp.pow(g, _1n$6 << BigInt(r - m - 1)); // ge = 2^(r-m-1)
            g = Fp.sqr(ge); // g = ge * ge
            x = Fp.mul(x, ge); // x *= ge
            b = Fp.mul(b, g); // b *= g
            r = m;
        }
        return x;
    };
}
function FpSqrt(P) {
    // NOTE: different algorithms can give different roots, it is up to user to decide which one they want.
    // For example there is FpSqrtOdd/FpSqrtEven to choice root based on oddness (used for hash-to-curve).
    // P ≡ 3 (mod 4)
    // √n = n^((P+1)/4)
    if (P % _4n === _3n$1) {
        // Not all roots possible!
        // const ORDER =
        //   0x1a0111ea397fe69a4b1ba7b6434bacd764774b84f38512bf6730d2a0f6b0f6241eabfffeb153ffffb9feffffffffaaabn;
        // const NUM = 72057594037927816n;
        const p1div4 = (P + _1n$6) / _4n;
        return function sqrt3mod4(Fp, n) {
            const root = Fp.pow(n, p1div4);
            // Throw if root**2 != n
            if (!Fp.eql(Fp.sqr(root), n))
                throw new Error('Cannot find square root');
            return root;
        };
    }
    // Atkin algorithm for q ≡ 5 (mod 8), https://eprint.iacr.org/2012/685.pdf (page 10)
    if (P % _8n$2 === _5n$1) {
        const c1 = (P - _5n$1) / _8n$2;
        return function sqrt5mod8(Fp, n) {
            const n2 = Fp.mul(n, _2n$4);
            const v = Fp.pow(n2, c1);
            const nv = Fp.mul(n, v);
            const i = Fp.mul(Fp.mul(nv, _2n$4), v);
            const root = Fp.mul(nv, Fp.sub(i, Fp.ONE));
            if (!Fp.eql(Fp.sqr(root), n))
                throw new Error('Cannot find square root');
            return root;
        };
    }
    // Other cases: Tonelli-Shanks algorithm
    return tonelliShanks(P);
}
// Little-endian check for first LE bit (last BE bit);
const isNegativeLE = (num, modulo) => (mod(num, modulo) & _1n$6) === _1n$6;
// prettier-ignore
const FIELD_FIELDS = [
    'create', 'isValid', 'is0', 'neg', 'inv', 'sqrt', 'sqr',
    'eql', 'add', 'sub', 'mul', 'pow', 'div',
    'addN', 'subN', 'mulN', 'sqrN'
];
function validateField(field) {
    const initial = {
        ORDER: 'bigint',
        MASK: 'bigint',
        BYTES: 'isSafeInteger',
        BITS: 'isSafeInteger',
    };
    const opts = FIELD_FIELDS.reduce((map, val) => {
        map[val] = 'function';
        return map;
    }, initial);
    return validateObject(field, opts);
}
// Generic field functions
/**
 * Same as `pow` but for Fp: non-constant-time.
 * Unsafe in some contexts: uses ladder, so can expose bigint bits.
 */
function FpPow(f, num, power) {
    // Should have same speed as pow for bigints
    // TODO: benchmark!
    if (power < _0n$4)
        throw new Error('Expected power > 0');
    if (power === _0n$4)
        return f.ONE;
    if (power === _1n$6)
        return num;
    let p = f.ONE;
    let d = num;
    while (power > _0n$4) {
        if (power & _1n$6)
            p = f.mul(p, d);
        d = f.sqr(d);
        power >>= _1n$6;
    }
    return p;
}
/**
 * Efficiently invert an array of Field elements.
 * `inv(0)` will return `undefined` here: make sure to throw an error.
 */
function FpInvertBatch(f, nums) {
    const tmp = new Array(nums.length);
    // Walk from first to last, multiply them by each other MOD p
    const lastMultiplied = nums.reduce((acc, num, i) => {
        if (f.is0(num))
            return acc;
        tmp[i] = acc;
        return f.mul(acc, num);
    }, f.ONE);
    // Invert last element
    const inverted = f.inv(lastMultiplied);
    // Walk from last to first, multiply them by inverted each other MOD p
    nums.reduceRight((acc, num, i) => {
        if (f.is0(num))
            return acc;
        tmp[i] = f.mul(acc, tmp[i]);
        return f.mul(acc, num);
    }, inverted);
    return tmp;
}
// CURVE.n lengths
function nLength(n, nBitLength) {
    // Bit size, byte size of CURVE.n
    const _nBitLength = nBitLength !== undefined ? nBitLength : n.toString(2).length;
    const nByteLength = Math.ceil(_nBitLength / 8);
    return { nBitLength: _nBitLength, nByteLength };
}
/**
 * Initializes a finite field over prime. **Non-primes are not supported.**
 * Do not init in loop: slow. Very fragile: always run a benchmark on a change.
 * Major performance optimizations:
 * * a) denormalized operations like mulN instead of mul
 * * b) same object shape: never add or remove keys
 * * c) Object.freeze
 * @param ORDER prime positive bigint
 * @param bitLen how many bits the field consumes
 * @param isLE (def: false) if encoding / decoding should be in little-endian
 * @param redef optional faster redefinitions of sqrt and other methods
 */
function Field(ORDER, bitLen, isLE = false, redef = {}) {
    if (ORDER <= _0n$4)
        throw new Error(`Expected Field ORDER > 0, got ${ORDER}`);
    const { nBitLength: BITS, nByteLength: BYTES } = nLength(ORDER, bitLen);
    if (BYTES > 2048)
        throw new Error('Field lengths over 2048 bytes are not supported');
    const sqrtP = FpSqrt(ORDER);
    const f = Object.freeze({
        ORDER,
        BITS,
        BYTES,
        MASK: bitMask(BITS),
        ZERO: _0n$4,
        ONE: _1n$6,
        create: (num) => mod(num, ORDER),
        isValid: (num) => {
            if (typeof num !== 'bigint')
                throw new Error(`Invalid field element: expected bigint, got ${typeof num}`);
            return _0n$4 <= num && num < ORDER; // 0 is valid element, but it's not invertible
        },
        is0: (num) => num === _0n$4,
        isOdd: (num) => (num & _1n$6) === _1n$6,
        neg: (num) => mod(-num, ORDER),
        eql: (lhs, rhs) => lhs === rhs,
        sqr: (num) => mod(num * num, ORDER),
        add: (lhs, rhs) => mod(lhs + rhs, ORDER),
        sub: (lhs, rhs) => mod(lhs - rhs, ORDER),
        mul: (lhs, rhs) => mod(lhs * rhs, ORDER),
        pow: (num, power) => FpPow(f, num, power),
        div: (lhs, rhs) => mod(lhs * invert(rhs, ORDER), ORDER),
        // Same as above, but doesn't normalize
        sqrN: (num) => num * num,
        addN: (lhs, rhs) => lhs + rhs,
        subN: (lhs, rhs) => lhs - rhs,
        mulN: (lhs, rhs) => lhs * rhs,
        inv: (num) => invert(num, ORDER),
        sqrt: redef.sqrt || ((n) => sqrtP(f, n)),
        invertBatch: (lst) => FpInvertBatch(f, lst),
        // TODO: do we really need constant cmov?
        // We don't have const-time bigints anyway, so probably will be not very useful
        cmov: (a, b, c) => (c ? b : a),
        toBytes: (num) => (isLE ? numberToBytesLE(num, BYTES) : numberToBytesBE(num, BYTES)),
        fromBytes: (bytes) => {
            if (bytes.length !== BYTES)
                throw new Error(`Fp.fromBytes: expected ${BYTES}, got ${bytes.length}`);
            return isLE ? bytesToNumberLE(bytes) : bytesToNumberBE(bytes);
        },
    });
    return Object.freeze(f);
}
/**
 * Returns total number of bytes consumed by the field element.
 * For example, 32 bytes for usual 256-bit weierstrass curve.
 * @param fieldOrder number of field elements, usually CURVE.n
 * @returns byte length of field
 */
function getFieldBytesLength(fieldOrder) {
    if (typeof fieldOrder !== 'bigint')
        throw new Error('field order must be bigint');
    const bitLength = fieldOrder.toString(2).length;
    return Math.ceil(bitLength / 8);
}
/**
 * Returns minimal amount of bytes that can be safely reduced
 * by field order.
 * Should be 2^-128 for 128-bit curve such as P256.
 * @param fieldOrder number of field elements, usually CURVE.n
 * @returns byte length of target hash
 */
function getMinHashLength(fieldOrder) {
    const length = getFieldBytesLength(fieldOrder);
    return length + Math.ceil(length / 2);
}
/**
 * "Constant-time" private key generation utility.
 * Can take (n + n/2) or more bytes of uniform input e.g. from CSPRNG or KDF
 * and convert them into private scalar, with the modulo bias being negligible.
 * Needs at least 48 bytes of input for 32-byte private key.
 * https://research.kudelskisecurity.com/2020/07/28/the-definitive-guide-to-modulo-bias-and-how-to-avoid-it/
 * FIPS 186-5, A.2 https://csrc.nist.gov/publications/detail/fips/186/5/final
 * RFC 9380, https://www.rfc-editor.org/rfc/rfc9380#section-5
 * @param hash hash output from SHA3 or a similar function
 * @param groupOrder size of subgroup - (e.g. secp256k1.CURVE.n)
 * @param isLE interpret hash bytes as LE num
 * @returns valid private scalar
 */
function mapHashToField(key, fieldOrder, isLE = false) {
    const len = key.length;
    const fieldLen = getFieldBytesLength(fieldOrder);
    const minLen = getMinHashLength(fieldOrder);
    // No small numbers: need to understand bias story. No huge numbers: easier to detect JS timings.
    if (len < 16 || len < minLen || len > 1024)
        throw new Error(`expected ${minLen}-1024 bytes of input, got ${len}`);
    const num = isLE ? bytesToNumberBE(key) : bytesToNumberLE(key);
    // `mod(x, 11)` can sometimes produce 0. `mod(x, 10) + 1` is the same, but no 0
    const reduced = mod(num, fieldOrder - _1n$6) + _1n$6;
    return isLE ? numberToBytesLE(reduced, fieldLen) : numberToBytesBE(reduced, fieldLen);
}

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
const _0n$3 = BigInt(0);
const _1n$5 = BigInt(1);
// Elliptic curve multiplication of Point by scalar. Fragile.
// Scalars should always be less than curve order: this should be checked inside of a curve itself.
// Creates precomputation tables for fast multiplication:
// - private scalar is split by fixed size windows of W bits
// - every window point is collected from window's table & added to accumulator
// - since windows are different, same point inside tables won't be accessed more than once per calc
// - each multiplication is 'Math.ceil(CURVE_ORDER / 𝑊) + 1' point additions (fixed for any scalar)
// - +1 window is neccessary for wNAF
// - wNAF reduces table size: 2x less memory + 2x faster generation, but 10% slower multiplication
// TODO: Research returning 2d JS array of windows, instead of a single window. This would allow
// windows to be in different memory locations
function wNAF(c, bits) {
    const constTimeNegate = (condition, item) => {
        const neg = item.negate();
        return condition ? neg : item;
    };
    const opts = (W) => {
        const windows = Math.ceil(bits / W) + 1; // +1, because
        const windowSize = 2 ** (W - 1); // -1 because we skip zero
        return { windows, windowSize };
    };
    return {
        constTimeNegate,
        // non-const time multiplication ladder
        unsafeLadder(elm, n) {
            let p = c.ZERO;
            let d = elm;
            while (n > _0n$3) {
                if (n & _1n$5)
                    p = p.add(d);
                d = d.double();
                n >>= _1n$5;
            }
            return p;
        },
        /**
         * Creates a wNAF precomputation window. Used for caching.
         * Default window size is set by `utils.precompute()` and is equal to 8.
         * Number of precomputed points depends on the curve size:
         * 2^(𝑊−1) * (Math.ceil(𝑛 / 𝑊) + 1), where:
         * - 𝑊 is the window size
         * - 𝑛 is the bitlength of the curve order.
         * For a 256-bit curve and window size 8, the number of precomputed points is 128 * 33 = 4224.
         * @returns precomputed point tables flattened to a single array
         */
        precomputeWindow(elm, W) {
            const { windows, windowSize } = opts(W);
            const points = [];
            let p = elm;
            let base = p;
            for (let window = 0; window < windows; window++) {
                base = p;
                points.push(base);
                // =1, because we skip zero
                for (let i = 1; i < windowSize; i++) {
                    base = base.add(p);
                    points.push(base);
                }
                p = base.double();
            }
            return points;
        },
        /**
         * Implements ec multiplication using precomputed tables and w-ary non-adjacent form.
         * @param W window size
         * @param precomputes precomputed tables
         * @param n scalar (we don't check here, but should be less than curve order)
         * @returns real and fake (for const-time) points
         */
        wNAF(W, precomputes, n) {
            // TODO: maybe check that scalar is less than group order? wNAF behavious is undefined otherwise
            // But need to carefully remove other checks before wNAF. ORDER == bits here
            const { windows, windowSize } = opts(W);
            let p = c.ZERO;
            let f = c.BASE;
            const mask = BigInt(2 ** W - 1); // Create mask with W ones: 0b1111 for W=4 etc.
            const maxNumber = 2 ** W;
            const shiftBy = BigInt(W);
            for (let window = 0; window < windows; window++) {
                const offset = window * windowSize;
                // Extract W bits.
                let wbits = Number(n & mask);
                // Shift number by W bits.
                n >>= shiftBy;
                // If the bits are bigger than max size, we'll split those.
                // +224 => 256 - 32
                if (wbits > windowSize) {
                    wbits -= maxNumber;
                    n += _1n$5;
                }
                // This code was first written with assumption that 'f' and 'p' will never be infinity point:
                // since each addition is multiplied by 2 ** W, it cannot cancel each other. However,
                // there is negate now: it is possible that negated element from low value
                // would be the same as high element, which will create carry into next window.
                // It's not obvious how this can fail, but still worth investigating later.
                // Check if we're onto Zero point.
                // Add random point inside current window to f.
                const offset1 = offset;
                const offset2 = offset + Math.abs(wbits) - 1; // -1 because we skip zero
                const cond1 = window % 2 !== 0;
                const cond2 = wbits < 0;
                if (wbits === 0) {
                    // The most important part for const-time getPublicKey
                    f = f.add(constTimeNegate(cond1, precomputes[offset1]));
                }
                else {
                    p = p.add(constTimeNegate(cond2, precomputes[offset2]));
                }
            }
            // JIT-compiler should not eliminate f here, since it will later be used in normalizeZ()
            // Even if the variable is still unused, there are some checks which will
            // throw an exception, so compiler needs to prove they won't happen, which is hard.
            // At this point there is a way to F be infinity-point even if p is not,
            // which makes it less const-time: around 1 bigint multiply.
            return { p, f };
        },
        wNAFCached(P, precomputesMap, n, transform) {
            // @ts-ignore
            const W = P._WINDOW_SIZE || 1;
            // Calculate precomputes on a first run, reuse them after
            let comp = precomputesMap.get(P);
            if (!comp) {
                comp = this.precomputeWindow(P, W);
                if (W !== 1) {
                    precomputesMap.set(P, transform(comp));
                }
            }
            return this.wNAF(W, comp, n);
        },
    };
}
function validateBasic(curve) {
    validateField(curve.Fp);
    validateObject(curve, {
        n: 'bigint',
        h: 'bigint',
        Gx: 'field',
        Gy: 'field',
    }, {
        nBitLength: 'isSafeInteger',
        nByteLength: 'isSafeInteger',
    });
    // Set defaults
    return Object.freeze({
        ...nLength(curve.n, curve.nBitLength),
        ...curve,
        ...{ p: curve.Fp.ORDER },
    });
}

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
// Be friendly to bad ECMAScript parsers by not using bigint literals
// prettier-ignore
const _0n$2 = BigInt(0), _1n$4 = BigInt(1), _2n$3 = BigInt(2), _8n$1 = BigInt(8);
// verification rule is either zip215 or rfc8032 / nist186-5. Consult fromHex:
const VERIFY_DEFAULT = { zip215: true };
function validateOpts$1(curve) {
    const opts = validateBasic(curve);
    validateObject(curve, {
        hash: 'function',
        a: 'bigint',
        d: 'bigint',
        randomBytes: 'function',
    }, {
        adjustScalarBytes: 'function',
        domain: 'function',
        uvRatio: 'function',
        mapToCurve: 'function',
    });
    // Set defaults
    return Object.freeze({ ...opts });
}
// It is not generic twisted curve for now, but ed25519/ed448 generic implementation
function twistedEdwards(curveDef) {
    const CURVE = validateOpts$1(curveDef);
    const { Fp, n: CURVE_ORDER, prehash: prehash, hash: cHash, randomBytes, nByteLength, h: cofactor, } = CURVE;
    const MASK = _2n$3 << (BigInt(nByteLength * 8) - _1n$4);
    const modP = Fp.create; // Function overrides
    // sqrt(u/v)
    const uvRatio = CURVE.uvRatio ||
        ((u, v) => {
            try {
                return { isValid: true, value: Fp.sqrt(u * Fp.inv(v)) };
            }
            catch (e) {
                return { isValid: false, value: _0n$2 };
            }
        });
    const adjustScalarBytes = CURVE.adjustScalarBytes || ((bytes) => bytes); // NOOP
    const domain = CURVE.domain ||
        ((data, ctx, phflag) => {
            if (ctx.length || phflag)
                throw new Error('Contexts/pre-hash are not supported');
            return data;
        }); // NOOP
    const inBig = (n) => typeof n === 'bigint' && _0n$2 < n; // n in [1..]
    const inRange = (n, max) => inBig(n) && inBig(max) && n < max; // n in [1..max-1]
    const in0MaskRange = (n) => n === _0n$2 || inRange(n, MASK); // n in [0..MASK-1]
    function assertInRange(n, max) {
        // n in [1..max-1]
        if (inRange(n, max))
            return n;
        throw new Error(`Expected valid scalar < ${max}, got ${typeof n} ${n}`);
    }
    function assertGE0(n) {
        // n in [0..CURVE_ORDER-1]
        return n === _0n$2 ? n : assertInRange(n, CURVE_ORDER); // GE = prime subgroup, not full group
    }
    const pointPrecomputes = new Map();
    function isPoint(other) {
        if (!(other instanceof Point))
            throw new Error('ExtendedPoint expected');
    }
    // Extended Point works in extended coordinates: (x, y, z, t) ∋ (x=x/z, y=y/z, t=xy).
    // https://en.wikipedia.org/wiki/Twisted_Edwards_curve#Extended_coordinates
    class Point {
        constructor(ex, ey, ez, et) {
            this.ex = ex;
            this.ey = ey;
            this.ez = ez;
            this.et = et;
            if (!in0MaskRange(ex))
                throw new Error('x required');
            if (!in0MaskRange(ey))
                throw new Error('y required');
            if (!in0MaskRange(ez))
                throw new Error('z required');
            if (!in0MaskRange(et))
                throw new Error('t required');
        }
        get x() {
            return this.toAffine().x;
        }
        get y() {
            return this.toAffine().y;
        }
        static fromAffine(p) {
            if (p instanceof Point)
                throw new Error('extended point not allowed');
            const { x, y } = p || {};
            if (!in0MaskRange(x) || !in0MaskRange(y))
                throw new Error('invalid affine point');
            return new Point(x, y, _1n$4, modP(x * y));
        }
        static normalizeZ(points) {
            const toInv = Fp.invertBatch(points.map((p) => p.ez));
            return points.map((p, i) => p.toAffine(toInv[i])).map(Point.fromAffine);
        }
        // "Private method", don't use it directly
        _setWindowSize(windowSize) {
            this._WINDOW_SIZE = windowSize;
            pointPrecomputes.delete(this);
        }
        // Not required for fromHex(), which always creates valid points.
        // Could be useful for fromAffine().
        assertValidity() {
            const { a, d } = CURVE;
            if (this.is0())
                throw new Error('bad point: ZERO'); // TODO: optimize, with vars below?
            // Equation in affine coordinates: ax² + y² = 1 + dx²y²
            // Equation in projective coordinates (X/Z, Y/Z, Z):  (aX² + Y²)Z² = Z⁴ + dX²Y²
            const { ex: X, ey: Y, ez: Z, et: T } = this;
            const X2 = modP(X * X); // X²
            const Y2 = modP(Y * Y); // Y²
            const Z2 = modP(Z * Z); // Z²
            const Z4 = modP(Z2 * Z2); // Z⁴
            const aX2 = modP(X2 * a); // aX²
            const left = modP(Z2 * modP(aX2 + Y2)); // (aX² + Y²)Z²
            const right = modP(Z4 + modP(d * modP(X2 * Y2))); // Z⁴ + dX²Y²
            if (left !== right)
                throw new Error('bad point: equation left != right (1)');
            // In Extended coordinates we also have T, which is x*y=T/Z: check X*Y == Z*T
            const XY = modP(X * Y);
            const ZT = modP(Z * T);
            if (XY !== ZT)
                throw new Error('bad point: equation left != right (2)');
        }
        // Compare one point to another.
        equals(other) {
            isPoint(other);
            const { ex: X1, ey: Y1, ez: Z1 } = this;
            const { ex: X2, ey: Y2, ez: Z2 } = other;
            const X1Z2 = modP(X1 * Z2);
            const X2Z1 = modP(X2 * Z1);
            const Y1Z2 = modP(Y1 * Z2);
            const Y2Z1 = modP(Y2 * Z1);
            return X1Z2 === X2Z1 && Y1Z2 === Y2Z1;
        }
        is0() {
            return this.equals(Point.ZERO);
        }
        negate() {
            // Flips point sign to a negative one (-x, y in affine coords)
            return new Point(modP(-this.ex), this.ey, this.ez, modP(-this.et));
        }
        // Fast algo for doubling Extended Point.
        // https://hyperelliptic.org/EFD/g1p/auto-twisted-extended.html#doubling-dbl-2008-hwcd
        // Cost: 4M + 4S + 1*a + 6add + 1*2.
        double() {
            const { a } = CURVE;
            const { ex: X1, ey: Y1, ez: Z1 } = this;
            const A = modP(X1 * X1); // A = X12
            const B = modP(Y1 * Y1); // B = Y12
            const C = modP(_2n$3 * modP(Z1 * Z1)); // C = 2*Z12
            const D = modP(a * A); // D = a*A
            const x1y1 = X1 + Y1;
            const E = modP(modP(x1y1 * x1y1) - A - B); // E = (X1+Y1)2-A-B
            const G = D + B; // G = D+B
            const F = G - C; // F = G-C
            const H = D - B; // H = D-B
            const X3 = modP(E * F); // X3 = E*F
            const Y3 = modP(G * H); // Y3 = G*H
            const T3 = modP(E * H); // T3 = E*H
            const Z3 = modP(F * G); // Z3 = F*G
            return new Point(X3, Y3, Z3, T3);
        }
        // Fast algo for adding 2 Extended Points.
        // https://hyperelliptic.org/EFD/g1p/auto-twisted-extended.html#addition-add-2008-hwcd
        // Cost: 9M + 1*a + 1*d + 7add.
        add(other) {
            isPoint(other);
            const { a, d } = CURVE;
            const { ex: X1, ey: Y1, ez: Z1, et: T1 } = this;
            const { ex: X2, ey: Y2, ez: Z2, et: T2 } = other;
            // Faster algo for adding 2 Extended Points when curve's a=-1.
            // http://hyperelliptic.org/EFD/g1p/auto-twisted-extended-1.html#addition-add-2008-hwcd-4
            // Cost: 8M + 8add + 2*2.
            // Note: It does not check whether the `other` point is valid.
            if (a === BigInt(-1)) {
                const A = modP((Y1 - X1) * (Y2 + X2));
                const B = modP((Y1 + X1) * (Y2 - X2));
                const F = modP(B - A);
                if (F === _0n$2)
                    return this.double(); // Same point. Tests say it doesn't affect timing
                const C = modP(Z1 * _2n$3 * T2);
                const D = modP(T1 * _2n$3 * Z2);
                const E = D + C;
                const G = B + A;
                const H = D - C;
                const X3 = modP(E * F);
                const Y3 = modP(G * H);
                const T3 = modP(E * H);
                const Z3 = modP(F * G);
                return new Point(X3, Y3, Z3, T3);
            }
            const A = modP(X1 * X2); // A = X1*X2
            const B = modP(Y1 * Y2); // B = Y1*Y2
            const C = modP(T1 * d * T2); // C = T1*d*T2
            const D = modP(Z1 * Z2); // D = Z1*Z2
            const E = modP((X1 + Y1) * (X2 + Y2) - A - B); // E = (X1+Y1)*(X2+Y2)-A-B
            const F = D - C; // F = D-C
            const G = D + C; // G = D+C
            const H = modP(B - a * A); // H = B-a*A
            const X3 = modP(E * F); // X3 = E*F
            const Y3 = modP(G * H); // Y3 = G*H
            const T3 = modP(E * H); // T3 = E*H
            const Z3 = modP(F * G); // Z3 = F*G
            return new Point(X3, Y3, Z3, T3);
        }
        subtract(other) {
            return this.add(other.negate());
        }
        wNAF(n) {
            return wnaf.wNAFCached(this, pointPrecomputes, n, Point.normalizeZ);
        }
        // Constant-time multiplication.
        multiply(scalar) {
            const { p, f } = this.wNAF(assertInRange(scalar, CURVE_ORDER));
            return Point.normalizeZ([p, f])[0];
        }
        // Non-constant-time multiplication. Uses double-and-add algorithm.
        // It's faster, but should only be used when you don't care about
        // an exposed private key e.g. sig verification.
        // Does NOT allow scalars higher than CURVE.n.
        multiplyUnsafe(scalar) {
            let n = assertGE0(scalar); // 0 <= scalar < CURVE.n
            if (n === _0n$2)
                return I;
            if (this.equals(I) || n === _1n$4)
                return this;
            if (this.equals(G))
                return this.wNAF(n).p;
            return wnaf.unsafeLadder(this, n);
        }
        // Checks if point is of small order.
        // If you add something to small order point, you will have "dirty"
        // point with torsion component.
        // Multiplies point by cofactor and checks if the result is 0.
        isSmallOrder() {
            return this.multiplyUnsafe(cofactor).is0();
        }
        // Multiplies point by curve order and checks if the result is 0.
        // Returns `false` is the point is dirty.
        isTorsionFree() {
            return wnaf.unsafeLadder(this, CURVE_ORDER).is0();
        }
        // Converts Extended point to default (x, y) coordinates.
        // Can accept precomputed Z^-1 - for example, from invertBatch.
        toAffine(iz) {
            const { ex: x, ey: y, ez: z } = this;
            const is0 = this.is0();
            if (iz == null)
                iz = is0 ? _8n$1 : Fp.inv(z); // 8 was chosen arbitrarily
            const ax = modP(x * iz);
            const ay = modP(y * iz);
            const zz = modP(z * iz);
            if (is0)
                return { x: _0n$2, y: _1n$4 };
            if (zz !== _1n$4)
                throw new Error('invZ was invalid');
            return { x: ax, y: ay };
        }
        clearCofactor() {
            const { h: cofactor } = CURVE;
            if (cofactor === _1n$4)
                return this;
            return this.multiplyUnsafe(cofactor);
        }
        // Converts hash string or Uint8Array to Point.
        // Uses algo from RFC8032 5.1.3.
        static fromHex(hex, zip215 = false) {
            const { d, a } = CURVE;
            const len = Fp.BYTES;
            hex = ensureBytes('pointHex', hex, len); // copy hex to a new array
            const normed = hex.slice(); // copy again, we'll manipulate it
            const lastByte = hex[len - 1]; // select last byte
            normed[len - 1] = lastByte & ~0x80; // clear last bit
            const y = bytesToNumberLE(normed);
            if (y === _0n$2) ;
            else {
                // RFC8032 prohibits >= p, but ZIP215 doesn't
                if (zip215)
                    assertInRange(y, MASK); // zip215=true [1..P-1] (2^255-19-1 for ed25519)
                else
                    assertInRange(y, Fp.ORDER); // zip215=false [1..MASK-1] (2^256-1 for ed25519)
            }
            // Ed25519: x² = (y²-1)/(dy²+1) mod p. Ed448: x² = (y²-1)/(dy²-1) mod p. Generic case:
            // ax²+y²=1+dx²y² => y²-1=dx²y²-ax² => y²-1=x²(dy²-a) => x²=(y²-1)/(dy²-a)
            const y2 = modP(y * y); // denominator is always non-0 mod p.
            const u = modP(y2 - _1n$4); // u = y² - 1
            const v = modP(d * y2 - a); // v = d y² + 1.
            let { isValid, value: x } = uvRatio(u, v); // √(u/v)
            if (!isValid)
                throw new Error('Point.fromHex: invalid y coordinate');
            const isXOdd = (x & _1n$4) === _1n$4; // There are 2 square roots. Use x_0 bit to select proper
            const isLastByteOdd = (lastByte & 0x80) !== 0; // x_0, last bit
            if (!zip215 && x === _0n$2 && isLastByteOdd)
                // if x=0 and x_0 = 1, fail
                throw new Error('Point.fromHex: x=0 and x_0=1');
            if (isLastByteOdd !== isXOdd)
                x = modP(-x); // if x_0 != x mod 2, set x = p-x
            return Point.fromAffine({ x, y });
        }
        static fromPrivateKey(privKey) {
            return getExtendedPublicKey(privKey).point;
        }
        toRawBytes() {
            const { x, y } = this.toAffine();
            const bytes = numberToBytesLE(y, Fp.BYTES); // each y has 2 x values (x, -y)
            bytes[bytes.length - 1] |= x & _1n$4 ? 0x80 : 0; // when compressing, it's enough to store y
            return bytes; // and use the last byte to encode sign of x
        }
        toHex() {
            return bytesToHex$1(this.toRawBytes()); // Same as toRawBytes, but returns string.
        }
    }
    Point.BASE = new Point(CURVE.Gx, CURVE.Gy, _1n$4, modP(CURVE.Gx * CURVE.Gy));
    Point.ZERO = new Point(_0n$2, _1n$4, _1n$4, _0n$2); // 0, 1, 1, 0
    const { BASE: G, ZERO: I } = Point;
    const wnaf = wNAF(Point, nByteLength * 8);
    function modN(a) {
        return mod(a, CURVE_ORDER);
    }
    // Little-endian SHA512 with modulo n
    function modN_LE(hash) {
        return modN(bytesToNumberLE(hash));
    }
    /** Convenience method that creates public key and other stuff. RFC8032 5.1.5 */
    function getExtendedPublicKey(key) {
        const len = nByteLength;
        key = ensureBytes('private key', key, len);
        // Hash private key with curve's hash function to produce uniformingly random input
        // Check byte lengths: ensure(64, h(ensure(32, key)))
        const hashed = ensureBytes('hashed private key', cHash(key), 2 * len);
        const head = adjustScalarBytes(hashed.slice(0, len)); // clear first half bits, produce FE
        const prefix = hashed.slice(len, 2 * len); // second half is called key prefix (5.1.6)
        const scalar = modN_LE(head); // The actual private scalar
        const point = G.multiply(scalar); // Point on Edwards curve aka public key
        const pointBytes = point.toRawBytes(); // Uint8Array representation
        return { head, prefix, scalar, point, pointBytes };
    }
    // Calculates EdDSA pub key. RFC8032 5.1.5. Privkey is hashed. Use first half with 3 bits cleared
    function getPublicKey(privKey) {
        return getExtendedPublicKey(privKey).pointBytes;
    }
    // int('LE', SHA512(dom2(F, C) || msgs)) mod N
    function hashDomainToScalar(context = new Uint8Array(), ...msgs) {
        const msg = concatBytes(...msgs);
        return modN_LE(cHash(domain(msg, ensureBytes('context', context), !!prehash)));
    }
    /** Signs message with privateKey. RFC8032 5.1.6 */
    function sign(msg, privKey, options = {}) {
        msg = ensureBytes('message', msg);
        if (prehash)
            msg = prehash(msg); // for ed25519ph etc.
        const { prefix, scalar, pointBytes } = getExtendedPublicKey(privKey);
        const r = hashDomainToScalar(options.context, prefix, msg); // r = dom2(F, C) || prefix || PH(M)
        const R = G.multiply(r).toRawBytes(); // R = rG
        const k = hashDomainToScalar(options.context, R, pointBytes, msg); // R || A || PH(M)
        const s = modN(r + k * scalar); // S = (r + k * s) mod L
        assertGE0(s); // 0 <= s < l
        const res = concatBytes(R, numberToBytesLE(s, Fp.BYTES));
        return ensureBytes('result', res, nByteLength * 2); // 64-byte signature
    }
    const verifyOpts = VERIFY_DEFAULT;
    function verify(sig, msg, publicKey, options = verifyOpts) {
        const { context, zip215 } = options;
        const len = Fp.BYTES; // Verifies EdDSA signature against message and public key. RFC8032 5.1.7.
        sig = ensureBytes('signature', sig, 2 * len); // An extended group equation is checked.
        msg = ensureBytes('message', msg);
        if (prehash)
            msg = prehash(msg); // for ed25519ph, etc
        const s = bytesToNumberLE(sig.slice(len, 2 * len));
        // zip215: true is good for consensus-critical apps and allows points < 2^256
        // zip215: false follows RFC8032 / NIST186-5 and restricts points to CURVE.p
        let A, R, SB;
        try {
            A = Point.fromHex(publicKey, zip215);
            R = Point.fromHex(sig.slice(0, len), zip215);
            SB = G.multiplyUnsafe(s); // 0 <= s < l is done inside
        }
        catch (error) {
            return false;
        }
        if (!zip215 && A.isSmallOrder())
            return false;
        const k = hashDomainToScalar(context, R.toRawBytes(), A.toRawBytes(), msg);
        const RkA = R.add(A.multiplyUnsafe(k));
        // [8][S]B = [8]R + [8][k]A'
        return RkA.subtract(SB).clearCofactor().equals(Point.ZERO);
    }
    G._setWindowSize(8); // Enable precomputes. Slows down first publicKey computation by 20ms.
    const utils = {
        getExtendedPublicKey,
        // ed25519 private keys are uniform 32b. No need to check for modulo bias, like in secp256k1.
        randomPrivateKey: () => randomBytes(Fp.BYTES),
        /**
         * We're doing scalar multiplication (used in getPublicKey etc) with precomputed BASE_POINT
         * values. This slows down first getPublicKey() by milliseconds (see Speed section),
         * but allows to speed-up subsequent getPublicKey() calls up to 20x.
         * @param windowSize 2, 4, 8, 16
         */
        precompute(windowSize = 8, point = Point.BASE) {
            point._setWindowSize(windowSize);
            point.multiply(BigInt(3));
            return point;
        },
    };
    return {
        CURVE,
        getPublicKey,
        sign,
        verify,
        ExtendedPoint: Point,
        utils,
    };
}

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
/**
 * ed25519 Twisted Edwards curve with following addons:
 * - X25519 ECDH
 * - Ristretto cofactor elimination
 * - Elligator hash-to-group / point indistinguishability
 */
const ED25519_P = BigInt('57896044618658097711785492504343953926634992332820282019728792003956564819949');
// √(-1) aka √(a) aka 2^((p-1)/4)
const ED25519_SQRT_M1 = /* @__PURE__ */ BigInt('19681161376707505956807079304988542015446066515923890162744021073123829784752');
// prettier-ignore
BigInt(0); const _1n$3 = BigInt(1), _2n$2 = BigInt(2); BigInt(3);
// prettier-ignore
const _5n = BigInt(5), _8n = BigInt(8);
function ed25519_pow_2_252_3(x) {
    // prettier-ignore
    const _10n = BigInt(10), _20n = BigInt(20), _40n = BigInt(40), _80n = BigInt(80);
    const P = ED25519_P;
    const x2 = (x * x) % P;
    const b2 = (x2 * x) % P; // x^3, 11
    const b4 = (pow2(b2, _2n$2, P) * b2) % P; // x^15, 1111
    const b5 = (pow2(b4, _1n$3, P) * x) % P; // x^31
    const b10 = (pow2(b5, _5n, P) * b5) % P;
    const b20 = (pow2(b10, _10n, P) * b10) % P;
    const b40 = (pow2(b20, _20n, P) * b20) % P;
    const b80 = (pow2(b40, _40n, P) * b40) % P;
    const b160 = (pow2(b80, _80n, P) * b80) % P;
    const b240 = (pow2(b160, _80n, P) * b80) % P;
    const b250 = (pow2(b240, _10n, P) * b10) % P;
    const pow_p_5_8 = (pow2(b250, _2n$2, P) * x) % P;
    // ^ To pow to (p+3)/8, multiply it by x.
    return { pow_p_5_8, b2 };
}
function adjustScalarBytes(bytes) {
    // Section 5: For X25519, in order to decode 32 random bytes as an integer scalar,
    // set the three least significant bits of the first byte
    bytes[0] &= 248; // 0b1111_1000
    // and the most significant bit of the last to zero,
    bytes[31] &= 127; // 0b0111_1111
    // set the second most significant bit of the last byte to 1
    bytes[31] |= 64; // 0b0100_0000
    return bytes;
}
// sqrt(u/v)
function uvRatio(u, v) {
    const P = ED25519_P;
    const v3 = mod(v * v * v, P); // v³
    const v7 = mod(v3 * v3 * v, P); // v⁷
    // (p+3)/8 and (p-5)/8
    const pow = ed25519_pow_2_252_3(u * v7).pow_p_5_8;
    let x = mod(u * v3 * pow, P); // (uv³)(uv⁷)^(p-5)/8
    const vx2 = mod(v * x * x, P); // vx²
    const root1 = x; // First root candidate
    const root2 = mod(x * ED25519_SQRT_M1, P); // Second root candidate
    const useRoot1 = vx2 === u; // If vx² = u (mod p), x is a square root
    const useRoot2 = vx2 === mod(-u, P); // If vx² = -u, set x <-- x * 2^((p-1)/4)
    const noRoot = vx2 === mod(-u * ED25519_SQRT_M1, P); // There is no valid root, vx² = -u√(-1)
    if (useRoot1)
        x = root1;
    if (useRoot2 || noRoot)
        x = root2; // We return root2 anyway, for const-time
    if (isNegativeLE(x, P))
        x = mod(-x, P);
    return { isValid: useRoot1 || useRoot2, value: x };
}
const Fp$2 = /* @__PURE__ */ (() => Field(ED25519_P, undefined, true))();
const ed25519Defaults = /* @__PURE__ */ (() => ({
    // Param: a
    a: BigInt(-1), // Fp.create(-1) is proper; our way still works and is faster
    // d is equal to -121665/121666 over finite field.
    // Negative number is P - number, and division is invert(number, P)
    d: BigInt('37095705934669439343138083508754565189542113879843219016388785533085940283555'),
    // Finite field 𝔽p over which we'll do calculations; 2n**255n - 19n
    Fp: Fp$2,
    // Subgroup order: how many points curve has
    // 2n**252n + 27742317777372353535851937790883648493n;
    n: BigInt('7237005577332262213973186563042994240857116359379907606001950938285454250989'),
    // Cofactor
    h: _8n,
    // Base point (x, y) aka generator point
    Gx: BigInt('15112221349535400772501151409588531511454012693041857206046113283949847762202'),
    Gy: BigInt('46316835694926478169428394003475163141307993866256225615783033603165251855960'),
    hash: sha512,
    randomBytes: randomBytes$1,
    adjustScalarBytes,
    // dom2
    // Ratio of u to v. Allows us to combine inversion and square root. Uses algo from RFC8032 5.1.3.
    // Constant-time, u/√v
    uvRatio,
}))();
const ed25519 = /* @__PURE__ */ (() => twistedEdwards(ed25519Defaults))();

function createCommonjsModule(fn) {
  var module = { exports: {} };
	return fn(module, module.exports), module.exports;
}

// base-x encoding / decoding
// Copyright (c) 2018 base-x contributors
// Copyright (c) 2014-2018 The Bitcoin Core developers (base58.cpp)
// Distributed under the MIT software license, see the accompanying
// file LICENSE or http://www.opensource.org/licenses/mit-license.php.
function base$1 (ALPHABET) {
  if (ALPHABET.length >= 255) { throw new TypeError('Alphabet too long') }
  var BASE_MAP = new Uint8Array(256);
  for (var j = 0; j < BASE_MAP.length; j++) {
    BASE_MAP[j] = 255;
  }
  for (var i = 0; i < ALPHABET.length; i++) {
    var x = ALPHABET.charAt(i);
    var xc = x.charCodeAt(0);
    if (BASE_MAP[xc] !== 255) { throw new TypeError(x + ' is ambiguous') }
    BASE_MAP[xc] = i;
  }
  var BASE = ALPHABET.length;
  var LEADER = ALPHABET.charAt(0);
  var FACTOR = Math.log(BASE) / Math.log(256); // log(BASE) / log(256), rounded up
  var iFACTOR = Math.log(256) / Math.log(BASE); // log(256) / log(BASE), rounded up
  function encode (source) {
    if (source instanceof Uint8Array) ; else if (ArrayBuffer.isView(source)) {
      source = new Uint8Array(source.buffer, source.byteOffset, source.byteLength);
    } else if (Array.isArray(source)) {
      source = Uint8Array.from(source);
    }
    if (!(source instanceof Uint8Array)) { throw new TypeError('Expected Uint8Array') }
    if (source.length === 0) { return '' }
        // Skip & count leading zeroes.
    var zeroes = 0;
    var length = 0;
    var pbegin = 0;
    var pend = source.length;
    while (pbegin !== pend && source[pbegin] === 0) {
      pbegin++;
      zeroes++;
    }
        // Allocate enough space in big-endian base58 representation.
    var size = ((pend - pbegin) * iFACTOR + 1) >>> 0;
    var b58 = new Uint8Array(size);
        // Process the bytes.
    while (pbegin !== pend) {
      var carry = source[pbegin];
            // Apply "b58 = b58 * 256 + ch".
      var i = 0;
      for (var it1 = size - 1; (carry !== 0 || i < length) && (it1 !== -1); it1--, i++) {
        carry += (256 * b58[it1]) >>> 0;
        b58[it1] = (carry % BASE) >>> 0;
        carry = (carry / BASE) >>> 0;
      }
      if (carry !== 0) { throw new Error('Non-zero carry') }
      length = i;
      pbegin++;
    }
        // Skip leading zeroes in base58 result.
    var it2 = size - length;
    while (it2 !== size && b58[it2] === 0) {
      it2++;
    }
        // Translate the result into a string.
    var str = LEADER.repeat(zeroes);
    for (; it2 < size; ++it2) { str += ALPHABET.charAt(b58[it2]); }
    return str
  }
  function decodeUnsafe (source) {
    if (typeof source !== 'string') { throw new TypeError('Expected String') }
    if (source.length === 0) { return new Uint8Array() }
    var psz = 0;
        // Skip leading spaces.
    if (source[psz] === ' ') { return }
        // Skip and count leading '1's.
    var zeroes = 0;
    var length = 0;
    while (source[psz] === LEADER) {
      zeroes++;
      psz++;
    }
        // Allocate enough space in big-endian base256 representation.
    var size = (((source.length - psz) * FACTOR) + 1) >>> 0; // log(58) / log(256), rounded up.
    var b256 = new Uint8Array(size);
        // Process the characters.
    while (source[psz]) {
            // Decode character
      var carry = BASE_MAP[source.charCodeAt(psz)];
            // Invalid character
      if (carry === 255) { return }
      var i = 0;
      for (var it3 = size - 1; (carry !== 0 || i < length) && (it3 !== -1); it3--, i++) {
        carry += (BASE * b256[it3]) >>> 0;
        b256[it3] = (carry % 256) >>> 0;
        carry = (carry / 256) >>> 0;
      }
      if (carry !== 0) { throw new Error('Non-zero carry') }
      length = i;
      psz++;
    }
        // Skip trailing spaces.
    if (source[psz] === ' ') { return }
        // Skip leading zeroes in b256.
    var it4 = size - length;
    while (it4 !== size && b256[it4] === 0) {
      it4++;
    }
    var vch = new Uint8Array(zeroes + (size - it4));
    var j = zeroes;
    while (it4 !== size) {
      vch[j++] = b256[it4++];
    }
    return vch
  }
  function decode (string) {
    var buffer = decodeUnsafe(string);
    if (buffer) { return buffer }
    throw new Error('Non-base' + BASE + ' character')
  }
  return {
    encode: encode,
    decodeUnsafe: decodeUnsafe,
    decode: decode
  }
}
var src$1 = base$1;

const textDecoder = new TextDecoder();
/**
 * @param {ArrayBufferView|ArrayBuffer} bytes
 * @returns {string}
 */
const decodeText$1 = (bytes) => textDecoder.decode(bytes);

const textEncoder = new TextEncoder();
/**
 * @param {string} text
 * @returns {Uint8Array}
 */
const encodeText$2 = (text) => textEncoder.encode(text);

/**
 * Returns a new Uint8Array created by concatenating the passed Arrays
 *
 * @param {Array<ArrayLike<number>>} arrs
 * @param {number} length
 * @returns {Uint8Array}
 */
function concat (arrs, length) {
  const output = new Uint8Array(length);
  let offset = 0;

  for (const arr of arrs) {
    output.set(arr, offset);
    offset += arr.length;
  }

  return output
}

var util = { decodeText: decodeText$1, encodeText: encodeText$2, concat };

const { encodeText: encodeText$1 } = util;

/** @typedef {import('./types').CodecFactory} CodecFactory */
/** @typedef {import("./types").BaseName} BaseName */
/** @typedef {import("./types").BaseCode} BaseCode */

/**
 * Class to encode/decode in the supported Bases
 *
 */
class Base {
  /**
   * @param {BaseName} name
   * @param {BaseCode} code
   * @param {CodecFactory} factory
   * @param {string} alphabet
   */
  constructor (name, code, factory, alphabet) {
    this.name = name;
    this.code = code;
    this.codeBuf = encodeText$1(this.code);
    this.alphabet = alphabet;
    this.codec = factory(alphabet);
  }

  /**
   * @param {Uint8Array} buf
   * @returns {string}
   */
  encode (buf) {
    return this.codec.encode(buf)
  }

  /**
   * @param {string} string
   * @returns {Uint8Array}
   */
  decode (string) {
    for (const char of string) {
      if (this.alphabet && this.alphabet.indexOf(char) < 0) {
        throw new Error(`invalid character '${char}' in '${string}'`)
      }
    }
    return this.codec.decode(string)
  }
}

var base = Base;

/** @typedef {import('./types').CodecFactory} CodecFactory */

/**
 * @param {string} string
 * @param {string} alphabet
 * @param {number} bitsPerChar
 * @returns {Uint8Array}
 */
const decode = (string, alphabet, bitsPerChar) => {
  // Build the character lookup table:
  /** @type {Record<string, number>} */
  const codes = {};
  for (let i = 0; i < alphabet.length; ++i) {
    codes[alphabet[i]] = i;
  }

  // Count the padding bytes:
  let end = string.length;
  while (string[end - 1] === '=') {
    --end;
  }

  // Allocate the output:
  const out = new Uint8Array((end * bitsPerChar / 8) | 0);

  // Parse the data:
  let bits = 0; // Number of bits currently in the buffer
  let buffer = 0; // Bits waiting to be written out, MSB first
  let written = 0; // Next byte to write
  for (let i = 0; i < end; ++i) {
    // Read one character from the string:
    const value = codes[string[i]];
    if (value === undefined) {
      throw new SyntaxError('Invalid character ' + string[i])
    }

    // Append the bits to the buffer:
    buffer = (buffer << bitsPerChar) | value;
    bits += bitsPerChar;

    // Write out some bits if the buffer has a byte's worth:
    if (bits >= 8) {
      bits -= 8;
      out[written++] = 0xff & (buffer >> bits);
    }
  }

  // Verify that we have received just enough bits:
  if (bits >= bitsPerChar || 0xff & (buffer << (8 - bits))) {
    throw new SyntaxError('Unexpected end of data')
  }

  return out
};

/**
 * @param {Uint8Array} data
 * @param {string} alphabet
 * @param {number} bitsPerChar
 * @returns {string}
 */
const encode = (data, alphabet, bitsPerChar) => {
  const pad = alphabet[alphabet.length - 1] === '=';
  const mask = (1 << bitsPerChar) - 1;
  let out = '';

  let bits = 0; // Number of bits currently in the buffer
  let buffer = 0; // Bits waiting to be written out, MSB first
  for (let i = 0; i < data.length; ++i) {
    // Slurp data into the buffer:
    buffer = (buffer << 8) | data[i];
    bits += 8;

    // Write out as much as we can:
    while (bits > bitsPerChar) {
      bits -= bitsPerChar;
      out += alphabet[mask & (buffer >> bits)];
    }
  }

  // Partial character:
  if (bits) {
    out += alphabet[mask & (buffer << (bitsPerChar - bits))];
  }

  // Add padding characters until we hit a byte boundary:
  if (pad) {
    while ((out.length * bitsPerChar) & 7) {
      out += '=';
    }
  }

  return out
};

/**
 * RFC4648 Factory
 *
 * @param {number} bitsPerChar
 * @returns {CodecFactory}
 */
const rfc4648$1 = (bitsPerChar) => (alphabet) => {
  return {
    /**
     * @param {Uint8Array} input
     * @returns {string}
     */
    encode (input) {
      return encode(input, alphabet, bitsPerChar)
    },
    /**
     * @param {string} input
     * @returns {Uint8Array}
     */
    decode (input) {
      return decode(input, alphabet, bitsPerChar)
    }
  }
};

var rfc4648_1 = { rfc4648: rfc4648$1 };

const { rfc4648 } = rfc4648_1;
const { decodeText, encodeText } = util;

/** @typedef {import('./types').CodecFactory} CodecFactory */
/** @typedef {import('./types').Codec} Codec */
/** @typedef {import('./types').BaseName} BaseName */
/** @typedef {import('./types').BaseCode} BaseCode */

/** @type {CodecFactory} */
const identity = () => {
  return {
    encode: decodeText,
    decode: encodeText
  }
};

/**
 *
 * name, code, implementation, alphabet
 *
 * @type {Array<[BaseName, BaseCode, CodecFactory, string]>}
 */
const constants = [
  ['identity', '\x00', identity, ''],
  ['base2', '0', rfc4648(1), '01'],
  ['base8', '7', rfc4648(3), '01234567'],
  ['base10', '9', src$1, '0123456789'],
  ['base16', 'f', rfc4648(4), '0123456789abcdef'],
  ['base16upper', 'F', rfc4648(4), '0123456789ABCDEF'],
  ['base32hex', 'v', rfc4648(5), '0123456789abcdefghijklmnopqrstuv'],
  ['base32hexupper', 'V', rfc4648(5), '0123456789ABCDEFGHIJKLMNOPQRSTUV'],
  ['base32hexpad', 't', rfc4648(5), '0123456789abcdefghijklmnopqrstuv='],
  ['base32hexpadupper', 'T', rfc4648(5), '0123456789ABCDEFGHIJKLMNOPQRSTUV='],
  ['base32', 'b', rfc4648(5), 'abcdefghijklmnopqrstuvwxyz234567'],
  ['base32upper', 'B', rfc4648(5), 'ABCDEFGHIJKLMNOPQRSTUVWXYZ234567'],
  ['base32pad', 'c', rfc4648(5), 'abcdefghijklmnopqrstuvwxyz234567='],
  ['base32padupper', 'C', rfc4648(5), 'ABCDEFGHIJKLMNOPQRSTUVWXYZ234567='],
  ['base32z', 'h', rfc4648(5), 'ybndrfg8ejkmcpqxot1uwisza345h769'],
  ['base36', 'k', src$1, '0123456789abcdefghijklmnopqrstuvwxyz'],
  ['base36upper', 'K', src$1, '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'],
  ['base58btc', 'z', src$1, '123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz'],
  ['base58flickr', 'Z', src$1, '123456789abcdefghijkmnopqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ'],
  ['base64', 'm', rfc4648(6), 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'],
  ['base64pad', 'M', rfc4648(6), 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/='],
  ['base64url', 'u', rfc4648(6), 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_'],
  ['base64urlpad', 'U', rfc4648(6), 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_=']
];

/** @type {Record<BaseName,Base>} */
const names = constants.reduce((prev, tupple) => {
  prev[tupple[0]] = new base(tupple[0], tupple[1], tupple[2], tupple[3]);
  return prev
}, /** @type {Record<BaseName,Base>} */({}));

/** @type {Record<BaseCode,Base>} */
const codes = constants.reduce((prev, tupple) => {
  prev[tupple[1]] = names[tupple[0]];
  return prev
}, /** @type {Record<BaseCode,Base>} */({}));

var constants_1 = {
  names,
  codes
};

/**
 * Implementation of the [multibase](https://github.com/multiformats/multibase) specification.
 *
 */

var src = createCommonjsModule(function (module, exports) {


const { encodeText, decodeText, concat } = util;

/** @typedef {import('./base')} Base */
/** @typedef {import("./types").BaseNameOrCode} BaseNameOrCode */
/** @typedef {import("./types").BaseCode} BaseCode */
/** @typedef {import("./types").BaseName} BaseName */

/**
 * Create a new Uint8Array with the multibase varint+code.
 *
 * @param {BaseNameOrCode} nameOrCode - The multibase name or code number.
 * @param {Uint8Array} buf - The data to be prefixed with multibase.
 * @returns {Uint8Array}
 * @throws {Error} Will throw if the encoding is not supported
 */
function multibase (nameOrCode, buf) {
  if (!buf) {
    throw new Error('requires an encoded Uint8Array')
  }
  const { name, codeBuf } = encoding(nameOrCode);
  validEncode(name, buf);

  return concat([codeBuf, buf], codeBuf.length + buf.length)
}

/**
 * Encode data with the specified base and add the multibase prefix.
 *
 * @param {BaseNameOrCode} nameOrCode - The multibase name or code number.
 * @param {Uint8Array} buf - The data to be encoded.
 * @returns {Uint8Array}
 * @throws {Error} Will throw if the encoding is not supported
 *
 */
function encode (nameOrCode, buf) {
  const enc = encoding(nameOrCode);
  const data = encodeText(enc.encode(buf));

  return concat([enc.codeBuf, data], enc.codeBuf.length + data.length)
}

/**
 * Takes a Uint8Array or string encoded with multibase header, decodes it and
 * returns the decoded buffer
 *
 * @param {Uint8Array|string} data
 * @returns {Uint8Array}
 * @throws {Error} Will throw if the encoding is not supported
 *
 */
function decode (data) {
  if (data instanceof Uint8Array) {
    data = decodeText(data);
  }
  const prefix = data[0];

  // Make all encodings case-insensitive except the ones that include upper and lower chars in the alphabet
  if (['f', 'F', 'v', 'V', 't', 'T', 'b', 'B', 'c', 'C', 'h', 'k', 'K'].includes(prefix)) {
    data = data.toLowerCase();
  }
  const enc = encoding(/** @type {BaseCode} */(data[0]));
  return enc.decode(data.substring(1))
}

/**
 * Is the given data multibase encoded?
 *
 * @param {Uint8Array|string} data
 */
function isEncoded (data) {
  if (data instanceof Uint8Array) {
    data = decodeText(data);
  }

  // Ensure bufOrString is a string
  if (Object.prototype.toString.call(data) !== '[object String]') {
    return false
  }

  try {
    const enc = encoding(/** @type {BaseCode} */(data[0]));
    return enc.name
  } catch (err) {
    return false
  }
}

/**
 * Validate encoded data
 *
 * @param {BaseNameOrCode} name
 * @param {Uint8Array} buf
 * @returns {void}
 * @throws {Error} Will throw if the encoding is not supported
 */
function validEncode (name, buf) {
  const enc = encoding(name);
  enc.decode(decodeText(buf));
}

/**
 * Get the encoding by name or code
 *
 * @param {BaseNameOrCode} nameOrCode
 * @returns {Base}
 * @throws {Error} Will throw if the encoding is not supported
 */
function encoding (nameOrCode) {
  if (Object.prototype.hasOwnProperty.call(constants_1.names, /** @type {BaseName} */(nameOrCode))) {
    return constants_1.names[/** @type {BaseName} */(nameOrCode)]
  } else if (Object.prototype.hasOwnProperty.call(constants_1.codes, /** @type {BaseCode} */(nameOrCode))) {
    return constants_1.codes[/** @type {BaseCode} */(nameOrCode)]
  } else {
    throw new Error(`Unsupported encoding: ${nameOrCode}`)
  }
}

/**
 * Get encoding from data
 *
 * @param {string|Uint8Array} data
 * @returns {Base}
 * @throws {Error} Will throw if the encoding is not supported
 */
function encodingFromData (data) {
  if (data instanceof Uint8Array) {
    data = decodeText(data);
  }

  return encoding(/** @type {BaseCode} */(data[0]))
}

exports = module.exports = multibase;
exports.encode = encode;
exports.decode = decode;
exports.isEncoded = isEncoded;
exports.encoding = encoding;
exports.encodingFromData = encodingFromData;
const names = Object.freeze(constants_1.names);
const codes = Object.freeze(constants_1.codes);
exports.names = names;
exports.codes = codes;
});

// SHA2-256 need to try 2^128 hashes to execute birthday attack.
// BTC network is doing 2^67 hashes/sec as per early 2023.
// Round constants:
// first 32 bits of the fractional parts of the cube roots of the first 64 primes 2..311)
// prettier-ignore
const SHA256_K = /* @__PURE__ */ new Uint32Array([
    0x428a2f98, 0x71374491, 0xb5c0fbcf, 0xe9b5dba5, 0x3956c25b, 0x59f111f1, 0x923f82a4, 0xab1c5ed5,
    0xd807aa98, 0x12835b01, 0x243185be, 0x550c7dc3, 0x72be5d74, 0x80deb1fe, 0x9bdc06a7, 0xc19bf174,
    0xe49b69c1, 0xefbe4786, 0x0fc19dc6, 0x240ca1cc, 0x2de92c6f, 0x4a7484aa, 0x5cb0a9dc, 0x76f988da,
    0x983e5152, 0xa831c66d, 0xb00327c8, 0xbf597fc7, 0xc6e00bf3, 0xd5a79147, 0x06ca6351, 0x14292967,
    0x27b70a85, 0x2e1b2138, 0x4d2c6dfc, 0x53380d13, 0x650a7354, 0x766a0abb, 0x81c2c92e, 0x92722c85,
    0xa2bfe8a1, 0xa81a664b, 0xc24b8b70, 0xc76c51a3, 0xd192e819, 0xd6990624, 0xf40e3585, 0x106aa070,
    0x19a4c116, 0x1e376c08, 0x2748774c, 0x34b0bcb5, 0x391c0cb3, 0x4ed8aa4a, 0x5b9cca4f, 0x682e6ff3,
    0x748f82ee, 0x78a5636f, 0x84c87814, 0x8cc70208, 0x90befffa, 0xa4506ceb, 0xbef9a3f7, 0xc67178f2
]);
// Initial state:
// first 32 bits of the fractional parts of the square roots of the first 8 primes 2..19
// prettier-ignore
const SHA256_IV = /* @__PURE__ */ new Uint32Array([
    0x6a09e667, 0xbb67ae85, 0x3c6ef372, 0xa54ff53a, 0x510e527f, 0x9b05688c, 0x1f83d9ab, 0x5be0cd19
]);
// Temporary buffer, not used to store anything between runs
// Named this way because it matches specification.
const SHA256_W = /* @__PURE__ */ new Uint32Array(64);
class SHA256 extends HashMD {
    constructor() {
        super(64, 32, 8, false);
        // We cannot use array here since array allows indexing by variable
        // which means optimizer/compiler cannot use registers.
        this.A = SHA256_IV[0] | 0;
        this.B = SHA256_IV[1] | 0;
        this.C = SHA256_IV[2] | 0;
        this.D = SHA256_IV[3] | 0;
        this.E = SHA256_IV[4] | 0;
        this.F = SHA256_IV[5] | 0;
        this.G = SHA256_IV[6] | 0;
        this.H = SHA256_IV[7] | 0;
    }
    get() {
        const { A, B, C, D, E, F, G, H } = this;
        return [A, B, C, D, E, F, G, H];
    }
    // prettier-ignore
    set(A, B, C, D, E, F, G, H) {
        this.A = A | 0;
        this.B = B | 0;
        this.C = C | 0;
        this.D = D | 0;
        this.E = E | 0;
        this.F = F | 0;
        this.G = G | 0;
        this.H = H | 0;
    }
    process(view, offset) {
        // Extend the first 16 words into the remaining 48 words w[16..63] of the message schedule array
        for (let i = 0; i < 16; i++, offset += 4)
            SHA256_W[i] = view.getUint32(offset, false);
        for (let i = 16; i < 64; i++) {
            const W15 = SHA256_W[i - 15];
            const W2 = SHA256_W[i - 2];
            const s0 = rotr(W15, 7) ^ rotr(W15, 18) ^ (W15 >>> 3);
            const s1 = rotr(W2, 17) ^ rotr(W2, 19) ^ (W2 >>> 10);
            SHA256_W[i] = (s1 + SHA256_W[i - 7] + s0 + SHA256_W[i - 16]) | 0;
        }
        // Compression function main loop, 64 rounds
        let { A, B, C, D, E, F, G, H } = this;
        for (let i = 0; i < 64; i++) {
            const sigma1 = rotr(E, 6) ^ rotr(E, 11) ^ rotr(E, 25);
            const T1 = (H + sigma1 + Chi(E, F, G) + SHA256_K[i] + SHA256_W[i]) | 0;
            const sigma0 = rotr(A, 2) ^ rotr(A, 13) ^ rotr(A, 22);
            const T2 = (sigma0 + Maj(A, B, C)) | 0;
            H = G;
            G = F;
            F = E;
            E = (D + T1) | 0;
            D = C;
            C = B;
            B = A;
            A = (T1 + T2) | 0;
        }
        // Add the compressed chunk to the current hash value
        A = (A + this.A) | 0;
        B = (B + this.B) | 0;
        C = (C + this.C) | 0;
        D = (D + this.D) | 0;
        E = (E + this.E) | 0;
        F = (F + this.F) | 0;
        G = (G + this.G) | 0;
        H = (H + this.H) | 0;
        this.set(A, B, C, D, E, F, G, H);
    }
    roundClean() {
        SHA256_W.fill(0);
    }
    destroy() {
        this.set(0, 0, 0, 0, 0, 0, 0, 0);
        this.buffer.fill(0);
    }
}
/**
 * SHA2-256 hash function
 * @param message - data that would be hashed
 */
const sha256$2 = /* @__PURE__ */ wrapConstructor(() => new SHA256());

// HMAC (RFC 2104)
class HMAC extends Hash {
    constructor(hash$1, _key) {
        super();
        this.finished = false;
        this.destroyed = false;
        hash(hash$1);
        const key = toBytes(_key);
        this.iHash = hash$1.create();
        if (typeof this.iHash.update !== 'function')
            throw new Error('Expected instance of class which extends utils.Hash');
        this.blockLen = this.iHash.blockLen;
        this.outputLen = this.iHash.outputLen;
        const blockLen = this.blockLen;
        const pad = new Uint8Array(blockLen);
        // blockLen can be bigger than outputLen
        pad.set(key.length > blockLen ? hash$1.create().update(key).digest() : key);
        for (let i = 0; i < pad.length; i++)
            pad[i] ^= 0x36;
        this.iHash.update(pad);
        // By doing update (processing of first block) of outer hash here we can re-use it between multiple calls via clone
        this.oHash = hash$1.create();
        // Undo internal XOR && apply outer XOR
        for (let i = 0; i < pad.length; i++)
            pad[i] ^= 0x36 ^ 0x5c;
        this.oHash.update(pad);
        pad.fill(0);
    }
    update(buf) {
        exists(this);
        this.iHash.update(buf);
        return this;
    }
    digestInto(out) {
        exists(this);
        bytes(out, this.outputLen);
        this.finished = true;
        this.iHash.digestInto(out);
        this.oHash.update(out);
        this.oHash.digestInto(out);
        this.destroy();
    }
    digest() {
        const out = new Uint8Array(this.oHash.outputLen);
        this.digestInto(out);
        return out;
    }
    _cloneInto(to) {
        // Create new instance without calling constructor since key already in state and we don't know it.
        to || (to = Object.create(Object.getPrototypeOf(this), {}));
        const { oHash, iHash, finished, destroyed, blockLen, outputLen } = this;
        to = to;
        to.finished = finished;
        to.destroyed = destroyed;
        to.blockLen = blockLen;
        to.outputLen = outputLen;
        to.oHash = oHash._cloneInto(to.oHash);
        to.iHash = iHash._cloneInto(to.iHash);
        return to;
    }
    destroy() {
        this.destroyed = true;
        this.oHash.destroy();
        this.iHash.destroy();
    }
}
/**
 * HMAC: RFC2104 message authentication code.
 * @param hash - function that would be used e.g. sha256
 * @param key - message key
 * @param message - message data
 */
const hmac = (hash, key, message) => new HMAC(hash, key).update(message).digest();
hmac.create = (hash, key) => new HMAC(hash, key);

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
function validatePointOpts(curve) {
    const opts = validateBasic(curve);
    validateObject(opts, {
        a: 'field',
        b: 'field',
    }, {
        allowedPrivateKeyLengths: 'array',
        wrapPrivateKey: 'boolean',
        isTorsionFree: 'function',
        clearCofactor: 'function',
        allowInfinityPoint: 'boolean',
        fromBytes: 'function',
        toBytes: 'function',
    });
    const { endo, Fp, a } = opts;
    if (endo) {
        if (!Fp.eql(a, Fp.ZERO)) {
            throw new Error('Endomorphism can only be defined for Koblitz curves that have a=0');
        }
        if (typeof endo !== 'object' ||
            typeof endo.beta !== 'bigint' ||
            typeof endo.splitScalar !== 'function') {
            throw new Error('Expected endomorphism with beta: bigint and splitScalar: function');
        }
    }
    return Object.freeze({ ...opts });
}
// ASN.1 DER encoding utilities
const { bytesToNumberBE: b2n, hexToBytes: h2b } = ut;
const DER = {
    // asn.1 DER encoding utils
    Err: class DERErr extends Error {
        constructor(m = '') {
            super(m);
        }
    },
    _parseInt(data) {
        const { Err: E } = DER;
        if (data.length < 2 || data[0] !== 0x02)
            throw new E('Invalid signature integer tag');
        const len = data[1];
        const res = data.subarray(2, len + 2);
        if (!len || res.length !== len)
            throw new E('Invalid signature integer: wrong length');
        // https://crypto.stackexchange.com/a/57734 Leftmost bit of first byte is 'negative' flag,
        // since we always use positive integers here. It must always be empty:
        // - add zero byte if exists
        // - if next byte doesn't have a flag, leading zero is not allowed (minimal encoding)
        if (res[0] & 0b10000000)
            throw new E('Invalid signature integer: negative');
        if (res[0] === 0x00 && !(res[1] & 0b10000000))
            throw new E('Invalid signature integer: unnecessary leading zero');
        return { d: b2n(res), l: data.subarray(len + 2) }; // d is data, l is left
    },
    toSig(hex) {
        // parse DER signature
        const { Err: E } = DER;
        const data = typeof hex === 'string' ? h2b(hex) : hex;
        abytes(data);
        let l = data.length;
        if (l < 2 || data[0] != 0x30)
            throw new E('Invalid signature tag');
        if (data[1] !== l - 2)
            throw new E('Invalid signature: incorrect length');
        const { d: r, l: sBytes } = DER._parseInt(data.subarray(2));
        const { d: s, l: rBytesLeft } = DER._parseInt(sBytes);
        if (rBytesLeft.length)
            throw new E('Invalid signature: left bytes after parsing');
        return { r, s };
    },
    hexFromSig(sig) {
        // Add leading zero if first byte has negative bit enabled. More details in '_parseInt'
        const slice = (s) => (Number.parseInt(s[0], 16) & 0b1000 ? '00' + s : s);
        const h = (num) => {
            const hex = num.toString(16);
            return hex.length & 1 ? `0${hex}` : hex;
        };
        const s = slice(h(sig.s));
        const r = slice(h(sig.r));
        const shl = s.length / 2;
        const rhl = r.length / 2;
        const sl = h(shl);
        const rl = h(rhl);
        return `30${h(rhl + shl + 4)}02${rl}${r}02${sl}${s}`;
    },
};
// Be friendly to bad ECMAScript parsers by not using bigint literals
// prettier-ignore
const _0n$1 = BigInt(0), _1n$2 = BigInt(1); BigInt(2); const _3n = BigInt(3); BigInt(4);
function weierstrassPoints(opts) {
    const CURVE = validatePointOpts(opts);
    const { Fp } = CURVE; // All curves has same field / group length as for now, but they can differ
    const toBytes = CURVE.toBytes ||
        ((_c, point, _isCompressed) => {
            const a = point.toAffine();
            return concatBytes(Uint8Array.from([0x04]), Fp.toBytes(a.x), Fp.toBytes(a.y));
        });
    const fromBytes = CURVE.fromBytes ||
        ((bytes) => {
            // const head = bytes[0];
            const tail = bytes.subarray(1);
            // if (head !== 0x04) throw new Error('Only non-compressed encoding is supported');
            const x = Fp.fromBytes(tail.subarray(0, Fp.BYTES));
            const y = Fp.fromBytes(tail.subarray(Fp.BYTES, 2 * Fp.BYTES));
            return { x, y };
        });
    /**
     * y² = x³ + ax + b: Short weierstrass curve formula
     * @returns y²
     */
    function weierstrassEquation(x) {
        const { a, b } = CURVE;
        const x2 = Fp.sqr(x); // x * x
        const x3 = Fp.mul(x2, x); // x2 * x
        return Fp.add(Fp.add(x3, Fp.mul(x, a)), b); // x3 + a * x + b
    }
    // Validate whether the passed curve params are valid.
    // We check if curve equation works for generator point.
    // `assertValidity()` won't work: `isTorsionFree()` is not available at this point in bls12-381.
    // ProjectivePoint class has not been initialized yet.
    if (!Fp.eql(Fp.sqr(CURVE.Gy), weierstrassEquation(CURVE.Gx)))
        throw new Error('bad generator point: equation left != right');
    // Valid group elements reside in range 1..n-1
    function isWithinCurveOrder(num) {
        return typeof num === 'bigint' && _0n$1 < num && num < CURVE.n;
    }
    function assertGE(num) {
        if (!isWithinCurveOrder(num))
            throw new Error('Expected valid bigint: 0 < bigint < curve.n');
    }
    // Validates if priv key is valid and converts it to bigint.
    // Supports options allowedPrivateKeyLengths and wrapPrivateKey.
    function normPrivateKeyToScalar(key) {
        const { allowedPrivateKeyLengths: lengths, nByteLength, wrapPrivateKey, n } = CURVE;
        if (lengths && typeof key !== 'bigint') {
            if (isBytes$1(key))
                key = bytesToHex$1(key);
            // Normalize to hex string, pad. E.g. P521 would norm 130-132 char hex to 132-char bytes
            if (typeof key !== 'string' || !lengths.includes(key.length))
                throw new Error('Invalid key');
            key = key.padStart(nByteLength * 2, '0');
        }
        let num;
        try {
            num =
                typeof key === 'bigint'
                    ? key
                    : bytesToNumberBE(ensureBytes('private key', key, nByteLength));
        }
        catch (error) {
            throw new Error(`private key must be ${nByteLength} bytes, hex or bigint, not ${typeof key}`);
        }
        if (wrapPrivateKey)
            num = mod(num, n); // disabled by default, enabled for BLS
        assertGE(num); // num in range [1..N-1]
        return num;
    }
    const pointPrecomputes = new Map();
    function assertPrjPoint(other) {
        if (!(other instanceof Point))
            throw new Error('ProjectivePoint expected');
    }
    /**
     * Projective Point works in 3d / projective (homogeneous) coordinates: (x, y, z) ∋ (x=x/z, y=y/z)
     * Default Point works in 2d / affine coordinates: (x, y)
     * We're doing calculations in projective, because its operations don't require costly inversion.
     */
    class Point {
        constructor(px, py, pz) {
            this.px = px;
            this.py = py;
            this.pz = pz;
            if (px == null || !Fp.isValid(px))
                throw new Error('x required');
            if (py == null || !Fp.isValid(py))
                throw new Error('y required');
            if (pz == null || !Fp.isValid(pz))
                throw new Error('z required');
        }
        // Does not validate if the point is on-curve.
        // Use fromHex instead, or call assertValidity() later.
        static fromAffine(p) {
            const { x, y } = p || {};
            if (!p || !Fp.isValid(x) || !Fp.isValid(y))
                throw new Error('invalid affine point');
            if (p instanceof Point)
                throw new Error('projective point not allowed');
            const is0 = (i) => Fp.eql(i, Fp.ZERO);
            // fromAffine(x:0, y:0) would produce (x:0, y:0, z:1), but we need (x:0, y:1, z:0)
            if (is0(x) && is0(y))
                return Point.ZERO;
            return new Point(x, y, Fp.ONE);
        }
        get x() {
            return this.toAffine().x;
        }
        get y() {
            return this.toAffine().y;
        }
        /**
         * Takes a bunch of Projective Points but executes only one
         * inversion on all of them. Inversion is very slow operation,
         * so this improves performance massively.
         * Optimization: converts a list of projective points to a list of identical points with Z=1.
         */
        static normalizeZ(points) {
            const toInv = Fp.invertBatch(points.map((p) => p.pz));
            return points.map((p, i) => p.toAffine(toInv[i])).map(Point.fromAffine);
        }
        /**
         * Converts hash string or Uint8Array to Point.
         * @param hex short/long ECDSA hex
         */
        static fromHex(hex) {
            const P = Point.fromAffine(fromBytes(ensureBytes('pointHex', hex)));
            P.assertValidity();
            return P;
        }
        // Multiplies generator point by privateKey.
        static fromPrivateKey(privateKey) {
            return Point.BASE.multiply(normPrivateKeyToScalar(privateKey));
        }
        // "Private method", don't use it directly
        _setWindowSize(windowSize) {
            this._WINDOW_SIZE = windowSize;
            pointPrecomputes.delete(this);
        }
        // A point on curve is valid if it conforms to equation.
        assertValidity() {
            if (this.is0()) {
                // (0, 1, 0) aka ZERO is invalid in most contexts.
                // In BLS, ZERO can be serialized, so we allow it.
                // (0, 0, 0) is wrong representation of ZERO and is always invalid.
                if (CURVE.allowInfinityPoint && !Fp.is0(this.py))
                    return;
                throw new Error('bad point: ZERO');
            }
            // Some 3rd-party test vectors require different wording between here & `fromCompressedHex`
            const { x, y } = this.toAffine();
            // Check if x, y are valid field elements
            if (!Fp.isValid(x) || !Fp.isValid(y))
                throw new Error('bad point: x or y not FE');
            const left = Fp.sqr(y); // y²
            const right = weierstrassEquation(x); // x³ + ax + b
            if (!Fp.eql(left, right))
                throw new Error('bad point: equation left != right');
            if (!this.isTorsionFree())
                throw new Error('bad point: not in prime-order subgroup');
        }
        hasEvenY() {
            const { y } = this.toAffine();
            if (Fp.isOdd)
                return !Fp.isOdd(y);
            throw new Error("Field doesn't support isOdd");
        }
        /**
         * Compare one point to another.
         */
        equals(other) {
            assertPrjPoint(other);
            const { px: X1, py: Y1, pz: Z1 } = this;
            const { px: X2, py: Y2, pz: Z2 } = other;
            const U1 = Fp.eql(Fp.mul(X1, Z2), Fp.mul(X2, Z1));
            const U2 = Fp.eql(Fp.mul(Y1, Z2), Fp.mul(Y2, Z1));
            return U1 && U2;
        }
        /**
         * Flips point to one corresponding to (x, -y) in Affine coordinates.
         */
        negate() {
            return new Point(this.px, Fp.neg(this.py), this.pz);
        }
        // Renes-Costello-Batina exception-free doubling formula.
        // There is 30% faster Jacobian formula, but it is not complete.
        // https://eprint.iacr.org/2015/1060, algorithm 3
        // Cost: 8M + 3S + 3*a + 2*b3 + 15add.
        double() {
            const { a, b } = CURVE;
            const b3 = Fp.mul(b, _3n);
            const { px: X1, py: Y1, pz: Z1 } = this;
            let X3 = Fp.ZERO, Y3 = Fp.ZERO, Z3 = Fp.ZERO; // prettier-ignore
            let t0 = Fp.mul(X1, X1); // step 1
            let t1 = Fp.mul(Y1, Y1);
            let t2 = Fp.mul(Z1, Z1);
            let t3 = Fp.mul(X1, Y1);
            t3 = Fp.add(t3, t3); // step 5
            Z3 = Fp.mul(X1, Z1);
            Z3 = Fp.add(Z3, Z3);
            X3 = Fp.mul(a, Z3);
            Y3 = Fp.mul(b3, t2);
            Y3 = Fp.add(X3, Y3); // step 10
            X3 = Fp.sub(t1, Y3);
            Y3 = Fp.add(t1, Y3);
            Y3 = Fp.mul(X3, Y3);
            X3 = Fp.mul(t3, X3);
            Z3 = Fp.mul(b3, Z3); // step 15
            t2 = Fp.mul(a, t2);
            t3 = Fp.sub(t0, t2);
            t3 = Fp.mul(a, t3);
            t3 = Fp.add(t3, Z3);
            Z3 = Fp.add(t0, t0); // step 20
            t0 = Fp.add(Z3, t0);
            t0 = Fp.add(t0, t2);
            t0 = Fp.mul(t0, t3);
            Y3 = Fp.add(Y3, t0);
            t2 = Fp.mul(Y1, Z1); // step 25
            t2 = Fp.add(t2, t2);
            t0 = Fp.mul(t2, t3);
            X3 = Fp.sub(X3, t0);
            Z3 = Fp.mul(t2, t1);
            Z3 = Fp.add(Z3, Z3); // step 30
            Z3 = Fp.add(Z3, Z3);
            return new Point(X3, Y3, Z3);
        }
        // Renes-Costello-Batina exception-free addition formula.
        // There is 30% faster Jacobian formula, but it is not complete.
        // https://eprint.iacr.org/2015/1060, algorithm 1
        // Cost: 12M + 0S + 3*a + 3*b3 + 23add.
        add(other) {
            assertPrjPoint(other);
            const { px: X1, py: Y1, pz: Z1 } = this;
            const { px: X2, py: Y2, pz: Z2 } = other;
            let X3 = Fp.ZERO, Y3 = Fp.ZERO, Z3 = Fp.ZERO; // prettier-ignore
            const a = CURVE.a;
            const b3 = Fp.mul(CURVE.b, _3n);
            let t0 = Fp.mul(X1, X2); // step 1
            let t1 = Fp.mul(Y1, Y2);
            let t2 = Fp.mul(Z1, Z2);
            let t3 = Fp.add(X1, Y1);
            let t4 = Fp.add(X2, Y2); // step 5
            t3 = Fp.mul(t3, t4);
            t4 = Fp.add(t0, t1);
            t3 = Fp.sub(t3, t4);
            t4 = Fp.add(X1, Z1);
            let t5 = Fp.add(X2, Z2); // step 10
            t4 = Fp.mul(t4, t5);
            t5 = Fp.add(t0, t2);
            t4 = Fp.sub(t4, t5);
            t5 = Fp.add(Y1, Z1);
            X3 = Fp.add(Y2, Z2); // step 15
            t5 = Fp.mul(t5, X3);
            X3 = Fp.add(t1, t2);
            t5 = Fp.sub(t5, X3);
            Z3 = Fp.mul(a, t4);
            X3 = Fp.mul(b3, t2); // step 20
            Z3 = Fp.add(X3, Z3);
            X3 = Fp.sub(t1, Z3);
            Z3 = Fp.add(t1, Z3);
            Y3 = Fp.mul(X3, Z3);
            t1 = Fp.add(t0, t0); // step 25
            t1 = Fp.add(t1, t0);
            t2 = Fp.mul(a, t2);
            t4 = Fp.mul(b3, t4);
            t1 = Fp.add(t1, t2);
            t2 = Fp.sub(t0, t2); // step 30
            t2 = Fp.mul(a, t2);
            t4 = Fp.add(t4, t2);
            t0 = Fp.mul(t1, t4);
            Y3 = Fp.add(Y3, t0);
            t0 = Fp.mul(t5, t4); // step 35
            X3 = Fp.mul(t3, X3);
            X3 = Fp.sub(X3, t0);
            t0 = Fp.mul(t3, t1);
            Z3 = Fp.mul(t5, Z3);
            Z3 = Fp.add(Z3, t0); // step 40
            return new Point(X3, Y3, Z3);
        }
        subtract(other) {
            return this.add(other.negate());
        }
        is0() {
            return this.equals(Point.ZERO);
        }
        wNAF(n) {
            return wnaf.wNAFCached(this, pointPrecomputes, n, (comp) => {
                const toInv = Fp.invertBatch(comp.map((p) => p.pz));
                return comp.map((p, i) => p.toAffine(toInv[i])).map(Point.fromAffine);
            });
        }
        /**
         * Non-constant-time multiplication. Uses double-and-add algorithm.
         * It's faster, but should only be used when you don't care about
         * an exposed private key e.g. sig verification, which works over *public* keys.
         */
        multiplyUnsafe(n) {
            const I = Point.ZERO;
            if (n === _0n$1)
                return I;
            assertGE(n); // Will throw on 0
            if (n === _1n$2)
                return this;
            const { endo } = CURVE;
            if (!endo)
                return wnaf.unsafeLadder(this, n);
            // Apply endomorphism
            let { k1neg, k1, k2neg, k2 } = endo.splitScalar(n);
            let k1p = I;
            let k2p = I;
            let d = this;
            while (k1 > _0n$1 || k2 > _0n$1) {
                if (k1 & _1n$2)
                    k1p = k1p.add(d);
                if (k2 & _1n$2)
                    k2p = k2p.add(d);
                d = d.double();
                k1 >>= _1n$2;
                k2 >>= _1n$2;
            }
            if (k1neg)
                k1p = k1p.negate();
            if (k2neg)
                k2p = k2p.negate();
            k2p = new Point(Fp.mul(k2p.px, endo.beta), k2p.py, k2p.pz);
            return k1p.add(k2p);
        }
        /**
         * Constant time multiplication.
         * Uses wNAF method. Windowed method may be 10% faster,
         * but takes 2x longer to generate and consumes 2x memory.
         * Uses precomputes when available.
         * Uses endomorphism for Koblitz curves.
         * @param scalar by which the point would be multiplied
         * @returns New point
         */
        multiply(scalar) {
            assertGE(scalar);
            let n = scalar;
            let point, fake; // Fake point is used to const-time mult
            const { endo } = CURVE;
            if (endo) {
                const { k1neg, k1, k2neg, k2 } = endo.splitScalar(n);
                let { p: k1p, f: f1p } = this.wNAF(k1);
                let { p: k2p, f: f2p } = this.wNAF(k2);
                k1p = wnaf.constTimeNegate(k1neg, k1p);
                k2p = wnaf.constTimeNegate(k2neg, k2p);
                k2p = new Point(Fp.mul(k2p.px, endo.beta), k2p.py, k2p.pz);
                point = k1p.add(k2p);
                fake = f1p.add(f2p);
            }
            else {
                const { p, f } = this.wNAF(n);
                point = p;
                fake = f;
            }
            // Normalize `z` for both points, but return only real one
            return Point.normalizeZ([point, fake])[0];
        }
        /**
         * Efficiently calculate `aP + bQ`. Unsafe, can expose private key, if used incorrectly.
         * Not using Strauss-Shamir trick: precomputation tables are faster.
         * The trick could be useful if both P and Q are not G (not in our case).
         * @returns non-zero affine point
         */
        multiplyAndAddUnsafe(Q, a, b) {
            const G = Point.BASE; // No Strauss-Shamir trick: we have 10% faster G precomputes
            const mul = (P, a // Select faster multiply() method
            ) => (a === _0n$1 || a === _1n$2 || !P.equals(G) ? P.multiplyUnsafe(a) : P.multiply(a));
            const sum = mul(this, a).add(mul(Q, b));
            return sum.is0() ? undefined : sum;
        }
        // Converts Projective point to affine (x, y) coordinates.
        // Can accept precomputed Z^-1 - for example, from invertBatch.
        // (x, y, z) ∋ (x=x/z, y=y/z)
        toAffine(iz) {
            const { px: x, py: y, pz: z } = this;
            const is0 = this.is0();
            // If invZ was 0, we return zero point. However we still want to execute
            // all operations, so we replace invZ with a random number, 1.
            if (iz == null)
                iz = is0 ? Fp.ONE : Fp.inv(z);
            const ax = Fp.mul(x, iz);
            const ay = Fp.mul(y, iz);
            const zz = Fp.mul(z, iz);
            if (is0)
                return { x: Fp.ZERO, y: Fp.ZERO };
            if (!Fp.eql(zz, Fp.ONE))
                throw new Error('invZ was invalid');
            return { x: ax, y: ay };
        }
        isTorsionFree() {
            const { h: cofactor, isTorsionFree } = CURVE;
            if (cofactor === _1n$2)
                return true; // No subgroups, always torsion-free
            if (isTorsionFree)
                return isTorsionFree(Point, this);
            throw new Error('isTorsionFree() has not been declared for the elliptic curve');
        }
        clearCofactor() {
            const { h: cofactor, clearCofactor } = CURVE;
            if (cofactor === _1n$2)
                return this; // Fast-path
            if (clearCofactor)
                return clearCofactor(Point, this);
            return this.multiplyUnsafe(CURVE.h);
        }
        toRawBytes(isCompressed = true) {
            this.assertValidity();
            return toBytes(Point, this, isCompressed);
        }
        toHex(isCompressed = true) {
            return bytesToHex$1(this.toRawBytes(isCompressed));
        }
    }
    Point.BASE = new Point(CURVE.Gx, CURVE.Gy, Fp.ONE);
    Point.ZERO = new Point(Fp.ZERO, Fp.ONE, Fp.ZERO);
    const _bits = CURVE.nBitLength;
    const wnaf = wNAF(Point, CURVE.endo ? Math.ceil(_bits / 2) : _bits);
    // Validate if generator point is on curve
    return {
        CURVE,
        ProjectivePoint: Point,
        normPrivateKeyToScalar,
        weierstrassEquation,
        isWithinCurveOrder,
    };
}
function validateOpts(curve) {
    const opts = validateBasic(curve);
    validateObject(opts, {
        hash: 'hash',
        hmac: 'function',
        randomBytes: 'function',
    }, {
        bits2int: 'function',
        bits2int_modN: 'function',
        lowS: 'boolean',
    });
    return Object.freeze({ lowS: true, ...opts });
}
function weierstrass(curveDef) {
    const CURVE = validateOpts(curveDef);
    const { Fp, n: CURVE_ORDER } = CURVE;
    const compressedLen = Fp.BYTES + 1; // e.g. 33 for 32
    const uncompressedLen = 2 * Fp.BYTES + 1; // e.g. 65 for 32
    function isValidFieldElement(num) {
        return _0n$1 < num && num < Fp.ORDER; // 0 is banned since it's not invertible FE
    }
    function modN(a) {
        return mod(a, CURVE_ORDER);
    }
    function invN(a) {
        return invert(a, CURVE_ORDER);
    }
    const { ProjectivePoint: Point, normPrivateKeyToScalar, weierstrassEquation, isWithinCurveOrder, } = weierstrassPoints({
        ...CURVE,
        toBytes(_c, point, isCompressed) {
            const a = point.toAffine();
            const x = Fp.toBytes(a.x);
            const cat = concatBytes;
            if (isCompressed) {
                return cat(Uint8Array.from([point.hasEvenY() ? 0x02 : 0x03]), x);
            }
            else {
                return cat(Uint8Array.from([0x04]), x, Fp.toBytes(a.y));
            }
        },
        fromBytes(bytes) {
            const len = bytes.length;
            const head = bytes[0];
            const tail = bytes.subarray(1);
            // this.assertValidity() is done inside of fromHex
            if (len === compressedLen && (head === 0x02 || head === 0x03)) {
                const x = bytesToNumberBE(tail);
                if (!isValidFieldElement(x))
                    throw new Error('Point is not on curve');
                const y2 = weierstrassEquation(x); // y² = x³ + ax + b
                let y;
                try {
                    y = Fp.sqrt(y2); // y = y² ^ (p+1)/4
                }
                catch (sqrtError) {
                    const suffix = sqrtError instanceof Error ? ': ' + sqrtError.message : '';
                    throw new Error('Point is not on curve' + suffix);
                }
                const isYOdd = (y & _1n$2) === _1n$2;
                // ECDSA
                const isHeadOdd = (head & 1) === 1;
                if (isHeadOdd !== isYOdd)
                    y = Fp.neg(y);
                return { x, y };
            }
            else if (len === uncompressedLen && head === 0x04) {
                const x = Fp.fromBytes(tail.subarray(0, Fp.BYTES));
                const y = Fp.fromBytes(tail.subarray(Fp.BYTES, 2 * Fp.BYTES));
                return { x, y };
            }
            else {
                throw new Error(`Point of length ${len} was invalid. Expected ${compressedLen} compressed bytes or ${uncompressedLen} uncompressed bytes`);
            }
        },
    });
    const numToNByteStr = (num) => bytesToHex$1(numberToBytesBE(num, CURVE.nByteLength));
    function isBiggerThanHalfOrder(number) {
        const HALF = CURVE_ORDER >> _1n$2;
        return number > HALF;
    }
    function normalizeS(s) {
        return isBiggerThanHalfOrder(s) ? modN(-s) : s;
    }
    // slice bytes num
    const slcNum = (b, from, to) => bytesToNumberBE(b.slice(from, to));
    /**
     * ECDSA signature with its (r, s) properties. Supports DER & compact representations.
     */
    class Signature {
        constructor(r, s, recovery) {
            this.r = r;
            this.s = s;
            this.recovery = recovery;
            this.assertValidity();
        }
        // pair (bytes of r, bytes of s)
        static fromCompact(hex) {
            const l = CURVE.nByteLength;
            hex = ensureBytes('compactSignature', hex, l * 2);
            return new Signature(slcNum(hex, 0, l), slcNum(hex, l, 2 * l));
        }
        // DER encoded ECDSA signature
        // https://bitcoin.stackexchange.com/questions/57644/what-are-the-parts-of-a-bitcoin-transaction-input-script
        static fromDER(hex) {
            const { r, s } = DER.toSig(ensureBytes('DER', hex));
            return new Signature(r, s);
        }
        assertValidity() {
            // can use assertGE here
            if (!isWithinCurveOrder(this.r))
                throw new Error('r must be 0 < r < CURVE.n');
            if (!isWithinCurveOrder(this.s))
                throw new Error('s must be 0 < s < CURVE.n');
        }
        addRecoveryBit(recovery) {
            return new Signature(this.r, this.s, recovery);
        }
        recoverPublicKey(msgHash) {
            const { r, s, recovery: rec } = this;
            const h = bits2int_modN(ensureBytes('msgHash', msgHash)); // Truncate hash
            if (rec == null || ![0, 1, 2, 3].includes(rec))
                throw new Error('recovery id invalid');
            const radj = rec === 2 || rec === 3 ? r + CURVE.n : r;
            if (radj >= Fp.ORDER)
                throw new Error('recovery id 2 or 3 invalid');
            const prefix = (rec & 1) === 0 ? '02' : '03';
            const R = Point.fromHex(prefix + numToNByteStr(radj));
            const ir = invN(radj); // r^-1
            const u1 = modN(-h * ir); // -hr^-1
            const u2 = modN(s * ir); // sr^-1
            const Q = Point.BASE.multiplyAndAddUnsafe(R, u1, u2); // (sr^-1)R-(hr^-1)G = -(hr^-1)G + (sr^-1)
            if (!Q)
                throw new Error('point at infinify'); // unsafe is fine: no priv data leaked
            Q.assertValidity();
            return Q;
        }
        // Signatures should be low-s, to prevent malleability.
        hasHighS() {
            return isBiggerThanHalfOrder(this.s);
        }
        normalizeS() {
            return this.hasHighS() ? new Signature(this.r, modN(-this.s), this.recovery) : this;
        }
        // DER-encoded
        toDERRawBytes() {
            return hexToBytes$1(this.toDERHex());
        }
        toDERHex() {
            return DER.hexFromSig({ r: this.r, s: this.s });
        }
        // padded bytes of r, then padded bytes of s
        toCompactRawBytes() {
            return hexToBytes$1(this.toCompactHex());
        }
        toCompactHex() {
            return numToNByteStr(this.r) + numToNByteStr(this.s);
        }
    }
    const utils = {
        isValidPrivateKey(privateKey) {
            try {
                normPrivateKeyToScalar(privateKey);
                return true;
            }
            catch (error) {
                return false;
            }
        },
        normPrivateKeyToScalar: normPrivateKeyToScalar,
        /**
         * Produces cryptographically secure private key from random of size
         * (groupLen + ceil(groupLen / 2)) with modulo bias being negligible.
         */
        randomPrivateKey: () => {
            const length = getMinHashLength(CURVE.n);
            return mapHashToField(CURVE.randomBytes(length), CURVE.n);
        },
        /**
         * Creates precompute table for an arbitrary EC point. Makes point "cached".
         * Allows to massively speed-up `point.multiply(scalar)`.
         * @returns cached point
         * @example
         * const fast = utils.precompute(8, ProjectivePoint.fromHex(someonesPubKey));
         * fast.multiply(privKey); // much faster ECDH now
         */
        precompute(windowSize = 8, point = Point.BASE) {
            point._setWindowSize(windowSize);
            point.multiply(BigInt(3)); // 3 is arbitrary, just need any number here
            return point;
        },
    };
    /**
     * Computes public key for a private key. Checks for validity of the private key.
     * @param privateKey private key
     * @param isCompressed whether to return compact (default), or full key
     * @returns Public key, full when isCompressed=false; short when isCompressed=true
     */
    function getPublicKey(privateKey, isCompressed = true) {
        return Point.fromPrivateKey(privateKey).toRawBytes(isCompressed);
    }
    /**
     * Quick and dirty check for item being public key. Does not validate hex, or being on-curve.
     */
    function isProbPub(item) {
        const arr = isBytes$1(item);
        const str = typeof item === 'string';
        const len = (arr || str) && item.length;
        if (arr)
            return len === compressedLen || len === uncompressedLen;
        if (str)
            return len === 2 * compressedLen || len === 2 * uncompressedLen;
        if (item instanceof Point)
            return true;
        return false;
    }
    /**
     * ECDH (Elliptic Curve Diffie Hellman).
     * Computes shared public key from private key and public key.
     * Checks: 1) private key validity 2) shared key is on-curve.
     * Does NOT hash the result.
     * @param privateA private key
     * @param publicB different public key
     * @param isCompressed whether to return compact (default), or full key
     * @returns shared public key
     */
    function getSharedSecret(privateA, publicB, isCompressed = true) {
        if (isProbPub(privateA))
            throw new Error('first arg must be private key');
        if (!isProbPub(publicB))
            throw new Error('second arg must be public key');
        const b = Point.fromHex(publicB); // check for being on-curve
        return b.multiply(normPrivateKeyToScalar(privateA)).toRawBytes(isCompressed);
    }
    // RFC6979: ensure ECDSA msg is X bytes and < N. RFC suggests optional truncating via bits2octets.
    // FIPS 186-4 4.6 suggests the leftmost min(nBitLen, outLen) bits, which matches bits2int.
    // bits2int can produce res>N, we can do mod(res, N) since the bitLen is the same.
    // int2octets can't be used; pads small msgs with 0: unacceptatble for trunc as per RFC vectors
    const bits2int = CURVE.bits2int ||
        function (bytes) {
            // For curves with nBitLength % 8 !== 0: bits2octets(bits2octets(m)) !== bits2octets(m)
            // for some cases, since bytes.length * 8 is not actual bitLength.
            const num = bytesToNumberBE(bytes); // check for == u8 done here
            const delta = bytes.length * 8 - CURVE.nBitLength; // truncate to nBitLength leftmost bits
            return delta > 0 ? num >> BigInt(delta) : num;
        };
    const bits2int_modN = CURVE.bits2int_modN ||
        function (bytes) {
            return modN(bits2int(bytes)); // can't use bytesToNumberBE here
        };
    // NOTE: pads output with zero as per spec
    const ORDER_MASK = bitMask(CURVE.nBitLength);
    /**
     * Converts to bytes. Checks if num in `[0..ORDER_MASK-1]` e.g.: `[0..2^256-1]`.
     */
    function int2octets(num) {
        if (typeof num !== 'bigint')
            throw new Error('bigint expected');
        if (!(_0n$1 <= num && num < ORDER_MASK))
            throw new Error(`bigint expected < 2^${CURVE.nBitLength}`);
        // works with order, can have different size than numToField!
        return numberToBytesBE(num, CURVE.nByteLength);
    }
    // Steps A, D of RFC6979 3.2
    // Creates RFC6979 seed; converts msg/privKey to numbers.
    // Used only in sign, not in verify.
    // NOTE: we cannot assume here that msgHash has same amount of bytes as curve order, this will be wrong at least for P521.
    // Also it can be bigger for P224 + SHA256
    function prepSig(msgHash, privateKey, opts = defaultSigOpts) {
        if (['recovered', 'canonical'].some((k) => k in opts))
            throw new Error('sign() legacy options not supported');
        const { hash, randomBytes } = CURVE;
        let { lowS, prehash, extraEntropy: ent } = opts; // generates low-s sigs by default
        if (lowS == null)
            lowS = true; // RFC6979 3.2: we skip step A, because we already provide hash
        msgHash = ensureBytes('msgHash', msgHash);
        if (prehash)
            msgHash = ensureBytes('prehashed msgHash', hash(msgHash));
        // We can't later call bits2octets, since nested bits2int is broken for curves
        // with nBitLength % 8 !== 0. Because of that, we unwrap it here as int2octets call.
        // const bits2octets = (bits) => int2octets(bits2int_modN(bits))
        const h1int = bits2int_modN(msgHash);
        const d = normPrivateKeyToScalar(privateKey); // validate private key, convert to bigint
        const seedArgs = [int2octets(d), int2octets(h1int)];
        // extraEntropy. RFC6979 3.6: additional k' (optional).
        if (ent != null && ent !== false) {
            // K = HMAC_K(V || 0x00 || int2octets(x) || bits2octets(h1) || k')
            const e = ent === true ? randomBytes(Fp.BYTES) : ent; // generate random bytes OR pass as-is
            seedArgs.push(ensureBytes('extraEntropy', e)); // check for being bytes
        }
        const seed = concatBytes(...seedArgs); // Step D of RFC6979 3.2
        const m = h1int; // NOTE: no need to call bits2int second time here, it is inside truncateHash!
        // Converts signature params into point w r/s, checks result for validity.
        function k2sig(kBytes) {
            // RFC 6979 Section 3.2, step 3: k = bits2int(T)
            const k = bits2int(kBytes); // Cannot use fields methods, since it is group element
            if (!isWithinCurveOrder(k))
                return; // Important: all mod() calls here must be done over N
            const ik = invN(k); // k^-1 mod n
            const q = Point.BASE.multiply(k).toAffine(); // q = Gk
            const r = modN(q.x); // r = q.x mod n
            if (r === _0n$1)
                return;
            // Can use scalar blinding b^-1(bm + bdr) where b ∈ [1,q−1] according to
            // https://tches.iacr.org/index.php/TCHES/article/view/7337/6509. We've decided against it:
            // a) dependency on CSPRNG b) 15% slowdown c) doesn't really help since bigints are not CT
            const s = modN(ik * modN(m + r * d)); // Not using blinding here
            if (s === _0n$1)
                return;
            let recovery = (q.x === r ? 0 : 2) | Number(q.y & _1n$2); // recovery bit (2 or 3, when q.x > n)
            let normS = s;
            if (lowS && isBiggerThanHalfOrder(s)) {
                normS = normalizeS(s); // if lowS was passed, ensure s is always
                recovery ^= 1; // // in the bottom half of N
            }
            return new Signature(r, normS, recovery); // use normS, not s
        }
        return { seed, k2sig };
    }
    const defaultSigOpts = { lowS: CURVE.lowS, prehash: false };
    const defaultVerOpts = { lowS: CURVE.lowS, prehash: false };
    /**
     * Signs message hash with a private key.
     * ```
     * sign(m, d, k) where
     *   (x, y) = G × k
     *   r = x mod n
     *   s = (m + dr)/k mod n
     * ```
     * @param msgHash NOT message. msg needs to be hashed to `msgHash`, or use `prehash`.
     * @param privKey private key
     * @param opts lowS for non-malleable sigs. extraEntropy for mixing randomness into k. prehash will hash first arg.
     * @returns signature with recovery param
     */
    function sign(msgHash, privKey, opts = defaultSigOpts) {
        const { seed, k2sig } = prepSig(msgHash, privKey, opts); // Steps A, D of RFC6979 3.2.
        const C = CURVE;
        const drbg = createHmacDrbg(C.hash.outputLen, C.nByteLength, C.hmac);
        return drbg(seed, k2sig); // Steps B, C, D, E, F, G
    }
    // Enable precomputes. Slows down first publicKey computation by 20ms.
    Point.BASE._setWindowSize(8);
    // utils.precompute(8, ProjectivePoint.BASE)
    /**
     * Verifies a signature against message hash and public key.
     * Rejects lowS signatures by default: to override,
     * specify option `{lowS: false}`. Implements section 4.1.4 from https://www.secg.org/sec1-v2.pdf:
     *
     * ```
     * verify(r, s, h, P) where
     *   U1 = hs^-1 mod n
     *   U2 = rs^-1 mod n
     *   R = U1⋅G - U2⋅P
     *   mod(R.x, n) == r
     * ```
     */
    function verify(signature, msgHash, publicKey, opts = defaultVerOpts) {
        const sg = signature;
        msgHash = ensureBytes('msgHash', msgHash);
        publicKey = ensureBytes('publicKey', publicKey);
        if ('strict' in opts)
            throw new Error('options.strict was renamed to lowS');
        const { lowS, prehash } = opts;
        let _sig = undefined;
        let P;
        try {
            if (typeof sg === 'string' || isBytes$1(sg)) {
                // Signature can be represented in 2 ways: compact (2*nByteLength) & DER (variable-length).
                // Since DER can also be 2*nByteLength bytes, we check for it first.
                try {
                    _sig = Signature.fromDER(sg);
                }
                catch (derError) {
                    if (!(derError instanceof DER.Err))
                        throw derError;
                    _sig = Signature.fromCompact(sg);
                }
            }
            else if (typeof sg === 'object' && typeof sg.r === 'bigint' && typeof sg.s === 'bigint') {
                const { r, s } = sg;
                _sig = new Signature(r, s);
            }
            else {
                throw new Error('PARSE');
            }
            P = Point.fromHex(publicKey);
        }
        catch (error) {
            if (error.message === 'PARSE')
                throw new Error(`signature must be Signature instance, Uint8Array or hex string`);
            return false;
        }
        if (lowS && _sig.hasHighS())
            return false;
        if (prehash)
            msgHash = CURVE.hash(msgHash);
        const { r, s } = _sig;
        const h = bits2int_modN(msgHash); // Cannot use fields methods, since it is group element
        const is = invN(s); // s^-1
        const u1 = modN(h * is); // u1 = hs^-1 mod n
        const u2 = modN(r * is); // u2 = rs^-1 mod n
        const R = Point.BASE.multiplyAndAddUnsafe(P, u1, u2)?.toAffine(); // R = u1⋅G + u2⋅P
        if (!R)
            return false;
        const v = modN(R.x);
        return v === r;
    }
    return {
        CURVE,
        getPublicKey,
        getSharedSecret,
        sign,
        verify,
        ProjectivePoint: Point,
        Signature,
        utils,
    };
}

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
// connects noble-curves to noble-hashes
function getHash(hash) {
    return {
        hash,
        hmac: (key, ...msgs) => hmac(hash, key, concatBytes$1(...msgs)),
        randomBytes: randomBytes$1,
    };
}
function createCurve(curveDef, defHash) {
    const create = (hash) => weierstrass({ ...curveDef, ...getHash(hash) });
    return Object.freeze({ ...create(defHash), create });
}

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
const secp256k1P = BigInt('0xfffffffffffffffffffffffffffffffffffffffffffffffffffffffefffffc2f');
const secp256k1N = BigInt('0xfffffffffffffffffffffffffffffffebaaedce6af48a03bbfd25e8cd0364141');
const _1n$1 = BigInt(1);
const _2n$1 = BigInt(2);
const divNearest = (a, b) => (a + b / _2n$1) / b;
/**
 * √n = n^((p+1)/4) for fields p = 3 mod 4. We unwrap the loop and multiply bit-by-bit.
 * (P+1n/4n).toString(2) would produce bits [223x 1, 0, 22x 1, 4x 0, 11, 00]
 */
function sqrtMod(y) {
    const P = secp256k1P;
    // prettier-ignore
    const _3n = BigInt(3), _6n = BigInt(6), _11n = BigInt(11), _22n = BigInt(22);
    // prettier-ignore
    const _23n = BigInt(23), _44n = BigInt(44), _88n = BigInt(88);
    const b2 = (y * y * y) % P; // x^3, 11
    const b3 = (b2 * b2 * y) % P; // x^7
    const b6 = (pow2(b3, _3n, P) * b3) % P;
    const b9 = (pow2(b6, _3n, P) * b3) % P;
    const b11 = (pow2(b9, _2n$1, P) * b2) % P;
    const b22 = (pow2(b11, _11n, P) * b11) % P;
    const b44 = (pow2(b22, _22n, P) * b22) % P;
    const b88 = (pow2(b44, _44n, P) * b44) % P;
    const b176 = (pow2(b88, _88n, P) * b88) % P;
    const b220 = (pow2(b176, _44n, P) * b44) % P;
    const b223 = (pow2(b220, _3n, P) * b3) % P;
    const t1 = (pow2(b223, _23n, P) * b22) % P;
    const t2 = (pow2(t1, _6n, P) * b2) % P;
    const root = pow2(t2, _2n$1, P);
    if (!Fp$1.eql(Fp$1.sqr(root), y))
        throw new Error('Cannot find square root');
    return root;
}
const Fp$1 = Field(secp256k1P, undefined, undefined, { sqrt: sqrtMod });
const secp256k1 = createCurve({
    a: BigInt(0), // equation params: a, b
    b: BigInt(7), // Seem to be rigid: bitcointalk.org/index.php?topic=289795.msg3183975#msg3183975
    Fp: Fp$1, // Field's prime: 2n**256n - 2n**32n - 2n**9n - 2n**8n - 2n**7n - 2n**6n - 2n**4n - 1n
    n: secp256k1N, // Curve order, total count of valid points in the field
    // Base point (x, y) aka generator point
    Gx: BigInt('55066263022277343669578718895168534326250603453777594175500187360389116729240'),
    Gy: BigInt('32670510020758816978083085130507043184471273380659243275938904335757337482424'),
    h: BigInt(1), // Cofactor
    lowS: true, // Allow only low-S signatures by default in sign() and verify()
    /**
     * secp256k1 belongs to Koblitz curves: it has efficiently computable endomorphism.
     * Endomorphism uses 2x less RAM, speeds up precomputation by 2x and ECDH / key recovery by 20%.
     * For precomputed wNAF it trades off 1/2 init time & 1/3 ram for 20% perf hit.
     * Explanation: https://gist.github.com/paulmillr/eb670806793e84df628a7c434a873066
     */
    endo: {
        beta: BigInt('0x7ae96a2b657c07106e64479eac3434e99cf0497512f58995c1396c28719501ee'),
        splitScalar: (k) => {
            const n = secp256k1N;
            const a1 = BigInt('0x3086d221a7d46bcde86c90e49284eb15');
            const b1 = -_1n$1 * BigInt('0xe4437ed6010e88286f547fa90abfe4c3');
            const a2 = BigInt('0x114ca50f7a8e2f3f657c1108d9d44cfd8');
            const b2 = a1;
            const POW_2_128 = BigInt('0x100000000000000000000000000000000'); // (2n**128n).toString(16)
            const c1 = divNearest(b2 * k, n);
            const c2 = divNearest(-b1 * k, n);
            let k1 = mod(k - c1 * a1 - c2 * a2, n);
            let k2 = mod(-c1 * b1 - c2 * b2, n);
            const k1neg = k1 > POW_2_128;
            const k2neg = k2 > POW_2_128;
            if (k1neg)
                k1 = n - k1;
            if (k2neg)
                k2 = n - k2;
            if (k1 > POW_2_128 || k2 > POW_2_128) {
                throw new Error('splitScalar: Endomorphism failed, k=' + k);
            }
            return { k1neg, k1, k2neg, k2 };
        },
    },
}, sha256$2);
// Schnorr signatures are superior to ECDSA from above. Below is Schnorr-specific BIP0340 code.
// https://github.com/bitcoin/bips/blob/master/bip-0340.mediawiki
BigInt(0);

/*! noble-curves - MIT License (c) 2022 Paul Miller (paulmillr.com) */
// NIST secp256r1 aka p256
// https://www.secg.org/sec2-v2.pdf, https://neuromancer.sk/std/nist/P-256
const Fp = Field(BigInt('0xffffffff00000001000000000000000000000000ffffffffffffffffffffffff'));
const CURVE_A = Fp.create(BigInt('-3'));
const CURVE_B = BigInt('0x5ac635d8aa3a93e7b3ebbd55769886bc651d06b0cc53b0f63bce3c3e27d2604b');
// prettier-ignore
const p256 = createCurve({
    a: CURVE_A, // Equation params: a, b
    b: CURVE_B,
    Fp, // Field: 2n**224n * (2n**32n-1n) + 2n**192n + 2n**96n-1n
    // Curve order, total count of valid points in the field
    n: BigInt('0xffffffff00000000ffffffffffffffffbce6faada7179e84f3b9cac2fc632551'),
    // Base (generator) point (x, y)
    Gx: BigInt('0x6b17d1f2e12c4247f8bce6e563a440f277037d812deb33a0f4a13945d898c296'),
    Gy: BigInt('0x4fe342e2fe1a7f9b8ee7eb4a7c0f9e162bce33576b315ececbb6406837bf51f5'),
    h: BigInt(1),
    lowS: false,
}, sha256$2);

// https://homes.esat.kuleuven.be/~bosselae/ripemd160.html
// https://homes.esat.kuleuven.be/~bosselae/ripemd160/pdf/AB-9601/AB-9601.pdf
const Rho = /* @__PURE__ */ new Uint8Array([7, 4, 13, 1, 10, 6, 15, 3, 12, 0, 9, 5, 2, 14, 11, 8]);
const Id = /* @__PURE__ */ new Uint8Array(new Array(16).fill(0).map((_, i) => i));
const Pi = /* @__PURE__ */ Id.map((i) => (9 * i + 5) % 16);
let idxL = [Id];
let idxR = [Pi];
for (let i = 0; i < 4; i++)
    for (let j of [idxL, idxR])
        j.push(j[i].map((k) => Rho[k]));
const shifts = /* @__PURE__ */ [
    [11, 14, 15, 12, 5, 8, 7, 9, 11, 13, 14, 15, 6, 7, 9, 8],
    [12, 13, 11, 15, 6, 9, 9, 7, 12, 15, 11, 13, 7, 8, 7, 7],
    [13, 15, 14, 11, 7, 7, 6, 8, 13, 14, 13, 12, 5, 5, 6, 9],
    [14, 11, 12, 14, 8, 6, 5, 5, 15, 12, 15, 14, 9, 9, 8, 6],
    [15, 12, 13, 13, 9, 5, 8, 6, 14, 11, 12, 11, 8, 6, 5, 5],
].map((i) => new Uint8Array(i));
const shiftsL = /* @__PURE__ */ idxL.map((idx, i) => idx.map((j) => shifts[i][j]));
const shiftsR = /* @__PURE__ */ idxR.map((idx, i) => idx.map((j) => shifts[i][j]));
const Kl = /* @__PURE__ */ new Uint32Array([
    0x00000000, 0x5a827999, 0x6ed9eba1, 0x8f1bbcdc, 0xa953fd4e,
]);
const Kr = /* @__PURE__ */ new Uint32Array([
    0x50a28be6, 0x5c4dd124, 0x6d703ef3, 0x7a6d76e9, 0x00000000,
]);
// It's called f() in spec.
function f(group, x, y, z) {
    if (group === 0)
        return x ^ y ^ z;
    else if (group === 1)
        return (x & y) | (~x & z);
    else if (group === 2)
        return (x | ~y) ^ z;
    else if (group === 3)
        return (x & z) | (y & ~z);
    else
        return x ^ (y | ~z);
}
// Temporary buffer, not used to store anything between runs
const R_BUF = /* @__PURE__ */ new Uint32Array(16);
class RIPEMD160 extends HashMD {
    constructor() {
        super(64, 20, 8, true);
        this.h0 = 0x67452301 | 0;
        this.h1 = 0xefcdab89 | 0;
        this.h2 = 0x98badcfe | 0;
        this.h3 = 0x10325476 | 0;
        this.h4 = 0xc3d2e1f0 | 0;
    }
    get() {
        const { h0, h1, h2, h3, h4 } = this;
        return [h0, h1, h2, h3, h4];
    }
    set(h0, h1, h2, h3, h4) {
        this.h0 = h0 | 0;
        this.h1 = h1 | 0;
        this.h2 = h2 | 0;
        this.h3 = h3 | 0;
        this.h4 = h4 | 0;
    }
    process(view, offset) {
        for (let i = 0; i < 16; i++, offset += 4)
            R_BUF[i] = view.getUint32(offset, true);
        // prettier-ignore
        let al = this.h0 | 0, ar = al, bl = this.h1 | 0, br = bl, cl = this.h2 | 0, cr = cl, dl = this.h3 | 0, dr = dl, el = this.h4 | 0, er = el;
        // Instead of iterating 0 to 80, we split it into 5 groups
        // And use the groups in constants, functions, etc. Much simpler
        for (let group = 0; group < 5; group++) {
            const rGroup = 4 - group;
            const hbl = Kl[group], hbr = Kr[group]; // prettier-ignore
            const rl = idxL[group], rr = idxR[group]; // prettier-ignore
            const sl = shiftsL[group], sr = shiftsR[group]; // prettier-ignore
            for (let i = 0; i < 16; i++) {
                const tl = (rotl(al + f(group, bl, cl, dl) + R_BUF[rl[i]] + hbl, sl[i]) + el) | 0;
                al = el, el = dl, dl = rotl(cl, 10) | 0, cl = bl, bl = tl; // prettier-ignore
            }
            // 2 loops are 10% faster
            for (let i = 0; i < 16; i++) {
                const tr = (rotl(ar + f(rGroup, br, cr, dr) + R_BUF[rr[i]] + hbr, sr[i]) + er) | 0;
                ar = er, er = dr, dr = rotl(cr, 10) | 0, cr = br, br = tr; // prettier-ignore
            }
        }
        // Add the compressed chunk to the current hash value
        this.set((this.h1 + cl + dr) | 0, (this.h2 + dl + er) | 0, (this.h3 + el + ar) | 0, (this.h4 + al + br) | 0, (this.h0 + bl + cr) | 0);
    }
    roundClean() {
        R_BUF.fill(0);
    }
    destroy() {
        this.destroyed = true;
        this.buffer.fill(0);
        this.set(0, 0, 0, 0, 0);
    }
}
/**
 * RIPEMD-160 - a hash function from 1990s.
 * @param message - msg that would be hashed
 */
const ripemd160 = /* @__PURE__ */ wrapConstructor(() => new RIPEMD160());

// SHA3 (keccak) is based on a new design: basically, the internal state is bigger than output size.
// It's called a sponge function.
// Various per round constants calculations
const SHA3_PI = [];
const SHA3_ROTL = [];
const _SHA3_IOTA = [];
const _0n = /* @__PURE__ */ BigInt(0);
const _1n = /* @__PURE__ */ BigInt(1);
const _2n = /* @__PURE__ */ BigInt(2);
const _7n = /* @__PURE__ */ BigInt(7);
const _256n = /* @__PURE__ */ BigInt(256);
const _0x71n = /* @__PURE__ */ BigInt(0x71);
for (let round = 0, R = _1n, x = 1, y = 0; round < 24; round++) {
    // Pi
    [x, y] = [y, (2 * x + 3 * y) % 5];
    SHA3_PI.push(2 * (5 * y + x));
    // Rotational
    SHA3_ROTL.push((((round + 1) * (round + 2)) / 2) % 64);
    // Iota
    let t = _0n;
    for (let j = 0; j < 7; j++) {
        R = ((R << _1n) ^ ((R >> _7n) * _0x71n)) % _256n;
        if (R & _2n)
            t ^= _1n << ((_1n << /* @__PURE__ */ BigInt(j)) - _1n);
    }
    _SHA3_IOTA.push(t);
}
const [SHA3_IOTA_H, SHA3_IOTA_L] = /* @__PURE__ */ split(_SHA3_IOTA, true);
// Left rotation (without 0, 32, 64)
const rotlH = (h, l, s) => (s > 32 ? rotlBH(h, l, s) : rotlSH(h, l, s));
const rotlL = (h, l, s) => (s > 32 ? rotlBL(h, l, s) : rotlSL(h, l, s));
// Same as keccakf1600, but allows to skip some rounds
function keccakP(s, rounds = 24) {
    const B = new Uint32Array(5 * 2);
    // NOTE: all indices are x2 since we store state as u32 instead of u64 (bigints to slow in js)
    for (let round = 24 - rounds; round < 24; round++) {
        // Theta θ
        for (let x = 0; x < 10; x++)
            B[x] = s[x] ^ s[x + 10] ^ s[x + 20] ^ s[x + 30] ^ s[x + 40];
        for (let x = 0; x < 10; x += 2) {
            const idx1 = (x + 8) % 10;
            const idx0 = (x + 2) % 10;
            const B0 = B[idx0];
            const B1 = B[idx0 + 1];
            const Th = rotlH(B0, B1, 1) ^ B[idx1];
            const Tl = rotlL(B0, B1, 1) ^ B[idx1 + 1];
            for (let y = 0; y < 50; y += 10) {
                s[x + y] ^= Th;
                s[x + y + 1] ^= Tl;
            }
        }
        // Rho (ρ) and Pi (π)
        let curH = s[2];
        let curL = s[3];
        for (let t = 0; t < 24; t++) {
            const shift = SHA3_ROTL[t];
            const Th = rotlH(curH, curL, shift);
            const Tl = rotlL(curH, curL, shift);
            const PI = SHA3_PI[t];
            curH = s[PI];
            curL = s[PI + 1];
            s[PI] = Th;
            s[PI + 1] = Tl;
        }
        // Chi (χ)
        for (let y = 0; y < 50; y += 10) {
            for (let x = 0; x < 10; x++)
                B[x] = s[y + x];
            for (let x = 0; x < 10; x++)
                s[y + x] ^= ~B[(x + 2) % 10] & B[(x + 4) % 10];
        }
        // Iota (ι)
        s[0] ^= SHA3_IOTA_H[round];
        s[1] ^= SHA3_IOTA_L[round];
    }
    B.fill(0);
}
class Keccak extends Hash {
    // NOTE: we accept arguments in bytes instead of bits here.
    constructor(blockLen, suffix, outputLen, enableXOF = false, rounds = 24) {
        super();
        this.blockLen = blockLen;
        this.suffix = suffix;
        this.outputLen = outputLen;
        this.enableXOF = enableXOF;
        this.rounds = rounds;
        this.pos = 0;
        this.posOut = 0;
        this.finished = false;
        this.destroyed = false;
        // Can be passed from user as dkLen
        number(outputLen);
        // 1600 = 5x5 matrix of 64bit.  1600 bits === 200 bytes
        if (0 >= this.blockLen || this.blockLen >= 200)
            throw new Error('Sha3 supports only keccak-f1600 function');
        this.state = new Uint8Array(200);
        this.state32 = u32(this.state);
    }
    keccak() {
        if (!isLE)
            byteSwap32(this.state32);
        keccakP(this.state32, this.rounds);
        if (!isLE)
            byteSwap32(this.state32);
        this.posOut = 0;
        this.pos = 0;
    }
    update(data) {
        exists(this);
        const { blockLen, state } = this;
        data = toBytes(data);
        const len = data.length;
        for (let pos = 0; pos < len;) {
            const take = Math.min(blockLen - this.pos, len - pos);
            for (let i = 0; i < take; i++)
                state[this.pos++] ^= data[pos++];
            if (this.pos === blockLen)
                this.keccak();
        }
        return this;
    }
    finish() {
        if (this.finished)
            return;
        this.finished = true;
        const { state, suffix, pos, blockLen } = this;
        // Do the padding
        state[pos] ^= suffix;
        if ((suffix & 0x80) !== 0 && pos === blockLen - 1)
            this.keccak();
        state[blockLen - 1] ^= 0x80;
        this.keccak();
    }
    writeInto(out) {
        exists(this, false);
        bytes(out);
        this.finish();
        const bufferOut = this.state;
        const { blockLen } = this;
        for (let pos = 0, len = out.length; pos < len;) {
            if (this.posOut >= blockLen)
                this.keccak();
            const take = Math.min(blockLen - this.posOut, len - pos);
            out.set(bufferOut.subarray(this.posOut, this.posOut + take), pos);
            this.posOut += take;
            pos += take;
        }
        return out;
    }
    xofInto(out) {
        // Sha3/Keccak usage with XOF is probably mistake, only SHAKE instances can do XOF
        if (!this.enableXOF)
            throw new Error('XOF is not possible for this instance');
        return this.writeInto(out);
    }
    xof(bytes) {
        number(bytes);
        return this.xofInto(new Uint8Array(bytes));
    }
    digestInto(out) {
        output(out, this);
        if (this.finished)
            throw new Error('digest() was already called');
        this.writeInto(out);
        this.destroy();
        return out;
    }
    digest() {
        return this.digestInto(new Uint8Array(this.outputLen));
    }
    destroy() {
        this.destroyed = true;
        this.state.fill(0);
    }
    _cloneInto(to) {
        const { blockLen, suffix, outputLen, rounds, enableXOF } = this;
        to || (to = new Keccak(blockLen, suffix, outputLen, enableXOF, rounds));
        to.state32.set(this.state32);
        to.pos = this.pos;
        to.posOut = this.posOut;
        to.finished = this.finished;
        to.rounds = rounds;
        // Suffix can change in cSHAKE
        to.suffix = suffix;
        to.outputLen = outputLen;
        to.enableXOF = enableXOF;
        to.destroyed = this.destroyed;
        return to;
    }
}
const gen = (suffix, blockLen, outputLen) => wrapConstructor(() => new Keccak(blockLen, suffix, outputLen));
/**
 * keccak-256 hash function. Different from SHA3-256.
 * @param message - that would be hashed
 */
const keccak_256 = /* @__PURE__ */ gen(0x01, 136, 256 / 8);

/* jshint esversion: 6 */

var canonicalize = function serialize (object) {
  if (typeof object === 'number' && isNaN(object)) {
    throw new Error('NaN is not allowed');
  }

  if (typeof object === 'number' && !isFinite(object)) {
    throw new Error('Infinity is not allowed');
  }

  if (object === null || typeof object !== 'object') {
    return JSON.stringify(object);
  }

  if (object.toJSON instanceof Function) {
    return serialize(object.toJSON());
  }

  if (Array.isArray(object)) {
    const values = object.reduce((t, cv, ci) => {
      const comma = ci === 0 ? '' : ',';
      const value = cv === undefined || typeof cv === 'symbol' ? null : cv;
      return `${t}${comma}${serialize(value)}`;
    }, '');
    return `[${values}]`;
  }

  const values = Object.keys(object).sort().reduce((t, cv) => {
    if (object[cv] === undefined ||
        typeof object[cv] === 'symbol') {
      return t;
    }
    const comma = t.length === 0 ? '' : ',';
    return `${t}${comma}${serialize(cv)}:${serialize(object[cv])}`;
  }, '');
  return `{${values}}`;
};

// Copyright 2018 Consensys AG

function _catch$7(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
function inMemoryCache() {
  const cache = new Map();
  return function (parsed, resolve) {
    try {
      let _exit;
      function _temp2(_result) {
        if (_exit) return _result;
        const cached = cache.get(parsed.didUrl);
        return cached !== undefined ? cached : Promise.resolve(resolve()).then(function (result) {
          var _result$didResolution;
          if (((_result$didResolution = result.didResolutionMetadata) == null ? void 0 : _result$didResolution.error) !== 'notFound') {
            cache.set(parsed.didUrl, result);
          }
          return result;
        });
      }
      const _temp = function () {
        if (parsed.params && parsed.params['no-cache'] === 'true') {
          return Promise.resolve(resolve()).then(function (_await$resolve) {
            _exit = 1;
            return _await$resolve;
          });
        }
      }();
      return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
function noCache(parsed, resolve) {
  return resolve();
}
const PCT_ENCODED = '(?:%[0-9a-fA-F]{2})';
const ID_CHAR = `(?:[a-zA-Z0-9._-]|${PCT_ENCODED})`;
const METHOD = '([a-z0-9]+)';
const METHOD_ID = `((?:${ID_CHAR}*:)*(${ID_CHAR}+))`;
const PARAM_CHAR = '[a-zA-Z0-9_.:%-]';
const PARAM = `;${PARAM_CHAR}+=${PARAM_CHAR}*`;
const PARAMS = `((${PARAM})*)`;
const PATH = `(/[^#?]*)?`;
const QUERY = `([?][^#]*)?`;
const FRAGMENT = `(#.*)?`;
const DID_MATCHER = new RegExp(`^did:${METHOD}:${METHOD_ID}${PARAMS}${PATH}${QUERY}${FRAGMENT}$`);
/**
 * Parses a DID URL and builds a {@link ParsedDID | ParsedDID object}
 *
 * @param didUrl - the DID URL string to be parsed
 * @returns a ParsedDID object, or null if the input is not a DID URL
 */
function parse(didUrl) {
  if (didUrl === '' || !didUrl) return null;
  const sections = didUrl.match(DID_MATCHER);
  if (sections) {
    const parts = {
      did: `did:${sections[1]}:${sections[2]}`,
      method: sections[1],
      id: sections[2],
      didUrl
    };
    if (sections[4]) {
      const params = sections[4].slice(1).split(';');
      parts.params = {};
      for (const p of params) {
        const kv = p.split('=');
        parts.params[kv[0]] = kv[1];
      }
    }
    if (sections[6]) parts.path = sections[6];
    if (sections[7]) parts.query = sections[7].slice(1);
    if (sections[8]) parts.fragment = sections[8].slice(1);
    return parts;
  }
  return null;
}
const EMPTY_RESULT = {
  didResolutionMetadata: {},
  didDocument: null,
  didDocumentMetadata: {}
};
function wrapLegacyResolver(resolve) {
  return function (did, parsed, resolver) {
    try {
      return Promise.resolve(_catch$7(function () {
        return Promise.resolve(resolve(did, parsed, resolver)).then(function (doc) {
          return {
            ...EMPTY_RESULT,
            didResolutionMetadata: {
              contentType: 'application/did+ld+json'
            },
            didDocument: doc
          };
          // eslint-disable-next-line @typescript-eslint/no-explicit-any
        });
      }, function (e) {
        return {
          ...EMPTY_RESULT,
          didResolutionMetadata: {
            error: 'notFound',
            message: e.toString() // This is not in spec, but may be helpful
          }
        };
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
/**
 * This implementation of {@link Resolvable} bundles together multiple implementations of {@link DIDResolver} and
 * presents a single function call to users.
 */
class Resolver {
  constructor(registry = {}, options = {}) {
    this.registry = void 0;
    this.cache = void 0;
    this.registry = registry;
    this.cache = options.cache === true ? inMemoryCache() : options.cache || noCache;
    if (options.legacyResolvers) {
      Object.keys(options.legacyResolvers).map(methodName => {
        if (!this.registry[methodName]) {
          this.registry[methodName] = wrapLegacyResolver(
          // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
          options.legacyResolvers[methodName]);
        }
      });
    }
  }
  resolve(didUrl, options = {}) {
    try {
      const _this = this;
      const parsed = parse(didUrl);
      if (parsed === null) {
        return Promise.resolve({
          ...EMPTY_RESULT,
          didResolutionMetadata: {
            error: 'invalidDid'
          }
        });
      }
      const resolver = _this.registry[parsed.method];
      if (!resolver) {
        return Promise.resolve({
          ...EMPTY_RESULT,
          didResolutionMetadata: {
            error: 'unsupportedDidMethod'
          }
        });
      }
      return Promise.resolve(_this.cache(parsed, () => resolver(parsed.did, parsed, _this, options)));
    } catch (e) {
      return Promise.reject(e);
    }
  }
}

/*! scure-base - MIT License (c) 2022 Paul Miller (paulmillr.com) */
// Utilities
/**
 * @__NO_SIDE_EFFECTS__
 */
function assertNumber(n) {
    if (!Number.isSafeInteger(n))
        throw new Error(`Wrong integer: ${n}`);
}
function isBytes(a) {
    return (a instanceof Uint8Array ||
        (a != null && typeof a === 'object' && a.constructor.name === 'Uint8Array'));
}
/**
 * @__NO_SIDE_EFFECTS__
 */
function chain(...args) {
    const id = (a) => a;
    // Wrap call in closure so JIT can inline calls
    const wrap = (a, b) => (c) => a(b(c));
    // Construct chain of args[-1].encode(args[-2].encode([...]))
    const encode = args.map((x) => x.encode).reduceRight(wrap, id);
    // Construct chain of args[0].decode(args[1].decode(...))
    const decode = args.map((x) => x.decode).reduce(wrap, id);
    return { encode, decode };
}
/**
 * Encodes integer radix representation to array of strings using alphabet and back
 * @__NO_SIDE_EFFECTS__
 */
function alphabet(alphabet) {
    return {
        encode: (digits) => {
            if (!Array.isArray(digits) || (digits.length && typeof digits[0] !== 'number'))
                throw new Error('alphabet.encode input should be an array of numbers');
            return digits.map((i) => {
                assertNumber(i);
                if (i < 0 || i >= alphabet.length)
                    throw new Error(`Digit index outside alphabet: ${i} (alphabet: ${alphabet.length})`);
                return alphabet[i];
            });
        },
        decode: (input) => {
            if (!Array.isArray(input) || (input.length && typeof input[0] !== 'string'))
                throw new Error('alphabet.decode input should be array of strings');
            return input.map((letter) => {
                if (typeof letter !== 'string')
                    throw new Error(`alphabet.decode: not string element=${letter}`);
                const index = alphabet.indexOf(letter);
                if (index === -1)
                    throw new Error(`Unknown letter: "${letter}". Allowed: ${alphabet}`);
                return index;
            });
        },
    };
}
/**
 * @__NO_SIDE_EFFECTS__
 */
function join(separator = '') {
    if (typeof separator !== 'string')
        throw new Error('join separator should be string');
    return {
        encode: (from) => {
            if (!Array.isArray(from) || (from.length && typeof from[0] !== 'string'))
                throw new Error('join.encode input should be array of strings');
            for (let i of from)
                if (typeof i !== 'string')
                    throw new Error(`join.encode: non-string input=${i}`);
            return from.join(separator);
        },
        decode: (to) => {
            if (typeof to !== 'string')
                throw new Error('join.decode input should be string');
            return to.split(separator);
        },
    };
}
/**
 * Pad strings array so it has integer number of bits
 * @__NO_SIDE_EFFECTS__
 */
function padding(bits, chr = '=') {
    assertNumber(bits);
    if (typeof chr !== 'string')
        throw new Error('padding chr should be string');
    return {
        encode(data) {
            if (!Array.isArray(data) || (data.length && typeof data[0] !== 'string'))
                throw new Error('padding.encode input should be array of strings');
            for (let i of data)
                if (typeof i !== 'string')
                    throw new Error(`padding.encode: non-string input=${i}`);
            while ((data.length * bits) % 8)
                data.push(chr);
            return data;
        },
        decode(input) {
            if (!Array.isArray(input) || (input.length && typeof input[0] !== 'string'))
                throw new Error('padding.encode input should be array of strings');
            for (let i of input)
                if (typeof i !== 'string')
                    throw new Error(`padding.decode: non-string input=${i}`);
            let end = input.length;
            if ((end * bits) % 8)
                throw new Error('Invalid padding: string should have whole number of bytes');
            for (; end > 0 && input[end - 1] === chr; end--) {
                if (!(((end - 1) * bits) % 8))
                    throw new Error('Invalid padding: string has too much padding');
            }
            return input.slice(0, end);
        },
    };
}
/**
 * @__NO_SIDE_EFFECTS__
 */
function normalize(fn) {
    if (typeof fn !== 'function')
        throw new Error('normalize fn should be function');
    return { encode: (from) => from, decode: (to) => fn(to) };
}
const gcd = /* @__NO_SIDE_EFFECTS__ */ (a, b) => (!b ? a : gcd(b, a % b));
const radix2carry = /*@__NO_SIDE_EFFECTS__ */ (from, to) => from + (to - gcd(from, to));
/**
 * Implemented with numbers, because BigInt is 5x slower
 * @__NO_SIDE_EFFECTS__
 */
function convertRadix2(data, from, to, padding) {
    if (!Array.isArray(data))
        throw new Error('convertRadix2: data should be array');
    if (from <= 0 || from > 32)
        throw new Error(`convertRadix2: wrong from=${from}`);
    if (to <= 0 || to > 32)
        throw new Error(`convertRadix2: wrong to=${to}`);
    if (radix2carry(from, to) > 32) {
        throw new Error(`convertRadix2: carry overflow from=${from} to=${to} carryBits=${radix2carry(from, to)}`);
    }
    let carry = 0;
    let pos = 0; // bitwise position in current element
    const mask = 2 ** to - 1;
    const res = [];
    for (const n of data) {
        assertNumber(n);
        if (n >= 2 ** from)
            throw new Error(`convertRadix2: invalid data word=${n} from=${from}`);
        carry = (carry << from) | n;
        if (pos + from > 32)
            throw new Error(`convertRadix2: carry overflow pos=${pos} from=${from}`);
        pos += from;
        for (; pos >= to; pos -= to)
            res.push(((carry >> (pos - to)) & mask) >>> 0);
        carry &= 2 ** pos - 1; // clean carry, otherwise it will cause overflow
    }
    carry = (carry << (to - pos)) & mask;
    if (!padding && pos >= from)
        throw new Error('Excess padding');
    if (!padding && carry)
        throw new Error(`Non-zero padding: ${carry}`);
    if (padding && pos > 0)
        res.push(carry >>> 0);
    return res;
}
/**
 * If both bases are power of same number (like `2**8 <-> 2**64`),
 * there is a linear algorithm. For now we have implementation for power-of-two bases only.
 * @__NO_SIDE_EFFECTS__
 */
function radix2(bits, revPadding = false) {
    assertNumber(bits);
    if (bits <= 0 || bits > 32)
        throw new Error('radix2: bits should be in (0..32]');
    if (radix2carry(8, bits) > 32 || radix2carry(bits, 8) > 32)
        throw new Error('radix2: carry overflow');
    return {
        encode: (bytes) => {
            if (!isBytes(bytes))
                throw new Error('radix2.encode input should be Uint8Array');
            return convertRadix2(Array.from(bytes), 8, bits, !revPadding);
        },
        decode: (digits) => {
            if (!Array.isArray(digits) || (digits.length && typeof digits[0] !== 'number'))
                throw new Error('radix2.decode input should be array of numbers');
            return Uint8Array.from(convertRadix2(digits, bits, 8, revPadding));
        },
    };
}
/**
 * @__NO_SIDE_EFFECTS__
 */
function unsafeWrapper(fn) {
    if (typeof fn !== 'function')
        throw new Error('unsafeWrapper fn should be function');
    return function (...args) {
        try {
            return fn.apply(null, args);
        }
        catch (e) { }
    };
}
// RFC 4648 aka RFC 3548
// ---------------------
/* @__PURE__ */ chain(radix2(4), alphabet('0123456789ABCDEF'), join(''));
/* @__PURE__ */ chain(radix2(5), alphabet('ABCDEFGHIJKLMNOPQRSTUVWXYZ234567'), padding(5), join(''));
/* @__PURE__ */ chain(radix2(5), alphabet('ABCDEFGHIJKLMNOPQRSTUVWXYZ234567'), join(''));
/* @__PURE__ */ chain(radix2(5), alphabet('0123456789ABCDEFGHIJKLMNOPQRSTUV'), padding(5), join(''));
/* @__PURE__ */ chain(radix2(5), alphabet('0123456789ABCDEFGHIJKLMNOPQRSTUV'), join(''));
/* @__PURE__ */ chain(radix2(5), alphabet('0123456789ABCDEFGHJKMNPQRSTVWXYZ'), join(''), normalize((s) => s.toUpperCase().replace(/O/g, '0').replace(/[IL]/g, '1')));
/* @__PURE__ */ chain(radix2(6), alphabet('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'), padding(6), join(''));
/* @__PURE__ */ chain(radix2(6), alphabet('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'), join(''));
/* @__PURE__ */ chain(radix2(6), alphabet('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_'), padding(6), join(''));
/* @__PURE__ */ chain(radix2(6), alphabet('ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_'), join(''));
const BECH_ALPHABET = /* @__PURE__ */ chain(alphabet('qpzry9x8gf2tvdw0s3jn54khce6mua7l'), join(''));
const POLYMOD_GENERATORS = [0x3b6a57b2, 0x26508e6d, 0x1ea119fa, 0x3d4233dd, 0x2a1462b3];
/**
 * @__NO_SIDE_EFFECTS__
 */
function bech32Polymod(pre) {
    const b = pre >> 25;
    let chk = (pre & 0x1ffffff) << 5;
    for (let i = 0; i < POLYMOD_GENERATORS.length; i++) {
        if (((b >> i) & 1) === 1)
            chk ^= POLYMOD_GENERATORS[i];
    }
    return chk;
}
/**
 * @__NO_SIDE_EFFECTS__
 */
function bechChecksum(prefix, words, encodingConst = 1) {
    const len = prefix.length;
    let chk = 1;
    for (let i = 0; i < len; i++) {
        const c = prefix.charCodeAt(i);
        if (c < 33 || c > 126)
            throw new Error(`Invalid prefix (${prefix})`);
        chk = bech32Polymod(chk) ^ (c >> 5);
    }
    chk = bech32Polymod(chk);
    for (let i = 0; i < len; i++)
        chk = bech32Polymod(chk) ^ (prefix.charCodeAt(i) & 0x1f);
    for (let v of words)
        chk = bech32Polymod(chk) ^ v;
    for (let i = 0; i < 6; i++)
        chk = bech32Polymod(chk);
    chk ^= encodingConst;
    return BECH_ALPHABET.encode(convertRadix2([chk % 2 ** 30], 30, 5, false));
}
/**
 * @__NO_SIDE_EFFECTS__
 */
function genBech32(encoding) {
    const ENCODING_CONST = encoding === 'bech32' ? 1 : 0x2bc830a3;
    const _words = radix2(5);
    const fromWords = _words.decode;
    const toWords = _words.encode;
    const fromWordsUnsafe = unsafeWrapper(fromWords);
    function encode(prefix, words, limit = 90) {
        if (typeof prefix !== 'string')
            throw new Error(`bech32.encode prefix should be string, not ${typeof prefix}`);
        if (!Array.isArray(words) || (words.length && typeof words[0] !== 'number'))
            throw new Error(`bech32.encode words should be array of numbers, not ${typeof words}`);
        if (prefix.length === 0)
            throw new TypeError(`Invalid prefix length ${prefix.length}`);
        const actualLength = prefix.length + 7 + words.length;
        if (limit !== false && actualLength > limit)
            throw new TypeError(`Length ${actualLength} exceeds limit ${limit}`);
        const lowered = prefix.toLowerCase();
        const sum = bechChecksum(lowered, words, ENCODING_CONST);
        return `${lowered}1${BECH_ALPHABET.encode(words)}${sum}`;
    }
    function decode(str, limit = 90) {
        if (typeof str !== 'string')
            throw new Error(`bech32.decode input should be string, not ${typeof str}`);
        if (str.length < 8 || (limit !== false && str.length > limit))
            throw new TypeError(`Wrong string length: ${str.length} (${str}). Expected (8..${limit})`);
        // don't allow mixed case
        const lowered = str.toLowerCase();
        if (str !== lowered && str !== str.toUpperCase())
            throw new Error(`String must be lowercase or uppercase`);
        const sepIndex = lowered.lastIndexOf('1');
        if (sepIndex === 0 || sepIndex === -1)
            throw new Error(`Letter "1" must be present between prefix and data only`);
        const prefix = lowered.slice(0, sepIndex);
        const data = lowered.slice(sepIndex + 1);
        if (data.length < 6)
            throw new Error('Data must be at least 6 characters long');
        const words = BECH_ALPHABET.decode(data).slice(0, -6);
        const sum = bechChecksum(prefix, words, ENCODING_CONST);
        if (!data.endsWith(sum))
            throw new Error(`Invalid checksum in ${str}: expected "${sum}"`);
        return { prefix, words };
    }
    const decodeUnsafe = unsafeWrapper(decode);
    function decodeToBytes(str) {
        const { prefix, words } = decode(str, false);
        return { prefix, words, bytes: fromWords(words) };
    }
    return { encode, decode, decodeToBytes, decodeUnsafe, fromWords, fromWordsUnsafe, toWords };
}
const bech32 = /* @__PURE__ */ genBech32('bech32');
/* @__PURE__ */ chain(radix2(4), alphabet('0123456789abcdef'), join(''), normalize((s) => {
    if (typeof s !== 'string' || s.length % 2)
        throw new TypeError(`hex.decode: expected string, got ${typeof s} with length ${s.length}`);
    return s.toLowerCase();
}));

const u8a = {
  toString,
  fromString,
  concat: concat$1
};
function bytesToBase64url(b) {
  return u8a.toString(b, 'base64url');
}
function base64ToBytes(s) {
  const inputBase64Url = s.replace(/\+/g, '-').replace(/\//g, '_').replace(/=/g, '');
  return u8a.fromString(inputBase64Url, 'base64url');
}
function base58ToBytes(s) {
  return u8a.fromString(s, 'base58btc');
}
function bytesToBase58(b) {
  return u8a.toString(b, 'base58btc');
}
const SUPPORTED_PUBLIC_KEY_TYPES = {
  ES256: ['JsonWebKey2020', 'Multikey', 'EcdsaSecp256r1VerificationKey2019'],
  ES256K: ['EcdsaSecp256k1VerificationKey2019',
  /**
   * Equivalent to EcdsaSecp256k1VerificationKey2019 when key is an ethereumAddress
   */
  'EcdsaSecp256k1RecoveryMethod2020',
  /**
   * @deprecated, supported for backward compatibility. Equivalent to EcdsaSecp256k1VerificationKey2019 when key is
   *   not an ethereumAddress
   */
  'Secp256k1VerificationKey2018',
  /**
   * @deprecated, supported for backward compatibility. Equivalent to EcdsaSecp256k1VerificationKey2019 when key is
   *   not an ethereumAddress
   */
  'Secp256k1SignatureVerificationKey2018',
  /**
   * @deprecated, supported for backward compatibility. Equivalent to EcdsaSecp256k1VerificationKey2019 when key is
   *   not an ethereumAddress
   */
  'EcdsaPublicKeySecp256k1',
  /**
   *  TODO - support R1 key as well
   *   'ConditionalProof2022',
   */
  'JsonWebKey2020', 'Multikey'],
  'ES256K-R': ['EcdsaSecp256k1VerificationKey2019',
  /**
   * Equivalent to EcdsaSecp256k1VerificationKey2019 when key is an ethereumAddress
   */
  'EcdsaSecp256k1RecoveryMethod2020',
  /**
   * @deprecated, supported for backward compatibility. Equivalent to EcdsaSecp256k1VerificationKey2019 when key is
   *   not an ethereumAddress
   */
  'Secp256k1VerificationKey2018',
  /**
   * @deprecated, supported for backward compatibility. Equivalent to EcdsaSecp256k1VerificationKey2019 when key is
   *   not an ethereumAddress
   */
  'Secp256k1SignatureVerificationKey2018',
  /**
   * @deprecated, supported for backward compatibility. Equivalent to EcdsaSecp256k1VerificationKey2019 when key is
   *   not an ethereumAddress
   */
  'EcdsaPublicKeySecp256k1', 'ConditionalProof2022', 'JsonWebKey2020', 'Multikey'],
  Ed25519: ['ED25519SignatureVerification', 'Ed25519VerificationKey2018', 'Ed25519VerificationKey2020', 'JsonWebKey2020', 'Multikey'],
  EdDSA: ['ED25519SignatureVerification', 'Ed25519VerificationKey2018', 'Ed25519VerificationKey2020', 'JsonWebKey2020', 'Multikey']
};
const VM_TO_KEY_TYPE = {
  Secp256k1SignatureVerificationKey2018: 'Secp256k1',
  Secp256k1VerificationKey2018: 'Secp256k1',
  EcdsaSecp256k1VerificationKey2019: 'Secp256k1',
  EcdsaPublicKeySecp256k1: 'Secp256k1',
  EcdsaSecp256k1RecoveryMethod2020: 'Secp256k1',
  EcdsaSecp256r1VerificationKey2019: 'P-256',
  Ed25519VerificationKey2018: 'Ed25519',
  Ed25519VerificationKey2020: 'Ed25519',
  ED25519SignatureVerification: 'Ed25519',
  X25519KeyAgreementKey2019: 'X25519',
  X25519KeyAgreementKey2020: 'X25519',
  ConditionalProof2022: undefined,
  JsonWebKey2020: undefined,
  Multikey: undefined // key type must be extracted from the multicodec

}; // this is from the multicodec table https://github.com/multiformats/multicodec/blob/master/table.csv

const supportedCodecs = {
  'ed25519-pub': 0xed,
  'x25519-pub': 0xec,
  'secp256k1-pub': 0xe7,
  'bls12_381-g1-pub': 0xea,
  'bls12_381-g2-pub': 0xeb,
  'p256-pub': 0x1200
};
const CODEC_TO_KEY_TYPE = {
  'bls12_381-g1-pub': 'Bls12381G1',
  'bls12_381-g2-pub': 'Bls12381G2',
  'ed25519-pub': 'Ed25519',
  'p256-pub': 'P-256',
  'secp256k1-pub': 'Secp256k1',
  'x25519-pub': 'X25519'
};
/**
 * Extracts the raw byte representation of a public key from a VerificationMethod along with an inferred key type
 * @param pk a VerificationMethod entry from a DIDDocument
 * @return an object containing the `keyBytes` of the public key and an inferred `keyType`
 */

function extractPublicKeyBytes(pk) {
  if (pk.publicKeyBase58) {
    return {
      keyBytes: base58ToBytes(pk.publicKeyBase58),
      keyType: VM_TO_KEY_TYPE[pk.type]
    };
  } else if (pk.publicKeyBase64) {
    return {
      keyBytes: base64ToBytes(pk.publicKeyBase64),
      keyType: VM_TO_KEY_TYPE[pk.type]
    };
  } else if (pk.publicKeyHex) {
    return {
      keyBytes: hexToBytes(pk.publicKeyHex),
      keyType: VM_TO_KEY_TYPE[pk.type]
    };
  } else if (pk.publicKeyJwk && pk.publicKeyJwk.crv === 'secp256k1' && pk.publicKeyJwk.x && pk.publicKeyJwk.y) {
    return {
      keyBytes: secp256k1.ProjectivePoint.fromAffine({
        x: bytesToBigInt(base64ToBytes(pk.publicKeyJwk.x)),
        y: bytesToBigInt(base64ToBytes(pk.publicKeyJwk.y))
      }).toRawBytes(false),
      keyType: 'Secp256k1'
    };
  } else if (pk.publicKeyJwk && pk.publicKeyJwk.crv === 'P-256' && pk.publicKeyJwk.x && pk.publicKeyJwk.y) {
    return {
      keyBytes: p256.ProjectivePoint.fromAffine({
        x: bytesToBigInt(base64ToBytes(pk.publicKeyJwk.x)),
        y: bytesToBigInt(base64ToBytes(pk.publicKeyJwk.y))
      }).toRawBytes(false),
      keyType: 'P-256'
    };
  } else if (pk.publicKeyJwk && pk.publicKeyJwk.kty === 'OKP' && ['Ed25519', 'X25519'].includes(pk.publicKeyJwk.crv ?? '') && pk.publicKeyJwk.x) {
    return {
      keyBytes: base64ToBytes(pk.publicKeyJwk.x),
      keyType: pk.publicKeyJwk.crv
    };
  } else if (pk.publicKeyMultibase) {
    const {
      keyBytes,
      keyType
    } = multibaseToBytes(pk.publicKeyMultibase);
    return {
      keyBytes,
      keyType: keyType ?? VM_TO_KEY_TYPE[pk.type]
    };
  }

  return {
    keyBytes: new Uint8Array()
  };
}
/**
 * Encodes the given byte array to a multibase string (defaulting to base58btc).
 * If a codec is provided, the corresponding multicodec prefix will be added.
 *
 * @param b - the Uint8Array to be encoded
 * @param base - the base to use for encoding (defaults to base58btc)
 * @param codec - the codec to use for encoding (defaults to no codec)
 *
 * @returns the multibase encoded string
 *
 * @public
 */

function bytesToMultibase(b, base = 'base58btc', codec) {
  if (!codec) {
    return u8a.toString(src.encode(base, b), 'utf-8');
  } else {
    const codecCode = typeof codec === 'string' ? supportedCodecs[codec] : codec;
    const prefixLength = encodingLength(codecCode);
    const multicodecEncoding = new Uint8Array(prefixLength + b.length);
    encodeTo(codecCode, multicodecEncoding); // set prefix

    multicodecEncoding.set(b, prefixLength); // add the original bytes

    return u8a.toString(src.encode(base, multicodecEncoding), 'utf-8');
  }
}
/**
 * Converts a multibase string to the Uint8Array it represents.
 * This method will assume the byte array that is multibase encoded is a multicodec and will attempt to decode it.
 *
 * @param s - the string to be converted
 *
 * @throws if the string is not formatted correctly.
 *
 * @public
 */

function multibaseToBytes(s) {
  const bytes = src.decode(s); // look for known key lengths first
  // Ed25519/X25519, secp256k1/P256 compressed or not, BLS12-381 G1/G2 compressed

  if ([32, 33, 48, 64, 65, 96].includes(bytes.length)) {
    return {
      keyBytes: bytes
    };
  } // then assume multicodec, otherwise return the bytes


  try {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const [codec, length] = decode$1(bytes);
    const possibleCodec = Object.entries(supportedCodecs).filter(([, code]) => code === codec)?.[0][0] ?? '';
    return {
      keyBytes: bytes.slice(length),
      keyType: CODEC_TO_KEY_TYPE[possibleCodec]
    };
  } catch (e) {
    // not a multicodec, return the bytes
    return {
      keyBytes: bytes
    };
  }
}
function hexToBytes(s, minLength) {
  let input = s.startsWith('0x') ? s.substring(2) : s;

  if (input.length % 2 !== 0) {
    input = `0${input}`;
  }

  if (minLength) {
    const paddedLength = Math.max(input.length, minLength * 2);
    input = input.padStart(paddedLength, '00');
  }

  return u8a.fromString(input.toLowerCase(), 'base16');
}
function encodeBase64url(s) {
  return bytesToBase64url(u8a.fromString(s));
}
function decodeBase64url(s) {
  return u8a.toString(base64ToBytes(s));
}
function bytesToHex(b) {
  return u8a.toString(b, 'base16');
}
function bytesToBigInt(b) {
  return BigInt(`0x` + u8a.toString(b, 'base16'));
}
function stringToBytes(s) {
  return u8a.fromString(s, 'utf-8');
}
function toJose({
  r,
  s,
  recoveryParam
}, recoverable) {
  const jose = new Uint8Array(recoverable ? 65 : 64);
  jose.set(u8a.fromString(r, 'base16'), 0);
  jose.set(u8a.fromString(s, 'base16'), 32);

  if (recoverable) {
    if (typeof recoveryParam === 'undefined') {
      throw new Error('Signer did not return a recoveryParam');
    }

    jose[64] = recoveryParam;
  }

  return bytesToBase64url(jose);
}
function fromJose(signature) {
  const signatureBytes = base64ToBytes(signature);

  if (signatureBytes.length < 64 || signatureBytes.length > 65) {
    throw new TypeError(`Wrong size for signature. Expected 64 or 65 bytes, but got ${signatureBytes.length}`);
  }

  const r = bytesToHex(signatureBytes.slice(0, 32));
  const s = bytesToHex(signatureBytes.slice(32, 64));
  const recoveryParam = signatureBytes.length === 65 ? signatureBytes[64] : undefined;
  return {
    r,
    s,
    recoveryParam
  };
}
function leftpad(data, size = 64) {
  if (data.length === size) return data;
  return '0'.repeat(size - data.length) + data;
}

function sha256$1(payload) {
  const data = typeof payload === 'string' ? fromString(payload) : payload;
  return sha256$2(data);
}
const keccak = keccak_256;
function toEthereumAddress(hexPublicKey) {
  const hashInput = fromString(hexPublicKey.slice(2), 'base16');
  return `0x${toString(keccak(hashInput).slice(-20), 'base16')}`;
}

/**
 *  Creates a configured signer function for signing data using the ES256K (secp256k1 + sha256) algorithm.
 *
 *  The signing function itself takes the data as a `Uint8Array` or `string` and returns a `base64Url`-encoded signature
 *
 *  @example
 *  ```typescript
 *  const sign: Signer = ES256KSigner(process.env.PRIVATE_KEY)
 *  const signature: string = await sign(data)
 *  ```
 *
 *  @param    {String}    privateKey   a private key as `Uint8Array`
 *  @param    {Boolean}   recoverable  an optional flag to add the recovery param to the generated signatures
 *  @return   {Function}               a configured signer function `(data: string | Uint8Array): Promise<string>`
 */

function ES256KSigner(privateKey, recoverable = false) {
  const privateKeyBytes = privateKey;

  if (privateKeyBytes.length !== 32) {
    throw new Error(`bad_key: Invalid private key format. Expecting 32 bytes, but got ${privateKeyBytes.length}`);
  }

  return function (data) {
    try {
      const signature = secp256k1.sign(sha256$1(data), privateKeyBytes);
      return Promise.resolve(toJose({
        r: leftpad(signature.r.toString(16)),
        s: leftpad(signature.s.toString(16)),
        recoveryParam: signature.recovery
      }, recoverable));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}

/**
 *  Creates a configured signer function for signing data using the ES256 (secp256r1 + sha256) algorithm.
 *
 *  The signing function itself takes the data as a `Uint8Array` or `string` and returns a `base64Url`-encoded signature
 *
 *  @example
 *  ```typescript
 *  const sign: Signer = ES256Signer(process.env.PRIVATE_KEY)
 *  const signature: string = await sign(data)
 *  ```
 *
 *  @param    {String}    privateKey   a private key as `Uint8Array`
 *  @return   {Function}               a configured signer function `(data: string | Uint8Array): Promise<string>`
 */

function ES256Signer(privateKey) {
  if (privateKey.length !== 32) {
    throw new Error(`bad_key: Invalid private key format. Expecting 32 bytes, but got ${privateKey.length}`);
  }

  return function (data) {
    try {
      const signature = p256.sign(sha256$1(data), privateKey);
      return Promise.resolve(toJose({
        r: leftpad(signature.r.toString(16)),
        s: leftpad(signature.s.toString(16))
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}

function instanceOfEcdsaSignature(object) {
  return typeof object === 'object' && 'r' in object && 's' in object;
}

function ES256SignerAlg() {
  return function sign(payload, signer) {
    try {
      return Promise.resolve(signer(payload)).then(function (signature) {
        if (instanceOfEcdsaSignature(signature)) {
          return toJose(signature);
        } else {
          return signature;
        }
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
function ES256KSignerAlg(recoverable) {
  return function sign(payload, signer) {
    try {
      return Promise.resolve(signer(payload)).then(function (signature) {
        if (instanceOfEcdsaSignature(signature)) {
          return toJose(signature, recoverable);
        } else {
          if (recoverable && typeof fromJose(signature).recoveryParam === 'undefined') {
            throw new Error(`not_supported: ES256K-R not supported when signer doesn't provide a recovery param`);
          }

          return signature;
        }
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
function Ed25519SignerAlg() {
  return function sign(payload, signer) {
    try {
      return Promise.resolve(signer(payload)).then(function (signature) {
        if (!instanceOfEcdsaSignature(signature)) {
          return signature;
        } else {
          throw new Error('invalid_config: expected a signer function that returns a string instead of signature object');
        }
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
const algorithms$1 = {
  ES256: ES256SignerAlg(),
  ES256K: ES256KSignerAlg(),
  // This is a non-standard algorithm but retained for backwards compatibility
  // see https://github.com/decentralized-identity/did-jwt/issues/146
  'ES256K-R': ES256KSignerAlg(true),
  // This is actually incorrect but retained for backwards compatibility
  // see https://github.com/decentralized-identity/did-jwt/issues/130
  Ed25519: Ed25519SignerAlg(),
  EdDSA: Ed25519SignerAlg()
};

function SignerAlg(alg) {
  const impl = algorithms$1[alg];
  if (!impl) throw new Error(`not_supported: Unsupported algorithm ${alg}`);
  return impl;
}

function publicKeyToAddress$1(publicKey, otherAddress) {
  // Use the same version/prefix byte as the given address.
  const version = bytesToHex(base58ToBytes(otherAddress).slice(0, 1));
  const publicKeyBuffer = hexToBytes(publicKey);
  const publicKeyHash = ripemd160(sha256$1(publicKeyBuffer));
  const step1 = version + bytesToHex(publicKeyHash);
  const step2 = sha256$1(hexToBytes(step1));
  const step3 = sha256$1(step2);
  const checksum = bytesToHex(step3).substring(0, 8);
  const step4 = step1 + checksum;
  return bytesToBase58(hexToBytes(step4));
}

function publicKeyToAddress(publicKey, prefix) {
  const publicKeyBuffer = secp256k1.ProjectivePoint.fromHex(publicKey).toRawBytes();
  const hash = ripemd160(sha256$1(publicKeyBuffer));
  const words = bech32.toWords(hash);
  return bech32.encode(prefix, words).replace(prefix, '');
}

function verifyBlockchainAccountId(publicKey, blockchainAccountId) {
  if (blockchainAccountId) {
    const chain = blockchainAccountId.split(':');

    switch (chain[0]) {
      case 'bip122':
        chain[chain.length - 1] = publicKeyToAddress$1(publicKey, chain[chain.length - 1]);
        break;

      case 'cosmos':
        chain[chain.length - 1] = publicKeyToAddress(publicKey, chain[1]);
        break;

      case 'eip155':
        chain[chain.length - 1] = toEthereumAddress(publicKey);
        break;

      default:
        return false;
    }

    return chain.join(':').toLowerCase() === blockchainAccountId.toLowerCase();
  }

  return false;
}

function toSignatureObject(signature, recoverable = false) {
  const rawSig = base64ToBytes(signature);

  if (rawSig.length !== (recoverable ? 65 : 64)) {
    throw new Error('wrong signature length');
  }

  const r = bytesToHex(rawSig.slice(0, 32));
  const s = bytesToHex(rawSig.slice(32, 64));
  const sigObj = {
    r,
    s
  };

  if (recoverable) {
    sigObj.recoveryParam = rawSig[64];
  }

  return sigObj;
}
function toSignatureObject2(signature, recoverable = false) {
  const bytes = base64ToBytes(signature);

  if (bytes.length !== (recoverable ? 65 : 64)) {
    throw new Error('wrong signature length');
  }

  return {
    compact: bytes.slice(0, 64),
    recovery: bytes[64]
  };
}
function verifyES256(data, signature, authenticators) {
  const hash = sha256$1(data);
  const sig = p256.Signature.fromCompact(toSignatureObject2(signature).compact);
  const fullPublicKeys = authenticators.filter(a => !a.ethereumAddress && !a.blockchainAccountId);
  const signer = fullPublicKeys.find(pk => {
    try {
      const {
        keyBytes
      } = extractPublicKeyBytes(pk);
      return p256.verify(sig, hash, keyBytes);
    } catch (err) {
      return false;
    }
  });
  if (!signer) throw new Error('invalid_signature: Signature invalid for JWT');
  return signer;
}
function verifyES256K(data, signature, authenticators) {
  const hash = sha256$1(data);
  const signatureNormalized = secp256k1.Signature.fromCompact(base64ToBytes(signature)).normalizeS();
  const fullPublicKeys = authenticators.filter(a => {
    return !a.ethereumAddress && !a.blockchainAccountId;
  });
  const blockchainAddressKeys = authenticators.filter(a => {
    return a.ethereumAddress || a.blockchainAccountId;
  });
  let signer = fullPublicKeys.find(pk => {
    try {
      const {
        keyBytes
      } = extractPublicKeyBytes(pk);
      return secp256k1.verify(signatureNormalized, hash, keyBytes);
    } catch (err) {
      return false;
    }
  });

  if (!signer && blockchainAddressKeys.length > 0) {
    signer = verifyRecoverableES256K(data, signature, blockchainAddressKeys);
  }

  if (!signer) throw new Error('invalid_signature: Signature invalid for JWT');
  return signer;
}
function verifyRecoverableES256K(data, signature, authenticators) {
  const signatures = [];

  if (signature.length > 86) {
    signatures.push(toSignatureObject2(signature, true));
  } else {
    const so = toSignatureObject2(signature, false);
    signatures.push({ ...so,
      recovery: 0
    });
    signatures.push({ ...so,
      recovery: 1
    });
  }

  const hash = sha256$1(data);

  const checkSignatureAgainstSigner = sigObj => {
    const signature = secp256k1.Signature.fromCompact(sigObj.compact).addRecoveryBit(sigObj.recovery || 0);
    const recoveredPublicKey = signature.recoverPublicKey(hash);
    const recoveredAddress = toEthereumAddress(recoveredPublicKey.toHex(false)).toLowerCase();
    const recoveredPublicKeyHex = recoveredPublicKey.toHex(false);
    const recoveredCompressedPublicKeyHex = recoveredPublicKey.toHex(true);
    return authenticators.find(a => {
      const {
        keyBytes
      } = extractPublicKeyBytes(a);
      const keyHex = bytesToHex(keyBytes);
      return keyHex === recoveredPublicKeyHex || keyHex === recoveredCompressedPublicKeyHex || a.ethereumAddress?.toLowerCase() === recoveredAddress || a.blockchainAccountId?.split('@eip155')?.[0].toLowerCase() === recoveredAddress || // CAIP-2
      verifyBlockchainAccountId(recoveredPublicKeyHex, a.blockchainAccountId) // CAIP-10
      ;
    });
  }; // Find first verification method


  for (const signature of signatures) {
    const verificationMethod = checkSignatureAgainstSigner(signature);
    if (verificationMethod) return verificationMethod;
  } // If no one found matching


  throw new Error('invalid_signature: Signature invalid for JWT');
}
function verifyEd25519(data, signature, authenticators) {
  const clear = stringToBytes(data);
  const signatureBytes = base64ToBytes(signature);
  const signer = authenticators.find(a => {
    const {
      keyBytes,
      keyType
    } = extractPublicKeyBytes(a);

    if (keyType === 'Ed25519') {
      return ed25519.verify(signatureBytes, clear, keyBytes);
    } else {
      return false;
    }
  });
  if (!signer) throw new Error('invalid_signature: Signature invalid for JWT');
  return signer;
}
const algorithms = {
  ES256: verifyES256,
  ES256K: verifyES256K,
  // This is a non-standard algorithm but retained for backwards compatibility
  // see https://github.com/decentralized-identity/did-jwt/issues/146
  'ES256K-R': verifyRecoverableES256K,
  // This is actually incorrect but retained for backwards compatibility
  // see https://github.com/decentralized-identity/did-jwt/issues/130
  Ed25519: verifyEd25519,
  EdDSA: verifyEd25519
};

function VerifierAlgorithm(alg) {
  const impl = algorithms[alg];
  if (!impl) throw new Error(`not_supported: Unsupported algorithm ${alg}`);
  return impl;
}

VerifierAlgorithm.toSignatureObject = toSignatureObject;

/**
 * Error prefixes used for known verification failure cases.
 *
 * For compatibility, these error prefixes match the existing error messages, but will be adjusted in a future major
 * version update to match the scenarios better.
 *
 * @beta
 */
const JWT_ERROR = {
  /**
   * Thrown when a JWT payload schema is unexpected or when validity period does not match
   */
  INVALID_JWT: 'invalid_jwt',

  /**
   * Thrown when the verifier audience does not match the one set in the JWT payload
   */
  INVALID_AUDIENCE: 'invalid_config',

  /**
   * Thrown when none of the public keys of the issuer match the signature of the JWT.
   *
   * This is equivalent to `NO_SUITABLE_KEYS` when the `proofPurpose` is NOT specified.
   */
  INVALID_SIGNATURE: 'invalid_signature',

  /**
   * Thrown when the DID document of the issuer does not have any keys that match the signature for the given
   * `proofPurpose`.
   *
   * This is equivalent to `invalid_signature`, when a `proofPurpose` is specified.
   */
  NO_SUITABLE_KEYS: 'no_suitable_keys',

  /**
   * Thrown when the `alg` of the JWT or the encoding of the key is not supported
   */
  NOT_SUPPORTED: 'not_supported',

  /**
   * Thrown when the DID resolver is unable to resolve the issuer DID.
   */
  RESOLVER_ERROR: 'resolver_error'
};

function _catch$1$1(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }

  if (result && result.then) {
    return result.then(void 0, recover);
  }

  return result;
}

const verifyConditionDelegated = function (jwt, {
  header,
  payload,
  data,
  signature
}, authenticator, options) {
  try {
    if (!authenticator.conditionDelegated) {
      throw new Error('Expected conditionDelegated');
    }

    if (!options.resolver) {
      throw new Error('Expected resolver');
    }

    let foundSigner;
    const issuer = authenticator.conditionDelegated;
    return Promise.resolve(resolveAuthenticator(options.resolver, header.alg, issuer, options.proofPurpose)).then(function (didAuthenticator) {
      let _exit2;

      function _temp6(_result4) {
        if (_exit2) ;

        if (foundSigner) {
          return authenticator;
        }

        throw new Error(`${JWT_ERROR.INVALID_SIGNATURE}: condition for authenticator ${authenticator.id} is not met.`);
      }

      const didResolutionResult = didAuthenticator.didResolutionResult;

      if (!didResolutionResult?.didDocument) {
        throw new Error(`${JWT_ERROR.RESOLVER_ERROR}: Could not resolve delegated DID ${issuer}.`);
      }

      const delegatedAuthenticator = didAuthenticator.authenticators.find(authenticator => authenticator.id === issuer);

      if (!delegatedAuthenticator) {
        throw new Error(`${JWT_ERROR.NO_SUITABLE_KEYS}: Could not find delegated authenticator ${issuer} in it's DID Document`);
      }

      const _temp5 = function () {
        if (delegatedAuthenticator.type === CONDITIONAL_PROOF_2022) {
          return Promise.resolve(verifyJWT(jwt, { ...options,
            ...{
              didAuthenticator: {
                didResolutionResult,
                authenticators: [delegatedAuthenticator],
                issuer: delegatedAuthenticator.id
              }
            }
          })).then(function ({
            verified
          }) {
            if (verified) {
              foundSigner = delegatedAuthenticator;
            }
          });
        } else {
          try {
            foundSigner = verifyJWTDecoded({
              header,
              payload,
              data,
              signature
            }, delegatedAuthenticator);
          } catch (e) {
            if (!e.message.startsWith('invalid_signature:')) throw e;
          }
        }
      }();

      return _temp5 && _temp5.then ? _temp5.then(_temp6) : _temp6(_temp5);
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

const _iteratorSymbol$1$1 = typeof Symbol !== "undefined" ? Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator")) : "@@iterator";

function _settle$2$1(pact, state, value) {
  if (!pact.s) {
    if (value instanceof _Pact$2$1) {
      if (value.s) {
        if (state & 1) {
          state = value.s;
        }

        value = value.v;
      } else {
        value.o = _settle$2$1.bind(null, pact, state);
        return;
      }
    }

    if (value && value.then) {
      value.then(_settle$2$1.bind(null, pact, state), _settle$2$1.bind(null, pact, 2));
      return;
    }

    pact.s = state;
    pact.v = value;
    const observer = pact.o;

    if (observer) {
      observer(pact);
    }
  }
}

const _Pact$2$1 = /*#__PURE__*/function () {
  function _Pact() {}

  _Pact.prototype.then = function (onFulfilled, onRejected) {
    const result = new _Pact();
    const state = this.s;

    if (state) {
      const callback = state & 1 ? onFulfilled : onRejected;

      if (callback) {
        try {
          _settle$2$1(result, 1, callback(this.v));
        } catch (e) {
          _settle$2$1(result, 2, e);
        }

        return result;
      } else {
        return this;
      }
    }

    this.o = function (_this) {
      try {
        const value = _this.v;

        if (_this.s & 1) {
          _settle$2$1(result, 1, onFulfilled ? onFulfilled(value) : value);
        } else if (onRejected) {
          _settle$2$1(result, 1, onRejected(value));
        } else {
          _settle$2$1(result, 2, value);
        }
      } catch (e) {
        _settle$2$1(result, 2, e);
      }
    };

    return result;
  };

  return _Pact;
}();

function _isSettledPact$2$1(thenable) {
  return thenable instanceof _Pact$2$1 && thenable.s & 1;
}

function _forTo$2$1(array, body, check) {
  var i = -1,
      pact,
      reject;

  function _cycle(result) {
    try {
      while (++i < array.length && (!check || !check())) {
        result = body(i);

        if (result && result.then) {
          if (_isSettledPact$2$1(result)) {
            result = result.v;
          } else {
            result.then(_cycle, reject || (reject = _settle$2$1.bind(null, pact = new _Pact$2$1(), 2)));
            return;
          }
        }
      }

      if (pact) {
        _settle$2$1(pact, 1, result);
      } else {
        pact = result;
      }
    } catch (e) {
      _settle$2$1(pact || (pact = new _Pact$2$1()), 2, e);
    }
  }

  _cycle();

  return pact;
}

const verifyConditionWeightedThreshold = function (jwt, {
  header,
  payload,
  data,
  signature
}, authenticator, options) {
  try {
    let _exit;

    function _temp4(_result3) {
      if (_exit) return _result3;
      throw new Error(`${JWT_ERROR.INVALID_SIGNATURE}: condition for authenticator ${authenticator.id} is not met.`);
    }

    if (!authenticator.conditionWeightedThreshold || !authenticator.threshold) {
      throw new Error('Expected conditionWeightedThreshold and threshold');
    }

    const issuers = [];
    const threshold = authenticator.threshold;
    let weightCount = 0;

    const _temp3 = _forOf$1$1(authenticator.conditionWeightedThreshold, function (weightedCondition) {
      function _temp2(_result2) {
        if (_exit) return _result2;

        if (foundSigner && !issuers.includes(foundSigner.id)) {
          issuers.push(foundSigner.id);
          weightCount += weightedCondition.weight;

          if (weightCount >= threshold) {
            _exit = 1;
            return authenticator;
          }
        }
      }

      const currentCondition = weightedCondition.condition;
      let foundSigner;

      const _temp = _catch$1$1(function () {
        if (currentCondition.type === CONDITIONAL_PROOF_2022) {
          if (!options.didAuthenticator) {
            throw new Error('Expected didAuthenticator');
          }

          const newOptions = { ...options,
            didAuthenticator: {
              didResolutionResult: options.didAuthenticator?.didResolutionResult,
              authenticators: [currentCondition],
              issuer: currentCondition.id
            }
          };
          return Promise.resolve(verifyJWT(jwt, newOptions)).then(function ({
            verified
          }) {
            if (verified) {
              foundSigner = currentCondition;
            }
          });
        } else {
          return Promise.resolve(verifyJWTDecoded({
            header,
            payload,
            data,
            signature
          }, currentCondition)).then(function (_verifyJWTDecoded) {
            foundSigner = _verifyJWTDecoded;
          });
        }
      }, function (e) {
        if (!e.message.startsWith(JWT_ERROR.INVALID_SIGNATURE)) throw e;
      });

      return _temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp);
    }, function () {
      return _exit;
    });

    return Promise.resolve(_temp3 && _temp3.then ? _temp3.then(_temp4) : _temp4(_temp3));
  } catch (e) {
    return Promise.reject(e);
  }
};

function _forOf$1$1(target, body, check) {
  if (typeof target[_iteratorSymbol$1$1] === "function") {
    var iterator = target[_iteratorSymbol$1$1](),
        step,
        pact,
        reject;

    function _cycle(result) {
      try {
        while (!(step = iterator.next()).done && (!check || !check())) {
          result = body(step.value);

          if (result && result.then) {
            if (_isSettledPact$2$1(result)) {
              result = result.v;
            } else {
              result.then(_cycle, reject || (reject = _settle$2$1.bind(null, pact = new _Pact$2$1(), 2)));
              return;
            }
          }
        }

        if (pact) {
          _settle$2$1(pact, 1, result);
        } else {
          pact = result;
        }
      } catch (e) {
        _settle$2$1(pact || (pact = new _Pact$2$1()), 2, e);
      }
    }

    _cycle();

    if (iterator.return) {
      var _fixup = function (value) {
        try {
          if (!step.done) {
            iterator.return();
          }
        } catch (e) {}

        return value;
      };

      if (pact && pact.then) {
        return pact.then(_fixup, function (e) {
          throw _fixup(e);
        });
      }

      _fixup();
    }

    return pact;
  } // No support for Symbol.iterator


  if (!("length" in target)) {
    throw new TypeError("Object is not iterable");
  } // Handle live collections properly


  var values = [];

  for (var i = 0; i < target.length; i++) {
    values.push(target[i]);
  }

  return _forTo$2$1(values, function (i) {
    return body(values[i]);
  }, check);
}

const verifyConditionalProof = function (jwt, {
  header,
  payload,
  signature,
  data
}, authenticator, options) {
  try {
    // Validate the condition according to its condition property
    if (authenticator.conditionWeightedThreshold) {
      return verifyConditionWeightedThreshold(jwt, {
        header,
        payload,
        data,
        signature
      }, authenticator, options);
    } else if (authenticator.conditionDelegated) {
      return verifyConditionDelegated(jwt, {
        header,
        payload,
        data,
        signature
      }, authenticator, options);
    } // TODO other conditions


    throw new Error(`${JWT_ERROR.INVALID_JWT}: conditional proof type did not find condition for authenticator ${authenticator.id}.`);
  } catch (e) {
    return Promise.reject(e);
  }
};
const verifyProof = function (jwt, {
  header,
  payload,
  signature,
  data
}, authenticator, options) {
  try {
    if (authenticator.type === CONDITIONAL_PROOF_2022) {
      return verifyConditionalProof(jwt, {
        payload,
        header,
        signature,
        data
      }, authenticator, options);
    } else {
      return Promise.resolve(verifyJWTDecoded({
        header,
        payload,
        data,
        signature
      }, [authenticator]));
    }
  } catch (e) {
    return Promise.reject(e);
  }
};
const CONDITIONAL_PROOF_2022 = 'ConditionalProof2022';

/**
 * Resolves relevant public keys or other authenticating material used to verify signature from the DID document of
 * provided DID
 *
 *  @example
 *  ```ts
 *  resolveAuthenticator(resolver, 'ES256K', 'did:uport:2nQtiQG6Cgm1GYTBaaKAgr76uY7iSexUkqX').then(obj => {
 *      const payload = obj.payload
 *      const profile = obj.profile
 *      const jwt = obj.jwt
 *      // ...
 *  })
 *  ```
 *
 *  @param resolver - {Resolvable} a DID resolver function that can obtain the `DIDDocument` for the `issuer`
 *  @param alg - {String} a JWT algorithm
 *  @param issuer - {String} a Decentralized Identifier (DID) to lookup
 *  @param proofPurpose - {ProofPurposeTypes} *Optional* Use the verificationMethod linked in that section of the
 *   issuer DID document
 *  @return {Promise<DIDAuthenticator>} a promise which resolves with an object containing an array of authenticators
 *   or rejects with an error if none exist
 */
function _settle$1$1(pact, state, value) {
  if (!pact.s) {
    if (value instanceof _Pact$1$1) {
      if (value.s) {
        if (state & 1) {
          state = value.s;
        }

        value = value.v;
      } else {
        value.o = _settle$1$1.bind(null, pact, state);
        return;
      }
    }

    if (value && value.then) {
      value.then(_settle$1$1.bind(null, pact, state), _settle$1$1.bind(null, pact, 2));
      return;
    }

    pact.s = state;
    pact.v = value;
    const observer = pact.o;

    if (observer) {
      observer(pact);
    }
  }
}

const _Pact$1$1 = /*#__PURE__*/function () {
  function _Pact() {}

  _Pact.prototype.then = function (onFulfilled, onRejected) {
    const result = new _Pact();
    const state = this.s;

    if (state) {
      const callback = state & 1 ? onFulfilled : onRejected;

      if (callback) {
        try {
          _settle$1$1(result, 1, callback(this.v));
        } catch (e) {
          _settle$1$1(result, 2, e);
        }

        return result;
      } else {
        return this;
      }
    }

    this.o = function (_this) {
      try {
        const value = _this.v;

        if (_this.s & 1) {
          _settle$1$1(result, 1, onFulfilled ? onFulfilled(value) : value);
        } else if (onRejected) {
          _settle$1$1(result, 1, onRejected(value));
        } else {
          _settle$1$1(result, 2, value);
        }
      } catch (e) {
        _settle$1$1(result, 2, e);
      }
    };

    return result;
  };

  return _Pact;
}();

function _isSettledPact$1$1(thenable) {
  return thenable instanceof _Pact$1$1 && thenable.s & 1;
}

function _forTo$1$1(array, body, check) {
  var i = -1,
      pact,
      reject;

  function _cycle(result) {
    try {
      while (++i < array.length && (!check || !check())) {
        result = body(i);

        if (result && result.then) {
          if (_isSettledPact$1$1(result)) {
            result = result.v;
          } else {
            result.then(_cycle, reject || (reject = _settle$1$1.bind(null, pact = new _Pact$1$1(), 2)));
            return;
          }
        }
      }

      if (pact) {
        _settle$1$1(pact, 1, result);
      } else {
        pact = result;
      }
    } catch (e) {
      _settle$1$1(pact || (pact = new _Pact$1$1()), 2, e);
    }
  }

  _cycle();

  return pact;
}

function _catch$6(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }

  if (result && result.then) {
    return result.then(void 0, recover);
  }

  return result;
}

function _for$1(test, update, body) {
  var stage;

  for (;;) {
    var shouldContinue = test();

    if (_isSettledPact$1$1(shouldContinue)) {
      shouldContinue = shouldContinue.v;
    }

    if (!shouldContinue) {
      return result;
    }

    if (shouldContinue.then) {
      stage = 0;
      break;
    }

    var result = body();

    if (result && result.then) {
      if (_isSettledPact$1$1(result)) {
        result = result.s;
      } else {
        stage = 1;
        break;
      }
    }

    if (update) {
      var updateValue = update();

      if (updateValue && updateValue.then && !_isSettledPact$1$1(updateValue)) {
        stage = 2;
        break;
      }
    }
  }

  var pact = new _Pact$1$1();

  var reject = _settle$1$1.bind(null, pact, 2);

  (stage === 0 ? shouldContinue.then(_resumeAfterTest) : stage === 1 ? result.then(_resumeAfterBody) : updateValue.then(_resumeAfterUpdate)).then(void 0, reject);
  return pact;

  function _resumeAfterBody(value) {
    result = value;

    do {
      if (update) {
        updateValue = update();

        if (updateValue && updateValue.then && !_isSettledPact$1$1(updateValue)) {
          updateValue.then(_resumeAfterUpdate).then(void 0, reject);
          return;
        }
      }

      shouldContinue = test();

      if (!shouldContinue || _isSettledPact$1$1(shouldContinue) && !shouldContinue.v) {
        _settle$1$1(pact, 1, result);

        return;
      }

      if (shouldContinue.then) {
        shouldContinue.then(_resumeAfterTest).then(void 0, reject);
        return;
      }

      result = body();

      if (_isSettledPact$1$1(result)) {
        result = result.v;
      }
    } while (!result || !result.then);

    result.then(_resumeAfterBody).then(void 0, reject);
  }

  function _resumeAfterTest(shouldContinue) {
    if (shouldContinue) {
      result = body();

      if (result && result.then) {
        result.then(_resumeAfterBody).then(void 0, reject);
      } else {
        _resumeAfterBody(result);
      }
    } else {
      _settle$1$1(pact, 1, result);
    }
  }

  function _resumeAfterUpdate() {
    if (shouldContinue = test()) {
      if (shouldContinue.then) {
        shouldContinue.then(_resumeAfterTest).then(void 0, reject);
      } else {
        _resumeAfterTest(shouldContinue);
      }
    } else {
      _settle$1$1(pact, 1, result);
    }
  }
}

const resolveAuthenticator = function (resolver, alg, issuer, proofPurpose) {
  try {
    const types = SUPPORTED_PUBLIC_KEY_TYPES[alg];

    if (!types || types.length === 0) {
      throw new Error(`${JWT_ERROR.NOT_SUPPORTED}: No supported signature types for algorithm ${alg}`);
    }

    let didResult;
    return Promise.resolve(resolver.resolve(issuer, {
      accept: DID_JSON
    })).then(function (result) {
      // support legacy resolvers that do not produce DIDResolutionResult
      if (Object.getOwnPropertyNames(result).indexOf('didDocument') === -1) {
        didResult = {
          didDocument: result,
          didDocumentMetadata: {},
          didResolutionMetadata: {
            contentType: DID_JSON
          }
        };
      } else {
        didResult = result;
      }

      if (didResult.didResolutionMetadata?.error || didResult.didDocument == null) {
        const {
          error,
          message
        } = didResult.didResolutionMetadata;
        throw new Error(`${JWT_ERROR.RESOLVER_ERROR}: Unable to resolve DID document for ${issuer}: ${error}, ${message || ''}`);
      }

      const getPublicKeyById = (verificationMethods, pubid) => {
        const filtered = verificationMethods.filter(({
          id
        }) => pubid === id);
        return filtered.length > 0 ? filtered[0] : null;
      };

      let publicKeysToCheck = [...(didResult?.didDocument?.verificationMethod || []), ...(didResult?.didDocument?.publicKey || [])];

      if (typeof proofPurpose === 'string') {
        // support legacy DID Documents that do not list assertionMethod
        if (proofPurpose.startsWith('assertion') && !Object.getOwnPropertyNames(didResult?.didDocument).includes('assertionMethod')) {
          didResult.didDocument = { ...didResult.didDocument
          };
          didResult.didDocument.assertionMethod = [...publicKeysToCheck.map(pk => pk.id)];
        }

        publicKeysToCheck = (didResult.didDocument[proofPurpose] || []).map(verificationMethod => {
          if (typeof verificationMethod === 'string') {
            return getPublicKeyById(publicKeysToCheck, verificationMethod);
          } else if (typeof verificationMethod.publicKey === 'string') {
            // this is a legacy format
            return getPublicKeyById(publicKeysToCheck, verificationMethod.publicKey);
          } else {
            return verificationMethod;
          }
        }).filter(key => key != null);
      }

      const authenticators = publicKeysToCheck.filter(({
        type
      }) => types.find(supported => supported === type));

      if (typeof proofPurpose === 'string' && (!authenticators || authenticators.length === 0)) {
        throw new Error(`${JWT_ERROR.NO_SUITABLE_KEYS}: DID document for ${issuer} does not have public keys suitable for ${alg} with ${proofPurpose} purpose`);
      }

      if (!authenticators || authenticators.length === 0) {
        throw new Error(`${JWT_ERROR.NO_SUITABLE_KEYS}: DID document for ${issuer} does not have public keys for ${alg}`);
      }

      return {
        authenticators,
        issuer,
        didResolutionResult: didResult
      };
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

/**
 *  Verifies given JWT. If the JWT is valid, the promise returns an object including the JWT, the payload of the JWT,
 *  and the DID document of the issuer of the JWT.
 *
 *  @example
 *  ```ts
 *  verifyJWT(
 *      'did:uport:eyJ0eXAiOiJKV1QiLCJhbGciOiJFUzI1NksifQ.eyJyZXF1Z....',
 *      {audience: '5A8bRWU3F7j3REx3vkJ...', callbackUrl: 'https://...'}
 *    ).then(obj => {
 *        const did = obj.did // DID of signer
 *        const payload = obj.payload
 *        const doc = obj.didResolutionResult.didDocument // DID Document of issuer
 *        const jwt = obj.jwt
 *        const signerKeyId = obj.signer.id // ID of key in DID document that signed JWT
 *        ...
 *    })
 *  ```
 *
 *  @param    {String}            jwt                a JSON Web Token to verify
 *  @param    {Object}            [options]           an unsigned credential object
 *  @param    {Boolean}           options.auth        Require signer to be listed in the authentication section of the
 *   DID document (for Authentication purposes)
 *  @param    {String}            options.audience    DID of the recipient of the JWT
 *  @param    {String}            options.callbackUrl callback url in JWT
 *  @return   {Promise<Object, Error>}               a promise which resolves with a response object or rejects with an
 *   error
 */
const verifyJWT = function (jwt, options = {
  resolver: undefined,
  auth: undefined,
  audience: undefined,
  callbackUrl: undefined,
  skewTime: undefined,
  proofPurpose: undefined,
  policies: {},
  didAuthenticator: undefined
}) {
  try {
    function _temp7() {
      let _exit;

      function _temp5(_result) {
        if (_exit) ;

        if (signer) {
          const now = typeof options.policies?.now === 'number' ? options.policies.now : Math.floor(Date.now() / 1000);
          const skewTime = typeof options.skewTime !== 'undefined' && options.skewTime >= 0 ? options.skewTime : NBF_SKEW;
          const nowSkewed = now + skewTime;

          if (options.policies?.nbf !== false && payload.nbf) {
            if (payload.nbf > nowSkewed) {
              throw new Error(`${JWT_ERROR.INVALID_JWT}: JWT not valid before nbf: ${payload.nbf}`);
            }
          } else if (options.policies?.iat !== false && payload.iat && payload.iat > nowSkewed) {
            throw new Error(`${JWT_ERROR.INVALID_JWT}: JWT not valid yet (issued in the future) iat: ${payload.iat}`);
          }

          if (options.policies?.exp !== false && payload.exp && payload.exp <= now - skewTime) {
            throw new Error(`${JWT_ERROR.INVALID_JWT}: JWT has expired: exp: ${payload.exp} < now: ${now}`);
          }

          if (options.policies?.aud !== false && payload.aud) {
            if (!options.audience && !options.callbackUrl) {
              throw new Error(`${JWT_ERROR.INVALID_AUDIENCE}: JWT audience is required but your app address has not been configured`);
            }

            const audArray = Array.isArray(payload.aud) ? payload.aud : [payload.aud];
            const matchedAudience = audArray.find(item => options.audience === item || options.callbackUrl === item);

            if (typeof matchedAudience === 'undefined') {
              throw new Error(`${JWT_ERROR.INVALID_AUDIENCE}: JWT audience does not match your DID or callback url`);
            }
          }

          return {
            verified: true,
            payload,
            didResolutionResult,
            issuer,
            signer,
            jwt,
            policies: options.policies
          };
        }

        throw new Error(`${JWT_ERROR.INVALID_SIGNATURE}: JWT not valid. issuer DID document does not contain a verificationMethod that matches the signature.`);
      }

      const {
        did
      } = parse(didUrl);
      let signer = null;

      const _temp4 = function () {
        if (did !== didUrl) {
          const authenticator = authenticators.find(auth => auth.id === didUrl);

          if (!authenticator) {
            throw new Error(`${JWT_ERROR.INVALID_JWT}: No authenticator found for did URL ${didUrl}`);
          }

          return Promise.resolve(verifyProof(jwt, {
            payload,
            header,
            signature,
            data
          }, authenticator, options)).then(function (_verifyProof) {
            signer = _verifyProof;
          });
        } else {
          let i = 0;
          return _for$1(function () {
            return !_exit && !signer && i < authenticators.length;
          }, void 0, function () {
            function _temp3(_result2) {
              if (_exit) ;
              i++;
            }

            const authenticator = authenticators[i];

            const _temp2 = _catch$6(function () {
              return Promise.resolve(verifyProof(jwt, {
                payload,
                header,
                signature,
                data
              }, authenticator, options)).then(function (_verifyProof2) {
                signer = _verifyProof2;
              });
            }, function (e) {
              if (!e.message.includes(JWT_ERROR.INVALID_SIGNATURE) || i === authenticators.length - 1) throw e;
            });

            return _temp2 && _temp2.then ? _temp2.then(_temp3) : _temp3(_temp2);
          });
        }
      }();

      return _temp4 && _temp4.then ? _temp4.then(_temp5) : _temp5(_temp4);
    }

    if (!options.resolver) throw new Error('missing_resolver: No DID resolver has been configured');
    const {
      payload,
      header,
      signature,
      data
    } = decodeJWT(jwt, false);
    const proofPurpose = Object.prototype.hasOwnProperty.call(options, 'auth') ? options.auth ? 'authentication' : undefined : options.proofPurpose;
    let didUrl;

    if (!payload.iss && !payload.client_id) {
      throw new Error(`${JWT_ERROR.INVALID_JWT}: JWT iss or client_id are required`);
    }

    if (options.didAuthenticator) {
      didUrl = options.didAuthenticator.issuer;
    } else if (payload.iss === SELF_ISSUED_V2 || payload.iss === SELF_ISSUED_V2_VC_INTEROP) {
      if (!payload.sub) {
        throw new Error(`${JWT_ERROR.INVALID_JWT}: JWT sub is required`);
      }

      if (typeof payload.sub_jwk === 'undefined') {
        didUrl = payload.sub;
      } else {
        didUrl = (header.kid || '').split('#')[0];
      }
    } else if (payload.iss === SELF_ISSUED_V0_1) {
      if (!payload.did) {
        throw new Error(`${JWT_ERROR.INVALID_JWT}: JWT did is required`);
      }

      didUrl = payload.did;
    } else if (!payload.iss && payload.scope === 'openid' && payload.redirect_uri) {
      // SIOP Request payload
      // https://identity.foundation/jwt-vc-presentation-profile/#self-issued-op-request-object
      if (!payload.client_id) {
        throw new Error(`${JWT_ERROR.INVALID_JWT}: JWT client_id is required`);
      }

      didUrl = payload.client_id;
    } else {
      didUrl = payload.iss;
    }

    if (!didUrl) {
      throw new Error(`${JWT_ERROR.INVALID_JWT}: No DID has been found in the JWT`);
    }

    let authenticators;
    let issuer;
    let didResolutionResult;

    const _temp6 = function () {
      if (options.didAuthenticator) {
        ({
          didResolutionResult,
          authenticators,
          issuer
        } = options.didAuthenticator);
      } else {
        return Promise.resolve(resolveAuthenticator(options.resolver, header.alg, didUrl, proofPurpose)).then(function (_resolveAuthenticator) {
          ({
            didResolutionResult,
            authenticators,
            issuer
          } = _resolveAuthenticator);
          // Add to options object for recursive reference
          options.didAuthenticator = {
            didResolutionResult,
            authenticators,
            issuer
          };
        });
      }
    }();

    return Promise.resolve(_temp6 && _temp6.then ? _temp6.then(_temp7) : _temp7(_temp6));
  } catch (e) {
    return Promise.reject(e);
  }
};

/**
 *  Creates a multi-signature signed JWT given multiple issuers and their corresponding signers, and a payload for
 * which the signature is over.
 *
 *  @example
 *  const signer = ES256KSigner(process.env.PRIVATE_KEY)
 *  createJWT({address: '5A8bRWU3F7j3REx3vkJ...', signer}, {key1: 'value', key2: ..., ... }).then(jwt => {
 *      ...
 *  })
 *
 *  @param    {Object}            payload               payload object
 *  @param    {Object}            [options]             an unsigned credential object
 *  @param    {boolean}           options.expiresIn     optional flag to denote the expiration time
 *  @param    {boolean}           options.canonicalize  optional flag to canonicalize header and payload before signing
 *  @param    {Object[]}          issuers               array of the issuers, their signers and algorithms
 *  @param    {string}            issuers[].issuer      The DID of the issuer (signer) of JWT
 *  @param    {Signer}            issuers[].signer      a `Signer` function, Please see `ES256KSigner` or `EdDSASigner`
 *  @param    {String}            issuers[].alg         [DEPRECATED] The JWT signing algorithm to use. Supports:
 *   [ES256K, ES256K-R, Ed25519, EdDSA], Defaults to: ES256K. Please use `header.alg` to specify the algorithm
 *  @return   {Promise<Object, Error>}                  a promise which resolves with a signed JSON Web Token or
 *   rejects with an error
 */
const createMultisignatureJWT = function (payload, {
  expiresIn,
  canonicalize
}, issuers) {
  try {
    if (issuers.length === 0) throw new Error('invalid_argument: must provide one or more issuers');
    let payloadResult = payload;
    let jwt = '';

    const _temp = _forTo$1$1(issuers, function (i) {
      const issuer = issuers[i];
      const header = {
        typ: 'JWT',
        alg: issuer.alg
      }; // Create nested JWT
      // See Point 5 of https://www.rfc-editor.org/rfc/rfc7519#section-7.1
      // After the first JWT is created (the first JWS), the next JWT is created by inputting the previous JWT as the
      // payload

      if (i !== 0) {
        header.cty = 'JWT';
      }

      return Promise.resolve(createJWT(payloadResult, { ...issuer,
        canonicalize,
        expiresIn
      }, header)).then(function (_createJWT) {
        jwt = _createJWT;
        payloadResult = {
          jwt
        };
      });
    });

    return Promise.resolve(_temp && _temp.then ? _temp.then(function () {
      return jwt;
    }) : jwt);
  } catch (e) {
    return Promise.reject(e);
  }
};

/**
 *  Creates a signed JWT given an address which becomes the issuer, a signer, and a payload for which the signature is
 * over.
 *
 *  @example
 *  const signer = ES256KSigner(process.env.PRIVATE_KEY)
 *  createJWT({address: '5A8bRWU3F7j3REx3vkJ...', signer}, {key1: 'value', key2: ..., ... }).then(jwt => {
 *      ...
 *  })
 *
 *  @param    {Object}            payload               payload object
 *  @param    {Object}            [options]             an unsigned credential object
 *  @param    {String}            options.issuer        The DID of the issuer (signer) of JWT
 *  @param    {String}            options.alg           [DEPRECATED] The JWT signing algorithm to use. Supports:
 *   [ES256K, ES256K-R, Ed25519, EdDSA], Defaults to: ES256K. Please use `header.alg` to specify the algorithm
 *  @param    {Signer}            options.signer        a `Signer` function, Please see `ES256KSigner` or `EdDSASigner`
 *  @param    {boolean}           options.canonicalize  optional flag to canonicalize header and payload before signing
 *  @param    {Object}            header                optional object to specify or customize the JWT header
 *  @return   {Promise<Object, Error>}                  a promise which resolves with a signed JSON Web Token or
 *   rejects with an error
 */
const createJWT = function (payload, {
  issuer,
  signer,
  alg,
  expiresIn,
  canonicalize
}, header = {}) {
  try {
    if (!signer) throw new Error('missing_signer: No Signer functionality has been configured');
    if (!issuer) throw new Error('missing_issuer: No issuing DID has been configured');
    if (!header.typ) header.typ = 'JWT';
    if (!header.alg) header.alg = alg;
    const timestamps = {
      iat: Math.floor(Date.now() / 1000),
      exp: undefined
    };

    if (expiresIn) {
      if (typeof expiresIn === 'number') {
        timestamps.exp = (payload.nbf || timestamps.iat) + Math.floor(expiresIn);
      } else {
        throw new Error('invalid_argument: JWT expiresIn is not a number');
      }
    }

    const fullPayload = { ...timestamps,
      ...payload,
      iss: issuer
    };
    return createJWS(fullPayload, signer, header, {
      canonicalize
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

/**
 *  Creates a signed JWS given a payload, a signer, and an optional header.
 *
 *  @example
 *  const signer = ES256KSigner(process.env.PRIVATE_KEY)
 *  const jws = await createJWS({ my: 'payload' }, signer)
 *
 *  @param    {Object}            payload           payload object
 *  @param    {Signer}            signer            a signer, see `ES256KSigner or `EdDSASigner`
 *  @param    {Object}            header            optional object to specify or customize the JWS header
 *  @param    {Object}            options           can be used to trigger automatic canonicalization of header and
 *                                                    payload properties
 *  @return   {Promise<string>}                     a Promise which resolves to a JWS string or rejects with an error
 */
const createJWS = function (payload, signer, header = {}, options = {}) {
  try {
    if (!header.alg) header.alg = defaultAlg;
    const encodedPayload = typeof payload === 'string' ? payload : encodeSection(payload, options.canonicalize);
    const signingInput = [encodeSection(header, options.canonicalize), encodedPayload].join('.');
    const jwtSigner = SignerAlg(header.alg);
    return Promise.resolve(jwtSigner(signingInput, signer)).then(function (signature) {
      // JWS Compact Serialization
      // https://www.rfc-editor.org/rfc/rfc7515#section-7.1
      return [signingInput, signature].join('.');
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
const SELF_ISSUED_V2 = 'https://self-issued.me/v2';
const SELF_ISSUED_V2_VC_INTEROP = 'https://self-issued.me/v2/openid-vc'; // https://identity.foundation/jwt-vc-presentation-profile/#id-token-validation

const SELF_ISSUED_V0_1 = 'https://self-issued.me';
const defaultAlg = 'ES256K';
const DID_JSON = 'application/did+json'; // eslint-disable-next-line @typescript-eslint/no-explicit-any

function encodeSection(data, shouldCanonicalize = false) {
  if (shouldCanonicalize) {
    return encodeBase64url(canonicalize(data));
  } else {
    return encodeBase64url(JSON.stringify(data));
  }
}

const NBF_SKEW = 300;

function decodeJWS(jws) {
  const parts = jws.match(/^([a-zA-Z0-9_-]+)\.([a-zA-Z0-9_-]+)\.([a-zA-Z0-9_-]+)$/);

  if (parts) {
    return {
      header: JSON.parse(decodeBase64url(parts[1])),
      payload: parts[2],
      signature: parts[3],
      data: `${parts[1]}.${parts[2]}`
    };
  }

  throw new Error('invalid_argument: Incorrect format JWS');
}
/**
 *  Decodes a JWT and returns an object representing the payload
 *
 *  @example
 *  decodeJWT('eyJ0eXAiOiJKV1QiLCJhbGciOiJFUzI1NksifQ.eyJpYXQiOjE1...')
 *
 *  @param    {String}            jwt                a JSON Web Token to verify
 * @param    {Object}            [recurse]          whether to recurse into the payload to decode any nested JWTs
 *  @return   {Object}                               a JS object representing the decoded JWT
 */


function decodeJWT(jwt, recurse = true) {
  if (!jwt) throw new Error('invalid_argument: no JWT passed into decodeJWT');

  try {
    const jws = decodeJWS(jwt);
    const decodedJwt = Object.assign(jws, {
      payload: JSON.parse(decodeBase64url(jws.payload))
    });
    const iss = decodedJwt.payload.iss;

    if (decodedJwt.header.cty === 'JWT' && recurse) {
      const innerDecodedJwt = decodeJWT(decodedJwt.payload.jwt);
      if (innerDecodedJwt.payload.iss !== iss) throw new Error(`${JWT_ERROR.INVALID_JWT}: multiple issuers`);
      return innerDecodedJwt;
    }

    return decodedJwt;
  } catch (e) {
    throw new Error('invalid_argument: Incorrect format JWT');
  }
}
function verifyJWTDecoded({
  header,
  payload,
  data,
  signature
}, pubKeys) {
  if (!Array.isArray(pubKeys)) pubKeys = [pubKeys];
  const iss = payload.iss;
  let recurse = true;

  do {
    if (iss !== payload.iss) throw new Error(`${JWT_ERROR.INVALID_JWT}: multiple issuers`);

    try {
      const result = VerifierAlgorithm(header.alg)(data, signature, pubKeys);
      return result;
    } catch (e) {
      if (!e.message.startsWith(JWT_ERROR.INVALID_SIGNATURE)) throw e;
    } // TODO probably best to create copy objects than replace reference objects


    if (header.cty !== 'JWT') {
      recurse = false;
    } else {
      ({
        payload,
        header,
        signature,
        data
      } = decodeJWT(payload.jwt, false));
    }
  } while (recurse);

  throw new Error(`${JWT_ERROR.INVALID_SIGNATURE}: no matching public key found`);
}

typeof Symbol !== "undefined" ? Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator")) : "@@iterator";

function randomBytes(bytes) {
  return rb(new Uint8Array(bytes));
}
function byteArrayToNumber(byteArray) {
  var result = 0;
  for (var i = 0; i < byteArray.length; i++) {
    result += byteArray[i] << i * 8;
  }
  return result;
}
function randomNumber(min, max) {
  if (min > max) {
    throwError('Min value cannot be greater than max value');
  }
  var range = max - min;
  var calculateByte = Math.floor(Math.log(range) / Math.log(256)) + 1;
  var randomBytesArray = randomBytes(calculateByte);
  var randomValue = byteArrayToNumber(randomBytesArray) % (range + 1) + min;
  return randomValue;
}
/*

/* Creates a signer from a private key that can be used to sign a JWT
 *
 * @param privateKey the private key to use to sign the JWT
 * @returns a signer (function) that can be used to sign a JWT
 */
function createSigner$1(privateKey) {
  if (privateKey.type === KeyType.K1) {
    return ES256KSigner(privateKey.data.array, true);
  }
  if (privateKey.type === KeyType.R1 || privateKey.type === KeyType.WA) {
    return ES256Signer(privateKey.data.array);
  }
  throw new Error('Unsupported key type');
}
function randomString(bytes) {
  var random = randomBytes(bytes);
  return Array.from(random).map(int2hex).join('');
}
function sha256(digest) {
  return Checksum256.hash(Bytes.from(encodeHex(digest), 'hex')).toString();
}
function int2hex(i) {
  return ('0' + i.toString(16)).slice(-2);
}
function encodeHex(str) {
  return str.split('').map(function (c) {
    return c.charCodeAt(0).toString(16).padStart(2, '0');
  }).join('');
}
function generateRandomKeyPair() {
  var bytes = randomBytes(32);
  var privateKey = new PrivateKey(KeyType.K1, new Bytes(bytes));
  var publicKey = privateKey.toPublic();
  return {
    privateKey: privateKey,
    publicKey: publicKey
  };
}
function createVCSigner(keyManager, level) {
  return {
    sign: function sign(data) {
      try {
        return Promise.resolve(keyManager.signData({
          level: level,
          data: data,
          outputType: 'jwt'
        }));
      } catch (e) {
        return Promise.reject(e);
      }
    }
  };
}

function copyObject(object) {
  return JSON.parse(JSON.stringify(object));
}

// reference links is https://github.com/bitcoin/bips/blob/master/bip-0039/english.txt
var englishPassphraseWords = ['abandon', 'ability', 'able', 'about', 'above', 'absent', 'absorb', 'abstract', 'absurd', 'abuse', 'access', 'accident', 'account', 'accuse', 'achieve', 'acid', 'acoustic', 'acquire', 'across', 'act', 'action', 'actor', 'actress', 'actual', 'adapt', 'add', 'addict', 'address', 'adjust', 'admit', 'adult', 'advance', 'advice', 'aerobic', 'affair', 'afford', 'afraid', 'again', 'age', 'agent', 'agree', 'ahead', 'aim', 'air', 'airport', 'aisle', 'alarm', 'album', 'alcohol', 'alert', 'alien', 'all', 'alley', 'allow', 'almost', 'alone', 'alpha', 'already', 'also', 'alter', 'always', 'amateur', 'amazing', 'among', 'amount', 'amused', 'analyst', 'anchor', 'ancient', 'anger', 'angle', 'angry', 'animal', 'ankle', 'announce', 'annual', 'another', 'answer', 'antenna', 'antique', 'anxiety', 'any', 'apart', 'apology', 'appear', 'apple', 'approve', 'april', 'arch', 'arctic', 'area', 'arena', 'argue', 'arm', 'armed', 'armor', 'army', 'around', 'arrange', 'arrest', 'arrive', 'arrow', 'art', 'artefact', 'artist', 'artwork', 'ask', 'aspect', 'assault', 'asset', 'assist', 'assume', 'asthma', 'athlete', 'atom', 'attack', 'attend', 'attitude', 'attract', 'auction', 'audit', 'august', 'aunt', 'author', 'auto', 'autumn', 'average', 'avocado', 'avoid', 'awake', 'aware', 'away', 'awesome', 'awful', 'awkward', 'axis', 'baby', 'bachelor', 'bacon', 'badge', 'bag', 'balance', 'balcony', 'ball', 'bamboo', 'banana', 'banner', 'bar', 'barely', 'bargain', 'barrel', 'base', 'basic', 'basket', 'battle', 'beach', 'bean', 'beauty', 'because', 'become', 'beef', 'before', 'begin', 'behave', 'behind', 'believe', 'below', 'belt', 'bench', 'benefit', 'best', 'betray', 'better', 'between', 'beyond', 'bicycle', 'bid', 'bike', 'bind', 'biology', 'bird', 'birth', 'bitter', 'black', 'blade', 'blame', 'blanket', 'blast', 'bleak', 'bless', 'blind', 'blood', 'blossom', 'blouse', 'blue', 'blur', 'blush', 'board', 'boat', 'body', 'boil', 'bomb', 'bone', 'bonus', 'book', 'boost', 'border', 'boring', 'borrow', 'boss', 'bottom', 'bounce', 'box', 'boy', 'bracket', 'brain', 'brand', 'brass', 'brave', 'bread', 'breeze', 'brick', 'bridge', 'brief', 'bright', 'bring', 'brisk', 'broccoli', 'broken', 'bronze', 'broom', 'brother', 'brown', 'brush', 'bubble', 'buddy', 'budget', 'buffalo', 'build', 'bulb', 'bulk', 'bullet', 'bundle', 'bunker', 'burden', 'burger', 'burst', 'bus', 'business', 'busy', 'butter', 'buyer', 'buzz', 'cabbage', 'cabin', 'cable', 'cactus', 'cage', 'cake', 'call', 'calm', 'camera', 'camp', 'can', 'canal', 'cancel', 'candy', 'cannon', 'canoe', 'canvas', 'canyon', 'capable', 'capital', 'captain', 'car', 'carbon', 'card', 'cargo', 'carpet', 'carry', 'cart', 'case', 'cash', 'casino', 'castle', 'casual', 'cat', 'catalog', 'catch', 'category', 'cattle', 'caught', 'cause', 'caution', 'cave', 'ceiling', 'celery', 'cement', 'census', 'century', 'cereal', 'certain', 'chair', 'chalk', 'champion', 'change', 'chaos', 'chapter', 'charge', 'chase', 'chat', 'cheap', 'check', 'cheese', 'chef', 'cherry', 'chest', 'chicken', 'chief', 'child', 'chimney', 'choice', 'choose', 'chronic', 'chuckle', 'chunk', 'churn', 'cigar', 'cinnamon', 'circle', 'citizen', 'city', 'civil', 'claim', 'clap', 'clarify', 'claw', 'clay', 'clean', 'clerk', 'clever', 'click', 'client', 'cliff', 'climb', 'clinic', 'clip', 'clock', 'clog', 'close', 'cloth', 'cloud', 'clown', 'club', 'clump', 'cluster', 'clutch', 'coach', 'coast', 'coconut', 'code', 'coffee', 'coil', 'coin', 'collect', 'color', 'column', 'combine', 'come', 'comfort', 'comic', 'common', 'company', 'concert', 'conduct', 'confirm', 'congress', 'connect', 'consider', 'control', 'convince', 'cook', 'cool', 'copper', 'copy', 'coral', 'core', 'corn', 'correct', 'cost', 'cotton', 'couch', 'country', 'couple', 'course', 'cousin', 'cover', 'coyote', 'crack', 'cradle', 'craft', 'cram', 'crane', 'crash', 'crater', 'crawl', 'crazy', 'cream', 'credit', 'creek', 'crew', 'cricket', 'crime', 'crisp', 'critic', 'crop', 'cross', 'crouch', 'crowd', 'crucial', 'cruel', 'cruise', 'crumble', 'crunch', 'crush', 'cry', 'crystal', 'cube', 'culture', 'cup', 'cupboard', 'curious', 'current', 'curtain', 'curve', 'cushion', 'custom', 'cute', 'cycle', 'dad', 'damage', 'damp', 'dance', 'danger', 'daring', 'dash', 'daughter', 'dawn', 'day', 'deal', 'debate', 'debris', 'decade', 'december', 'decide', 'decline', 'decorate', 'decrease', 'deer', 'defense', 'define', 'defy', 'degree', 'delay', 'deliver', 'demand', 'demise', 'denial', 'dentist', 'deny', 'depart', 'depend', 'deposit', 'depth', 'deputy', 'derive', 'describe', 'desert', 'design', 'desk', 'despair', 'destroy', 'detail', 'detect', 'develop', 'device', 'devote', 'diagram', 'dial', 'diamond', 'diary', 'dice', 'diesel', 'diet', 'differ', 'digital', 'dignity', 'dilemma', 'dinner', 'dinosaur', 'direct', 'dirt', 'disagree', 'discover', 'disease', 'dish', 'dismiss', 'disorder', 'display', 'distance', 'divert', 'divide', 'divorce', 'dizzy', 'doctor', 'document', 'dog', 'doll', 'dolphin', 'domain', 'donate', 'donkey', 'donor', 'door', 'dose', 'double', 'dove', 'draft', 'dragon', 'drama', 'drastic', 'draw', 'dream', 'dress', 'drift', 'drill', 'drink', 'drip', 'drive', 'drop', 'drum', 'dry', 'duck', 'dumb', 'dune', 'during', 'dust', 'dutch', 'duty', 'dwarf', 'dynamic', 'eager', 'eagle', 'early', 'earn', 'earth', 'easily', 'east', 'easy', 'echo', 'ecology', 'economy', 'edge', 'edit', 'educate', 'effort', 'egg', 'eight', 'either', 'elbow', 'elder', 'electric', 'elegant', 'element', 'elephant', 'elevator', 'elite', 'else', 'embark', 'embody', 'embrace', 'emerge', 'emotion', 'employ', 'empower', 'empty', 'enable', 'enact', 'end', 'endless', 'endorse', 'enemy', 'energy', 'enforce', 'engage', 'engine', 'enhance', 'enjoy', 'enlist', 'enough', 'enrich', 'enroll', 'ensure', 'enter', 'entire', 'entry', 'envelope', 'episode', 'equal', 'equip', 'era', 'erase', 'erode', 'erosion', 'error', 'erupt', 'escape', 'essay', 'essence', 'estate', 'eternal', 'ethics', 'evidence', 'evil', 'evoke', 'evolve', 'exact', 'example', 'excess', 'exchange', 'excite', 'exclude', 'excuse', 'execute', 'exercise', 'exhaust', 'exhibit', 'exile', 'exist', 'exit', 'exotic', 'expand', 'expect', 'expire', 'explain', 'expose', 'express', 'extend', 'extra', 'eye', 'eyebrow', 'fabric', 'face', 'faculty', 'fade', 'faint', 'faith', 'fall', 'false', 'fame', 'family', 'famous', 'fan', 'fancy', 'fantasy', 'farm', 'fashion', 'fat', 'fatal', 'father', 'fatigue', 'fault', 'favorite', 'feature', 'february', 'federal', 'fee', 'feed', 'feel', 'female', 'fence', 'festival', 'fetch', 'fever', 'few', 'fiber', 'fiction', 'field', 'figure', 'file', 'film', 'filter', 'final', 'find', 'fine', 'finger', 'finish', 'fire', 'firm', 'first', 'fiscal', 'fish', 'fit', 'fitness', 'fix', 'flag', 'flame', 'flash', 'flat', 'flavor', 'flee', 'flight', 'flip', 'float', 'flock', 'floor', 'flower', 'fluid', 'flush', 'fly', 'foam', 'focus', 'fog', 'foil', 'fold', 'follow', 'food', 'foot', 'force', 'forest', 'forget', 'fork', 'fortune', 'forum', 'forward', 'fossil', 'foster', 'found', 'fox', 'fragile', 'frame', 'frequent', 'fresh', 'friend', 'fringe', 'frog', 'front', 'frost', 'frown', 'frozen', 'fruit', 'fuel', 'fun', 'funny', 'furnace', 'fury', 'future', 'gadget', 'gain', 'galaxy', 'gallery', 'game', 'gap', 'garage', 'garbage', 'garden', 'garlic', 'garment', 'gas', 'gasp', 'gate', 'gather', 'gauge', 'gaze', 'general', 'genius', 'genre', 'gentle', 'genuine', 'gesture', 'ghost', 'giant', 'gift', 'giggle', 'ginger', 'giraffe', 'girl', 'give', 'glad', 'glance', 'glare', 'glass', 'glide', 'glimpse', 'globe', 'gloom', 'glory', 'glove', 'glow', 'glue', 'goat', 'goddess', 'gold', 'good', 'goose', 'gorilla', 'gospel', 'gossip', 'govern', 'gown', 'grab', 'grace', 'grain', 'grant', 'grape', 'grass', 'gravity', 'great', 'green', 'grid', 'grief', 'grit', 'grocery', 'group', 'grow', 'grunt', 'guard', 'guess', 'guide', 'guilt', 'guitar', 'gun', 'gym', 'habit', 'hair', 'half', 'hammer', 'hamster', 'hand', 'happy', 'harbor', 'hard', 'harsh', 'harvest', 'hat', 'have', 'hawk', 'hazard', 'head', 'health', 'heart', 'heavy', 'hedgehog', 'height', 'hello', 'helmet', 'help', 'hen', 'hero', 'hidden', 'high', 'hill', 'hint', 'hip', 'hire', 'history', 'hobby', 'hockey', 'hold', 'hole', 'holiday', 'hollow', 'home', 'honey', 'hood', 'hope', 'horn', 'horror', 'horse', 'hospital', 'host', 'hotel', 'hour', 'hover', 'hub', 'huge', 'human', 'humble', 'humor', 'hundred', 'hungry', 'hunt', 'hurdle', 'hurry', 'hurt', 'husband', 'hybrid', 'ice', 'icon', 'idea', 'identify', 'idle', 'ignore', 'ill', 'illegal', 'illness', 'image', 'imitate', 'immense', 'immune', 'impact', 'impose', 'improve', 'impulse', 'inch', 'include', 'income', 'increase', 'index', 'indicate', 'indoor', 'industry', 'infant', 'inflict', 'inform', 'inhale', 'inherit', 'initial', 'inject', 'injury', 'inmate', 'inner', 'innocent', 'input', 'inquiry', 'insane', 'insect', 'inside', 'inspire', 'install', 'intact', 'interest', 'into', 'invest', 'invite', 'involve', 'iron', 'island', 'isolate', 'issue', 'item', 'ivory', 'jacket', 'jaguar', 'jar', 'jazz', 'jealous', 'jeans', 'jelly', 'jewel', 'job', 'join', 'joke', 'journey', 'joy', 'judge', 'juice', 'jump', 'jungle', 'junior', 'junk', 'just', 'kangaroo', 'keen', 'keep', 'ketchup', 'key', 'kick', 'kid', 'kidney', 'kind', 'kingdom', 'kiss', 'kit', 'kitchen', 'kite', 'kitten', 'kiwi', 'knee', 'knife', 'knock', 'know', 'lab', 'label', 'labor', 'ladder', 'lady', 'lake', 'lamp', 'language', 'laptop', 'large', 'later', 'latin', 'laugh', 'laundry', 'lava', 'law', 'lawn', 'lawsuit', 'layer', 'lazy', 'leader', 'leaf', 'learn', 'leave', 'lecture', 'left', 'leg', 'legal', 'legend', 'leisure', 'lemon', 'lend', 'length', 'lens', 'leopard', 'lesson', 'letter', 'level', 'liar', 'liberty', 'library', 'license', 'life', 'lift', 'light', 'like', 'limb', 'limit', 'link', 'lion', 'liquid', 'list', 'little', 'live', 'lizard', 'load', 'loan', 'lobster', 'local', 'lock', 'logic', 'lonely', 'long', 'loop', 'lottery', 'loud', 'lounge', 'love', 'loyal', 'lucky', 'luggage', 'lumber', 'lunar', 'lunch', 'luxury', 'lyrics', 'machine', 'mad', 'magic', 'magnet', 'maid', 'mail', 'main', 'major', 'make', 'mammal', 'man', 'manage', 'mandate', 'mango', 'mansion', 'manual', 'maple', 'marble', 'march', 'margin', 'marine', 'market', 'marriage', 'mask', 'mass', 'master', 'match', 'material', 'math', 'matrix', 'matter', 'maximum', 'maze', 'meadow', 'mean', 'measure', 'meat', 'mechanic', 'medal', 'media', 'melody', 'melt', 'member', 'memory', 'mention', 'menu', 'mercy', 'merge', 'merit', 'merry', 'mesh', 'message', 'metal', 'method', 'middle', 'midnight', 'milk', 'million', 'mimic', 'mind', 'minimum', 'minor', 'minute', 'miracle', 'mirror', 'misery', 'miss', 'mistake', 'mix', 'mixed', 'mixture', 'mobile', 'model', 'modify', 'mom', 'moment', 'monitor', 'monkey', 'monster', 'month', 'moon', 'moral', 'more', 'morning', 'mosquito', 'mother', 'motion', 'motor', 'mountain', 'mouse', 'move', 'movie', 'much', 'muffin', 'mule', 'multiply', 'muscle', 'museum', 'mushroom', 'music', 'must', 'mutual', 'myself', 'mystery', 'myth', 'naive', 'name', 'napkin', 'narrow', 'nasty', 'nation', 'nature', 'near', 'neck', 'need', 'negative', 'neglect', 'neither', 'nephew', 'nerve', 'nest', 'net', 'network', 'neutral', 'never', 'news', 'next', 'nice', 'night', 'noble', 'noise', 'nominee', 'noodle', 'normal', 'north', 'nose', 'notable', 'note', 'nothing', 'notice', 'novel', 'now', 'nuclear', 'number', 'nurse', 'nut', 'oak', 'obey', 'object', 'oblige', 'obscure', 'observe', 'obtain', 'obvious', 'occur', 'ocean', 'october', 'odor', 'off', 'offer', 'office', 'often', 'oil', 'okay', 'old', 'olive', 'olympic', 'omit', 'once', 'one', 'onion', 'online', 'only', 'open', 'opera', 'opinion', 'oppose', 'option', 'orange', 'orbit', 'orchard', 'order', 'ordinary', 'organ', 'orient', 'original', 'orphan', 'ostrich', 'other', 'outdoor', 'outer', 'output', 'outside', 'oval', 'oven', 'over', 'own', 'owner', 'oxygen', 'oyster', 'ozone', 'pact', 'paddle', 'page', 'pair', 'palace', 'palm', 'panda', 'panel', 'panic', 'panther', 'paper', 'parade', 'parent', 'park', 'parrot', 'party', 'pass', 'patch', 'path', 'patient', 'patrol', 'pattern', 'pause', 'pave', 'payment', 'peace', 'peanut', 'pear', 'peasant', 'pelican', 'pen', 'penalty', 'pencil', 'people', 'pepper', 'perfect', 'permit', 'person', 'pet', 'phone', 'photo', 'phrase', 'physical', 'piano', 'picnic', 'picture', 'piece', 'pig', 'pigeon', 'pill', 'pilot', 'pink', 'pioneer', 'pipe', 'pistol', 'pitch', 'pizza', 'place', 'planet', 'plastic', 'plate', 'play', 'please', 'pledge', 'pluck', 'plug', 'plunge', 'poem', 'poet', 'point', 'polar', 'pole', 'police', 'pond', 'pony', 'pool', 'popular', 'portion', 'position', 'possible', 'post', 'potato', 'pottery', 'poverty', 'powder', 'power', 'practice', 'praise', 'predict', 'prefer', 'prepare', 'present', 'pretty', 'prevent', 'price', 'pride', 'primary', 'print', 'priority', 'prison', 'private', 'prize', 'problem', 'process', 'produce', 'profit', 'program', 'project', 'promote', 'proof', 'property', 'prosper', 'protect', 'proud', 'provide', 'public', 'pudding', 'pull', 'pulp', 'pulse', 'pumpkin', 'punch', 'pupil', 'puppy', 'purchase', 'purity', 'purpose', 'purse', 'push', 'put', 'puzzle', 'pyramid', 'quality', 'quantum', 'quarter', 'question', 'quick', 'quit', 'quiz', 'quote', 'rabbit', 'raccoon', 'race', 'rack', 'radar', 'radio', 'rail', 'rain', 'raise', 'rally', 'ramp', 'ranch', 'random', 'range', 'rapid', 'rare', 'rate', 'rather', 'raven', 'raw', 'razor', 'ready', 'real', 'reason', 'rebel', 'rebuild', 'recall', 'receive', 'recipe', 'record', 'recycle', 'reduce', 'reflect', 'reform', 'refuse', 'region', 'regret', 'regular', 'reject', 'relax', 'release', 'relief', 'rely', 'remain', 'remember', 'remind', 'remove', 'render', 'renew', 'rent', 'reopen', 'repair', 'repeat', 'replace', 'report', 'require', 'rescue', 'resemble', 'resist', 'resource', 'response', 'result', 'retire', 'retreat', 'return', 'reunion', 'reveal', 'review', 'reward', 'rhythm', 'rib', 'ribbon', 'rice', 'rich', 'ride', 'ridge', 'rifle', 'right', 'rigid', 'ring', 'riot', 'ripple', 'risk', 'ritual', 'rival', 'river', 'road', 'roast', 'robot', 'robust', 'rocket', 'romance', 'roof', 'rookie', 'room', 'rose', 'rotate', 'rough', 'round', 'route', 'royal', 'rubber', 'rude', 'rug', 'rule', 'run', 'runway', 'rural', 'sad', 'saddle', 'sadness', 'safe', 'sail', 'salad', 'salmon', 'salon', 'salt', 'salute', 'same', 'sample', 'sand', 'satisfy', 'satoshi', 'sauce', 'sausage', 'save', 'say', 'scale', 'scan', 'scare', 'scatter', 'scene', 'scheme', 'school', 'science', 'scissors', 'scorpion', 'scout', 'scrap', 'screen', 'script', 'scrub', 'sea', 'search', 'season', 'seat', 'second', 'secret', 'section', 'security', 'seed', 'seek', 'segment', 'select', 'sell', 'seminar', 'senior', 'sense', 'sentence', 'series', 'service', 'session', 'settle', 'setup', 'seven', 'shadow', 'shaft', 'shallow', 'share', 'shed', 'shell', 'sheriff', 'shield', 'shift', 'shine', 'ship', 'shiver', 'shock', 'shoe', 'shoot', 'shop', 'short', 'shoulder', 'shove', 'shrimp', 'shrug', 'shuffle', 'shy', 'sibling', 'sick', 'side', 'siege', 'sight', 'sign', 'silent', 'silk', 'silly', 'silver', 'similar', 'simple', 'since', 'sing', 'siren', 'sister', 'situate', 'six', 'size', 'skate', 'sketch', 'ski', 'skill', 'skin', 'skirt', 'skull', 'slab', 'slam', 'sleep', 'slender', 'slice', 'slide', 'slight', 'slim', 'slogan', 'slot', 'slow', 'slush', 'small', 'smart', 'smile', 'smoke', 'smooth', 'snack', 'snake', 'snap', 'sniff', 'snow', 'soap', 'soccer', 'social', 'sock', 'soda', 'soft', 'solar', 'soldier', 'solid', 'solution', 'solve', 'someone', 'song', 'soon', 'sorry', 'sort', 'soul', 'sound', 'soup', 'source', 'south', 'space', 'spare', 'spatial', 'spawn', 'speak', 'special', 'speed', 'spell', 'spend', 'sphere', 'spice', 'spider', 'spike', 'spin', 'spirit', 'split', 'spoil', 'sponsor', 'spoon', 'sport', 'spot', 'spray', 'spread', 'spring', 'spy', 'square', 'squeeze', 'squirrel', 'stable', 'stadium', 'staff', 'stage', 'stairs', 'stamp', 'stand', 'start', 'state', 'stay', 'steak', 'steel', 'stem', 'step', 'stereo', 'stick', 'still', 'sting', 'stock', 'stomach', 'stone', 'stool', 'story', 'stove', 'strategy', 'street', 'strike', 'strong', 'struggle', 'student', 'stuff', 'stumble', 'style', 'subject', 'submit', 'subway', 'success', 'such', 'sudden', 'suffer', 'sugar', 'suggest', 'suit', 'summer', 'sun', 'sunny', 'sunset', 'super', 'supply', 'supreme', 'sure', 'surface', 'surge', 'surprise', 'surround', 'survey', 'suspect', 'sustain', 'swallow', 'swamp', 'swap', 'swarm', 'swear', 'sweet', 'swift', 'swim', 'swing', 'switch', 'sword', 'symbol', 'symptom', 'syrup', 'system', 'table', 'tackle', 'tag', 'tail', 'talent', 'talk', 'tank', 'tape', 'target', 'task', 'taste', 'tattoo', 'taxi', 'teach', 'team', 'tell', 'ten', 'tenant', 'tennis', 'tent', 'term', 'test', 'text', 'thank', 'that', 'theme', 'then', 'theory', 'there', 'they', 'thing', 'this', 'thought', 'three', 'thrive', 'throw', 'thumb', 'thunder', 'ticket', 'tide', 'tiger', 'tilt', 'timber', 'time', 'tiny', 'tip', 'tired', 'tissue', 'title', 'toast', 'tobacco', 'today', 'toddler', 'toe', 'together', 'toilet', 'token', 'tomato', 'tomorrow', 'tone', 'tongue', 'tonight', 'tool', 'tooth', 'top', 'topic', 'topple', 'torch', 'tornado', 'tortoise', 'toss', 'total', 'tourist', 'toward', 'tower', 'town', 'toy', 'track', 'trade', 'traffic', 'tragic', 'train', 'transfer', 'trap', 'trash', 'travel', 'tray', 'treat', 'tree', 'trend', 'trial', 'tribe', 'trick', 'trigger', 'trim', 'trip', 'trophy', 'trouble', 'truck', 'true', 'truly', 'trumpet', 'trust', 'truth', 'try', 'tube', 'tuition', 'tumble', 'tuna', 'tunnel', 'turkey', 'turn', 'turtle', 'twelve', 'twenty', 'twice', 'twin', 'twist', 'two', 'type', 'typical', 'ugly', 'umbrella', 'unable', 'unaware', 'uncle', 'uncover', 'under', 'undo', 'unfair', 'unfold', 'unhappy', 'uniform', 'unique', 'unit', 'universe', 'unknown', 'unlock', 'until', 'unusual', 'unveil', 'update', 'upgrade', 'uphold', 'upon', 'upper', 'upset', 'urban', 'urge', 'usage', 'use', 'used', 'useful', 'useless', 'usual', 'utility', 'vacant', 'vacuum', 'vague', 'valid', 'valley', 'valve', 'van', 'vanish', 'vapor', 'various', 'vast', 'vault', 'vehicle', 'velvet', 'vendor', 'venture', 'venue', 'verb', 'verify', 'version', 'very', 'vessel', 'veteran', 'viable', 'vibrant', 'vicious', 'victory', 'video', 'view', 'village', 'vintage', 'violin', 'virtual', 'virus', 'visa', 'visit', 'visual', 'vital', 'vivid', 'vocal', 'voice', 'void', 'volcano', 'volume', 'vote', 'voyage', 'wage', 'wagon', 'wait', 'walk', 'wall', 'walnut', 'want', 'warfare', 'warm', 'warrior', 'wash', 'wasp', 'waste', 'water', 'wave', 'way', 'wealth', 'weapon', 'wear', 'weasel', 'weather', 'web', 'wedding', 'weekend', 'weird', 'welcome', 'west', 'wet', 'whale', 'what', 'wheat', 'wheel', 'when', 'where', 'whip', 'whisper', 'wide', 'width', 'wife', 'wild', 'will', 'win', 'window', 'wine', 'wing', 'wink', 'winner', 'winter', 'wire', 'wisdom', 'wise', 'wish', 'witness', 'wolf', 'woman', 'wonder', 'wood', 'wool', 'word', 'work', 'world', 'worry', 'worth', 'wrap', 'wreck', 'wrestle', 'wrist', 'write', 'wrong', 'yard', 'year', 'yellow', 'you', 'young', 'youth', 'zebra', 'zero', 'zone', 'zoo'];

/**
 * Generates an array of random keywords.
 * @returns {string[]} An array of 6 random keywords.
 */
function generateRandomKeywords() {
  var randomIndices = [];
  while (randomIndices.length < 6) {
    var randomIndex = randomNumber(0, 2047);
    if (!randomIndices.includes(randomIndex)) {
      randomIndices.push(randomIndex);
    }
  }
  var randomKeywords = randomIndices.map(function (index) {
    return englishPassphraseWords[index];
  });
  return randomKeywords;
}
/**
 * Generates auto-suggestions based on the input string.
 * @param {string} inputString - The input string for which auto-suggestions are generated.
 * @returns {string[]} An array of auto-suggestions with a maximum of 4 words.
 */
function generateAutoSuggestions(inputString) {
  if (inputString.trim() === '') {
    return []; // Return an empty array for empty input string
  }
  inputString = inputString.toLowerCase();
  var matchingSuggestions = englishPassphraseWords.filter(function (word) {
    return word.toLowerCase().includes(inputString);
  }).slice(0, 4);
  return matchingSuggestions;
}
/**
 * Checks if the input string is a valid keyword.
 * @param {string} word - The input string to be checked.
 * @returns {boolean} True if the input string is a valid keyword, false otherwise.
 */
function isKeyword(word) {
  return englishPassphraseWords.includes(word);
}

var debug$9 = Debug('tonomy-sdk:settings');
if (typeof Proxy === 'undefined') {
  throw new Error("This environment doesn't support Proxy");
}
var settings;
var fetchFunction;
var initialized = false;
function setSettings(newSettings) {
  debug$9('Settings initialized', newSettings);
  settings = newSettings;
  initialized = true;
}
function setFetch(fetch) {
  debug$9('Fetch initialized', typeof fetch);
  fetchFunction = fetch;
}
function getFetch() {
  return fetchFunction;
}
function getSettings() {
  if (!initialized) {
    throwError('Settings not yet initialized', SdkErrors.SettingsNotInitialized);
  }
  var proxy = new Proxy(settings, {
    get: function get(target, name, receiver) {
      if (Reflect.has(target, name)) {
        return Reflect.get(target, name, receiver);
      }
      throw new Error("Tonomy SDK settings has not been initialized using setSettings() with property for variable: " + name.toString());
    }
  });
  return proxy;
}
function isProduction() {
  debug$9('Checking if production for environment:', settings.environment);
  if (!initialized) {
    throwError('Settings not yet initialized', SdkErrors.SettingsNotInitialized);
  }
  return ['production', 'staging', 'testnet'].includes(settings.environment);
}

const JWT_ALG = 'ES256K';
const JWT_FORMAT = /^[A-Za-z0-9-_=]+\.[A-Za-z0-9-_=]+\.?[A-Za-z0-9-_.+/=]*$/;
const DEFAULT_CONTEXT = 'https://www.w3.org/2018/credentials/v1';
const DEFAULT_VC_TYPE = 'VerifiableCredential';
/**
 * The `JwtProof2020` is a synthetic proof type, usable for differentiating credentials by proof type when representing
 * JWT credentials as W3C VC JSON. It is not a registered W3C VC Data Model algorithm and should not be treated as
 * such.
 *
 * This proof type is only intended as a convenience and does not actually prove the validity of a VC/VP in JSON
 * representation. The actual verifiable credential or presentation is represented in the `jwt` property.
 */
const DEFAULT_JWT_PROOF_TYPE = 'JwtProof2020';

/**
 * Additional W3C VC fields:
 * These are defined as optional top-level properties in the W3C spec but are not mapped to top-level JWT names,
 * so they should be moved inside the "vc" object when transforming to a JWT.
 * Conversely, they should be moved out of the "vc" object when transforming from a JWT to W3C JSON.
 */
const additionalPropNames = ['evidence', 'termsOfUse', 'refreshService', 'credentialSchema', 'credentialStatus'];
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function asArray(arg) {
  return Array.isArray(arg) ? arg : [arg];
}
function deepCopy(source) {
  return Array.isArray(source) ? source.map(item => deepCopy(item)) : source instanceof Date ? new Date(source.getTime()) : source && typeof source === 'object' ? Object.getOwnPropertyNames(source).reduce((o, prop) => {
    Object.defineProperty(o, prop, Object.getOwnPropertyDescriptor(source, prop));
    o[prop] = deepCopy(source[prop]);
    return o;
  }, Object.create(Object.getPrototypeOf(source))) : source;
}
function notEmpty(value) {
  return value !== null && value !== undefined;
}
function cleanUndefined(input) {
  if (typeof input !== 'object' || input === null) {
    return input;
  }
  const obj = {
    ...input
  };
  Object.keys(obj).forEach(key => obj[key] === undefined && delete obj[key]);
  return obj;
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function isLegacyAttestationFormat(payload) {
  // payload is an object and has all the required fields of old attestation format
  return typeof payload === 'object' && payload.sub && payload.iss && payload.claim && payload.iat;
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function attestationToVcFormat(payload) {
  const {
    iat,
    nbf,
    claim,
    vc,
    ...rest
  } = payload;
  const result = {
    ...rest,
    nbf: nbf ? nbf : iat,
    vc: {
      '@context': [DEFAULT_CONTEXT],
      type: [DEFAULT_VC_TYPE],
      credentialSubject: claim
    }
  };
  if (vc) payload.issVc = vc;
  return result;
}
function normalizeJwtCredentialPayload(input, removeOriginalFields = true) {
  let result = deepCopy(input);
  if (isLegacyAttestationFormat(input)) {
    result = attestationToVcFormat(input);
  }
  // FIXME: handle case when credentialSubject(s) are not object types
  result.credentialSubject = {
    ...input.credentialSubject,
    ...input.vc?.credentialSubject
  };
  if (input.sub && !input.credentialSubject?.id && result.credentialSubject) {
    result.credentialSubject.id = input.sub;
    if (removeOriginalFields) {
      delete result.sub;
    }
  }
  if (removeOriginalFields) {
    delete result.vc?.credentialSubject;
  }
  if (typeof input.issuer === 'undefined' || typeof input.issuer === 'object') {
    result.issuer = cleanUndefined({
      id: input.iss,
      ...input.issuer
    });
    if (removeOriginalFields && !input.issuer?.id) {
      delete result.iss;
    }
  }
  if (!input.id && input.jti) {
    result.id = result.id || result.jti;
    if (removeOriginalFields) {
      delete result.jti;
    }
  }
  const types = [...asArray(result.type), ...asArray(result.vc?.type)].filter(notEmpty);
  result.type = [...new Set(types)];
  if (removeOriginalFields) {
    delete result.vc?.type;
  }
  for (const prop of additionalPropNames) {
    if (input.vc && input.vc[prop]) {
      if (!result[prop]) {
        result[prop] = input.vc[prop];
      }
      if (removeOriginalFields) {
        delete result.vc[prop];
      }
    }
  }
  const contextArray = [...asArray(input.context), ...asArray(input['@context']), ...asArray(input.vc?.['@context'])].filter(notEmpty);
  result['@context'] = [...new Set(contextArray)];
  if (removeOriginalFields) {
    delete result.context;
    delete result.vc?.['@context'];
  }
  if (!input.issuanceDate && (input.iat || input.nbf)) {
    result.issuanceDate = new Date((input.nbf || input.iat) * 1000).toISOString();
    if (removeOriginalFields) {
      if (input.nbf) {
        delete result.nbf;
      } else {
        delete result.iat;
      }
    }
  }
  if (!input.expirationDate && input.exp) {
    result.expirationDate = new Date(input.exp * 1000).toISOString();
    if (removeOriginalFields) {
      delete result.exp;
    }
  }
  if (removeOriginalFields) {
    if (result.vc && Object.keys(result.vc).length === 0) {
      delete result.vc;
    }
  }
  // FIXME: interpret `aud` property as `verifier`
  return result;
}
function normalizeJwtCredential(input, removeOriginalFields = true) {
  let decoded;
  try {
    decoded = decodeJWT(input);
  } catch (e) {
    throw new TypeError('unknown credential format');
  }
  return {
    ...normalizeJwtCredentialPayload(decoded.payload, removeOriginalFields),
    proof: {
      type: DEFAULT_JWT_PROOF_TYPE,
      jwt: input
    }
  };
}
/**
 * Normalizes a credential payload into an unambiguous W3C credential data type In case of conflict, existing W3C
 * Credential specific properties take precedence, except for arrays and object types which get merged.
 *
 * @param input - either a JWT or JWT payload, or a VerifiableCredential
 * @param removeOriginalFields - if true, removes all fields that were transformed according to the W3C mapping
 *
 * @see {@link https://www.w3.org/TR/vc-data-model/#jwt-encoding | VC JWT encoding }
 */
function normalizeCredential(input, removeOriginalFields = true) {
  if (typeof input === 'string') {
    if (JWT_FORMAT.test(input)) {
      return normalizeJwtCredential(input, removeOriginalFields);
    } else {
      let parsed;
      try {
        parsed = JSON.parse(input);
      } catch (e) {
        throw new TypeError('unknown credential format');
      }
      return normalizeCredential(parsed, removeOriginalFields);
    }
  } else if (input.proof?.jwt) {
    // TODO: test that it correctly propagates app specific proof properties
    return deepCopy({
      ...normalizeJwtCredential(input.proof.jwt, removeOriginalFields),
      proof: input.proof
    });
  } else {
    // TODO: test that it accepts JWT payload, CredentialPayload, VerifiableCredential
    // TODO: test that it correctly propagates proof, if any
    return {
      proof: {},
      ...normalizeJwtCredentialPayload(input, removeOriginalFields)
    };
  }
}
/**
 * Transforms a W3C Credential payload into a JWT compatible encoding.
 * The method accepts app specific fields and in case of collision, existing JWT properties will take precedence.
 * Also, `nbf`, `exp` and `jti` properties can be explicitly set to `undefined` and they will be kept intact.
 * @param input - either a JWT payload or a CredentialPayloadInput
 * @param removeOriginalFields - if true, removes original W3C fields from the resulting object
 *
 * @see {@link https://www.w3.org/TR/vc-data-model/#jwt-encoding | VC JWT encoding }
 */
function transformCredentialInput(input, removeOriginalFields = true) {
  if (Array.isArray(input.credentialSubject)) throw Error('credentialSubject of type array not supported');
  const result = deepCopy({
    vc: {
      ...input.vc
    },
    ...input
  });
  result.vc = result.vc;
  const credentialSubject = {
    ...input.credentialSubject,
    ...input.vc?.credentialSubject
  };
  if (!input.sub) {
    result.sub = input.credentialSubject?.id;
    if (removeOriginalFields) {
      delete credentialSubject.id;
    }
  }
  const contextEntries = [...asArray(input.context), ...asArray(input['@context']), ...asArray(input.vc?.['@context'])].filter(notEmpty);
  result.vc['@context'] = [...new Set(contextEntries)];
  if (removeOriginalFields) {
    delete result.context;
    delete result['@context'];
  }
  const types = [...asArray(input.type), ...asArray(input.vc?.type)].filter(notEmpty);
  result.vc.type = [...new Set(types)];
  if (removeOriginalFields) {
    delete result.type;
  }
  if (input.id && Object.getOwnPropertyNames(input).indexOf('jti') === -1) {
    result.jti = input.id;
    if (removeOriginalFields) {
      delete result.id;
    }
  }
  if (input.issuanceDate && Object.getOwnPropertyNames(input).indexOf('nbf') === -1) {
    const converted = Date.parse(input.issuanceDate);
    if (!isNaN(converted)) {
      result.nbf = Math.floor(converted / 1000);
      if (removeOriginalFields) {
        delete result.issuanceDate;
      }
    }
  }
  if (input.expirationDate && Object.getOwnPropertyNames(input).indexOf('exp') === -1) {
    const converted = Date.parse(input.expirationDate);
    if (!isNaN(converted)) {
      result.exp = Math.floor(converted / 1000);
      if (removeOriginalFields) {
        delete result.expirationDate;
      }
    }
  }
  if (input.issuer && Object.getOwnPropertyNames(input).indexOf('iss') === -1) {
    if (typeof input.issuer === 'object') {
      result.iss = input.issuer?.id;
      if (removeOriginalFields) {
        delete result.issuer.id;
        if (Object.keys(result.issuer).length === 0) {
          delete result.issuer;
        }
      }
    } else if (typeof input.issuer === 'string') {
      result.iss = input.iss || '' + input.issuer;
      if (removeOriginalFields) {
        delete result.issuer;
      }
    } else ;
  }
  result.vc.credentialSubject = credentialSubject;
  if (removeOriginalFields) {
    delete result.credentialSubject;
  }
  for (const prop of additionalPropNames) {
    if (input[prop]) {
      if (!result.vc[prop]) {
        result.vc[prop] = input[prop];
      }
      if (removeOriginalFields) {
        delete result[prop];
      }
    }
  }
  return result;
}

/**
 * Error prefixes used for known verification failure cases related to the
 * {@link https://www.w3.org/TR/vc-data-model/ | Verifiable Credential data model }
 */
const VC_ERROR = {
  /**
   * Thrown when the credential or presentation being verified does not conform to the data model defined by
   * {@link https://www.w3.org/TR/vc-data-model/ | the spec}
   */
  SCHEMA_ERROR: 'schema_error',
  /**
   * Thrown when the input is not a JWT string
   */
  FORMAT_ERROR: 'format_error',
  /**
   * Thrown when verifying a presentation where `challenge` and/or `domain` don't match the expected values.
   */
  AUTH_ERROR: 'auth_error'
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function isDateObject(input) {
  return input && !isNaN(input) && Object.prototype.toString.call(input) === '[object Date]';
}
// The main scenario we want to guard against is having a timestamp in milliseconds
// instead of seconds (ex: from new Date().getTime()).
// We will check the number of digits and assume that any number with 12 or more
// digits is a millisecond timestamp.
// 10 digits max is 9999999999 -> 11/20/2286 @ 5:46pm (UTC)
// 11 digits max is 99999999999 -> 11/16/5138 @ 9:46am (UTC)
// 12 digits max is 999999999999 -> 09/27/33658 @ 1:46am (UTC)
function validateTimestamp(value) {
  if (typeof value === 'number') {
    if (!(Number.isInteger(value) && value < 100000000000)) {
      throw new TypeError(`${VC_ERROR.SCHEMA_ERROR}: "${value}" is not a unix timestamp in seconds`);
    }
  } else if (typeof value === 'string') {
    validateTimestamp(Math.floor(new Date(value).valueOf() / 1000));
  } else if (!isDateObject(value)) {
    throw new TypeError(`${VC_ERROR.SCHEMA_ERROR}: "${value}" is not a valid time`);
  }
}
function validateContext(value) {
  const input = asArray(value);
  if (input.length < 1 || input.indexOf(DEFAULT_CONTEXT) === -1) {
    throw new TypeError(`${VC_ERROR.SCHEMA_ERROR}: @context is missing default context "${DEFAULT_CONTEXT}"`);
  }
}
function validateVcType(value) {
  const input = asArray(value);
  if (input.length < 1 || input.indexOf(DEFAULT_VC_TYPE) === -1) {
    throw new TypeError(`${VC_ERROR.SCHEMA_ERROR}: type is missing default "${DEFAULT_VC_TYPE}"`);
  }
}
function validateCredentialSubject(value) {
  if (Object.keys(value).length === 0) {
    throw new TypeError(`${VC_ERROR.SCHEMA_ERROR}: credentialSubject must not be empty`);
  }
}
/**
 * Verifies and validates a VerifiableCredential that is encoded as a JWT according to the W3C spec.
 *
 * @return a `Promise` that resolves to a `VerifiedCredential` or rejects with `TypeError` if the input is not
 * W3C compliant
 * @param vc - the credential to be verified. Currently only the JWT encoding is supported by this library
 * @param resolver - a configured `Resolver` (or an implementation of `Resolvable`) that can provide the DID document
 *   of the JWT issuer
 * @param options - optional tweaks to the verification process. These are forwarded to did-jwt.
 */
const verifyCredential$1 = function (vc, resolver, options = {}) {
  try {
    const nbf = options?.policies?.issuanceDate === false ? false : undefined;
    const exp = options?.policies?.expirationDate === false ? false : undefined;
    options = {
      ...options,
      policies: {
        ...options?.policies,
        nbf,
        exp,
        iat: nbf
      }
    };
    return Promise.resolve(verifyJWT(vc, {
      resolver,
      ...options
    })).then(function (verified) {
      verified.verifiableCredential = normalizeCredential(verified.jwt, options?.removeOriginalFields);
      if (options?.policies?.format !== false) {
        validateCredentialPayload(verified.verifiableCredential);
      }
      return verified;
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
/**
 * Creates a VerifiableCredential given a `CredentialPayload` or `JwtCredentialPayload` and an `Issuer`.
 *
 * This method transforms the payload into the [JWT encoding](https://www.w3.org/TR/vc-data-model/#jwt-encoding)
 * described in the [W3C VC spec](https://www.w3.org/TR/vc-data-model) and then validated to conform to the minimum
 * spec
 * required spec.
 *
 * The `issuer` is then used to assign an algorithm, override the `iss` field of the payload and then sign the JWT.
 *
 * @param payload - `CredentialPayload` or `JwtCredentialPayload`
 * @param issuer - `Issuer` the DID, signer and algorithm that will sign the token
 * @param options - Use these options to tweak the creation of the JWT Credential. These are forwarded to did-jwt.
 * @return a `Promise` that resolves to the JWT encoded verifiable credential or rejects with `TypeError` if the
 * `payload` is not W3C compliant
 */
const createVerifiableCredentialJwt = function (payload, issuer, options = {}) {
  try {
    const parsedPayload = {
      iat: undefined,
      ...transformCredentialInput(payload, options.removeOriginalFields)
    };
    validateJwtCredentialPayload(parsedPayload);
    if (!Array.isArray(issuer)) {
      return Promise.resolve(createJWT(parsedPayload, {
        ...options,
        issuer: issuer.did || parsedPayload.iss || '',
        signer: issuer.signer
      }, {
        ...options.header,
        alg: issuer.alg || options.header?.alg || JWT_ALG
      }));
    } else {
      const did = issuer[0].did;
      const issuers = [];
      for (const iss of issuer) {
        if (iss.did !== did) {
          throw new Error('All issuers must be the same did to comply with the Verifiable Conditions spec');
        }
        issuers.push({
          issuer: iss.did || parsedPayload.iss || '',
          signer: iss.signer,
          alg: iss.alg || options.header?.alg || JWT_ALG
        });
      }
      return Promise.resolve(createMultisignatureJWT(parsedPayload, {
        ...options
      }, issuers));
    }
  } catch (e) {
    return Promise.reject(e);
  }
};
function validateJwtCredentialPayload(payload) {
  validateContext(payload.vc['@context']);
  validateVcType(payload.vc.type);
  validateCredentialSubject(payload.vc.credentialSubject);
  if (payload.nbf) validateTimestamp(payload.nbf);
  if (payload.exp) validateTimestamp(payload.exp);
}
function validateCredentialPayload(payload) {
  validateContext(payload['@context']);
  validateVcType(payload.type);
  validateCredentialSubject(payload.credentialSubject);
  if (payload.issuanceDate) validateTimestamp(payload.issuanceDate);
  if (payload.expirationDate) validateTimestamp(payload.expirationDate);
}

/**
 * Sleeps until the given date
 *
 * @async
 * @param {Date} date - Date to sleep until
 */
var sleepUntil = function sleepUntil(date) {
  try {
    var now = new Date();
    if (date.getTime() <= now.getTime()) {
      return Promise.resolve();
    }
    return Promise.resolve(sleep(date.getTime() - now.getTime())).then(function () {});
  } catch (e) {
    return Promise.reject(e);
  }
};
/**
 * Adds a number of seconds and returns a new Date object
 *
 * @param {Date} date - Date object
 * @param {number} secs - Number of seconds to add
 */
/**
 * Sleeps for the given number of milliseconds
 *
 * @async
 * @param {number} ms - Number of milliseconds to sleep
 */
var sleep = function sleep(ms) {
  try {
    return Promise.resolve(new Promise(function (resolve) {
      return setTimeout(resolve, ms);
    }));
  } catch (e) {
    return Promise.reject(e);
  }
};
/**
 * Takes the number of seconds since epoch and returns a Date object
 *
 * @param {number} secs - Number of seconds since epoch
 * @returns {Date} - Date object
 */
function toDateTime(secs) {
  var t = new Date(1970, 0, 1); // Epoch
  t.setSeconds(secs);
  return t;
}
function addSeconds(date, secs) {
  return new Date(date.getTime() + secs * 1000);
}
/**
 * Subtracts a number of seconds and returns a new Date object
 *
 * @param {Date} date - Date object
 * @param {number} secs - Number of seconds to subtract
 */
function subtractSeconds(date, secs) {
  return new Date(date.getTime() - secs * 1000);
}
/**
 * Adds a number of microseconds and returns a new Date object
 *
 * @param {Date} date - Date object
 * @param {number} ms - Number of microseconds to add
 */
function addMicroseconds(date, ms) {
  return new Date(date.getTime() + ms / 1000);
}
/**
 * Subtracts a number of microseconds and returns a new Date object
 *
 * @param {Date} date - Date object
 * @param {number} ms - Number of microseconds to subtract
 */
function subtractMicroseconds(date, ms) {
  return new Date(date.getTime() - ms / 1000);
}

/**
 * A W3C Verifiable Credential
 */
var VerifiableCredential = /*#__PURE__*/function () {
  /**
   * @param {JWT} jwt - a JWT string
   *
   * @returns {VerifiableCredential} a VerifiableCredential object
   */
  function VerifiableCredential(jwt) {
    this.decodedJwt = void 0;
    this.jwt = void 0;
    this.decodedJwt = decodeJWT(jwt);
    this.jwt = jwt;
  }
  /**
   * Returns the payload of the JWT
   *
   * @returns {JWTPayload} the payload of the JWT
   */
  var _proto = VerifiableCredential.prototype;
  _proto.getPayload = function getPayload() {
    return this.decodedJwt.payload;
  }
  /**
   * Returns the vc object of the JWT
   *
   * @returns {JWTVCPayload} the vc object
   */;
  _proto.getVc = function getVc() {
    return this.getPayload().vc;
  }
  /**
   * Returns the credentialSubject object of the Verifiable Credential
   *
   * @returns {any} the credentialSubject object
   */;
  _proto.getCredentialSubject = function getCredentialSubject() {
    return this.getVc().credentialSubject;
  }
  /**
   * Returns the issuer of the Verifiable Credential
   *
   * @returns {DIDurl | undefined} the issuer
   */;
  _proto.getIssuer = function getIssuer() {
    return this.getPayload().iss;
  }
  /**
   * Returns the subject of the Verifiable Credential
   *
   * @returns {DIDurl | undefined} the subject of the Verifiable Credential
   */;
  _proto.getSubject = function getSubject() {
    return this.getPayload().sub;
  }
  /**
   * Returns the ID of the Verifiable Credential
   *
   * @returns {URL | undefined} the id
   */;
  _proto.getId = function getId() {
    return this.getPayload().jti;
  }
  /**
   * Returns the audience of the Verifiable Credential
   *
   * @returns {DIDurl | DIDurl[] | undefined} the audience
   */;
  _proto.getAudience = function getAudience() {
    return this.getPayload().aud;
  }
  /**
   * Returns the expiration of the Verifiable Credential
   *
   * @returns {Date | undefined} the expiration
   */;
  _proto.getExpiration = function getExpiration() {
    var secSinceEpoc = this.getPayload().exp;
    if (secSinceEpoc) {
      return toDateTime(secSinceEpoc);
    } else return undefined;
  }
  /**
   * Returns the issued time of the Verifiable Credential
   *
   * @returns {Date | undefined} the issued time
   */;
  _proto.getIssuedAt = function getIssuedAt() {
    var secSinceEpoc = this.getPayload().iat;
    if (secSinceEpoc) {
      return toDateTime(secSinceEpoc);
    } else return undefined;
  }
  /**
   * Returns the time the verifiable credential is valid after
   *
   * @returns {Date | undefined} the time the verifiable credential is valid after
   */;
  _proto.getNotBefore = function getNotBefore() {
    var secSinceEpoc = this.getPayload().nbf;
    if (secSinceEpoc) {
      return toDateTime(secSinceEpoc);
    } else return undefined;
  }
  /**
   * Verifies the Verifiable Credential is signed by the issuer
   *
   * @returns {Promise<VerifiedCredential>} the verified credential
   * @throws {Error} if the Verifiable Credential is not signed correctly by the issuer
   */;
  _proto.verify = function verify() {
    try {
      var _this = this;
      var settings = getSettings();
      var resolver = new Resolver(_extends({}, getDidKeyResolver(), getResolver({
        antelopeChainUrl: settings.blockchainUrl,
        fetch: getFetch()
      })));
      return Promise.resolve(verifyCredential$1(_this.jwt, resolver));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Creates a new Verifiable Credential object signed by the issuer
   *
   * @param {DIDurl} id - the id of the Verifiable Credential
   * @param {string[]} type - the type of the Verifiable Credential
   * @param {object} credentialSubject - the credential subject of the Verifiable Credential
   * @param {Issuer} issuer - the issuer of the Verifiable Credential
   * @property {URL} [options.subject] - the subject of the Verifiable Credential
   *
   * @returns {Promise<VerifiableCredential>} the Verifiable Credential
   */
  ;
  VerifiableCredential.sign = function sign(id, type, credentialSubject, issuer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var typeArray = Array.isArray(type) ? type : [type];
      if (!typeArray.includes('VerifiableCredential')) typeArray.push('VerifiableCredential');
      var vc = {
        '@context': ['https://www.w3.org/2018/credentials/v1'],
        id: id,
        type: typeArray,
        issuer: {
          id: issuer.did
        },
        issuanceDate: new Date().toISOString(),
        credentialSubject: credentialSubject
      };
      if (options.subject) vc.credentialSubject.id = options.subject;
      return Promise.resolve(createVerifiableCredentialJwt(vc, issuer, {
        canonicalize: true
      })).then(function (jwt) {
        return new VerifiableCredential(jwt);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Returns the JWT string
   *
   * @returns {string} the JWT string
   */
  ;
  _proto.toString = function toString() {
    return this.jwt;
  }
  /**
   * Returns the JSON string representation of the object - which is the jwt string
   *
   * @description This is used in JSON.stringify(). It is not recommended to use this method directly.
   * Only the jwt is returned, not the full object. This is all that is needed to reconstruct the
   * full object in the constructor, and thus minimizes the size of the JSON string.
   *
   * @override Serializable.toJSON
   * @returns {string} the jwt
   */;
  _proto.toJSON = function toJSON() {
    return this.toString();
  };
  return VerifiableCredential;
}();
/**
 * A wrapper that adds a type object to VCs to allow for identification, and presents a simper interface
 *
 * This is the base class. It is expected that extension classes will be created for the different VC types.
 *
 * @inheritdoc sign() is a protected alternative constructor. In child classes, a new alternative constructor
 * should be created which returns the child class type.
 * @inheritdoc protected "type" property should be overridden in child classes with the name of the class
 * @inheritdoc if the payload type requires ad-hoc decoding, override the constructor and decode the payload
 *
 * @example see an example of the above in the LoginRequestMessage class in `../..services/communication/messages.ts`
 */
var VerifiableCredentialWithType = /*#__PURE__*/function () {
  /**
   *
   * @param vc the VC to wrap
   *
   * @inheritdoc override me if the payload type requires ad-hoc decoding
   */
  function VerifiableCredentialWithType(vc) {
    this.vc = void 0;
    this.decodedPayload = void 0;
    if (typeof vc === 'string') {
      this.vc = new VerifiableCredential(vc);
    } else if (vc instanceof VerifiableCredentialWithType) {
      this.vc = vc.getVc();
    } else {
      this.vc = vc;
    }
    this.decodedPayload = this.getVc().getCredentialSubject().payload;
  }
  /**
   * Creates a signed VC object
   *
   * @access protected
   *
   * @param {object} payload the payload
   * @param {Issuer} issuer the issuer id
   * @param {VerifiableCredentialOptions} options the options
   *
   * @returns a VC object
   */
  VerifiableCredentialWithType.sign = function sign(payload, issuer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this2 = this;
      var payloadType = _this2.type;
      if (payloadType === 'VerifiableCredentialWithType' || payloadType === '') {
        throw new Error('class should be a derived class of VerifiableCredentialWithType to use the type property');
      }
      var credentialSubject = Object.assign({}, {
        payload: payload,
        type: payloadType
      });
      var id = 'https://tonomy.foundation/vc/id/' + randomString(10);
      var vcType = ['VerifiableCredential', 'TonomyVerifiableCredentialWithType'];
      if (options.additionalTypes) {
        vcType.push.apply(vcType, options.additionalTypes);
      }
      return Promise.resolve(VerifiableCredential.sign(id, vcType, credentialSubject, issuer, options)).then(function (vc) {
        return new VerifiableCredentialWithType(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Returns the type of the VC
   * @returns {string} the class type of the VC
   */
  ;
  VerifiableCredentialWithType.getType = function getType() {
    return this.type;
  }
  /**
   * Returns the internal Verifiable Credential
   * @returns {VerifiableCredential} the VC
   */;
  var _proto2 = VerifiableCredentialWithType.prototype;
  _proto2.getVc = function getVc() {
    return this.vc;
  }
  /**
   * Returns the issuer of the payload
   * @returns {DIDurl} the payload issuer
   */;
  _proto2.getIssuer = function getIssuer() {
    return this.getVc().getIssuer();
  }
  /**
   * Returns the payload
   * @returns {object} the payload
   */;
  _proto2.getPayload = function getPayload() {
    return this.decodedPayload;
  }
  /**
   * Returns the payload type used to determine what kind of payload it is
   * @returns {string | undefined} the payload type
   */;
  _proto2.getType = function getType() {
    return this.getVc().getCredentialSubject().type;
  }
  /**
   * Verifies that the VC is signed by the issuer
   *
   * @returns {Promise<boolean>} true if the VC is signed by the issuer
   * @throws {Error} if the VC is not signed by the issuer
   */;
  _proto2.verify = function verify() {
    try {
      var _this3 = this;
      return Promise.resolve(_this3.getVc().verify()).then(function (_this3$getVc$verify) {
        return _this3$getVc$verify.verified;
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Returns the JWT string
   *
   * @returns {string} the JWT string
   */
  ;
  _proto2.toString = function toString() {
    return this.getVc().toString();
  }
  /**
   * Returns the JSON string representation of the object - which is the jwt string
   *
   * @description This is used in JSON.stringify(). It is not recommended to use this method directly.
   * Only the jwt is returned, not the full object. This is all that is needed to reconstruct the
   * full object in the constructor, and thus minimizes the size of the JSON string.
   *
   * @override Serializable.toJSON
   * @returns {string} the jwt
   */;
  _proto2.toJSON = function toJSON() {
    return this.toString();
  };
  return VerifiableCredentialWithType;
}();
VerifiableCredentialWithType.type = 'VerifiableCredentialWithType';

var WalletRequest = /*#__PURE__*/function (_VerifiableCredential) {
  /**
   * @inheritdoc override me if the payload type requires ad-hoc decoding
   */
  function WalletRequest(vc) {
    return _VerifiableCredential.call(this, vc) || this;
  }
  /**
   * Alternative constructor that returns type WalletRequest. To be used in derived classes
   *
   * @access protected
   *
   * @param {object} payload the payload
   * @param {Issuer} issuer the issuer id
   * @param {VerifiableCredentialOptions} options the options
   *
   * @returns a WalletRequest object
   */
  _inheritsLoose(WalletRequest, _VerifiableCredential);
  WalletRequest.signWalletRequest = function signWalletRequest(payload, issuer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this = this;
      if (_this.type === 'WalletRequest') {
        throw new Error('class should be a derived class of WalletRequest to use the type property');
      }
      return Promise.resolve(_VerifiableCredential.sign.call(_this, payload, issuer, options)).then(function (vc) {
        return new WalletRequest(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return WalletRequest;
}(VerifiableCredentialWithType);
WalletRequest.type = 'WalletRequest';
var LoginRequest = /*#__PURE__*/function (_WalletRequest2) {
  /**
   * @override the VerifiableCredentialWithType constructor to decode the payload of type LoginRequestPayload
   */
  function LoginRequest(vc) {
    var _this2;
    _this2 = _WalletRequest2.call(this, vc) || this;
    _this2.decodedPayload.publicKey = PublicKey.from(_WalletRequest2.prototype.getPayload.call(_this2).publicKey);
    return _this2;
  }
  /**
   * Alternative constructor that returns type LoginRequest
   */
  _inheritsLoose(LoginRequest, _WalletRequest2);
  LoginRequest.signRequest = function signRequest(payload, issuer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this3 = this;
      return Promise.resolve(_WalletRequest2.signWalletRequest.call(_this3, payload, issuer, options)).then(function (vc) {
        return new LoginRequest(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return LoginRequest;
}(WalletRequest);
LoginRequest.type = 'LoginRequest';
var DataSharingRequest = /*#__PURE__*/function (_WalletRequest3) {
  function DataSharingRequest() {
    return _WalletRequest3.apply(this, arguments) || this;
  }
  _inheritsLoose(DataSharingRequest, _WalletRequest3);
  /**
   * Alternative constructor that returns type DataSharingRequest
   */
  DataSharingRequest.signRequest = function signRequest(payload, issuer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this4 = this;
      return Promise.resolve(_WalletRequest3.signWalletRequest.call(_this4, payload, issuer, options)).then(function (vc) {
        return new DataSharingRequest(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return DataSharingRequest;
}(WalletRequest);
DataSharingRequest.type = 'DataSharingRequest';

function getAccountNameFromDid(did) {
  var parsed = parseDid(did);
  var id = parsed.id.split(':');
  var accountName = id[id.length - 1];
  return Name.from(accountName);
}
function parseDid(did) {
  var parsed = parse(did);
  if (!parsed) throw new Error('Invalid DID');
  return parsed;
}

var resolveDidKey = function resolveDidKey(did) {
  try {
    var resolver = new Resolver(_extends({}, getDidKeyResolver()));
    return Promise.resolve(resolver.resolve(did));
  } catch (e) {
    return Promise.reject(e);
  }
};
var toDidKeyIssuer = function toDidKeyIssuer(privateKey) {
  try {
    var publicKey = privateKey.toPublic();
    return Promise.resolve(toDidKey(publicKey)).then(function (did) {
      return {
        did: did,
        signer: createSigner$1(privateKey),
        alg: 'ES256K-R'
      };
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var toDidKey = function toDidKey(publicKey) {
  try {
    // adapted from https://github.com/decentralized-identity/veramo/blob/next/packages/did-provider-key/src/key-did-provider.ts#L51
    if (publicKey.type !== KeyType.K1) throw new Error('Only K1 keys are supported');
    var publicKeyHexString = publicKey.data.toString('hex');
    var publicKeyHex = SigningKey.computePublicKey('0x' + publicKeyHexString, true);
    var methodSpecificId = bytesToMultibase(hexToBytes(publicKeyHex), 'base58btc', 'secp256k1-pub');
    return Promise.resolve('did:key:' + methodSpecificId);
  } catch (e) {
    return Promise.reject(e);
  }
};

var AccountType;
(function (AccountType) {
  AccountType["PERSON"] = "PERSON";
  AccountType["ORG"] = "ORG";
  AccountType["APP"] = "APP";
  AccountType["GOV"] = "GOV";
})(AccountType || (AccountType = {}));
// eslint-disable-next-line @typescript-eslint/no-namespace
(function (AccountType) {
  /*
   * Returns the index of the enum value
   *
   * @param value The level to get the index of
   */
  function indexFor(value) {
    return Object.keys(AccountType).indexOf(value);
  }
  AccountType.indexFor = indexFor;
  /*
   * Creates an AccountType from a string or index of the level
   *
   * @param value The string or index
   */
  function from(value) {
    var index;
    if (typeof value !== 'number') {
      index = AccountType.indexFor(value);
    } else {
      index = value;
    }
    return Object.values(AccountType)[index];
  }
  AccountType.from = from;
  function getPreSuffix(value) {
    return value.toLowerCase();
  }
  AccountType.getPreSuffix = getPreSuffix;
})(AccountType || (AccountType = {}));
var TonomyUsername = /*#__PURE__*/function () {
  function TonomyUsername(username) {
    this.username = void 0;
    this.usernameHash = void 0;
    this.username = username;
    this.usernameHash = sha256(this.username);
  }
  TonomyUsername.fromUsername = function fromUsername(username, type, suffix) {
    var fullUsername = username.normalize('NFKC').toLowerCase() + '.' + AccountType.getPreSuffix(type) + suffix;
    return new TonomyUsername(fullUsername);
  };
  TonomyUsername.fromFullUsername = function fromFullUsername(username) {
    return new TonomyUsername(username);
  };
  var _proto = TonomyUsername.prototype;
  _proto.getBaseUsername = function getBaseUsername() {
    var _this$username;
    return (_this$username = this.username) == null ? void 0 : _this$username.split('.')[0];
  }
  /**
   * @returns the username hash
   */;
  _proto.toString = function toString() {
    return this.username;
  }
  /**
   * Returns the JSON string representation of the object - which is the username string
   *
   * @description This is used in JSON.stringify(). It is not recommended to use this method directly.
   * Only the username is returned, not the full object. This is all that is needed to reconstruct the
   * full object in the constructor, and thus minimizes the size of the JSON string.
   *
   * @override Serializable.toJSON
   * @returns {string} the username
   */;
  _proto.toJSON = function toJSON() {
    return this.toString();
  };
  return TonomyUsername;
}();

/**
 *
 * @param {string} qrCode - The QR code to validate
 * @returns {string} - the DID of the user if the QR code is valid
 *
 * @throws if QR code is invalid
 */
function validateQrCode(qrCode) {
  if (!qrCode) {
    throwError('QR code is empty', SdkErrors.InvalidQrCode);
  }
  var schema = getSettings().tonomyIdSchema;
  if (!qrCode.startsWith(schema)) {
    throwError('QR schema does not match app', SdkErrors.InvalidQrCode);
  }
  var path = qrCode.replace(schema, '').split('?')[0];
  var query = qrCode.replace(schema, '').split('?')[1];
  if (path !== 'ScanQR') {
    throwError('QR path is not correct', SdkErrors.InvalidQrCode);
  }
  if (!query || query.indexOf('did=') === -1) {
    throwError('QR did param not found', SdkErrors.InvalidQrCode);
  }
  var did = query.split('did=')[1];
  if (!did) {
    throwError('QR did param is empty', SdkErrors.InvalidQrCode);
  }
  return did;
}
function createLoginQrCode(did) {
  var schema = getSettings().tonomyIdSchema;
  return schema + 'ScanQR?did=' + did;
}

var index$1 = {
  __proto__: null,
  objToBase64Url: objToBase64Url,
  base64UrlToObj: base64UrlToObj,
  randomBytes: randomBytes,
  randomNumber: randomNumber,
  createSigner: createSigner$1,
  randomString: randomString,
  sha256: sha256,
  int2hex: int2hex,
  encodeHex: encodeHex,
  generateRandomKeyPair: generateRandomKeyPair,
  createVCSigner: createVCSigner,
  HttpError: HttpError,
  CommunicationError: CommunicationError,
  SdkError: SdkError,
  createSdkError: createSdkError,
  throwError: throwError,
  get SdkErrors () { return SdkErrors; },
  copyObject: copyObject,
  generateRandomKeywords: generateRandomKeywords,
  generateAutoSuggestions: generateAutoSuggestions,
  isKeyword: isKeyword,
  WalletRequest: WalletRequest,
  LoginRequest: LoginRequest,
  DataSharingRequest: DataSharingRequest,
  setSettings: setSettings,
  setFetch: setFetch,
  getFetch: getFetch,
  getSettings: getSettings,
  isProduction: isProduction,
  getAccountNameFromDid: getAccountNameFromDid,
  parseDid: parseDid,
  resolveDidKey: resolveDidKey,
  toDidKeyIssuer: toDidKeyIssuer,
  toDidKey: toDidKey,
  VerifiableCredential: VerifiableCredential,
  VerifiableCredentialWithType: VerifiableCredentialWithType,
  sleepUntil: sleepUntil,
  sleep: sleep,
  toDateTime: toDateTime,
  addSeconds: addSeconds,
  subtractSeconds: subtractSeconds,
  addMicroseconds: addMicroseconds,
  subtractMicroseconds: subtractMicroseconds,
  get AccountType () { return AccountType; },
  TonomyUsername: TonomyUsername,
  validateQrCode: validateQrCode,
  createLoginQrCode: createLoginQrCode
};

var KeyManagerLevel;
(function (KeyManagerLevel) {
  KeyManagerLevel["PASSWORD"] = "PASSWORD";
  KeyManagerLevel["ACTIVE"] = "ACTIVE";
  KeyManagerLevel["PIN"] = "PIN";
  KeyManagerLevel["BIOMETRIC"] = "BIOMETRIC";
  KeyManagerLevel["LOCAL"] = "LOCAL";
  KeyManagerLevel["BROWSER_LOCAL_STORAGE"] = "BROWSER_LOCAL_STORAGE";
  KeyManagerLevel["BROWSER_SESSION_STORAGE"] = "BROWSER_SESSION_STORAGE";
})(KeyManagerLevel || (KeyManagerLevel = {}));
// eslint-disable-next-line @typescript-eslint/no-namespace
(function (KeyManagerLevel) {
  /*
   * Returns the index of the enum value
   *
   * @param value The level to get the index of
   */
  function indexFor(value) {
    return Object.keys(KeyManagerLevel).indexOf(value);
  }
  KeyManagerLevel.indexFor = indexFor;
  /*
   * Creates an AuthenticatorLevel from a string or index of the level
   *
   * @param value The string or index
   */
  function from(value) {
    var index;
    if (typeof value !== 'number') {
      index = KeyManagerLevel.indexFor(value);
    } else {
      index = value;
    }
    return Object.values(KeyManagerLevel)[index];
  }
  KeyManagerLevel.from = from;
  function validate(value) {
    if (KeyManagerLevel.indexFor(value) === -1) {
      throwError('Invalid level', SdkErrors.InvalidKeyLevel);
    }
  }
  KeyManagerLevel.validate = validate;
})(KeyManagerLevel || (KeyManagerLevel = {}));
/**
 * @param {KeyManagerLevel} level - The security level of the key
 * @param {PrivateKey} privateKey - The private key to be stored
 * @param {string} [challenge] - A challenge that needs to be presented in order for the key to be used
 */
var StoreKeyOptions = /*#__PURE__*/function () {
  function StoreKeyOptions() {
    this.level = void 0;
    this.privateKey = void 0;
    this.challenge = void 0;
  }
  StoreKeyOptions.validate = function validate(options) {
    KeyManagerLevel.validate(options.level); // throws if level not valid
    if (options.challenge !== undefined) {
      if (typeof options.challenge !== 'string' || options.challenge.length === 0) {
        throwError('Invalid challenge', SdkErrors.InvalidChallenge);
      }
    }
  };
  return StoreKeyOptions;
}();
/**
 * @param {KeyManagerLevel} level - The security level of the key
 * @param {string | Checksum256} data - The data that will be used to create a digital signature
 * @param {string} [challenge] - A challenge that needs to be presented in order for the key to be used
 * @param {'jwt' | 'transaction'} [outputType] - The type of output to return
 */
var SignDataOptions = /*#__PURE__*/function () {
  function SignDataOptions() {
    this.level = void 0;
    this.data = void 0;
    this.challenge = void 0;
    this.outputType = void 0;
  }
  SignDataOptions.validate = function validate(options) {
    KeyManagerLevel.validate(options.level); // throws if level not valid
    if (options.challenge !== undefined) {
      if (typeof options.challenge !== 'string' || options.challenge.length === 0) {
        throwError('Invalid challenge', SdkErrors.InvalidChallenge);
      }
    }
    if (options.outputType) {
      if (options.outputType !== 'jwt' && options.outputType !== 'transaction') {
        throwError('Invalid output type', SdkErrors.InvalidData);
      }
    }
  };
  return SignDataOptions;
}();
/**
 * @param {KeyManagerLevel} level - The security level of the key
 */
var GetKeyOptions = /*#__PURE__*/function () {
  function GetKeyOptions() {
    this.level = void 0;
  }
  GetKeyOptions.validate = function validate(options) {
    KeyManagerLevel.validate(options.level); // throws if level not valid
  };
  return GetKeyOptions;
}();
/**
 * @param {KeyManagerLevel} level - The security level of the key
 * @param {string} challenge - the challenge to check
 */
var CheckKeyOptions = /*#__PURE__*/function () {
  function CheckKeyOptions() {
    this.level = void 0;
    this.challenge = void 0;
  }
  CheckKeyOptions.validate = function validate(options) {
    KeyManagerLevel.validate(options.level); // throws if level not valid
    if (options.challenge !== undefined) {
      if (typeof options.challenge !== 'string' || options.challenge.length === 0) {
        throwError('Invalid challenge', SdkErrors.InvalidChallenge);
      }
    }
  };
  return CheckKeyOptions;
}();

/**
 * A proxy handler that will create magic getters and setters for the storage
 */
var storageProxyHandler = {
  /**
   * return the called property from the storage if it exists
   * @param target - The target object
   * @param key - The property key
   * @returns The value of the property from the storage or cached value
   * @throws {Error} If the data could not be retrieved
   */
  get: function get(target, key) {
    if (key === 'scope') throwError('Scope is a reserved key');
    if (key === 'cache') throwError('Cache is a reserved key');
    var scopedKey = target.scope + key;
    if (key in target) {
      if (key === 'clear') {
        target.cache = {};
      }
      return function () {
        target[key]();
      };
    }
    if (target.cache[scopedKey]) return target.cache[scopedKey];
    return target.retrieve(scopedKey).then(function (data) {
      target.cache[scopedKey] = data; // cache the data
      return data;
    })["catch"](function (e) {
      throwError("Could not get " + scopedKey + " from storage - " + e);
    });
  },
  /**
   * store the value in the storage
   * @param target - The target object
   * @param key - The property key
   * @param value - The value to store
   * @returns true if the value was stored
   * @throws {Error} If the data could not be stored
   */
  set: function set(target, key, value) {
    try {
      var scopedKey = target.scope + key;
      return Promise.resolve(target.store(scopedKey, value).then(function () {
        target.cache[scopedKey] = value;
        return true;
      })["catch"](function () {
        return false;
        // throw new Error(`Could not store data - ${e}`);
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }
};
var STORAGE_NAMESPACE = 'tonomy.id.';
function createStorage(scope, storageFactory) {
  var storage = storageFactory(scope);
  storage.cache = {};
  var proxy = new Proxy(storage, storageProxyHandler);
  return proxy;
}

var UserBase = /*#__PURE__*/function () {
  function UserBase(_keyManager, storageFactory) {
    this.keyManager = void 0;
    this.storage = void 0;
    this.keyManager = _keyManager;
    this.storage = createStorage(STORAGE_NAMESPACE + 'user.', storageFactory);
  }
  var _proto = UserBase.prototype;
  _proto.getStatus = function getStatus() {
    try {
      var _this = this;
      return Promise.resolve(_this.storage.status);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getAccountName = function getAccountName() {
    try {
      var _this2 = this;
      return Promise.resolve(_this2.storage.accountName);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getUsername = function getUsername() {
    try {
      var _this3 = this;
      return Promise.resolve(_this3.storage.username).then(function (username) {
        if (!username) throwError('Username not set', SdkErrors.InvalidData);else if (username instanceof TonomyUsername) {
          return username;
        } else if (typeof username === 'string') {
          return new TonomyUsername(username);
        } else {
          throwError('Username not in expected format', SdkErrors.InvalidData);
        }
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getDid = function getDid() {
    try {
      var _this4 = this;
      return Promise.resolve(_this4.storage.did);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getIssuer = function getIssuer() {
    try {
      var _this5 = this;
      return Promise.resolve(_this5.getDid()).then(function (did) {
        var signer = createVCSigner(_this5.keyManager, KeyManagerLevel.LOCAL);
        return {
          did: did + '#local',
          signer: signer.sign,
          alg: 'ES256K-R'
        };
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return UserBase;
}();

function _catch$5(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
var getProducers = function getProducers() {
  return Promise.resolve(getApi()).then(function (api) {
    return Promise.resolve(api.v1.chain.get_producer_schedule());
  });
};
var getAccount = function getAccount(account) {
  try {
    return Promise.resolve(_catch$5(function () {
      return Promise.resolve(getApi()).then(function (api) {
        return Promise.resolve(api.v1.chain.get_account(account));
      });
    }, function (e) {
      if (e.message === 'Account not found at /v1/chain/get_account') {
        throwError('Account "' + account.toString() + '" not found', SdkErrors.AccountDoesntExist);
      } else {
        throw e;
      }
    }));
  } catch (e) {
    return Promise.reject(e);
  }
};
var getChainInfo = function getChainInfo() {
  return Promise.resolve(getApi()).then(function (api) {
    return Promise.resolve(api.v1.chain.get_info());
  });
};
/**
 * This function serializes one action into hex string
 *
 * @param {string} account - name of the contract account to pull the ABI from
 * @param {string } type - name of the action that will be executed
 * @param {object} data - data of the action that will be executed
 * @returns {string} - hex string of the serialized action
 */
var serializeActionData = function serializeActionData(account, type, data) {
  return Promise.resolve(getApi()).then(function (_getApi) {
    return Promise.resolve(_getApi.v1.chain.get_abi(account)).then(function (_ref) {
      var abi = _ref.abi;
      if (!abi) {
        throw new Error("No ABI for " + account);
      }
      var _Serializer$encode = Serializer.encode({
          object: data,
          abi: abi,
          type: type
        }),
        hexString = _Serializer$encode.hexString;
      return hexString;
    });
  });
};
var getApi = function getApi() {
  try {
    if (api) return Promise.resolve(api);
    var settings = getSettings();
    api = new APIClient({
      url: settings.blockchainUrl,
      provider: new FetchProvider(settings.blockchainUrl, {
        fetch: getFetch() || fetch
      })
    });
    if (!api) throwError('Could not create API client', SdkErrors.CouldntCreateApi);
    return Promise.resolve(api);
  } catch (e) {
    return Promise.reject(e);
  }
};
var debug$8 = Debug('tonomy-sdk:services:blockchain:eosio:eosio');
var api;
function getTonomyOperationsKey() {
  if (isProduction() && !process.env.TONOMY_OPS_PRIVATE_KEY) throw new Error('TONOMY_OPS_PRIVATE_KEY must be set in production');
  if (process.env.TONOMY_OPS_PRIVATE_KEY) {
    debug$8('Using TONOMY_OPS_PRIVATE_KEY from env');
    return PrivateKey.from(process.env.TONOMY_OPS_PRIVATE_KEY);
  }
  return PrivateKey.from('PVT_K1_24kG9VcMk3VkkgY4hh42X262AWV18YcPjBTd2Hox4YWoP8vRTU');
}

function _catch$4(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
var transact = function transact(contract, actions, signer) {
  try {
    // Get the ABI
    return Promise.resolve(getApi()).then(function (api) {
      return Promise.resolve(api.v1.chain.get_abi(contract)).then(function (abi) {
        // Create the action data
        var actionData = [];
        actions.forEach(function (data) {
          actionData.push(Action.from(_extends({
            account: contract
          }, data), abi.abi));
        });
        // Construct the transaction
        return Promise.resolve(api.v1.chain.get_info()).then(function (info) {
          var header = info.getTransactionHeader();
          var transaction = Transaction.from(_extends({}, header, {
            actions: actionData
          }));
          // Create signature
          if (!Array.isArray(signer)) signer = [signer];
          var signDigest = transaction.signingDigest(info.chain_id);
          return Promise.resolve(Promise.all(signer.map(function (s) {
            return s.sign(signDigest);
          }))).then(function (signatures) {
            var _exit;
            var signedTransaction = SignedTransaction.from(_extends({}, transaction, {
              signatures: signatures
            }));
            // Send to the node
            var res;
            var _temp = _catch$4(function () {
              debug$7('Pushing transaction', JSON.stringify(actions, null, 2));
              return Promise.resolve(api.v1.chain.push_transaction(signedTransaction)).then(function (_api$v1$chain$push_tr) {
                res = _api$v1$chain$push_tr;
              });
            }, function (e) {
              var _e$response;
              debug$7('Error pushing transaction', e);
              if ((_e$response = e.response) != null && _e$response.headers) {
                var _e$response2;
                if ((_e$response2 = e.response) != null && _e$response2.json) {
                  throw new AntelopePushTransactionError(_extends({}, e.response.json, {
                    contract: contract,
                    actions: actions
                  }));
                }
                throw new HttpError(e);
              }
              throw e;
            });
            return _temp && _temp.then ? _temp.then(function (_result) {
              return _exit ? _result : res;
            }) : _exit ? _temp : res;
          });
        });
      });
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var debug$7 = Debug('tonomy-sdk:services:blockchain:eosio:transaction');
function createSigner(privateKey) {
  return {
    sign: function sign(digest) {
      try {
        return Promise.resolve(privateKey.signDigest(digest));
      } catch (e) {
        return Promise.reject(e);
      }
    }
  };
}
function createKeyManagerSigner(keyManager, level, challenge) {
  return {
    sign: function sign(digest) {
      try {
        return Promise.resolve(keyManager.signData({
          level: level,
          data: digest,
          challenge: challenge
        }));
      } catch (e) {
        return Promise.reject(e);
      }
    }
  };
}
var AntelopePushTransactionError = /*#__PURE__*/function (_Error) {
  function AntelopePushTransactionError(err) {
    var _err$error;
    var _this;
    _this = _Error.call(this, 'AntelopePushTransactionError') || this;
    _this.code = void 0;
    // HTTP error code
    _this.message = void 0;
    // HTTP error message
    _this.error = void 0;
    _this.actions = void 0;
    _this.contract = void 0;
    _this.code = err.code;
    _this.message = err.error.what;
    if (Array.isArray((_err$error = err.error) == null ? void 0 : _err$error.details) && err.error.details.length > 0) {
      _this.message += ': ' + err.error.details[0].message;
    }
    _this.error = err.error;
    _this.contract = err.contract;
    _this.actions = err.actions;
    _this.stack = new Error().stack;
    // Ensure the name of this error is the same as the class name
    _this.name = _this.constructor.name;
    // This clips the constructor invocation from the stack trace.
    // It's not absolutely essential, but it does make the stack trace a little nicer.
    //  @see Node.js reference (bottom)
    if (Error.captureStackTrace) {
      Error.captureStackTrace(_this, _this.constructor);
    }
    return _this;
  }
  _inheritsLoose(AntelopePushTransactionError, _Error);
  var _proto = AntelopePushTransactionError.prototype;
  _proto.hasErrorCode = function hasErrorCode(code) {
    return this.error.code === code;
  };
  _proto.hasTonomyErrorCode = function hasTonomyErrorCode(code) {
    // TODO iterate over deatils array instead of only looking at first element
    return this.error.details[0].message.search(code) > 0;
  };
  return AntelopePushTransactionError;
}( /*#__PURE__*/_wrapNativeSuper(Error));

var _iteratorSymbol$4 = typeof Symbol !== "undefined" ? Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator")) : "@@iterator";
function _settle$4(pact, state, value) {
  if (!pact.s) {
    if (value instanceof _Pact$4) {
      if (value.s) {
        if (state & 1) {
          state = value.s;
        }
        value = value.v;
      } else {
        value.o = _settle$4.bind(null, pact, state);
        return;
      }
    }
    if (value && value.then) {
      value.then(_settle$4.bind(null, pact, state), _settle$4.bind(null, pact, 2));
      return;
    }
    pact.s = state;
    pact.v = value;
    var observer = pact.o;
    if (observer) {
      observer(pact);
    }
  }
}
var _Pact$4 = /*#__PURE__*/function () {
  function _Pact() {}
  _Pact.prototype.then = function (onFulfilled, onRejected) {
    var result = new _Pact();
    var state = this.s;
    if (state) {
      var callback = state & 1 ? onFulfilled : onRejected;
      if (callback) {
        try {
          _settle$4(result, 1, callback(this.v));
        } catch (e) {
          _settle$4(result, 2, e);
        }
        return result;
      } else {
        return this;
      }
    }
    this.o = function (_this) {
      try {
        var value = _this.v;
        if (_this.s & 1) {
          _settle$4(result, 1, onFulfilled ? onFulfilled(value) : value);
        } else if (onRejected) {
          _settle$4(result, 1, onRejected(value));
        } else {
          _settle$4(result, 2, value);
        }
      } catch (e) {
        _settle$4(result, 2, e);
      }
    };
    return result;
  };
  return _Pact;
}();
function _isSettledPact$4(thenable) {
  return thenable instanceof _Pact$4 && thenable.s & 1;
}
function _forTo$4(array, body, check) {
  var i = -1,
    pact,
    reject;
  function _cycle(result) {
    try {
      while (++i < array.length && (!check || !check())) {
        result = body(i);
        if (result && result.then) {
          if (_isSettledPact$4(result)) {
            result = result.v;
          } else {
            result.then(_cycle, reject || (reject = _settle$4.bind(null, pact = new _Pact$4(), 2)));
            return;
          }
        }
      }
      if (pact) {
        _settle$4(pact, 1, result);
      } else {
        pact = result;
      }
    } catch (e) {
      _settle$4(pact || (pact = new _Pact$4()), 2, e);
    }
  }
  _cycle();
  return pact;
}
var CONTRACT_NAME$5 = 'vesting.tmy';
function _forOf$4(target, body, check) {
  if (typeof target[_iteratorSymbol$4] === "function") {
    var iterator = target[_iteratorSymbol$4](),
      step,
      pact,
      reject;
    function _cycle(result) {
      try {
        while (!(step = iterator.next()).done && (!check || !check())) {
          result = body(step.value);
          if (result && result.then) {
            if (_isSettledPact$4(result)) {
              result = result.v;
            } else {
              result.then(_cycle, reject || (reject = _settle$4.bind(null, pact = new _Pact$4(), 2)));
              return;
            }
          }
        }
        if (pact) {
          _settle$4(pact, 1, result);
        } else {
          pact = result;
        }
      } catch (e) {
        _settle$4(pact || (pact = new _Pact$4()), 2, e);
      }
    }
    _cycle();
    if (iterator.return) {
      var _fixup = function (value) {
        try {
          if (!step.done) {
            iterator.return();
          }
        } catch (e) {}
        return value;
      };
      if (pact && pact.then) {
        return pact.then(_fixup, function (e) {
          throw _fixup(e);
        });
      }
      _fixup();
    }
    return pact;
  }
  // No support for Symbol.iterator
  if (!("length" in target)) {
    throw new TypeError("Object is not iterable");
  }
  // Handle live collections properly
  var values = [];
  for (var i = 0; i < target.length; i++) {
    values.push(target[i]);
  }
  return _forTo$4(values, function (i) {
    return body(values[i]);
  }, check);
}
var LEOS_SEED_ROUND_PRICE = 0.0002;
var LEOS_SEED_LATE_ROUND_PRICE = 0.0004;
var LEOS_PUBLIC_SALE_PRICE = 0.0012;
var LEOS_CURRENT_PRICE = LEOS_SEED_ROUND_PRICE;
var MICROSECONDS_PER_SECOND = 1000000;
var SECONDS_PER_HOUR = 3600;
var MICROSECONDS_PER_DAY = 24 * SECONDS_PER_HOUR * MICROSECONDS_PER_SECOND;
var MICROSECONDS_PER_MONTH = 30 * MICROSECONDS_PER_DAY;
var MICROSECONDS_PER_YEAR = 365 * MICROSECONDS_PER_DAY;
var vestingCategories = new Map([[999,
// Testing Category
{
  startDelay: 10 * MICROSECONDS_PER_SECOND,
  cliffPeriod: 10 * MICROSECONDS_PER_SECOND,
  vestingPeriod: 20 * MICROSECONDS_PER_SECOND,
  tgeUnlock: 0.0
}], [998,
// Testing Category
{
  startDelay: 10 * MICROSECONDS_PER_SECOND,
  cliffPeriod: 10 * MICROSECONDS_PER_SECOND,
  vestingPeriod: 20 * MICROSECONDS_PER_SECOND,
  tgeUnlock: 0.5
}], [1,
// Seed Private Sale (DEPRECIATED)
{
  startDelay: 0 * MICROSECONDS_PER_DAY,
  cliffPeriod: 6 * 30 * MICROSECONDS_PER_DAY,
  vestingPeriod: 2 * 365 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.0
}], [2,
// Strategic Partnerships Private Sale (DEPRECIATED)
{
  startDelay: 6 * 30 * MICROSECONDS_PER_DAY,
  cliffPeriod: 6 * 30 * MICROSECONDS_PER_DAY,
  vestingPeriod: 2 * 365 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.0
}],
// Unchanged:
[3,
// Public Sale (DO NOT USED YET)
{
  startDelay: 0 * MICROSECONDS_PER_DAY,
  cliffPeriod: 0 * MICROSECONDS_PER_DAY,
  vestingPeriod: 0 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.0
}], [4,
// Team and Advisors, Ecosystem
{
  startDelay: 1 * 365 * MICROSECONDS_PER_DAY,
  cliffPeriod: 0 * MICROSECONDS_PER_DAY,
  vestingPeriod: 5 * 365 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.0
}], [5,
// Legal and Compliance
{
  startDelay: 0 * MICROSECONDS_PER_DAY,
  cliffPeriod: 0 * MICROSECONDS_PER_DAY,
  vestingPeriod: 1 * 365 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.0
}], [6,
// Reserves, Partnerships, Liquidly Allocation
{
  startDelay: 0 * MICROSECONDS_PER_DAY,
  cliffPeriod: 0 * MICROSECONDS_PER_DAY,
  vestingPeriod: 2 * 365 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.0
}], [7,
// Community and Marketing, Platform Dev, Infra Rewards
{
  startDelay: 0 * MICROSECONDS_PER_DAY,
  cliffPeriod: 0 * MICROSECONDS_PER_DAY,
  vestingPeriod: 5 * 365 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.0
}],
// New (replacing depreciated):
[8,
// Seed (Early Bird)
{
  startDelay: 0 * MICROSECONDS_PER_DAY,
  cliffPeriod: 0 * MICROSECONDS_PER_DAY,
  vestingPeriod: 2 * 365 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.05
}], [9,
// Seed (Last Chance)
{
  startDelay: 0 * MICROSECONDS_PER_DAY,
  cliffPeriod: 0 * MICROSECONDS_PER_DAY,
  vestingPeriod: 2 * 365 * MICROSECONDS_PER_DAY,
  tgeUnlock: 0.025
}], [10,
// Public (TGE)
{
  startDelay: 14 * MICROSECONDS_PER_DAY,
  cliffPeriod: 0 * MICROSECONDS_PER_DAY,
  vestingPeriod: 0 * MICROSECONDS_PER_DAY,
  tgeUnlock: 1.0
}]]);
var VestingContract = /*#__PURE__*/function () {
  function VestingContract(contractName) {
    if (contractName === void 0) {
      contractName = CONTRACT_NAME$5;
    }
    this.contractName = CONTRACT_NAME$5;
    this.contractName = contractName;
  }
  VestingContract.calculateVestingPeriod = function calculateVestingPeriod(settings, allocation) {
    var vestingCategory = vestingCategories.get(allocation.vesting_category_type);
    if (!vestingCategory) throw new Error('Invalid vesting category');
    var launchDate = new Date(settings.launch_date + 'Z');
    var vestingStart = addMicroseconds(launchDate, vestingCategory.startDelay);
    var cliffEnd = addMicroseconds(vestingStart, vestingCategory.cliffPeriod);
    var vestingEnd = addMicroseconds(vestingStart, vestingCategory.vestingPeriod);
    return {
      launchDate: launchDate,
      vestingStart: vestingStart,
      cliffEnd: cliffEnd,
      vestingEnd: vestingEnd
    };
  };
  var _proto = VestingContract.prototype;
  _proto.setSettings = function setSettings(salesDateStr, launchDateStr, signer) {
    try {
      var action = {
        authorization: [{
          actor: CONTRACT_NAME$5,
          permission: 'active'
        }],
        account: CONTRACT_NAME$5,
        name: 'setsettings',
        data: {
          sales_start_date: salesDateStr,
          launch_date: launchDateStr
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$5), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.assignTokens = function assignTokens(sender, holder, amount, categoryId, signer) {
    try {
      var action = {
        authorization: [{
          actor: sender.toString(),
          permission: 'active'
        }],
        account: CONTRACT_NAME$5,
        name: 'assigntokens',
        data: {
          sender: sender,
          holder: holder,
          amount: amount,
          category: categoryId
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$5), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.withdraw = function withdraw(holder, signer) {
    try {
      var action = {
        authorization: [{
          actor: holder.toString(),
          permission: 'active'
        }],
        account: CONTRACT_NAME$5,
        name: 'withdraw',
        data: {
          holder: holder
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$5), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.migrateAllocation = function migrateAllocation(sender, holder, allocationId, oldAmount, newAmount, oldCategoryId, newCategoryId, signer) {
    try {
      var action = {
        authorization: [{
          actor: sender.toString(),
          permission: 'active'
        }, {
          actor: CONTRACT_NAME$5,
          permission: 'active'
        }],
        account: CONTRACT_NAME$5,
        name: 'migratealloc',
        data: {
          sender: sender,
          holder: holder,
          allocation_id: allocationId,
          old_amount: oldAmount,
          new_amount: newAmount,
          old_category_id: oldCategoryId,
          new_category_id: newCategoryId
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$5), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getSettings = function getSettings() {
    try {
      return Promise.resolve(getApi()).then(function (_getApi) {
        return Promise.resolve(_getApi.v1.chain.get_table_rows({
          code: 'vesting.tmy',
          scope: 'vesting.tmy',
          table: 'settings',
          json: true
        })).then(function (res) {
          if (res.rows.length === 0) throw new Error('Settings have not yet been set');
          return res.rows[0];
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getAllocations = function getAllocations(account) {
    try {
      return Promise.resolve(getApi()).then(function (_getApi2) {
        return Promise.resolve(_getApi2.v1.chain.get_table_rows({
          code: 'vesting.tmy',
          scope: account.toString(),
          table: 'allocation',
          json: true,
          limit: VestingContract.MAX_ALLOCATIONS + 1
        })).then(function (res) {
          return res.rows;
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getBalance = function getBalance(account) {
    try {
      var _this = this;
      return Promise.resolve(_this.getAllocations(account)).then(function (allocations) {
        var totalBalance = new Decimal(0);
        for (var _iterator = _createForOfIteratorHelperLoose(allocations), _step; !(_step = _iterator()).done;) {
          var allocation = _step.value;
          var tokens = allocation.tokens_allocated.split(' ')[0];
          var numberTokens = new Decimal(tokens);
          totalBalance = totalBalance.add(numberTokens);
        }
        return totalBalance.toNumber();
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getVestingCategory = function getVestingCategory(categoryId) {
    var vestingCategory = vestingCategories.get(categoryId);
    if (!vestingCategory) {
      throw new Error("Vesting category " + categoryId + " not found");
    }
    return vestingCategory;
  };
  _proto.getVestingPeriodYears = function getVestingPeriodYears(categoryId) {
    var vestingCategory = vestingCategories.get(categoryId);
    if (!vestingCategory) {
      throw new Error("Vesting category " + categoryId + " not found");
    }
    var vestingPeriod = vestingCategory.vestingPeriod;
    // Convert to seconds for categories 999 and 998, otherwise to years
    if (categoryId === 999 || categoryId === 998) {
      return "" + (vestingPeriod / MICROSECONDS_PER_SECOND).toFixed(2);
    } else {
      return "" + (vestingPeriod / MICROSECONDS_PER_DAY).toFixed(2);
    }
  };
  _proto.getVestingPeriod = function getVestingPeriod(categoryId) {
    var vestingCategory = vestingCategories.get(categoryId);
    if (!vestingCategory) {
      throw new Error("Vesting category " + categoryId + " not found");
    }
    var vestingPeriod = vestingCategory.vestingPeriod;
    var vestingPeriodInDays = vestingPeriod / MICROSECONDS_PER_DAY;
    if (vestingPeriodInDays < 1) {
      // If less than a day, check if it's less than an hour (in seconds)
      var vestingPeriodInSeconds = vestingPeriod / MICROSECONDS_PER_SECOND;
      if (vestingPeriodInSeconds < 60) {
        // Return seconds if it's less than a minute
        return vestingPeriodInSeconds.toFixed(0) + " seconds";
      } else {
        // Return hours if it's more than a minute but less than a day
        return (vestingPeriodInSeconds / SECONDS_PER_HOUR).toFixed(1) + " hours";
      }
    } else if (vestingPeriodInDays < 30) {
      // Return days if it's less than 30 days
      return vestingPeriodInDays.toFixed(1) + " days";
    } else {
      // Calculate months or years if it's 30 days or more
      var vestingPeriodInMonths = vestingPeriod / MICROSECONDS_PER_MONTH;
      var vestingPeriodInYears = vestingPeriod / MICROSECONDS_PER_YEAR;
      if (vestingPeriodInMonths < 12) {
        return vestingPeriodInMonths.toFixed(1) + " months";
      } else {
        return vestingPeriodInYears.toFixed(1) + " years";
      }
    }
  };
  _proto.getVestingAllocations = function getVestingAllocations(account) {
    try {
      var _this2 = this;
      return Promise.resolve(_this2.getAllocations(account)).then(function (allocations) {
        function _temp2() {
          var totalAllocation = allocationsDetails.reduce(function (sum, allocation) {
            return sum + allocation.totalAllocation;
          }, 0);
          var totalUnlockable = allocationsDetails.reduce(function (sum, allocation) {
            return sum + allocation.unlockable;
          }, 0);
          var totalUnlocked = allocationsDetails.reduce(function (sum, allocation) {
            return sum + allocation.unlocked;
          }, 0);
          var totalLocked = allocationsDetails.reduce(function (sum, allocation) {
            return sum + allocation.locked;
          }, 0);
          return {
            totalAllocation: totalAllocation,
            unlockable: totalUnlockable,
            unlocked: totalUnlocked,
            locked: totalLocked,
            allocationsDetails: allocationsDetails
          };
        }
        var currentTime = new Date();
        var allocationsDetails = [];
        var _temp = _forOf$4(allocations, function (allocation) {
          var tokensAllocated = parseFloat(allocation.tokens_allocated.split(' ')[0]);
          var unlocked = parseFloat(allocation.tokens_claimed.split(' ')[0]);
          return Promise.resolve(_this2.getSettings()).then(function (settings) {
            var vestingPeriods = VestingContract.calculateVestingPeriod(settings, allocation);
            var vestingStart = vestingPeriods.vestingStart,
              cliffEnd = vestingPeriods.cliffEnd,
              vestingEnd = vestingPeriods.vestingEnd;
            var vestingCategory = _this2.getVestingCategory(allocation.vesting_category_type);
            var claimable = 0;
            if (currentTime >= cliffEnd) {
              // Calculate the percentage of the vesting period that has passed
              var timeSinceVestingStart = (currentTime.getTime() - vestingStart.getTime()) / 1000;
              var vestingDuration = (vestingEnd.getTime() - vestingStart.getTime()) / 1000;
              var vestingProgress = Math.min(timeSinceVestingStart / vestingDuration, 1.0); // Ensure it doesn't exceed 100%
              // Calculate unlockable amount considering TGE unlock
              claimable = tokensAllocated * ((1.0 - vestingCategory.tgeUnlock) * vestingProgress + vestingCategory.tgeUnlock);
            }
            var unlockable = claimable - unlocked;
            var locked = tokensAllocated - unlocked;
            var unlockAtVestingStart = vestingCategory.tgeUnlock;
            var saleStart = new Date(settings.sales_start_date);
            allocationsDetails.push({
              totalAllocation: tokensAllocated,
              unlockable: unlockable,
              unlocked: unlocked,
              locked: locked,
              vestingStart: vestingStart,
              unlockAtVestingStart: unlockAtVestingStart,
              allocationDate: new Date(saleStart.getTime() + allocation.time_since_sale_start._count / 1000),
              vestingPeriod: _this2.getVestingPeriod(allocation.vesting_category_type),
              categoryId: allocation.vesting_category_type
            });
          });
        });
        return _temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return _createClass(VestingContract, null, [{
    key: "Instance",
    get: function get() {
      return this.singletonInstance || (this.singletonInstance = new this());
    }
  }]);
}();
VestingContract.singletonInstance = void 0;
VestingContract.MAX_ALLOCATIONS = 150;

var getAccountNameFromUsername = function getAccountNameFromUsername(username) {
  try {
    return Promise.resolve(TonomyContract.Instance.getPerson(username)).then(function (_TonomyContract$Insta) {
      return _TonomyContract$Insta.account_name;
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var CONTRACT_NAME$4 = 'tonomy';
var GOVERNANCE_ACCOUNT_NAME = 'tonomy';
var PermissionLevel;
(function (PermissionLevel) {
  PermissionLevel["OWNER"] = "OWNER";
  PermissionLevel["ACTIVE"] = "ACTIVE";
  PermissionLevel["PASSWORD"] = "PASSWORD";
  PermissionLevel["PIN"] = "PIN";
  PermissionLevel["BIOMETRIC"] = "BIOMETRIC";
  PermissionLevel["LOCAL"] = "LOCAL";
})(PermissionLevel || (PermissionLevel = {}));
var AccountTypeEnum;
(function (AccountTypeEnum) {
  AccountTypeEnum[AccountTypeEnum["Person"] = 0] = "Person";
  AccountTypeEnum[AccountTypeEnum["Organization"] = 1] = "Organization";
  AccountTypeEnum[AccountTypeEnum["App"] = 2] = "App";
  AccountTypeEnum[AccountTypeEnum["Gov"] = 3] = "Gov";
  AccountTypeEnum[AccountTypeEnum["Service"] = 4] = "Service";
})(AccountTypeEnum || (AccountTypeEnum = {}));
// eslint-disable-next-line @typescript-eslint/no-namespace
(function (PermissionLevel) {
  /*
   * Returns the index of the enum value
   *
   * @param value The value to get the index of
   */
  function indexFor(value) {
    return Object.keys(PermissionLevel).indexOf(value);
  }
  PermissionLevel.indexFor = indexFor;
  /*
   * Creates an PermissionLevel from a string or index of the level
   *
   * @param value The string or index
   */
  function from(value) {
    var index;
    if (typeof value !== 'number') {
      index = PermissionLevel.indexFor(value);
    } else {
      index = value;
    }
    return Object.values(PermissionLevel)[index];
  }
  PermissionLevel.from = from;
})(PermissionLevel || (PermissionLevel = {}));
function calculateRamPrice() {
  // See https://docs.google.com/spreadsheets/d/1_S0S7Gu-PHzt-IzCqNl3CaWnniAt1KwaXDB50roTZUQ/edit?gid=1773951365#gid=1773951365&range=C84
  var ramPricePerGb = 7; // $7.00 per GB of RAM taken from standard AWS EC2 pricing
  var numberOfNodes = 29;
  var costOverhead = 1; // 100% overhead
  var totalRamPrice = ramPricePerGb * numberOfNodes * (1 + costOverhead); // $ / Gb
  var totalRamPriceBytes = totalRamPrice / (1024 * 1024 * 1024); // $ / byte
  return LEOS_PUBLIC_SALE_PRICE / totalRamPriceBytes; // bytes / LEOS
}
var RAM_PRICE = calculateRamPrice(); // bytes / token
var RAM_FEE = 0.25 / 100; // 0.25%
var TOTAL_RAM_AVAILABLE = 8 * 1024 * 1024 * 1024; // 8 GB
/**
 * Converts bytes to tokens.
 *
 * @param bytes The number of bytes to convert.
 * @returns The converted value in tokens.
 */
function bytesToTokens(bytes) {
  return (bytes * (1 + RAM_FEE) / RAM_PRICE).toFixed(6) + (" " + getSettings().currencySymbol);
}
var TonomyContract = /*#__PURE__*/function () {
  function TonomyContract() {}
  var _proto = TonomyContract.prototype;
  /**
   * Buys RAM for an account
   *
   * @param  daoOwner - The owner of the DAO (Name is assumed to be a class that represents an EOSIO account name)
   * @param account - The name of the app buying RAM (Name is assumed to be a class that represents an EOSIO account name)
   * @param quant - The quantity of RAM to buy (Asset is assumed to be a class that represents an EOSIO asset)
   */
  _proto.buyRam = function buyRam(dao_owner, app, quant, signer) {
    try {
      var actions = [{
        account: CONTRACT_NAME$4,
        name: 'buyram',
        authorization: [{
          actor: app,
          permission: 'active'
        }, {
          actor: dao_owner,
          permission: 'active'
        }],
        data: {
          dao_owner: dao_owner,
          app: app,
          quant: quant
        }
      }];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$4), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Sets the resource parameters
   *
   * @param ram_price - The price of RAM (bytes per token)
   * @param total_ram_available - The total available RAM.
   * @param ram_fee - The fee for RAM.
  
   */
  ;
  _proto.setResourceParams = function setResourceParams(ram_price, total_ram_available, ram_fee, signer) {
    try {
      var action = {
        authorization: [{
          actor: GOVERNANCE_ACCOUNT_NAME,
          permission: 'active'
        }],
        account: CONTRACT_NAME$4,
        name: 'setresparams',
        data: {
          ram_price: ram_price,
          total_ram_available: total_ram_available,
          ram_fee: ram_fee
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$4), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.newperson = function newperson(username_hash, password_key, password_salt, signer) {
    try {
      var action = {
        authorization: [{
          actor: CONTRACT_NAME$4,
          permission: 'active'
        }],
        account: CONTRACT_NAME$4,
        name: 'newperson',
        data: {
          username_hash: username_hash,
          password_key: password_key,
          password_salt: password_salt
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$4), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.updatekeysper = function updatekeysper(account, keys, signer) {
    try {
      return Promise.resolve(getAccount(account)).then(function (accountInfo) {
        var actions = [];
        if (Object.keys(keys).length === 0) throwError('At least one key must be provided', SdkErrors.UpdateKeysTransactionNoKeys);
        for (var key in keys) {
          var permission = PermissionLevel.from(key);
          // "keys as any" fixes typescript issue see https://stackoverflow.com/a/57192972
          var publicKey = keys[key];
          var link_auth = true;
          try {
            var accountPermission = accountInfo.getPermission(permission.toLowerCase());
            if (accountPermission && accountPermission.linked_actions.find(function (a) {
              return a.account.equals(CONTRACT_NAME$4) && a.action.equals('loginwithapp');
            })) {
              link_auth = false;
            }
          } catch (e) {
            if (!e.message.startsWith('Unknown permission ')) {
              throw e;
            }
          }
          actions.push({
            authorization: [{
              actor: account,
              permission: 'active'
            }],
            account: CONTRACT_NAME$4,
            name: 'updatekeyper',
            data: {
              account: account,
              permission: PermissionLevel.indexFor(permission),
              key: publicKey,
              link_auth: link_auth
            }
          });
        }
        return Promise.resolve(transact(Name.from(CONTRACT_NAME$4), actions, signer));
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.newapp = function newapp(app_name, description, username_hash, logo_url, origin, key, signer) {
    try {
      /^(((http:\/\/)|(https:\/\/))?)(([a-zA-Z0-9.])+)((:{1}[0-9]+)?)$/g.test(origin);
      /^(((http:\/\/)|(https:\/\/))?)(([a-zA-Z0-9.])+)((:{1}[0-9]+)?)([?#/a-zA-Z0-9.]*)$/g.test(logo_url);
      var action = {
        authorization: [{
          actor: CONTRACT_NAME$4,
          permission: 'active'
        }],
        account: CONTRACT_NAME$4,
        name: 'newapp',
        data: {
          app_name: app_name,
          description: description,
          logo_url: logo_url,
          origin: origin,
          username_hash: username_hash,
          key: key
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$4), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.loginwithapp = function loginwithapp(account, app, parent, key, signer) {
    try {
      var action = {
        authorization: [{
          actor: account,
          permission: parent
        }],
        account: CONTRACT_NAME$4,
        name: 'loginwithapp',
        data: {
          account: account,
          app: app,
          parent: parent,
          key: key
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$4), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getPerson = function getPerson(account) {
    try {
      var data;
      return Promise.resolve(getApi()).then(function (api) {
        function _temp2() {
          var idData = data.rows[0];
          return {
            account_name: Name.from(idData.account_name),
            status: idData.status,
            username_hash: Checksum256.from(idData.username_hash),
            password_salt: Checksum256.from(idData.password_salt),
            version: idData.version
          };
        }
        var _temp = function () {
          if (account instanceof TonomyUsername) {
            // this is a username
            var usernameHash = account.usernameHash;
            return Promise.resolve(api.v1.chain.get_table_rows({
              code: CONTRACT_NAME$4,
              scope: CONTRACT_NAME$4,
              table: 'people',
              lower_bound: Checksum256.from(usernameHash),
              limit: 1,
              index_position: 'secondary'
            })).then(function (_api$v1$chain$get_tab) {
              data = _api$v1$chain$get_tab;
              if (!data || !data.rows) throwError('No data found', SdkErrors.DataQueryNoRowDataFound);
              if (data.rows.length === 0 || data.rows[0].username_hash.toString() !== usernameHash) {
                throwError('Person with username "' + account.username + '" not found', SdkErrors.UsernameNotFound);
              }
            });
          } else {
            // use the account name directly
            return Promise.resolve(api.v1.chain.get_table_rows({
              code: CONTRACT_NAME$4,
              scope: CONTRACT_NAME$4,
              table: 'people',
              lower_bound: account,
              limit: 1
            })).then(function (_api$v1$chain$get_tab2) {
              data = _api$v1$chain$get_tab2;
              if (!data || !data.rows) throwError('No data found', SdkErrors.DataQueryNoRowDataFound);
              if (data.rows.length === 0 || data.rows[0].account_name !== account.toString()) {
                throwError('Person with account name "' + account.toString() + '" not found', SdkErrors.AccountDoesntExist);
              }
            });
          }
        }();
        return _temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getApp = function getApp(account) {
    try {
      var data;
      return Promise.resolve(getApi()).then(function (api) {
        function _temp5() {
          var idData = data.rows[0];
          return {
            app_name: idData.app_name,
            description: idData.description,
            logo_url: idData.logo_url,
            origin: idData.origin,
            account_name: Name.from(idData.account_name),
            username_hash: Checksum256.from(idData.username_hash),
            version: idData.version
          };
        }
        var _temp4 = function () {
          if (account instanceof TonomyUsername) {
            // this is a username
            var usernameHash = account.usernameHash;
            return Promise.resolve(api.v1.chain.get_table_rows({
              code: CONTRACT_NAME$4,
              scope: CONTRACT_NAME$4,
              table: 'apps',
              lower_bound: Checksum256.from(usernameHash),
              limit: 1,
              index_position: 'secondary'
            })).then(function (_api$v1$chain$get_tab3) {
              data = _api$v1$chain$get_tab3;
              if (!data || !data.rows) throwError('No data found', SdkErrors.DataQueryNoRowDataFound);
              if (data.rows.length === 0 || data.rows[0].username_hash.toString() !== usernameHash) {
                throwError('Account with username "' + account.username + '" not found', SdkErrors.UsernameNotFound);
              }
            });
          } else {
            var _temp6 = function () {
              if (account instanceof Name) {
                // use the account name directly
                return Promise.resolve(api.v1.chain.get_table_rows({
                  code: CONTRACT_NAME$4,
                  scope: CONTRACT_NAME$4,
                  table: 'apps',
                  lower_bound: account,
                  limit: 1
                })).then(function (_api$v1$chain$get_tab4) {
                  data = _api$v1$chain$get_tab4;
                  if (!data || !data.rows) throwError('No data found', SdkErrors.DataQueryNoRowDataFound);
                  if (data.rows.length === 0 || data.rows[0].account_name !== account.toString()) {
                    throwError('Account "' + account.toString() + '" not found', SdkErrors.AccountDoesntExist);
                  }
                });
              } else {
                // account is the origin
                var origin = account;
                var originHash = sha256(origin);
                return Promise.resolve(api.v1.chain.get_table_rows({
                  code: CONTRACT_NAME$4,
                  scope: CONTRACT_NAME$4,
                  table: 'apps',
                  lower_bound: Checksum256.from(originHash),
                  limit: 1,
                  index_position: 'tertiary'
                })).then(function (_api$v1$chain$get_tab5) {
                  data = _api$v1$chain$get_tab5;
                  if (!data || !data.rows) throwError('No data found', SdkErrors.DataQueryNoRowDataFound);
                  if (data.rows.length === 0 || data.rows[0].origin !== origin) {
                    throwError('Account with origin "' + origin + '" not found', SdkErrors.OriginNotFound);
                  }
                });
              }
            }();
            if (_temp6 && _temp6.then) return _temp6.then(function () {});
          }
        }();
        return _temp4 && _temp4.then ? _temp4.then(_temp5) : _temp5(_temp4);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.adminSetApp = function adminSetApp(accountName, appName, description, usernameHash, logoUrl, origin, signer) {
    try {
      var action = {
        authorization: [{
          actor: CONTRACT_NAME$4,
          permission: 'active'
        }],
        account: CONTRACT_NAME$4,
        name: 'adminsetapp',
        data: {
          account_name: Name.from(accountName),
          app_name: appName,
          description: description,
          username_hash: usernameHash,
          logo_url: logoUrl,
          origin: origin
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$4), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return _createClass(TonomyContract, null, [{
    key: "Instance",
    get: function get() {
      return this.singletonInstance || (this.singletonInstance = new this());
    }
  }]);
}();
TonomyContract.singletonInstance = void 0;

var AppStatusEnum;
(function (AppStatusEnum) {
  AppStatusEnum["PENDING"] = "PENDING";
  AppStatusEnum["CREATING"] = "CREATING";
  AppStatusEnum["READY"] = "READY";
  AppStatusEnum["DEACTIVATED"] = "DEACTIVATED";
})(AppStatusEnum || (AppStatusEnum = {}));
// eslint-disable-next-line @typescript-eslint/no-namespace
(function (AppStatusEnum) {
  /*
   * Returns the index of the enum value
   *
   * @param value The level to get the index of
   */
  function indexFor(value) {
    return Object.keys(AppStatusEnum).indexOf(value);
  }
  AppStatusEnum.indexFor = indexFor;
  /*
   * Creates an AppStatusEnum from a string or index of the level
   *
   * @param value The string or index
   */
  function from(value) {
    var index;
    if (typeof value !== 'number') {
      index = AppStatusEnum.indexFor(value);
    } else {
      index = value;
    }
    return Object.values(AppStatusEnum)[index];
  }
  AppStatusEnum.from = from;
})(AppStatusEnum || (AppStatusEnum = {}));

var tonomyContract$6 = TonomyContract.Instance;
var App = /*#__PURE__*/function () {
  function App(options) {
    this.accountName = void 0;
    this.appName = void 0;
    this.username = void 0;
    this.usernameHash = void 0;
    this.description = void 0;
    this.logoUrl = void 0;
    this.origin = void 0;
    this.version = void 0;
    this.status = void 0;
    this.accountName = options.accountName;
    this.appName = options.appName;
    this.username = options.username;
    this.description = options.description;
    this.logoUrl = options.logoUrl;
    this.origin = options.origin;
    this.version = options.version;
    this.status = options.status;
    if (options.usernameHash) {
      this.usernameHash = options.usernameHash;
    } else if (options.username) {
      this.usernameHash = Checksum256.from(options.username.usernameHash);
    } else {
      throw new Error('Either username or usernameHash must be provided');
    }
  }
  App.create = function create(options) {
    try {
      var username = TonomyUsername.fromUsername(options.usernamePrefix, AccountType.APP, getSettings().accountSuffix);
      return Promise.resolve(tonomyContract$6.newapp(options.appName, options.description, username.usernameHash, options.logoUrl, options.origin, options.publicKey, options.signer)).then(function (res) {
        var newAccountAction = res.processed.action_traces[0].inline_traces[0].act;
        return new App(_extends({}, options, {
          accountName: Name.from(newAccountAction.data.name),
          username: username,
          version: newAccountAction.data.version,
          status: AppStatusEnum.READY
        }));
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  App.getApp = function getApp(origin) {
    try {
      return Promise.resolve(tonomyContract$6.getApp(origin)).then(function (contractAppData) {
        return new App({
          accountName: contractAppData.account_name,
          appName: contractAppData.app_name,
          usernameHash: contractAppData.username_hash,
          description: contractAppData.description,
          logoUrl: contractAppData.logo_url,
          origin: contractAppData.origin,
          version: contractAppData.version,
          status: AppStatusEnum.READY
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return App;
}();

var WalletRequestResponse = /*#__PURE__*/function (_VerifiableCredential) {
  /**
   * @inheritdoc override me if the payload type requires ad-hoc decoding
   */
  function WalletRequestResponse(vc) {
    return _VerifiableCredential.call(this, vc) || this;
  }
  /**
   * Alternative constructor that returns type WalletRequestResponse. To be used in derived classes
   *
   * @access protected
   *
   * @param {object} payload the payload
   * @param {Issuer} issuer the issuer id
   * @param {VerifiableCredentialOptions} options the options
   *
   * @returns a WalletRequestResponse object
   */
  _inheritsLoose(WalletRequestResponse, _VerifiableCredential);
  WalletRequestResponse.signWalletResponse = function signWalletResponse(payload, issuer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this = this;
      if (_this.type === 'WalletRequest') {
        throw new Error('class should be a derived class of WalletRequest to use the type property');
      }
      return Promise.resolve(_VerifiableCredential.sign.call(_this, payload, issuer, options)).then(function (vc) {
        return new WalletRequestResponse(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return WalletRequestResponse;
}(VerifiableCredentialWithType);
WalletRequestResponse.type = 'WalletRequestResponse';
var LoginRequestResponse = /*#__PURE__*/function (_WalletRequestRespons) {
  /**
   * @override the VerifiableCredentialWithType constructor to decode the payload of type LoginRequestPayload
   */
  function LoginRequestResponse(vc) {
    var _this2;
    _this2 = _WalletRequestRespons.call(this, vc) || this;
    _this2.decodedPayload.accountName = Name.from(_WalletRequestRespons.prototype.getPayload.call(_this2).accountName);
    return _this2;
  }
  /**
   * Alternative constructor that returns type LoginRequestResponse
   */
  _inheritsLoose(LoginRequestResponse, _WalletRequestRespons);
  LoginRequestResponse.signResponse = function signResponse(payload, issuer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this3 = this;
      return Promise.resolve(_WalletRequestRespons.signWalletResponse.call(_this3, payload, issuer, options)).then(function (vc) {
        return new LoginRequestResponse(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return LoginRequestResponse;
}(WalletRequestResponse);
LoginRequestResponse.type = 'LoginRequestResponse';
var DataRequestResponse = /*#__PURE__*/function (_WalletRequestRespons2) {
  /**
   * @override the VerifiableCredentialWithType constructor to decode the payload of type DataSharingRequestResponsePayload
   */
  function DataRequestResponse(vc) {
    var _this4;
    _this4 = _WalletRequestRespons2.call(this, vc) || this;
    if (_this4.decodedPayload.data.username && typeof _this4.decodedPayload.data.username === 'string') {
      _this4.decodedPayload.data.username = new TonomyUsername(_this4.decodedPayload.data.username);
    }
    return _this4;
  }
  /**
   * Alternative constructor that returns type DataRequestResponse
   */
  _inheritsLoose(DataRequestResponse, _WalletRequestRespons2);
  DataRequestResponse.signResponse = function signResponse(payload, issuer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this5 = this;
      return Promise.resolve(_WalletRequestRespons2.signWalletResponse.call(_this5, payload, issuer, options)).then(function (vc) {
        return new DataRequestResponse(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return DataRequestResponse;
}(WalletRequestResponse);
DataRequestResponse.type = 'DataRequestResponse';

var _iteratorSymbol$3 = typeof Symbol !== "undefined" ? Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator")) : "@@iterator";
function _settle$3(pact, state, value) {
  if (!pact.s) {
    if (value instanceof _Pact$3) {
      if (value.s) {
        if (state & 1) {
          state = value.s;
        }
        value = value.v;
      } else {
        value.o = _settle$3.bind(null, pact, state);
        return;
      }
    }
    if (value && value.then) {
      value.then(_settle$3.bind(null, pact, state), _settle$3.bind(null, pact, 2));
      return;
    }
    pact.s = state;
    pact.v = value;
    var observer = pact.o;
    if (observer) {
      observer(pact);
    }
  }
}
var _Pact$3 = /*#__PURE__*/function () {
  function _Pact() {}
  _Pact.prototype.then = function (onFulfilled, onRejected) {
    var result = new _Pact();
    var state = this.s;
    if (state) {
      var callback = state & 1 ? onFulfilled : onRejected;
      if (callback) {
        try {
          _settle$3(result, 1, callback(this.v));
        } catch (e) {
          _settle$3(result, 2, e);
        }
        return result;
      } else {
        return this;
      }
    }
    this.o = function (_this) {
      try {
        var value = _this.v;
        if (_this.s & 1) {
          _settle$3(result, 1, onFulfilled ? onFulfilled(value) : value);
        } else if (onRejected) {
          _settle$3(result, 1, onRejected(value));
        } else {
          _settle$3(result, 2, value);
        }
      } catch (e) {
        _settle$3(result, 2, e);
      }
    };
    return result;
  };
  return _Pact;
}();
function _isSettledPact$3(thenable) {
  return thenable instanceof _Pact$3 && thenable.s & 1;
}
function _forTo$3(array, body, check) {
  var i = -1,
    pact,
    reject;
  function _cycle(result) {
    try {
      while (++i < array.length && (!check || !check())) {
        result = body(i);
        if (result && result.then) {
          if (_isSettledPact$3(result)) {
            result = result.v;
          } else {
            result.then(_cycle, reject || (reject = _settle$3.bind(null, pact = new _Pact$3(), 2)));
            return;
          }
        }
      }
      if (pact) {
        _settle$3(pact, 1, result);
      } else {
        pact = result;
      }
    } catch (e) {
      _settle$3(pact || (pact = new _Pact$3()), 2, e);
    }
  }
  _cycle();
  return pact;
}
var debug$6 = Debug('tonomy-sdk:requestsManager');
function _forOf$3(target, body, check) {
  if (typeof target[_iteratorSymbol$3] === "function") {
    var iterator = target[_iteratorSymbol$3](),
      step,
      pact,
      reject;
    function _cycle(result) {
      try {
        while (!(step = iterator.next()).done && (!check || !check())) {
          result = body(step.value);
          if (result && result.then) {
            if (_isSettledPact$3(result)) {
              result = result.v;
            } else {
              result.then(_cycle, reject || (reject = _settle$3.bind(null, pact = new _Pact$3(), 2)));
              return;
            }
          }
        }
        if (pact) {
          _settle$3(pact, 1, result);
        } else {
          pact = result;
        }
      } catch (e) {
        _settle$3(pact || (pact = new _Pact$3()), 2, e);
      }
    }
    _cycle();
    if (iterator.return) {
      var _fixup = function (value) {
        try {
          if (!step.done) {
            iterator.return();
          }
        } catch (e) {}
        return value;
      };
      if (pact && pact.then) {
        return pact.then(_fixup, function (e) {
          throw _fixup(e);
        });
      }
      _fixup();
    }
    return pact;
  }
  // No support for Symbol.iterator
  if (!("length" in target)) {
    throw new TypeError("Object is not iterable");
  }
  // Handle live collections properly
  var values = [];
  for (var i = 0; i < target.length; i++) {
    values.push(target[i]);
  }
  return _forTo$3(values, function (i) {
    return body(values[i]);
  }, check);
}
var RequestsManager = /*#__PURE__*/function () {
  function RequestsManager(requests) {
    this.requests = [];
    if (typeof requests[0] === 'string') {
      this.fromStrings(requests);
    } else {
      this.from(requests);
    }
  }
  var _proto = RequestsManager.prototype;
  _proto.from = function from(requests) {
    var checkedRequests = this.checkArrayAndFilterNull(requests);
    var classInitializedRequests = [];
    for (var _iterator = _createForOfIteratorHelperLoose(checkedRequests), _step; !(_step = _iterator()).done;) {
      var request = _step.value;
      debug$6('RequestsManager from', request.getType(), request.getPayload());
      classInitializedRequests.push(castToWalletRequestSubclass(request));
    }
    this.requests = classInitializedRequests;
  };
  _proto.fromStrings = function fromStrings(requests) {
    var checkedRequests = this.checkArrayAndFilterNull(requests);
    this.from(checkedRequests.map(function (request) {
      return new WalletRequest(request);
    }));
  };
  _proto.checkArrayAndFilterNull = function checkArrayAndFilterNull(array) {
    if (!array || !Array.isArray(array)) {
      throwError('No requests found', SdkErrors.RequestsNotFound);
    }
    var response = array.filter(function (request) {
      return request !== null;
    });
    if (response.length === 0) {
      throwError('No requests found in array', SdkErrors.RequestsNotFound);
    }
    return response;
  };
  _proto.getRequests = function getRequests() {
    return this.requests;
  }
  /**
   * Verifies the WalletRequests are valid requests signed by valid DIDs
   * @throws if the requests are not valid
   */;
  _proto.verify = function verify() {
    try {
      var _this = this;
      var _temp = _forOf$3(_this.requests, function (request) {
        return Promise.resolve(request.verify()).then(function (_request$verify) {
          if (!_request$verify) {
            if (request instanceof LoginRequest) {
              throwError("Invalid request for " + request.getType() + " " + request.getPayload().origin, SdkErrors.JwtNotValid);
            } else if (request instanceof DataSharingRequest) {
              throwError("Invalid request for " + request.getType() + " ", SdkErrors.JwtNotValid);
            }
          }
        });
      });
      return Promise.resolve(_temp && _temp.then ? _temp.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.checkReferrerOrigin = function checkReferrerOrigin() {
    var docReferrer = document.referrer;
    if (!docReferrer) throwError('No referrer found', SdkErrors.ReferrerEmpty);
    var referrerOrigin = new URL(docReferrer).origin;
    var myRequest = this.getLoginRequestsOrThrow().find(function (request) {
      return request.getPayload().origin === referrerOrigin;
    });
    if (!myRequest) {
      var msg = "No origins from: " + this.getLoginRequestsOrThrow().map(function (r) {
        return r.getPayload().origin;
      }) + " " + ("match referrer: " + referrerOrigin);
      throwError(msg, SdkErrors.WrongOrigin);
    }
  };
  _proto.getLoginRequests = function getLoginRequests() {
    var response = this.requests.filter(function (request) {
      return request instanceof LoginRequest;
    });
    return response.length > 0 ? response : undefined;
  };
  _proto.getLoginRequestsOrThrow = function getLoginRequestsOrThrow() {
    var response = this.getLoginRequests();
    if (!response) {
      throwError('No LoginRequests found', SdkErrors.RequestsNotFound);
    }
    return response;
  };
  _proto.getDataSharingRequests = function getDataSharingRequests() {
    var response = this.requests.filter(function (request) {
      return request instanceof DataSharingRequest;
    });
    return response.length > 0 ? response : undefined;
  };
  _proto.getDataSharingRequestsOrThrow = function getDataSharingRequestsOrThrow() {
    var response = this.getDataSharingRequests();
    if (!response) {
      throwError('No DataSharingRequests found', SdkErrors.RequestsNotFound);
    }
    return response;
  };
  _proto.getLoginRequestWithSameOriginOrThrow = function getLoginRequestWithSameOriginOrThrow() {
    var myOrigin = window.location.origin;
    var response = this.getLoginRequestsOrThrow().find(function (request) {
      return request.getPayload().origin === myOrigin;
    });
    if (!response) {
      throwError("No origin from " + myOrigin + " found", SdkErrors.OriginNotFound);
    }
    return response;
  };
  _proto.getLoginRequestWithDifferentOriginOrThrow = function getLoginRequestWithDifferentOriginOrThrow() {
    var myOrigin = window.location.origin;
    var response = this.getLoginRequestsOrThrow().find(function (request) {
      return request.getPayload().origin !== myOrigin;
    });
    if (!response) {
      throwError("No origin different from " + myOrigin + " found", SdkErrors.OriginNotFound);
    }
    return response;
  };
  _proto.getRequestsDifferentOriginOrThrow = function getRequestsDifferentOriginOrThrow() {
    var loginRequest = this.getLoginRequestWithDifferentOriginOrThrow();
    var issuer = loginRequest.getIssuer();
    var dataSharingRequest = this.requests.find(function (request) {
      return request instanceof DataSharingRequest && request.getIssuer() === issuer;
    });
    if (dataSharingRequest) {
      return [loginRequest, dataSharingRequest];
    } else {
      return [loginRequest];
    }
  };
  return RequestsManager;
}();
function castToWalletRequestSubclass(request) {
  if (request.getType() === LoginRequest.getType()) {
    return new LoginRequest(request);
  } else if (request.getType() === DataSharingRequest.getType()) {
    return new DataSharingRequest(request);
  } else {
    throwError('Invalid WalletRequest Type', SdkErrors.InvalidRequestType);
  }
}

function _catch$3(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
var debug$5 = Debug('tonomy-sdk:responsesManager');
const _iteratorSymbol$2 = typeof Symbol !== "undefined" ? Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator")) : "@@iterator";
function _settle$2(pact, state, value) {
  if (!pact.s) {
    if (value instanceof _Pact$2) {
      if (value.s) {
        if (state & 1) {
          state = value.s;
        }
        value = value.v;
      } else {
        value.o = _settle$2.bind(null, pact, state);
        return;
      }
    }
    if (value && value.then) {
      value.then(_settle$2.bind(null, pact, state), _settle$2.bind(null, pact, 2));
      return;
    }
    pact.s = state;
    pact.v = value;
    var observer = pact.o;
    if (observer) {
      observer(pact);
    }
  }
}
var _Pact$2 = /*#__PURE__*/function () {
  function _Pact() {}
  _Pact.prototype.then = function (onFulfilled, onRejected) {
    var result = new _Pact();
    var state = this.s;
    if (state) {
      var callback = state & 1 ? onFulfilled : onRejected;
      if (callback) {
        try {
          _settle$2(result, 1, callback(this.v));
        } catch (e) {
          _settle$2(result, 2, e);
        }
        return result;
      } else {
        return this;
      }
    }
    this.o = function (_this) {
      try {
        var value = _this.v;
        if (_this.s & 1) {
          _settle$2(result, 1, onFulfilled ? onFulfilled(value) : value);
        } else if (onRejected) {
          _settle$2(result, 1, onRejected(value));
        } else {
          _settle$2(result, 2, value);
        }
      } catch (e) {
        _settle$2(result, 2, e);
      }
    };
    return result;
  };
  return _Pact;
}();
function _isSettledPact$2(thenable) {
  return thenable instanceof _Pact$2 && thenable.s & 1;
}
function _forTo$2(array, body, check) {
  var i = -1,
    pact,
    reject;
  function _cycle(result) {
    try {
      while (++i < array.length && (!check || !check())) {
        result = body(i);
        if (result && result.then) {
          if (_isSettledPact$2(result)) {
            result = result.v;
          } else {
            result.then(_cycle, reject || (reject = _settle$2.bind(null, pact = new _Pact$2(), 2)));
            return;
          }
        }
      }
      if (pact) {
        _settle$2(pact, 1, result);
      } else {
        pact = result;
      }
    } catch (e) {
      _settle$2(pact || (pact = new _Pact$2()), 2, e);
    }
  }
  _cycle();
  return pact;
}
function _forOf$2(target, body, check) {
  if (typeof target[_iteratorSymbol$2] === "function") {
    var _cycle2 = function _cycle(result) {
      try {
        while (!(step = iterator.next()).done && (!check || !check())) {
          result = body(step.value);
          if (result && result.then) {
            if (_isSettledPact$2(result)) {
              result = result.v;
            } else {
              result.then(_cycle2, reject || (reject = _settle$2.bind(null, pact = new _Pact$2(), 2)));
              return;
            }
          }
        }
        if (pact) {
          _settle$2(pact, 1, result);
        } else {
          pact = result;
        }
      } catch (e) {
        _settle$2(pact || (pact = new _Pact$2()), 2, e);
      }
    };
    var iterator = target[_iteratorSymbol$2](),
      step,
      pact,
      reject;
    _cycle2();
    if (iterator["return"]) {
      var _fixup = function _fixup(value) {
        try {
          if (!step.done) {
            iterator["return"]();
          }
        } catch (e) {}
        return value;
      };
      if (pact && pact.then) {
        return pact.then(_fixup, function (e) {
          throw _fixup(e);
        });
      }
      _fixup();
    }
    return pact;
  }
  // No support for Symbol.iterator
  if (!("length" in target)) {
    throw new TypeError("Object is not iterable");
  }
  // Handle live collections properly
  var values = [];
  for (var i = 0; i < target.length; i++) {
    values.push(target[i]);
  }
  return _forTo$2(values, function (i) {
    return body(values[i]);
  }, check);
}
var WalletRequestAndResponseObject = /*#__PURE__*/function () {
  function WalletRequestAndResponseObject(arg) {
    this.request = void 0;
    this.meta = void 0;
    this.response = void 0;
    if (typeof arg === 'string') {
      var parsed = JSON.parse(arg);
      var request = new WalletRequest(parsed.request);
      var response = new WalletRequestResponse(parsed.response);
      this.setRequest(castToWalletRequestSubclass(request));
      this.setResponse(castToWalletRequestResponseSubclass(response));
    } else if (arg instanceof WalletRequestAndResponse) {
      this.setRequest(castToWalletRequestSubclass(arg.request));
      this.setResponse(castToWalletRequestResponseSubclass(arg.response));
    } else if (WalletRequestAndResponse.isInstance(arg)) {
      this.setRequest(castToWalletRequestSubclass(arg.request));
      this.setResponse(castToWalletRequestResponseSubclass(arg.response));
    } else if (arg instanceof WalletRequest) {
      this.setRequest(castToWalletRequestSubclass(arg));
    } else if (WalletRequestAndResponseStrings.isInstance(arg)) {
      this.setRequest(castToWalletRequestSubclass(new WalletRequest(arg.request)));
      this.setResponse(castToWalletRequestResponseSubclass(new WalletRequestResponse(arg.response)));
    } else {
      throwError('Invalid argument type', SdkErrors.InvalidArgumentType);
    }
  }
  var _proto = WalletRequestAndResponseObject.prototype;
  _proto.setRequest = function setRequest(request) {
    this.request = request;
  };
  _proto.setMeta = function setMeta(meta) {
    this.meta = meta;
  };
  _proto.setResponse = function setResponse(response) {
    this.response = response;
  };
  _proto.getRequestType = function getRequestType() {
    return this.request.getType();
  };
  _proto.getRequest = function getRequest() {
    return this.request;
  };
  _proto.getMetaOrThrow = function getMetaOrThrow() {
    if (!this.meta) {
      throwError('Response meta not set', SdkErrors.ResponsesNotFound);
    }
    return this.meta;
  };
  _proto.getAppOrThrow = function getAppOrThrow() {
    return this.getMetaOrThrow().app;
  };
  _proto.getResponse = function getResponse() {
    if (!this.response) {
      throwError('Response not set', SdkErrors.ResponsesNotFound);
    }
    return this.response;
  };
  _proto.getRequestAndResponse = function getRequestAndResponse() {
    return {
      request: this.getRequest(),
      response: this.getResponse()
    };
  };
  _proto.toString = function toString() {
    return JSON.stringify(this.getRequestAndResponse());
  };
  _proto.toJSON = function toJSON() {
    return this.toString();
  };
  return WalletRequestAndResponseObject;
}();
var WalletRequestAndResponse = /*#__PURE__*/function () {
  function WalletRequestAndResponse() {
    this.request = void 0;
    this.response = void 0;
  }
  WalletRequestAndResponse.isInstance = function isInstance(arg) {
    return arg instanceof Object && arg.request && arg.request instanceof WalletRequest && arg.response && arg.response instanceof WalletRequestResponse;
  };
  return WalletRequestAndResponse;
}();
var WalletRequestAndResponseStrings = /*#__PURE__*/function () {
  function WalletRequestAndResponseStrings() {
    this.request = void 0;
    this.response = void 0;
  }
  WalletRequestAndResponseStrings.isInstance = function isInstance(arg) {
    return arg instanceof Object && arg.request && typeof arg.request === 'string' && arg.response && typeof arg.response === 'string';
  };
  return WalletRequestAndResponseStrings;
}();
var ResponsesManager = /*#__PURE__*/function () {
  function ResponsesManager(args) {
    this.responses = [];
    if (args instanceof RequestsManager) {
      this.fromRequestsManager(args);
    } else {
      this.responses = args.map(function (response) {
        var responseObject = new WalletRequestAndResponseObject(response);
        debug$5('Response added:', responseObject.getRequest().getType(), responseObject.getRequest().getPayload(), responseObject.getRequest().getIssuer());
        return responseObject;
      });
    }
  }
  var _proto2 = ResponsesManager.prototype;
  _proto2.fromRequestsManager = function fromRequestsManager(requestsManager) {
    var _this = this;
    requestsManager.getRequests().forEach(function (request) {
      _this.responses.push(new WalletRequestAndResponseObject(request));
    });
  };
  _proto2.fetchMeta = function fetchMeta(options) {
    try {
      var _this2 = this;
      // fetch apps for all requests
      return Promise.resolve(Promise.all(_this2.responses.map(function (response) {
        try {
          return Promise.resolve(App.getApp(response.getRequest().getPayload().origin)).then(function (_App$getApp) {
            var _exit;
            function _temp4(_result2) {
              if (_exit) ;
              response.setMeta(meta);
            }
            var meta = {
              app: _App$getApp
            };
            var _temp3 = function () {
              if (options != null && options.accountName && response.getRequest() instanceof LoginRequest) {
                var _temp2 = function _temp2(_result) {
                  if (_exit) ;
                  meta.requiresLogin = _requiresLogin;
                };
                var _requiresLogin = true;
                var _temp = _catch$3(function () {
                  return Promise.resolve(verifyKeyExistsForApp(options.accountName, {
                    publicKey: response.getRequest().getPayload().publicKey
                  })).then(function () {
                    // User already logged in with this key
                    _requiresLogin = false;
                  });
                }, function (e) {
                  if (e instanceof SdkError && e.code === SdkErrors.UserNotLoggedInWithThisApp) {
                    // Never consented
                    _requiresLogin = true;
                  } else {
                    throw e;
                  }
                });
                return _temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp);
              }
            }();
            // Check if user is logged in with this app (LoginRequest only)
            return _temp3 && _temp3.then ? _temp3.then(_temp4) : _temp4(_temp3);
          });
        } catch (e) {
          return Promise.reject(e);
        }
      }))).then(function () {
        // check that all requests from the same issuers have the same apps
        var issuers = new Set();
        _this2.responses.map(function (response) {
          return issuers.add(response.getRequest().getIssuer());
        });
        var _loop = function _loop() {
          var issuer = _step.value;
          var apps = _this2.responses.filter(function (response) {
            return response.getRequest().getIssuer() === issuer;
          }).map(function (response) {
            return response.getAppOrThrow();
          });
          if (apps.some(function (app) {
            return !app.accountName.equals(apps[0].accountName);
          })) {
            throw new Error("Requests with the same issuer have different apps, which can happen if origins change");
          }
        };
        for (var _iterator = _createForOfIteratorHelperLoose(issuers), _step; !(_step = _iterator()).done;) {
          _loop();
        }
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto2.createResponses = function createResponses(user) {
    try {
      var _this3 = this;
      return Promise.resolve(user.getIssuer()).then(function (issuer) {
        function _temp12() {
          return _this3.exportFinalResponses();
        }
        var _temp11 = _forOf$2(_this3.responses, function (response) {
          var request = response.getRequest();
          debug$5('createResponses() getPayload', request.getPayload(), request.getType(), request.getIssuer());
          var _temp10 = function () {
            if (request instanceof LoginRequest) {
              var _temp6 = function _temp6() {
                var _setResponse = response.setResponse;
                var _signResponse = LoginRequestResponse.signResponse;
                return Promise.resolve(user.getAccountName()).then(function (_user$getAccountName) {
                  return Promise.resolve(_signResponse.call(LoginRequestResponse, {
                    accountName: _user$getAccountName
                  }, issuer)).then(function (_LoginRequestResponse) {
                    _setResponse.call(response, _LoginRequestResponse);
                  });
                });
              };
              var _temp5 = function () {
                if (response.getMetaOrThrow().requiresLogin === true) {
                  return Promise.resolve(user.loginWithApp(response.getAppOrThrow(), request.getPayload().publicKey)).then(function () {});
                }
              }();
              return _temp5 && _temp5.then ? _temp5.then(_temp6) : _temp6(_temp5);
            } else {
              var _temp13 = function () {
                if (request instanceof DataSharingRequest) {
                  var _temp8 = function _temp8() {
                    var _setResponse2 = response.setResponse;
                    return Promise.resolve(DataRequestResponse.signResponse({
                      data: _data
                    }, issuer)).then(function (_DataRequestResponse$) {
                      _setResponse2.call(response, _DataRequestResponse$);
                    });
                  };
                  var _data = {};
                  var _temp7 = function () {
                    if (request.getPayload().username) {
                      return Promise.resolve(user.getUsername()).then(function (_user$getUsername) {
                        _data.username = _user$getUsername;
                      });
                    }
                  }();
                  return _temp7 && _temp7.then ? _temp7.then(_temp8) : _temp8(_temp7);
                }
              }();
              if (_temp13 && _temp13.then) return _temp13.then(function () {});
            }
          }();
          if (_temp10 && _temp10.then) return _temp10.then(function () {});
        });
        return _temp11 && _temp11.then ? _temp11.then(_temp12) : _temp12(_temp11);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto2.verify = function verify() {
    try {
      var _this4 = this;
      return Promise.resolve(Promise.all(_this4.responses.map(function (response) {
        try {
          return Promise.resolve(Promise.all([response.getRequest().verify(), response.getResponse().verify()]));
        } catch (e) {
          return Promise.reject(e);
        }
      }))).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto2.exportFinalResponses = function exportFinalResponses() {
    return this.responses.map(function (response) {
      return response.getRequestAndResponse();
    });
  };
  _proto2.getResponsesWithSameOriginOrThrow = function getResponsesWithSameOriginOrThrow() {
    var responses = this.responses.filter(function (response) {
      return response.getAppOrThrow().origin === window.location.origin;
    });
    if (responses.length === 0) {
      throwError('No external app requests found', SdkErrors.ResponsesNotFound);
    }
    return responses;
  };
  _proto2.getLoginResponsesWithSameOriginOrThrow = function getLoginResponsesWithSameOriginOrThrow() {
    var response = this.getResponsesWithSameOriginOrThrow().find(function (response) {
      return response.getRequest() instanceof LoginRequest;
    });
    if (!response) {
      throwError('No external login request found', SdkErrors.ResponsesNotFound);
    }
    return response;
  };
  _proto2.getLoginResponseWithDifferentOriginOrThrow = function getLoginResponseWithDifferentOriginOrThrow() {
    var response = this.getResponsesWithDifferentOriginOrThrow().find(function (response) {
      return response.getRequest() instanceof LoginRequest;
    });
    if (!response) {
      throwError('No external login request found', SdkErrors.ResponsesNotFound);
    }
    return response;
  };
  _proto2.getDataSharingResponseWithSameOrigin = function getDataSharingResponseWithSameOrigin() {
    return this.getResponsesWithSameOriginOrThrow().find(function (response) {
      return response.getRequest() instanceof DataSharingRequest;
    });
  };
  _proto2.getRequests = function getRequests() {
    return this.responses.map(function (response) {
      return response.getRequest();
    });
  };
  _proto2.getResponsesWithDifferentOriginOrThrow = function getResponsesWithDifferentOriginOrThrow() {
    return this.responses.filter(function (response) {
      return response.getAppOrThrow().origin !== window.location.origin;
    });
  };
  _proto2.getAccountsLoginRequestsIssuerOrThrow = function getAccountsLoginRequestsIssuerOrThrow() {
    return this.getAccountsLoginRequestOrThrow().getIssuer();
  };
  _proto2.getAccountsLoginRequestOrThrow = function getAccountsLoginRequestOrThrow() {
    var externalLoginResponse = this.responses.find(function (response) {
      return response.getRequest() instanceof LoginRequest && response.getRequest().getPayload().origin === getSettings().ssoWebsiteOrigin;
    });
    if (!externalLoginResponse) throwError('No external login request found', SdkErrors.ResponsesNotFound);
    return externalLoginResponse.getRequest();
  };
  _proto2.getExternalLoginResponseOrThrow = function getExternalLoginResponseOrThrow() {
    var externalLoginResponse = this.responses.find(function (response) {
      return response.getRequest() instanceof LoginRequest && response.getRequest().getPayload().origin !== getSettings().ssoWebsiteOrigin;
    });
    if (!externalLoginResponse) throwError('No external login request found', SdkErrors.ResponsesNotFound);
    return externalLoginResponse;
  };
  return ResponsesManager;
}();
function castToWalletRequestResponseSubclass(response) {
  if (response.getType() === LoginRequestResponse.getType()) {
    return new LoginRequestResponse(response);
  } else if (response.getType() === DataRequestResponse.getType()) {
    return new DataRequestResponse(response);
  } else {
    throwError('Invalid WalletRequestResponse Type', SdkErrors.InvalidRequestResponseType);
  }
}

/**
 * A message that can be sent between two Tonomy identities
 *
 * @inheritdoc signMessageWithRecipient() is a protected alternative constructor. In child classes,
 * a new alternative constructor called signMessage() should be created which returns the child class type.
 * @inheritdoc protected "type" property should be overridden in child classes with the name of the class
 * @inheritdoc if the payload type requires ad-hoc decoding, override the constructor and decode the payload
 *
 * @example see an example of the above in the LoginRequestMessage class
 */
var Message = /*#__PURE__*/function (_VerifiableCredential) {
  /**
   * @inheritdoc override me if the payload type requires ad-hoc decoding
   */
  function Message(vc) {
    return _VerifiableCredential.call(this, vc) || this;
  }
  /**
   * Alternative constructor that returns type Message
   *
   * @access protected
   *
   * @param {object} message the message
   * @param {Issuer} issuer the issuer id
   * @param {DIDUrl} recipient the recipient id
   * @param {VerifiableCredentialOptions} options the options
   *
   * @returns a message object
   */
  _inheritsLoose(Message, _VerifiableCredential);
  Message.signMessageWithRecipient = function signMessageWithRecipient(message, issuer, recipient, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this = this;
      if (_this.type === 'Message') {
        throw new Error('class should be a derived class of Message to use the type property');
      }
      var newOptions = _extends({
        subject: recipient,
        additionalTypes: ['TonomyMessage']
      }, options);
      return Promise.resolve(_VerifiableCredential.sign.call(_this, message, issuer, newOptions)).then(function (request) {
        return new Message(request.getVc());
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Returns the recipient of the message
   * @returns {DIDur} the message recipient
   */
  ;
  var _proto = Message.prototype;
  _proto.getRecipient = function getRecipient() {
    return this.getVc().getSubject();
  }
  /**
   * Returns the sender of the message
   * @returns {DIDur} the message sender
   */;
  _proto.getSender = function getSender() {
    return _VerifiableCredential.prototype.getIssuer.call(this);
  };
  return Message;
}(VerifiableCredentialWithType);
Message.type = 'Message';
var AuthenticationMessage = /*#__PURE__*/function (_Message2) {
  function AuthenticationMessage() {
    return _Message2.apply(this, arguments) || this;
  }
  _inheritsLoose(AuthenticationMessage, _Message2);
  /**
   * Alternative constructor that returns type AuthenticationMessage
   */
  AuthenticationMessage.signMessageWithoutRecipient = function signMessageWithoutRecipient(message, issuer, options) {
    try {
      var _this2 = this;
      return Promise.resolve(_Message2.signMessageWithRecipient.call(_this2, message, issuer, '', options)).then(function (vc) {
        return new AuthenticationMessage(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return AuthenticationMessage;
}(Message);
AuthenticationMessage.type = 'AuthenticationMessage';
var IdentifyMessage = /*#__PURE__*/function (_Message3) {
  function IdentifyMessage() {
    return _Message3.apply(this, arguments) || this;
  }
  _inheritsLoose(IdentifyMessage, _Message3);
  /**
   * Alternative constructor that returns type IdentifyMessage
   */
  IdentifyMessage.signMessage = function signMessage(message, issuer, recipient, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this3 = this;
      return Promise.resolve(_Message3.signMessageWithRecipient.call(_this3, message, issuer, recipient, options)).then(function (vc) {
        return new IdentifyMessage(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return IdentifyMessage;
}(Message);
IdentifyMessage.type = 'IdentifyMessage';
var LoginRequestsMessage = /*#__PURE__*/function (_Message4) {
  /**
   * @override the Message constructor to decode the payload of type LoginRequestsMessagePayload
   */
  function LoginRequestsMessage(vc) {
    var _this4;
    _this4 = _Message4.call(this, vc) || this;
    var payload = _this4.getVc().getPayload().vc.credentialSubject.payload;
    if (!payload.requests) {
      throw new Error('LoginRequestsMessage must have a requests property');
    }
    var requests = payload.requests.map(function (request) {
      return new WalletRequest(request);
    });
    var requestsManager = new RequestsManager(requests);
    _this4.decodedPayload = {
      requests: requestsManager.getRequests()
    };
    return _this4;
  }
  /**
   * Alternative constructor that returns type LoginRequestsMessage
   */
  _inheritsLoose(LoginRequestsMessage, _Message4);
  LoginRequestsMessage.signMessage = function signMessage(message, issuer, recipient, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this5 = this;
      return Promise.resolve(_Message4.signMessageWithRecipient.call(_this5, message, issuer, recipient, options)).then(function (vc) {
        return new LoginRequestsMessage(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return LoginRequestsMessage;
}(Message);
LoginRequestsMessage.type = 'LoginRequestsMessage';
var LoginRequestResponseMessage = /*#__PURE__*/function (_Message5) {
  /**
   * @override the Message constructor to decode the payload of type LoginRequestResponseMessagePayload
   */
  function LoginRequestResponseMessage(vc) {
    var _this6;
    _this6 = _Message5.call(this, vc) || this;
    var payload = _this6.getVc().getPayload().vc.credentialSubject.payload;
    if (payload.success) {
      if (!payload.response) {
        throw new Error('LoginRequestsResponseMessage must have a response property');
      }
      var responses = payload.response.map(function (response) {
        return new WalletRequestAndResponseObject(response).getRequestAndResponse();
      });
      _this6.decodedPayload = _extends({}, payload, {
        response: responses
      });
    } else {
      if (!payload.error) {
        throw new Error('LoginRequestsResponseMessage must have an error property');
      }
      var error = payload.error;
      var requests = error.requests.map(function (request) {
        return new WalletRequest(request);
      });
      var requestsManager = new RequestsManager(requests);
      _this6.decodedPayload = _extends({}, payload, {
        error: _extends({}, error, {
          requests: requestsManager.getRequests()
        })
      });
    }
    return _this6;
  }
  /**
   * Alternative constructor that returns type LoginRequestResponseMessage
   */
  _inheritsLoose(LoginRequestResponseMessage, _Message5);
  LoginRequestResponseMessage.signMessage = function signMessage(message, issuer, recipient, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this7 = this;
      return Promise.resolve(_Message5.signMessageWithRecipient.call(_this7, message, issuer, recipient, options)).then(function (vc) {
        return new LoginRequestResponseMessage(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return LoginRequestResponseMessage;
}(Message);
LoginRequestResponseMessage.type = 'LoginRequestResponseMessage';
var LinkAuthRequestMessage = /*#__PURE__*/function (_Message6) {
  /**
   * @override the Message constructor to decode the payload of type LinkAuthRequestMessagePayload
   */
  function LinkAuthRequestMessage(vc) {
    var _this8;
    _this8 = _Message6.call(this, vc) || this;
    var payload = _this8.getVc().getPayload().vc.credentialSubject.payload;
    _this8.decodedPayload = {
      contract: Name.from(payload.contract),
      action: Name.from(payload.action)
    };
    return _this8;
  }
  /**
   * Alternative constructor that returns type LoginRequestResponseMessage
   */
  _inheritsLoose(LinkAuthRequestMessage, _Message6);
  LinkAuthRequestMessage.signMessage = function signMessage(message, issuer, recipient, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this9 = this;
      return Promise.resolve(_Message6.signMessageWithRecipient.call(_this9, message, issuer, recipient, options)).then(function (vc) {
        return new LinkAuthRequestMessage(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return LinkAuthRequestMessage;
}(Message);
LinkAuthRequestMessage.type = 'LinkAuthRequestMessage';
var LinkAuthRequestResponseMessage = /*#__PURE__*/function (_Message7) {
  function LinkAuthRequestResponseMessage() {
    return _Message7.apply(this, arguments) || this;
  }
  _inheritsLoose(LinkAuthRequestResponseMessage, _Message7);
  /**
   * Alternative constructor that returns type LinkAuthRequestResponseMessage
   */
  LinkAuthRequestResponseMessage.signMessage = function signMessage(message, issuer, recipient, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this10 = this;
      return Promise.resolve(_Message7.signMessageWithRecipient.call(_this10, message, issuer, recipient, options)).then(function (vc) {
        return new LinkAuthRequestResponseMessage(vc);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return LinkAuthRequestResponseMessage;
}(Message);
LinkAuthRequestResponseMessage.type = 'LinkAuthRequestResponseMessage';

var CONTRACT_NAME$3 = 'eosio';
var EosioContract = /*#__PURE__*/function () {
  function EosioContract(contractName) {
    if (contractName === void 0) {
      contractName = CONTRACT_NAME$3;
    }
    this.contractName = CONTRACT_NAME$3;
    this.contractName = contractName;
  }
  /**
   * Deploys a contract at the specified address
   *
   * @param account - Account where the contract will be deployed
   * @param wasmFileContents - wasmFile after reading with fs.readFileSync(path) or equivalent
   * @param abiFileContents - abiFile after reading with fs.readFileSync(path, `utf8`) or equivalent
   * @param signer - Signer to sign the transaction
   * @param [extraAuthorization] - Extra authorization to be added to the transaction
   */
  var _proto = EosioContract.prototype;
  _proto.deployContract = function deployContract(account, wasmFileContent, abiFileContent, signer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      // 1. Prepare SETCODE
      // read the file and make a hex string out of it
      var wasm = wasmFileContent.toString("hex");
      // 2. Prepare SETABI
      var abi = JSON.parse(abiFileContent);
      var abiDef = ABI.from(abi);
      var abiSerializedHex = Serializer.encode({
        object: abiDef
      }).hexString;
      // 3. Send transaction with both setcode and setabi actions
      var setCodeAction = {
        account: CONTRACT_NAME$3,
        name: 'setcode',
        authorization: [{
          actor: account.toString(),
          permission: 'active'
        }],
        data: {
          account: account.toString(),
          vmtype: 0,
          vmversion: 0,
          code: wasm
        }
      };
      if (options.extraAuthorization) setCodeAction.authorization.push(options.extraAuthorization);
      var setAbiAction = {
        account: CONTRACT_NAME$3,
        name: 'setabi',
        authorization: [{
          actor: account.toString(),
          permission: 'active'
        }],
        data: {
          account: account,
          abi: abiSerializedHex
        }
      };
      if (options.extraAuthorization) setAbiAction.authorization.push(options.extraAuthorization);
      var actions = [setCodeAction, setAbiAction];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$3), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.updateauth = function updateauth(account, permission, parent, auth, signer) {
    try {
      var action = {
        authorization: [{
          actor: account,
          permission: parent // all higher parents, and permission, work as authorization. though permission is supposed to be the authorization that works
        }],
        account: CONTRACT_NAME$3,
        name: 'updateauth',
        data: {
          account: account,
          permission: permission,
          parent: permission === 'owner' ? '' : parent,
          auth: auth
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$3), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.newaccount = function newaccount(creator, name, owner, active, signer) {
    try {
      var action = {
        authorization: [{
          actor: creator.toString(),
          permission: 'active'
        }],
        account: CONTRACT_NAME$3,
        name: 'newaccount',
        data: {
          creator: creator,
          name: name,
          owner: owner,
          active: active
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$3), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * @param account - the permission's owner to be linked and the payer of the RAM needed to store this link,
   * @param code - the owner of the action to be linked,
   * @param type - the action to be linked,
   * @param requirement - the permission to be linked.
   */
  ;
  _proto.linkAuth = function linkAuth(account, code, type, requirement, signer) {
    try {
      var action = {
        authorization: [{
          actor: account,
          permission: 'active'
        }],
        account: CONTRACT_NAME$3,
        name: 'linkauth',
        data: {
          account: account,
          code: code,
          type: type,
          requirement: requirement
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$3), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.setPriv = function setPriv(account, isPriv, signer) {
    try {
      var action = {
        authorization: [{
          actor: CONTRACT_NAME$3,
          permission: 'active'
        }],
        account: CONTRACT_NAME$3,
        name: 'setpriv',
        data: {
          account: account,
          is_priv: isPriv
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$3), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.setParams = function setParams(blockchainParameters, signer) {
    if (blockchainParameters === void 0) {
      blockchainParameters = defaultBlockchainParams;
    }
    try {
      var action = {
        authorization: [{
          actor: CONTRACT_NAME$3,
          permission: 'active'
        }],
        account: CONTRACT_NAME$3,
        name: 'setparams',
        data: {
          params: blockchainParameters
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$3), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return _createClass(EosioContract, null, [{
    key: "Instance",
    get: function get() {
      return this.singletonInstance || (this.singletonInstance = new this());
    }
  }]);
}();
EosioContract.singletonInstance = void 0;
var defaultBlockchainParams = {
  // NET
  max_block_net_usage: 1024 * 1024,
  target_block_net_usage_pct: 8000,
  // 80%
  max_transaction_net_usage: 1024 * 512,
  base_per_transaction_net_usage: 12,
  net_usage_leeway: 500,
  context_free_discount_net_usage_num: 20,
  context_free_discount_net_usage_den: 100,
  // CPU
  max_block_cpu_usage: 200000,
  target_block_cpu_usage_pct: 8000,
  // 80%
  max_transaction_cpu_usage: 50000,
  min_transaction_cpu_usage: 100,
  // Other
  max_transaction_lifetime: 3600,
  deferred_trx_expiration_window: 600,
  max_transaction_delay: 3888000,
  max_inline_action_size: 512 * 1024,
  max_inline_action_depth: 4,
  max_authority_depth: 6
};

var CONTRACT_NAME$2 = 'tonomy';
var TonomyEosioProxyContract = /*#__PURE__*/function () {
  function TonomyEosioProxyContract() {}
  var _proto = TonomyEosioProxyContract.prototype;
  /**
   * Deploys a contract at the specified address
   *
   * @param account - Account where the contract will be deployed
   * @param wasmFileContents - wasmFile after reading with fs.readFileSync(path) or equivalent
   * @param abiFileContents - abiFile after reading with fs.readFileSync(path, `utf8`) or equivalent
   * @param signer - Signer or Signer[] to sign the transaction
   * @param extraAuthorization - Extra authorization to be added to the transaction
   */
  _proto.deployContract = function deployContract(account, wasmFileContent, abiFileContent, signer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      // 1. Prepare SETCODE
      // read the file and make a hex string out of it
      var wasm = wasmFileContent.toString("hex");
      // 2. Prepare SETABI
      var abi = JSON.parse(abiFileContent);
      var abiDef = ABI.from(abi);
      var abiSerializedHex = Serializer.encode({
        object: abiDef
      }).hexString;
      // 3. Send transaction with both setcode and setabi actions
      var setCodeAction = {
        account: CONTRACT_NAME$2,
        name: 'setcode',
        authorization: [{
          actor: account.toString(),
          permission: 'active'
        }],
        data: {
          account: account.toString(),
          vmtype: 0,
          vmversion: 0,
          code: wasm
        }
      };
      if (options.extraAuthorization) setCodeAction.authorization.push(options.extraAuthorization);
      var setAbiAction = {
        account: CONTRACT_NAME$2,
        name: 'setabi',
        authorization: [{
          actor: account.toString(),
          permission: 'active'
        }],
        data: {
          account: account,
          abi: abiSerializedHex
        }
      };
      if (options.extraAuthorization) setAbiAction.authorization.push(options.extraAuthorization);
      var actions = [setCodeAction, setAbiAction];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$2), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.updateauth = function updateauth(account, permission, parent, auth, signer, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _options$authParent;
      var action = {
        authorization: [{
          actor: GOVERNANCE_ACCOUNT_NAME,
          permission: 'active'
        }, {
          actor: account,
          permission: parent // all higher parents, and permission, work as authorization. though permission is supposed to be the authorization that works
        }],
        account: CONTRACT_NAME$2,
        name: 'updateauth',
        data: {
          account: account,
          permission: permission,
          parent: permission === 'owner' ? '' : parent,
          auth: auth,
          auth_parent: (_options$authParent = options.authParent) != null ? _options$authParent : false // should be true when a new permission is being created, otherwise false
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$2), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * @param account - the permission's owner to be linked and the payer of the RAM needed to store this link,
   * @param code - the owner of the action to be linked,
   * @param type - the action to be linked,
   * @param requirement - the permission to be linked.
   */
  ;
  _proto.linkAuth = function linkAuth(account, code, type, requirement, signer) {
    try {
      var action = {
        authorization: [{
          actor: account,
          permission: 'active'
        }],
        account: CONTRACT_NAME$2,
        name: 'linkauth',
        data: {
          account: account,
          code: code,
          type: type,
          requirement: requirement
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$2), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.setpriv = function setpriv(account, isPriv, signer) {
    try {
      var action = {
        authorization: [{
          actor: GOVERNANCE_ACCOUNT_NAME,
          permission: 'active'
        }, {
          actor: account,
          permission: 'active'
        }],
        account: CONTRACT_NAME$2,
        name: 'setpriv',
        data: {
          account: account,
          is_priv: isPriv
        }
      };
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$2), [action], signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return _createClass(TonomyEosioProxyContract, null, [{
    key: "Instance",
    get: function get() {
      return this.singletonInstance || (this.singletonInstance = new this());
    }
  }]);
}();
TonomyEosioProxyContract.singletonInstance = void 0;

var CONTRACT_NAME$1 = 'eosio.msig';
var EosioMsigContract = /*#__PURE__*/function () {
  function EosioMsigContract(contractName) {
    if (contractName === void 0) {
      contractName = CONTRACT_NAME$1;
    }
    this.contractName = CONTRACT_NAME$1;
    this.contractName = contractName;
  }
  var _proto = EosioMsigContract.prototype;
  _proto.propose = function propose(proposer, proposalName, requested, actions, signer) {
    try {
      // Serialize the actions
      return Promise.resolve(Promise.all(actions.map(function (action) {
        try {
          if (!action.account || !action.name) throw new Error('Invalid action');
          var _action$authorization = action.authorization,
            _action$name = action.name,
            _action$account = action.account;
          return Promise.resolve(serializeActionData(action.account, action.name, action.data)).then(function (_serializeActionData) {
            return {
              account: _action$account,
              name: _action$name,
              authorization: _action$authorization,
              data: _serializeActionData
            };
          });
        } catch (e) {
          return Promise.reject(e);
        }
      }))).then(function (serializedActions) {
        // Determine expiration
        var now = new Date();
        var expireInSeconds = 60 * 60 * 24 * 7; // 7 days
        var expiration = new Date(now.getTime() + expireInSeconds * 1000);
        var expirationString = expiration.toISOString().split('.')[0];
        return Promise.resolve(getApi()).then(function (_getApi) {
          return Promise.resolve(_getApi.v1.chain.get_info()).then(function (info) {
            var trx = {
              expiration: expirationString,
              ref_block_num: info.getTransactionHeader().ref_block_num,
              ref_block_prefix: info.getTransactionHeader().ref_block_prefix,
              max_net_usage_words: 0,
              max_cpu_usage_ms: 0,
              delay_sec: 0,
              context_free_actions: [],
              actions: serializedActions,
              transaction_extensions: []
            };
            var proposalTrx = Transaction.from(trx);
            var proposalHash = proposalTrx.id;
            // Action data (not sure if this is right format)
            var data = {
              proposer: proposer,
              proposal_name: proposalName,
              requested: requested,
              trx: trx
            };
            // Propose action
            var action = {
              authorization: [{
                actor: proposer.toString(),
                permission: 'active'
              }],
              account: CONTRACT_NAME$1,
              name: 'propose',
              data: data
            };
            return Promise.resolve(transact(Name.from(CONTRACT_NAME$1), [action], signer)).then(function (myTrx) {
              return {
                proposalHash: proposalHash,
                transaction: myTrx
              };
            });
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.approve = function approve(proposer, proposalName, approver, proposalHash, signer) {
    try {
      var auth = {
        actor: approver.toString(),
        permission: 'active'
      };
      var actions = [{
        account: CONTRACT_NAME$1,
        name: 'approve',
        authorization: [auth],
        data: {
          proposer: proposer,
          proposal_name: proposalName,
          level: auth,
          proposal_hash: proposalHash
        }
      }];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$1), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.exec = function exec(proposer, proposalName, executer, signer) {
    try {
      var actions = [{
        account: CONTRACT_NAME$1,
        name: 'exec',
        authorization: [{
          actor: executer.toString(),
          permission: 'active'
        }],
        data: {
          proposer: proposer,
          proposal_name: proposalName,
          executer: executer
        }
      }];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$1), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.cancel = function cancel(proposer, proposalName, canceler, signer) {
    try {
      var actions = [{
        account: CONTRACT_NAME$1,
        name: 'cancel',
        authorization: [{
          actor: canceler.toString(),
          permission: 'active'
        }],
        data: {
          proposer: proposer,
          proposal_name: proposalName,
          canceler: canceler
        }
      }];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME$1), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return _createClass(EosioMsigContract, null, [{
    key: "Instance",
    get: function get() {
      return this.singletonInstance || (this.singletonInstance = new this());
    }
  }]);
}();
EosioMsigContract.singletonInstance = void 0;

var tonomyContract$5 = TonomyContract.Instance;
var DemoTokenContract = /*#__PURE__*/function () {
  function DemoTokenContract() {
    this.contractName = void 0;
  }
  DemoTokenContract.atAccount = function atAccount(account) {
    var instance = new this();
    instance.contractName = account.toString();
    return instance;
  };
  var _proto = DemoTokenContract.prototype;
  _proto.getContractName = function getContractName() {
    try {
      var _temp2 = function _temp2() {
        return _this.contractName;
      };
      var _this = this;
      var _temp = function () {
        if (!_this.contractName) {
          var username = TonomyUsername.fromUsername('demo', AccountType.APP, getSettings().accountSuffix);
          return Promise.resolve(tonomyContract$5.getApp(username)).then(function (app) {
            _this.contractName = app.account_name.toString();
          });
        }
      }();
      return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.create = function create(supply, signer) {
    try {
      var _this2 = this;
      return Promise.resolve(_this2.getContractName()).then(function (_this2$getContractNam) {
        return Promise.resolve(_this2.getContractName()).then(function (_this2$getContractNam2) {
          return Promise.resolve(_this2.getContractName()).then(function (_this2$getContractNam3) {
            var actions = [{
              account: _this2$getContractNam,
              name: 'create',
              authorization: [{
                actor: _this2$getContractNam2,
                permission: 'active'
              }],
              data: {
                issuer: _this2$getContractNam3,
                maximum_supply: supply
              }
            }];
            var _from = Name.from;
            return Promise.resolve(_this2.getContractName()).then(function (_this2$getContractNam4) {
              return Promise.resolve(transact(_from.call(Name, _this2$getContractNam4), actions, signer));
            });
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.issue = function issue(quantity, signer) {
    try {
      var _this3 = this;
      return Promise.resolve(_this3.getContractName()).then(function (_this3$getContractNam) {
        return Promise.resolve(_this3.getContractName()).then(function (_this3$getContractNam2) {
          return Promise.resolve(_this3.getContractName()).then(function (_this3$getContractNam3) {
            var actions = [{
              account: _this3$getContractNam,
              name: 'issue',
              authorization: [{
                actor: _this3$getContractNam2,
                permission: 'active'
              }],
              data: {
                to: _this3$getContractNam3,
                quantity: quantity,
                memo: 'issued'
              }
            }];
            var _from2 = Name.from;
            return Promise.resolve(_this3.getContractName()).then(function (_this3$getContractNam4) {
              return Promise.resolve(transact(_from2.call(Name, _this3$getContractNam4), actions, signer));
            });
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.selfIssue = function selfIssue(to, quantity, signer) {
    try {
      var _this4 = this;
      return Promise.resolve(_this4.getContractName()).then(function (_this4$getContractNam) {
        return Promise.resolve(_this4.getContractName()).then(function (_this4$getContractNam2) {
          var actions = [{
            account: _this4$getContractNam,
            name: 'issue',
            authorization: [{
              actor: _this4$getContractNam2,
              permission: 'active'
            }],
            data: {
              to: to,
              quantity: quantity,
              memo: 'self issued'
            }
          }];
          var _from3 = Name.from;
          return Promise.resolve(_this4.getContractName()).then(function (_this4$getContractNam3) {
            return Promise.resolve(transact(_from3.call(Name, _this4$getContractNam3), actions, signer));
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getBalance = function getBalance(account) {
    try {
      var _this5 = this;
      return Promise.resolve(getApi()).then(function (_getApi) {
        var _getApi$v1$chain = _getApi.v1.chain,
          _get_currency_balance = _getApi$v1$chain.get_currency_balance;
        return Promise.resolve(_this5.getContractName()).then(function (_this5$getContractNam) {
          return Promise.resolve(_get_currency_balance.call(_getApi$v1$chain, _this5$getContractNam, account, getSettings().currencySymbol)).then(function (assets) {
            return assets.length === 0 ? 0 : assets[0].value;
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return _createClass(DemoTokenContract, null, [{
    key: "Instance",
    get: function get() {
      return this.singletonInstande || (this.singletonInstande = new this());
    }
  }]);
}();
DemoTokenContract.singletonInstande = void 0;

var CONTRACT_NAME = 'eosio.token';
function assetToAmount(asset) {
  return parseFloat(asset.split(' ')[0]);
}
var EosioTokenContract = /*#__PURE__*/function () {
  function EosioTokenContract() {}
  var _proto = EosioTokenContract.prototype;
  _proto.create = function create(supply, signer) {
    try {
      var actions = [{
        account: CONTRACT_NAME,
        name: 'create',
        authorization: [{
          actor: CONTRACT_NAME,
          permission: 'active'
        }],
        data: {
          issuer: CONTRACT_NAME,
          maximum_supply: supply
        }
      }];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.issue = function issue(to, quantity, signer) {
    try {
      var actions = [{
        account: CONTRACT_NAME,
        name: 'issue',
        authorization: [{
          actor: CONTRACT_NAME,
          permission: 'active'
        }],
        data: {
          to: to,
          quantity: quantity,
          memo: 'issued'
        }
      }];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.transfer = function transfer(from, to, quantity, memo, signer) {
    try {
      var actions = [{
        account: CONTRACT_NAME,
        name: 'transfer',
        authorization: [{
          actor: from.toString(),
          permission: 'active'
        }],
        data: {
          from: from,
          to: to,
          quantity: quantity,
          memo: memo
        }
      }];
      return Promise.resolve(transact(Name.from(CONTRACT_NAME), actions, signer));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getBalance = function getBalance(account) {
    try {
      return Promise.resolve(getApi()).then(function (_getApi) {
        return Promise.resolve(_getApi.v1.chain.get_currency_balance(CONTRACT_NAME, account, getSettings().currencySymbol)).then(function (assets) {
          return assets.length === 0 ? 0 : assets[0].value;
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return _createClass(EosioTokenContract, null, [{
    key: "Instance",
    get: function get() {
      return this.singletonInstande || (this.singletonInstande = new this());
    }
  }]);
}();
EosioTokenContract.singletonInstande = void 0;

var Authority = /*#__PURE__*/function () {
  function Authority(threshold, keys, accounts, waits) {
    this.threshold = void 0;
    this.keys = void 0;
    this.accounts = void 0;
    this.waits = void 0;
    this.threshold = threshold;
    this.keys = keys;
    this.accounts = accounts;
    this.waits = waits;
  }
  Authority.fromKey = function fromKey(key) {
    var keys = [{
      key: key,
      weight: 1
    }];
    return new this(1, keys, [], []);
  };
  Authority.fromAccount = function fromAccount(permission) {
    if (!Name.pattern.test(permission.actor)) throw new Error("Invalid account name " + permission.actor);
    if (!Name.pattern.test(permission.permission)) throw new Error("Invalid account permission " + permission.permission);
    var accounts = [{
      permission: permission,
      weight: 1
    }];
    return new this(1, [], accounts, []);
  };
  Authority.fromAccountArray = function fromAccountArray(accounts, permission, threshold) {
    if (threshold === void 0) {
      threshold = 1;
    }
    var authority = Authority.fromAccount({
      actor: accounts[0],
      permission: permission
    });
    if (accounts.length > 1) {
      for (var _iterator = _createForOfIteratorHelperLoose(accounts.slice(1)), _step; !(_step = _iterator()).done;) {
        var arg = _step.value;
        authority.addAccount({
          actor: arg,
          permission: permission
        });
      }
    }
    authority.setThreshold(threshold);
    authority.sort();
    return authority;
  };
  Authority.fromAccountPermission = function fromAccountPermission(permission) {
    return new Authority(permission.required_auth.threshold.toNumber(), permission.required_auth.keys.map(function (keyWeight) {
      return {
        key: keyWeight.key.toString(),
        weight: keyWeight.weight.toNumber()
      };
    }), permission.required_auth.accounts.map(function (permissionWeight) {
      return {
        permission: {
          actor: permissionWeight.permission.actor.toString(),
          permission: permissionWeight.permission.permission.toString()
        },
        weight: permissionWeight.weight.toNumber()
      };
    }), permission.required_auth.waits.map(function (waitWeight) {
      return {
        // eslint-disable-next-line camelcase
        wait_sec: waitWeight.wait_sec.toNumber(),
        weight: waitWeight.weight.toNumber()
      };
    }));
  }
  // to add the eosio.code authority for smart contracts
  // https://developers.eos.io/welcome/v2.1/smart-contract-guides/adding-inline-actions#step-1-adding-eosiocode-to-permissions
  ;
  var _proto = Authority.prototype;
  _proto.addCodePermission = function addCodePermission(account) {
    this.accounts.push({
      permission: {
        actor: account,
        permission: 'eosio.code'
      },
      weight: 1
    });
    this.sort();
    return this;
  };
  _proto.addAccount = function addAccount(permission) {
    this.accounts.push({
      permission: permission,
      weight: 1
    });
    this.sort();
    return this;
  };
  _proto.addKey = function addKey(key, weight) {
    this.keys.push({
      key: key,
      weight: weight
    });
    this.sort();
    return this;
  };
  _proto.setThreshold = function setThreshold(threshold) {
    this.threshold = threshold;
    return this;
  }
  /**
   * Sorts the authority weights in place, should be called before including the authority in a `updateauth` action or it might be rejected.
   */;
  _proto.sort = function sort() {
    this.keys.sort(function (a, b) {
      return String(a.key).localeCompare(String(b.key));
    });
    this.accounts.sort(function (a, b) {
      return comparePermissionLevelWeight(a, b);
    });
    this.waits.sort(function (a, b) {
      return a.wait_sec - b.wait_sec;
    });
  };
  return Authority;
}();
function comparePermissionLevelWeight(lhs, rhs) {
  if (compareNameType(lhs.permission.actor, rhs.permission.actor) !== 0) {
    return compareNameType(lhs.permission.actor, rhs.permission.actor);
  }
  if (compareNameType(lhs.permission.permission, rhs.permission.permission) !== 0) {
    return compareNameType(lhs.permission.permission, rhs.permission.permission);
  }
  return lhs.weight - rhs.weight;
}
function compareNameType(lhs, rhs) {
  var lhsValue = Name.from(lhs).value.value;
  var rhsValue = Name.from(rhs).value.value;
  return lhsValue.cmp(rhsValue);
}

var index = {
  __proto__: null,
  EosioContract: EosioContract,
  defaultBlockchainParams: defaultBlockchainParams,
  TonomyEosioProxyContract: TonomyEosioProxyContract,
  EosioMsigContract: EosioMsigContract,
  getAccountNameFromUsername: getAccountNameFromUsername,
  GOVERNANCE_ACCOUNT_NAME: GOVERNANCE_ACCOUNT_NAME,
  get AccountTypeEnum () { return AccountTypeEnum; },
  RAM_PRICE: RAM_PRICE,
  RAM_FEE: RAM_FEE,
  TOTAL_RAM_AVAILABLE: TOTAL_RAM_AVAILABLE,
  bytesToTokens: bytesToTokens,
  TonomyContract: TonomyContract,
  DemoTokenContract: DemoTokenContract,
  assetToAmount: assetToAmount,
  EosioTokenContract: EosioTokenContract,
  LEOS_SEED_ROUND_PRICE: LEOS_SEED_ROUND_PRICE,
  LEOS_SEED_LATE_ROUND_PRICE: LEOS_SEED_LATE_ROUND_PRICE,
  LEOS_PUBLIC_SALE_PRICE: LEOS_PUBLIC_SALE_PRICE,
  LEOS_CURRENT_PRICE: LEOS_CURRENT_PRICE,
  VestingContract: VestingContract,
  Authority: Authority,
  getProducers: getProducers,
  getAccount: getAccount,
  getChainInfo: getChainInfo,
  serializeActionData: serializeActionData,
  getApi: getApi,
  getTonomyOperationsKey: getTonomyOperationsKey,
  AntelopePushTransactionError: AntelopePushTransactionError,
  transact: transact,
  createSigner: createSigner,
  createKeyManagerSigner: createKeyManagerSigner
};

/**
 * Checks that a key exists in the key manager that has been authorized on the DID
 *
 * @description This is called on the callback page to verify that the user has logged in correctly
 *
 * @param {string} [accountName] - the account name to check the key on
 * @param {PublicKey} [publicKey] - the public key to check. if not supplied it will try lookup the app from window.location.origin
 * @param {KeyManager} [keyManager] - the key manager to check the key in
 * @param {KeyManagerLevel} [keyManagerLevel=BROWSER_LOCAL_STORAGE] - the level to check the key in
 * @returns {Promise<Name>} - the name of the permission that the key is authorized on
 *
 * @throws {SdkError} - if the key doesn't exist or isn't authorized
 */
var verifyKeyExistsForApp = function verifyKeyExistsForApp(accountName, options) {
  return Promise.resolve(getAccountInfo(accountName)).then(function (account) {
    if (!account) throwError("couldn't fetch account", SdkErrors.AccountNotFound);
    if (options.publicKey) {
      var pubKey = options.publicKey;
      var permissionWithKey = account.permissions.find(function (p) {
        return p.required_auth.keys[0].key.toString() === pubKey.toString();
      });
      if (!permissionWithKey) throwError("No permission found with key " + pubKey, SdkErrors.UserNotLoggedInWithThisApp);
      return permissionWithKey.perm_name;
    } else {
      if (!options.keyManager) throwError('keyManager missing', SdkErrors.MissingParams);
      return Promise.resolve(options.keyManager.getKey({
        level: KeyManagerLevel.BROWSER_LOCAL_STORAGE
      })).then(function (pubKey) {
        return Promise.resolve(App.getApp(window.location.origin)).then(function (app) {
          try {
            var permission = account.getPermission(app.accountName);
            var publicKey = permission.required_auth.keys[0].key;
            if (pubKey.toString() !== publicKey.toString()) throwError('key not authorized', SdkErrors.KeyNotFound);
          } catch (e) {
            if (e.message.startsWith('Unknown permission ')) throwError("No permission found for app " + app.accountName, SdkErrors.UserNotLoggedInWithThisApp);else throw e;
          }
          return app.accountName;
        });
      });
    }
  });
};
/**
 * Rejects a login request by sending a response to the requesting app
 *
 * @static function so that it can be used to cancel requests in flows where users are not logged in
 *
 * @param {WalletRequest[]} requests - Array of requests to reject
 * @param {'mobile' | 'browser'} platform - Platform of the request, either 'mobile' or 'browser'
 * @param {{ code: SdkErrors, reason: string }} error - Error to send back to the requesting app
 * @param {{callbackPath?: URLtype, messageRecipient?: DID}} options - Options for the response
 * @returns {Promise<void | URLtype>} the callback url if the platform is mobile, or undefined if it is browser (a message is sent to the user)
 */
var terminateLoginRequest = function terminateLoginRequest(responsesManager, returnType, error, options) {
  try {
    var responsePayload = {
      success: false,
      error: _extends({}, error, {
        requests: responsesManager.getRequests()
      })
    };
    return Promise.resolve(function () {
      if (returnType === 'mobile') {
        if (!options.callbackPath || !options.callbackOrigin) throwError('Missing callback path', SdkErrors.MissingParams);
        var callbackUrl = options.callbackOrigin + options.callbackPath + '?';
        callbackUrl += 'payload=' + objToBase64Url(responsePayload);
        return callbackUrl;
      } else {
        if (!options.messageRecipient || !options.user) throwError('Missing message recipient', SdkErrors.MissingParams);
        return Promise.resolve(options.user.getIssuer()).then(function (issuer) {
          return Promise.resolve(LoginRequestResponseMessage.signMessage(responsePayload, issuer, options.messageRecipient)).then(function (message) {
            return Promise.resolve(options.user.sendMessage(message)).then(function () {});
          });
        });
      }
    }());
  } catch (e) {
    return Promise.reject(e);
  }
};
var getAccountInfo = function getAccountInfo(account) {
  try {
    var _temp2 = function _temp2() {
      return Promise.resolve(getAccount(accountName));
    };
    var accountName;
    var _temp = function () {
      if (account instanceof TonomyUsername) {
        return Promise.resolve(tonomyContract$4.getPerson(account)).then(function (idData) {
          accountName = idData.account_name;
        });
      } else {
        accountName = account;
      }
    }();
    return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
  } catch (e) {
    return Promise.reject(e);
  }
};
/**
 * Initialize and return the user object
 * @param keyManager  the key manager
 * @param storage  the storage
 * @returns the user object
 */
var tonomyContract$4 = TonomyContract.Instance;
function createUserObject(keyManager, storageFactory) {
  return new User(keyManager, storageFactory);
}

var tonomyContract$3 = TonomyContract.Instance;
var UserAuthorization = /*#__PURE__*/function (_UserBase) {
  function UserAuthorization() {
    return _UserBase.apply(this, arguments) || this;
  }
  _inheritsLoose(UserAuthorization, _UserBase);
  var _proto = UserAuthorization.prototype;
  _proto.savePassword = function savePassword(masterPassword, options) {
    try {
      var _temp2 = function _temp2() {
        _this.storage.salt = salt;
        return Promise.resolve(_this.storage.salt).then(function () {
          // wait for magic setter on storage
          return Promise.resolve(_this.keyManager.storeKey({
            level: KeyManagerLevel.PASSWORD,
            privateKey: privateKey,
            challenge: masterPassword
          })).then(function () {
            return Promise.resolve(_this.keyManager.storeKey({
              level: KeyManagerLevel.ACTIVE,
              privateKey: privateKey
              // eventually this should be different than the password key, but for now Antelope protocol doesn't support it
              // ideally we would have a different structure, and active key will be linked to local key
            })).then(function () {});
          });
        });
      };
      var _this = this;
      var privateKey;
      var salt;
      var _temp = function () {
        if (options.salt) {
          salt = options.salt;
          return Promise.resolve(options.keyFromPasswordFn(masterPassword, salt)).then(function (res) {
            privateKey = res.privateKey;
          });
        } else {
          return Promise.resolve(options.keyFromPasswordFn(masterPassword)).then(function (res) {
            privateKey = res.privateKey;
            salt = res.salt;
          });
        }
      }();
      return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.checkPassword = function checkPassword(password, options) {
    try {
      var _this2 = this;
      return Promise.resolve(_this2.getAccountName()).then(function (username) {
        return Promise.resolve(tonomyContract$3.getPerson(username)).then(function (idData) {
          var salt = idData.password_salt;
          return Promise.resolve(_this2.savePassword(password, _extends({}, options, {
            salt: salt
          }))).then(function () {
            return Promise.resolve(_this2.keyManager.getKey({
              level: KeyManagerLevel.PASSWORD
            })).then(function (passwordKey) {
              return Promise.resolve(getAccountInfo(idData.account_name)).then(function (accountData) {
                var onchainKey = accountData.getPermission('owner').required_auth.keys[0].key; // TODO change to active/other permissions when we make the change
                if (passwordKey.toString() !== onchainKey.toString()) throwError('Password is incorrect', SdkErrors.PasswordInvalid);
                return true;
              });
            });
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.savePIN = function savePIN(pin) {
    try {
      var _this3 = this;
      var privateKey = generateRandomKeyPair().privateKey;
      return Promise.resolve(_this3.keyManager.storeKey({
        level: KeyManagerLevel.PIN,
        privateKey: privateKey,
        challenge: pin
      })).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.checkPin = function checkPin(pin) {
    try {
      var _this4 = this;
      return Promise.resolve(_this4.keyManager.checkKey({
        level: KeyManagerLevel.PIN,
        challenge: pin
      })).then(function (pinKey) {
        if (!pinKey) throwError('Pin is incorrect', SdkErrors.PinInvalid);
        return true;
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.saveFingerprint = function saveFingerprint() {
    try {
      var _this5 = this;
      var privateKey = generateRandomKeyPair().privateKey;
      return Promise.resolve(_this5.keyManager.storeKey({
        level: KeyManagerLevel.BIOMETRIC,
        privateKey: privateKey
      })).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.saveLocal = function saveLocal() {
    try {
      var _this6 = this;
      var privateKey = generateRandomKeyPair().privateKey;
      return Promise.resolve(_this6.keyManager.storeKey({
        level: KeyManagerLevel.LOCAL,
        privateKey: privateKey
      })).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return UserAuthorization;
}(UserBase);

var UserCaptcha = /*#__PURE__*/function (_UserBase) {
  function UserCaptcha() {
    return _UserBase.apply(this, arguments) || this;
  }
  _inheritsLoose(UserCaptcha, _UserBase);
  var _proto = UserCaptcha.prototype;
  _proto.getCaptchaToken = function getCaptchaToken() {
    try {
      var _this = this;
      return Promise.resolve(_this.storage.captchaToken);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.saveCaptchaToken = function saveCaptchaToken(captchaToken) {
    try {
      var _this2 = this;
      _this2.storage.captchaToken = captchaToken;
      return Promise.resolve(_this2.storage.captchaToken).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return UserCaptcha;
}(UserBase);

var createAccount = function createAccount(data) {
  try {
    var url = getSettings().accountsServiceUrl;
    return Promise.resolve(fetch(url + "/accounts", {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify(data)
    })).then(function (response) {
      return Promise.resolve(response.json()).then(function (resData) {
        if (response.status !== 201) {
          if (response.status === 400) {
            return throwError('Communication Service error: ' + resData.message + ', errors: ' + resData.errors, SdkErrors.AccountServiceError);
          }
          throwError('Communication Service error: ' + resData.message + ', status: ' + response.status, SdkErrors.AccountServiceError);
        }
        return {
          transactionId: resData.transactionId,
          accountName: Name.from(resData.accountName)
        };
      });
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

var UserStatusEnum;
(function (UserStatusEnum) {
  UserStatusEnum["CREATING_ACCOUNT"] = "CREATING_ACCOUNT";
  UserStatusEnum["LOGGING_IN"] = "LOGGING_IN";
  UserStatusEnum["READY"] = "READY";
  UserStatusEnum["DEACTIVATED"] = "DEACTIVATED";
})(UserStatusEnum || (UserStatusEnum = {}));
// eslint-disable-next-line @typescript-eslint/no-namespace
(function (UserStatusEnum) {
  /*
   * Returns the index of the enum value
   *
   * @param value The level to get the index of
   */
  function indexFor(value) {
    return Object.keys(UserStatusEnum).indexOf(value);
  }
  UserStatusEnum.indexFor = indexFor;
  /*
   * Creates an AuthenticatorLevel from a string or index of the level
   *
   * @param value The string or index
   */
  function from(value) {
    var index;
    if (typeof value !== 'number') {
      index = UserStatusEnum.indexFor(value);
    } else {
      index = value;
    }
    return Object.values(UserStatusEnum)[index];
  }
  UserStatusEnum.from = from;
})(UserStatusEnum || (UserStatusEnum = {}));

var debug$4 = Debug('tonomy-sdk:services:communication:communication');
var SOCKET_TIMEOUT = 5000;
var Communication = /*#__PURE__*/function () {
  function Communication(singleton) {
    if (singleton === void 0) {
      singleton = true;
    }
    this.socketServer = void 0;
    // TODO fix problem: if server restarts, this will be lost and all clients will need to reconnect
    this.subscribers = new Map();
    this.authMessage = void 0;
    this.loggedIn = false;
    this.url = void 0;
    if (Communication.singleton && singleton) return Communication.singleton;
    this.url = getSettings().communicationUrl;
    this.socketServer = io(this.url, {
      transports: ['websocket'],
      autoConnect: false
    });
    Communication.singleton = this;
  }
  var _proto = Communication.prototype;
  _proto.isConnected = function isConnected() {
    return this.socketServer && this.socketServer.connected;
  };
  _proto.isLoggedIn = function isLoggedIn() {
    return this.loggedIn && this.authMessage !== undefined && typeof this.authMessage === 'object';
  }
  /**
   * Connects to the Tonomy Communication server
   *
   * @returns {Promise<void>}
   * @throws {SdkError} CommunicationNotConnected
   */;
  _proto.connect = function connect() {
    try {
      var _this = this;
      if (_this.isConnected()) return Promise.resolve();
      _this.socketServer.connect();
      return Promise.resolve(new Promise(function (resolve, reject) {
        _this.socketServer.on('connect', function () {
          try {
            var _temp2 = function _temp2() {
              resolve(true);
            };
            var _temp = function () {
              if (_this.isLoggedIn()) {
                return Promise.resolve(_this.login(_this.authMessage)).then(function () {});
              }
            }();
            return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
          } catch (e) {
            return Promise.reject(e);
          }
        });
        setTimeout(function () {
          if (_this.isConnected()) return;
          reject(createSdkError('Could not connect to Tonomy Communication server', SdkErrors.CommunicationNotConnected));
        }, SOCKET_TIMEOUT);
      })).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Sends a Message object through a websocket connection to the Tonomy Communication server
   *
   * @param {string} event - the name of the event to emit
   * @param {Message} message - the Message object to send
   * @returns {Promise<boolean>} - true if successful and acknowledged by the server
   * @throws {SdkError} - CommunicationTimeout
   */
  ;
  _proto.emitMessage = function emitMessage(event, message) {
    try {
      var _this2 = this;
      debug$4('emitMessage', event, message.getType(), message.getSender(), message.getRecipient(), message.getPayload());
      return Promise.resolve(new Promise(function (resolve, reject) {
        _this2.socketServer.timeout(SOCKET_TIMEOUT).emit(event, {
          message: message.toString()
        }, function (error, response) {
          debug$4('emitMessage response', JSON.stringify(error, null, 2), JSON.stringify(response, null, 2));
          if (response != null && response.error) {
            var _response$exception;
            if ((response == null || (_response$exception = response.exception) == null ? void 0 : _response$exception.name) === 'HttpException') {
              var communicationError = new CommunicationError(response);
              reject(communicationError);
              return;
            }
            reject(response);
            return;
          }
          if (error) {
            reject(error);
            return;
          }
          resolve(response);
          return;
        });
      })).then(function (ack) {
        if (ack.status !== 200) {
          throw new CommunicationError({
            exception: {
              response: ack.error,
              name: 'HttpException',
              status: ack.status,
              message: ack.error
            },
            name: 'CommunicationError',
            message: ack.error
          });
        }
        return ack.details;
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * connects to the Tonomy Communication server, authenticates with it's DID
   * @param {AuthenticationMessage} authorization - the VC the user sent
   *
   * @returns {boolean} - true if successful
   */
  ;
  _proto.login = function login(authorization) {
    try {
      var _this3 = this;
      return Promise.resolve(_this3.connect()).then(function () {
        return Promise.resolve(_this3.emitMessage('login', authorization)).then(function (result) {
          if (result) {
            _this3.loggedIn = true;
            _this3.authMessage = authorization;
          }
          return result;
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /* sends a message to another DID
   * create a Message object from the message argument
   * the message is used as the `vc` property of a VC signed by the User's key
   */
  ;
  _proto.sendMessage = function sendMessage(message) {
    try {
      var _this4 = this;
      if (!_this4.isLoggedIn()) {
        throwError('You need to login before sending a messages', SdkErrors.CommunicationNotLoggedIn);
      }
      return Promise.resolve(_this4.emitMessage('message', message));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * function that adds a new subscriber, which is called every time a message is received
   *
   * @param {Subscriber} subscriber - the message object
   * @param {string} [type] - the type of message to subscribe to
   * @returns {number} - identifier which will be used for unsubscribe
   */
  ;
  _proto.subscribeMessage = function subscribeMessage(subscriber, type) {
    var _this5 = this;
    Communication.identifier++;
    var messageHandler = function messageHandler(message) {
      var msg = new Message(message);
      debug$4('receiveMessage', msg.getType(), msg.getSender(), msg.getRecipient(), msg.getPayload());
      if (!type || msg.getType() === type) {
        subscriber(msg);
      }
      return _this5;
    };
    this.socketServer.on('message', messageHandler);
    this.subscribers.set(Communication.identifier, messageHandler);
    return Communication.identifier;
  }
  /**
   * unsubscribes a function from the receiving a message
   *
   * @param {number} id - identifier which will be used for unsubscribe
   *
   */;
  _proto.unsubscribeMessage = function unsubscribeMessage(id) {
    var subscriber = this.subscribers.get(id);
    if (subscriber) {
      this.socketServer.off('message', subscriber);
      this.subscribers["delete"](id);
    }
  };
  _proto.disconnect = function disconnect() {
    this.loggedIn = false;
    delete this.authMessage;
    if (this.isConnected()) {
      this.socketServer.disconnect();
    }
  };
  return Communication;
}();
Communication.singleton = void 0;
Communication.identifier = void 0;

var UserCommunication = /*#__PURE__*/function (_UserAuthorization) {
  function UserCommunication(_keyManager, storageFactory) {
    var _this;
    _this = _UserAuthorization.call(this, _keyManager, storageFactory) || this;
    _this.communication = void 0;
    _this.communication = new Communication(false);
    return _this;
  }
  _inheritsLoose(UserCommunication, _UserAuthorization);
  var _proto = UserCommunication.prototype;
  _proto.loginCommunication = function loginCommunication(authorization) {
    try {
      var _this2 = this;
      return Promise.resolve(_this2.communication.login(authorization));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.unsubscribeMessage = function unsubscribeMessage(id) {
    this.communication.unsubscribeMessage(id);
  };
  _proto.subscribeMessage = function subscribeMessage(subscriber, type) {
    return this.communication.subscribeMessage(subscriber, type);
  };
  _proto.sendMessage = function sendMessage(message) {
    try {
      var _this3 = this;
      return Promise.resolve(_this3.communication.sendMessage(message));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.disconnectCommunication = function disconnectCommunication() {
    this.communication.disconnect();
  };
  return UserCommunication;
}(UserAuthorization);

function _catch$2(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
var debug$3 = Debug('tonomy-sdk:controllers:user-onboarding');
var _iteratorSymbol$1 = typeof Symbol !== "undefined" ? Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator")) : "@@iterator";
function _settle$1(pact, state, value) {
  if (!pact.s) {
    if (value instanceof _Pact$1) {
      if (value.s) {
        if (state & 1) {
          state = value.s;
        }
        value = value.v;
      } else {
        value.o = _settle$1.bind(null, pact, state);
        return;
      }
    }
    if (value && value.then) {
      value.then(_settle$1.bind(null, pact, state), _settle$1.bind(null, pact, 2));
      return;
    }
    pact.s = state;
    pact.v = value;
    var observer = pact.o;
    if (observer) {
      observer(pact);
    }
  }
}
var _Pact$1 = /*#__PURE__*/function () {
  function _Pact() {}
  _Pact.prototype.then = function (onFulfilled, onRejected) {
    var result = new _Pact();
    var state = this.s;
    if (state) {
      var callback = state & 1 ? onFulfilled : onRejected;
      if (callback) {
        try {
          _settle$1(result, 1, callback(this.v));
        } catch (e) {
          _settle$1(result, 2, e);
        }
        return result;
      } else {
        return this;
      }
    }
    this.o = function (_this) {
      try {
        var value = _this.v;
        if (_this.s & 1) {
          _settle$1(result, 1, onFulfilled ? onFulfilled(value) : value);
        } else if (onRejected) {
          _settle$1(result, 1, onRejected(value));
        } else {
          _settle$1(result, 2, value);
        }
      } catch (e) {
        _settle$1(result, 2, e);
      }
    };
    return result;
  };
  return _Pact;
}();
function _isSettledPact$1(thenable) {
  return thenable instanceof _Pact$1 && thenable.s & 1;
}
function _forTo$1(array, body, check) {
  var i = -1,
    pact,
    reject;
  function _cycle(result) {
    try {
      while (++i < array.length && (!check || !check())) {
        result = body(i);
        if (result && result.then) {
          if (_isSettledPact$1(result)) {
            result = result.v;
          } else {
            result.then(_cycle, reject || (reject = _settle$1.bind(null, pact = new _Pact$1(), 2)));
            return;
          }
        }
      }
      if (pact) {
        _settle$1(pact, 1, result);
      } else {
        pact = result;
      }
    } catch (e) {
      _settle$1(pact || (pact = new _Pact$1()), 2, e);
    }
  }
  _cycle();
  return pact;
}
var tonomyContract$2 = TonomyContract.Instance;
function _forOf$1(target, body, check) {
  if (typeof target[_iteratorSymbol$1] === "function") {
    var iterator = target[_iteratorSymbol$1](),
      step,
      pact,
      reject;
    function _cycle(result) {
      try {
        while (!(step = iterator.next()).done && (!check || !check())) {
          result = body(step.value);
          if (result && result.then) {
            if (_isSettledPact$1(result)) {
              result = result.v;
            } else {
              result.then(_cycle, reject || (reject = _settle$1.bind(null, pact = new _Pact$1(), 2)));
              return;
            }
          }
        }
        if (pact) {
          _settle$1(pact, 1, result);
        } else {
          pact = result;
        }
      } catch (e) {
        _settle$1(pact || (pact = new _Pact$1()), 2, e);
      }
    }
    _cycle();
    if (iterator.return) {
      var _fixup = function (value) {
        try {
          if (!step.done) {
            iterator.return();
          }
        } catch (e) {}
        return value;
      };
      if (pact && pact.then) {
        return pact.then(_fixup, function (e) {
          throw _fixup(e);
        });
      }
      _fixup();
    }
    return pact;
  }
  // No support for Symbol.iterator
  if (!("length" in target)) {
    throw new TypeError("Object is not iterable");
  }
  // Handle live collections properly
  var values = [];
  for (var i = 0; i < target.length; i++) {
    values.push(target[i]);
  }
  return _forTo$1(values, function (i) {
    return body(values[i]);
  }, check);
}
var UserOnboarding = /*#__PURE__*/function (_UserCommunication) {
  function UserOnboarding() {
    var _this;
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    _this = _UserCommunication.call.apply(_UserCommunication, [this].concat(args)) || this;
    _this.chainID = void 0;
    return _this;
  }
  _inheritsLoose(UserOnboarding, _UserCommunication);
  var _proto = UserOnboarding.prototype;
  _proto.validateUsername = function validateUsername(username) {
    if (typeof username !== 'string' || username.length === 0) throwError('Username must be a string', SdkErrors.InvalidData);
    // Allow only letters, numbers, underscore and dash (1 to 50 characters)
    if (!/^[A-Za-z0-9_-]{1,100}$/g.test(username)) throwError('Username contains invalid characters', SdkErrors.InvalidUsername);
  };
  _proto.createDid = function createDid() {
    try {
      var _temp2 = function _temp2() {
        return Promise.resolve(_this2.getAccountName()).then(function (accountName) {
          _this2.storage.did = "did:antelope:" + _this2.chainID + ":" + accountName.toString();
          return Promise.resolve(_this2.storage.did).then(function () {
            return _this2.storage.did;
          });
        });
      };
      var _this2 = this;
      var _temp = function () {
        if (!_this2.chainID) {
          return Promise.resolve(getChainInfo()).then(function (_getChainInfo) {
            _this2.chainID = _getChainInfo.chain_id;
          });
        }
      }();
      return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.login = function login(username, password, options) {
    try {
      var _this3 = this;
      _this3.validateUsername(username.getBaseUsername());
      var keyManager = _this3.keyManager;
      return Promise.resolve(tonomyContract$2.getPerson(username)).then(function (idData) {
        var salt = idData.password_salt;
        return Promise.resolve(_this3.savePassword(password, _extends({}, options, {
          salt: salt
        }))).then(function () {
          return Promise.resolve(keyManager.getKey({
            level: KeyManagerLevel.PASSWORD
          })).then(function (passwordKey) {
            return Promise.resolve(getAccountInfo(idData.account_name)).then(function (accountData) {
              var onchainKey = accountData.getPermission('owner').required_auth.keys[0].key; // TODO change to active/other permissions when we make the change
              if (passwordKey.toString() !== onchainKey.toString()) throwError('Password is incorrect', SdkErrors.PasswordInvalid);
              _this3.storage.accountName = Name.from(idData.account_name);
              _this3.storage.username = username;
              _this3.storage.status = UserStatusEnum.LOGGING_IN;
              return Promise.resolve(_this3.storage.accountName).then(function () {
                return Promise.resolve(_this3.storage.username).then(function () {
                  return Promise.resolve(_this3.storage.status).then(function () {
                    return Promise.resolve(_this3.createDid()).then(function () {
                      return idData;
                    });
                  });
                });
              });
            });
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.isLoggedIn = function isLoggedIn() {
    try {
      var _this4 = this;
      return Promise.resolve(_this4.getStatus()).then(function (_this4$getStatus) {
        return _this4$getStatus === UserStatusEnum.READY;
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.createPerson = function createPerson() {
    try {
      var _this5 = this;
      var keyManager = _this5.keyManager;
      return Promise.resolve(_this5.getUsername()).then(function (username) {
        var usernameHash = username.usernameHash;
        return Promise.resolve(keyManager.getKey({
          level: KeyManagerLevel.PASSWORD
        })).then(function (publicKey) {
          return Promise.resolve(_this5.storage.salt).then(function (salt) {
            return Promise.resolve(_this5.storage.captchaToken).then(function (captchaToken) {
              var _exit;
              function _temp4(_result) {
                return _exit ? _result : Promise.resolve(_this5.storage.accountName).then(function () {
                  _this5.storage.status = UserStatusEnum.CREATING_ACCOUNT;
                  return Promise.resolve(_this5.storage.status).then(function () {
                    return Promise.resolve(_this5.createDid()).then(function () {
                      return Promise.resolve(_this5.getAccountName()).then(function (_this5$getAccountName) {
                        var _this5$getAccountName2 = _this5$getAccountName.toString();
                        return Promise.resolve(_this5.getUsername()).then(function (_this5$getUsername) {
                          var _this5$getUsername$ge = _this5$getUsername.getBaseUsername();
                          return Promise.resolve(_this5.getDid()).then(function (_this5$getDid) {
                            debug$3('Created account', {
                              accountName: _this5$getAccountName2,
                              username: _this5$getUsername$ge,
                              did: _this5$getDid
                            });
                          });
                        });
                      });
                    });
                  });
                });
              }
              var _temp3 = _catch$2(function () {
                return Promise.resolve(createAccount({
                  usernameHash: usernameHash,
                  publicKey: publicKey,
                  salt: salt,
                  captchaToken: captchaToken
                })).then(function (res) {
                  _this5.storage.accountName = res.accountName;
                });
              }, function (e) {
                if (e.status === 400 && e.message === 'Username is taken') {
                  throwError('Username is taken', SdkErrors.UsernameTaken);
                }
                throw e;
              });
              return _temp3 && _temp3.then ? _temp3.then(_temp4) : _temp4(_temp3);
            });
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.saveUsername = function saveUsername(username) {
    try {
      var _temp6 = function _temp6(_result2) {
        if (_exit2) return _result2;
        _this6.storage.username = fullUsername;
        return Promise.resolve(_this6.storage.username).then(function () {});
      };
      var _exit2;
      var _this6 = this;
      _this6.validateUsername(username);
      var user;
      var fullUsername = TonomyUsername.fromUsername(username, AccountType.PERSON, getSettings().accountSuffix);
      var _temp5 = _catch$2(function () {
        return Promise.resolve(getAccountInfo(fullUsername)).then(function (_getAccountInfo) {
          user = _getAccountInfo;
          if (user) throwError('Username is taken', SdkErrors.UsernameTaken);
        });
      }, function (e) {
        if (!(e instanceof SdkError && e.code === SdkErrors.UsernameNotFound)) {
          throw e;
        }
      });
      return Promise.resolve(_temp5 && _temp5.then ? _temp5.then(_temp6) : _temp6(_temp5));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.usernameExists = function usernameExists(username) {
    try {
      var fullUsername = TonomyUsername.fromUsername(username, AccountType.PERSON, getSettings().accountSuffix);
      return Promise.resolve(_catch$2(function () {
        return Promise.resolve(getAccountInfo(fullUsername)).then(function () {
          return true;
        });
      }, function (e) {
        if (e instanceof SdkError && e.code === SdkErrors.UsernameNotFound) {
          return false;
        }
        throw e;
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.updateKeys = function updateKeys(password) {
    try {
      var _this7 = this;
      return Promise.resolve(_this7.getStatus()).then(function (status) {
        var _exit3;
        function _temp12(_result3) {
          var _exit4;
          if (_exit3) ;
          function _temp10(_result4) {
            var _exit5;
            if (_exit4) ;
            function _temp8(_result5) {
              if (_exit5) ;
              var signer = createKeyManagerSigner(keyManager, KeyManagerLevel.PASSWORD, password);
              return Promise.resolve(_this7.getAccountName()).then(function (accountName) {
                return Promise.resolve(tonomyContract$2.updatekeysper(accountName.toString(), keys, signer)).then(function () {
                  _this7.storage.status = UserStatusEnum.READY;
                  return Promise.resolve(_this7.storage.status).then(function () {});
                });
              });
            }
            var _temp7 = _catch$2(function () {
              return Promise.resolve(keyManager.getKey({
                level: KeyManagerLevel.LOCAL
              })).then(function (localKey) {
                keys.LOCAL = localKey.toString();
              });
            }, function (e) {
              if (!(e instanceof SdkError) || e.code !== SdkErrors.KeyNotFound) throw e;
            });
            return _temp7 && _temp7.then ? _temp7.then(_temp8) : _temp8(_temp7);
          }
          var _temp9 = _catch$2(function () {
            return Promise.resolve(keyManager.getKey({
              level: KeyManagerLevel.BIOMETRIC
            })).then(function (biometricKey) {
              keys.BIOMETRIC = biometricKey.toString();
            });
          }, function (e) {
            if (!(e instanceof SdkError) || e.code !== SdkErrors.KeyNotFound) throw e;
          });
          return _temp9 && _temp9.then ? _temp9.then(_temp10) : _temp10(_temp9);
        }
        if (status === UserStatusEnum.DEACTIVATED) {
          throwError("Can't update keys for deactivated user", SdkErrors.UserDeactivated);
        }
        var keyManager = _this7.keyManager;
        // TODO:
        // use status in smart contract to lock the account till finished creating
        var keys = {};
        var _temp11 = _catch$2(function () {
          return Promise.resolve(keyManager.getKey({
            level: KeyManagerLevel.PIN
          })).then(function (pinKey) {
            keys.PIN = pinKey.toString();
          });
        }, function (e) {
          if (!(e instanceof SdkError) || e.code !== SdkErrors.KeyNotFound) throw e;
        });
        return _temp11 && _temp11.then ? _temp11.then(_temp12) : _temp12(_temp11);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.checkKeysStillValid = function checkKeysStillValid() {
    try {
      var _this8 = this;
      // Account been created, or has not finished being created yet
      return Promise.resolve(_this8.getStatus()).then(function (_this8$getStatus) {
        if (_this8$getStatus !== UserStatusEnum.READY) throwError('User is not ready', SdkErrors.AccountDoesntExist);
        return Promise.resolve(_this8.storage.accountName).then(function (_this8$storage$accoun) {
          return Promise.resolve(getAccountInfo(_this8$storage$accoun)).then(function (accountInfo) {
            var checkPairs = [{
              level: KeyManagerLevel.PIN,
              permission: 'pin'
            }, {
              level: KeyManagerLevel.BIOMETRIC,
              permission: 'biometric'
            }, {
              level: KeyManagerLevel.LOCAL,
              permission: 'local'
            }, {
              level: KeyManagerLevel.PASSWORD,
              permission: 'active'
            }, {
              level: KeyManagerLevel.PASSWORD,
              permission: 'owner'
            }];
            var _temp15 = _forOf$1(checkPairs, function (pair) {
              function _temp14() {
                var blockchainPermission;
                try {
                  blockchainPermission = accountInfo.getPermission(pair.permission);
                } catch (e) {
                  blockchainPermission = null;
                }
                if (!localKey && blockchainPermission) {
                  // User probably logged into another device and finished create account flow there
                  throwError(pair.level + " key was not found in the keyManager, but was found on the blockchain", SdkErrors.KeyNotFound);
                }
                if (localKey && !blockchainPermission) {
                  // User probably hasn't finished create account flow yet
                  throwError(pair.level + " keys was not found on the blockchain, but was found in the keyManager", SdkErrors.KeyNotFound);
                }
                if (localKey && blockchainPermission && localKey.toString() !== blockchainPermission.required_auth.keys[0].key.toString()) {
                  // User has logged in on another device
                  throwError(pair.level + " keys do not match", SdkErrors.KeyNotFound);
                }
              }
              var localKey;
              var _temp13 = _catch$2(function () {
                return Promise.resolve(_this8.keyManager.getKey({
                  level: pair.level
                })).then(function (_this8$keyManager$get) {
                  localKey = _this8$keyManager$get;
                });
              }, function () {
                localKey = null;
              });
              return _temp13 && _temp13.then ? _temp13.then(_temp14) : _temp14(_temp13);
            });
            return _temp15 && _temp15.then ? _temp15.then(function () {
              return true;
            }) : true;
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.logout = function logout() {
    try {
      var _temp17 = function _temp17(_result7) {
        if (_exit6) return _result7;
        // clear storage data
        _this9.storage.clear();
        _this9.disconnectCommunication();
      };
      var _exit6;
      var _this9 = this;
      var _temp16 = _forOf$1(Object.keys(KeyManagerLevel), function (level) {
        return _catch$2(function () {
          return Promise.resolve(_this9.keyManager.getKey({
            level: KeyManagerLevel.from(level)
          })).then(function () {
            _this9.keyManager.removeKey({
              level: KeyManagerLevel.from(level)
            });
          });
        }, function (e) {
          if (!(e instanceof SdkError) || e.code !== SdkErrors.KeyNotFound && e.code !== SdkErrors.InvalidKeyLevel) throw e;
        });
      }, function () {
        return _exit6;
      });
      // remove all keys
      return Promise.resolve(_temp16 && _temp16.then ? _temp16.then(_temp17) : _temp17(_temp16));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.initializeFromStorage = function initializeFromStorage() {
    try {
      var _this10 = this;
      return Promise.resolve(_this10.getAccountName()).then(function (accountName) {
        return function () {
          if (accountName) {
            return Promise.resolve(_this10.checkKeysStillValid());
          } else {
            throwError('Account "' + accountName + '" not found', SdkErrors.AccountDoesntExist);
          }
        }();
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return UserOnboarding;
}(UserCommunication);

function _catch$1(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
var debug$2 = Debug('tonomy-sdk:UserRequestsManager');
var _iteratorSymbol = typeof Symbol !== "undefined" ? Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator")) : "@@iterator";
function _settle(pact, state, value) {
  if (!pact.s) {
    if (value instanceof _Pact) {
      if (value.s) {
        if (state & 1) {
          state = value.s;
        }
        value = value.v;
      } else {
        value.o = _settle.bind(null, pact, state);
        return;
      }
    }
    if (value && value.then) {
      value.then(_settle.bind(null, pact, state), _settle.bind(null, pact, 2));
      return;
    }
    pact.s = state;
    pact.v = value;
    var observer = pact.o;
    if (observer) {
      observer(pact);
    }
  }
}
var _Pact = /*#__PURE__*/function () {
  function _Pact() {}
  _Pact.prototype.then = function (onFulfilled, onRejected) {
    var result = new _Pact();
    var state = this.s;
    if (state) {
      var callback = state & 1 ? onFulfilled : onRejected;
      if (callback) {
        try {
          _settle(result, 1, callback(this.v));
        } catch (e) {
          _settle(result, 2, e);
        }
        return result;
      } else {
        return this;
      }
    }
    this.o = function (_this) {
      try {
        var value = _this.v;
        if (_this.s & 1) {
          _settle(result, 1, onFulfilled ? onFulfilled(value) : value);
        } else if (onRejected) {
          _settle(result, 1, onRejected(value));
        } else {
          _settle(result, 2, value);
        }
      } catch (e) {
        _settle(result, 2, e);
      }
    };
    return result;
  };
  return _Pact;
}();
function _isSettledPact(thenable) {
  return thenable instanceof _Pact && thenable.s & 1;
}
function _forTo(array, body, check) {
  var i = -1,
    pact,
    reject;
  function _cycle(result) {
    try {
      while (++i < array.length && (!check || !check())) {
        result = body(i);
        if (result && result.then) {
          if (_isSettledPact(result)) {
            result = result.v;
          } else {
            result.then(_cycle, reject || (reject = _settle.bind(null, pact = new _Pact(), 2)));
            return;
          }
        }
      }
      if (pact) {
        _settle(pact, 1, result);
      } else {
        pact = result;
      }
    } catch (e) {
      _settle(pact || (pact = new _Pact()), 2, e);
    }
  }
  _cycle();
  return pact;
}
var tonomyEosioProxyContract = TonomyEosioProxyContract.Instance;
function _forOf(target, body, check) {
  if (typeof target[_iteratorSymbol] === "function") {
    var _cycle2 = function _cycle(result) {
      try {
        while (!(step = iterator.next()).done && (!check || !check())) {
          result = body(step.value);
          if (result && result.then) {
            if (_isSettledPact(result)) {
              result = result.v;
            } else {
              result.then(_cycle2, reject || (reject = _settle.bind(null, pact = new _Pact(), 2)));
              return;
            }
          }
        }
        if (pact) {
          _settle(pact, 1, result);
        } else {
          pact = result;
        }
      } catch (e) {
        _settle(pact || (pact = new _Pact()), 2, e);
      }
    };
    var iterator = target[_iteratorSymbol](),
      step,
      pact,
      reject;
    _cycle2();
    if (iterator["return"]) {
      var _fixup = function _fixup(value) {
        try {
          if (!step.done) {
            iterator["return"]();
          }
        } catch (e) {}
        return value;
      };
      if (pact && pact.then) {
        return pact.then(_fixup, function (e) {
          throw _fixup(e);
        });
      }
      _fixup();
    }
    return pact;
  }
  // No support for Symbol.iterator
  if (!("length" in target)) {
    throw new TypeError("Object is not iterable");
  }
  // Handle live collections properly
  var values = [];
  for (var i = 0; i < target.length; i++) {
    values.push(target[i]);
  }
  return _forTo(values, function (i) {
    return body(values[i]);
  }, check);
}
var tonomyContract$1 = TonomyContract.Instance;
var UserRequestsManager = /*#__PURE__*/function (_UserCommunication) {
  function UserRequestsManager() {
    return _UserCommunication.apply(this, arguments) || this;
  }
  _inheritsLoose(UserRequestsManager, _UserCommunication);
  var _proto = UserRequestsManager.prototype;
  _proto.handleLinkAuthRequestMessage = function handleLinkAuthRequestMessage(message) {
    try {
      var _this = this;
      var linkAuthRequestMessage = new LinkAuthRequestMessage(message);
      return Promise.resolve(_catch$1(function () {
        var _getAccountNameFromDi = getAccountNameFromDid(message.getSender()),
          _equals = _getAccountNameFromDi.equals;
        return Promise.resolve(_this.getAccountName()).then(function (_this$getAccountName) {
          if (!_equals.call(_getAccountNameFromDi, _this$getAccountName)) throwError('Message not sent from authorized account', SdkErrors.SenderNotAuthorized);
          var payload = linkAuthRequestMessage.getPayload();
          var contract = payload.contract;
          var action = payload.action;
          var permission = parseDid(message.getSender()).fragment;
          if (!permission) throwError('DID does not contain App permission', SdkErrors.MissingParams);
          return Promise.resolve(tonomyContract$1.getApp(Name.from(permission))).then(function () {
            // Throws SdkErrors.DataQueryNoRowDataFound error if app does not exist
            // which cannot happen in theory, as the user is already logged in
            // if (permission !== contract.toString())
            //     throwError('Contract and permission do not match', SdkErrors.MismatchedParams);
            var signer = createKeyManagerSigner(_this.keyManager, KeyManagerLevel.ACTIVE);
            var _linkAuth = tonomyEosioProxyContract.linkAuth;
            return Promise.resolve(_this.getAccountName()).then(function (_this$getAccountName2) {
              return Promise.resolve(_linkAuth.call(tonomyEosioProxyContract, _this$getAccountName2.toString(), contract.toString(), action.toString(), permission, signer)).then(function () {
                var _signMessage = LinkAuthRequestResponseMessage.signMessage,
                  _requestId$success = {
                    requestId: linkAuthRequestMessage.getVc().getId(),
                    success: true
                  };
                return Promise.resolve(_this.getIssuer()).then(function (_this$getIssuer) {
                  return Promise.resolve(_signMessage.call(LinkAuthRequestResponseMessage, _requestId$success, _this$getIssuer, linkAuthRequestMessage.getSender())).then(function (linkAuthRequestResponseMessage) {
                    return Promise.resolve(_this.sendMessage(linkAuthRequestResponseMessage)).then(function () {});
                  });
                });
              });
            });
          });
        });
      }, function (e) {
        if (e instanceof SdkError && e.code === SdkErrors.SenderNotAuthorized) {} else {
          // all other errors are Tonomy software errors, so throw to bubble up
          throw e;
        }
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.loginWithApp = function loginWithApp(app, key) {
    try {
      var _this2 = this;
      return Promise.resolve(_this2.getAccountName()).then(function (myAccount) {
        var appRecord = {
          app: app,
          added: new Date(),
          status: AppStatusEnum.PENDING
        };
        return Promise.resolve(_this2.storage.appRecords).then(function (apps) {
          if (!apps) {
            apps = [];
          }
          apps.push(appRecord);
          _this2.storage.appRecords = apps;
          return Promise.resolve(_this2.storage.appRecords).then(function () {
            function _temp4() {
              debug$2('loginWithApp key', key);
              return Promise.resolve(tonomyContract$1.loginwithapp(myAccount.toString(), app.accountName.toString(), 'local', key, localSigner)).then(function () {
                function _temp2() {
                  appRecord.status = AppStatusEnum.READY;
                  _this2.storage.appRecords = apps;
                  return Promise.resolve(_this2.storage.appRecords).then(function () {});
                }
                var _temp = function () {
                  if (linkAuth) {
                    return Promise.resolve(sleep(1000)).then(function () {
                      // wait for the blockchain to catch up
                      var activeSigner = createKeyManagerSigner(_this2.keyManager, KeyManagerLevel.ACTIVE);
                      return Promise.resolve(tonomyEosioProxyContract.linkAuth(myAccount.toString(), app.accountName.toString(), '', app.accountName.toString(), activeSigner)).then(function () {});
                    });
                  }
                }();
                // If the permission was only just created, we link it to the app (using its account name)
                // so that this permission can be used to sign transactions in the app immediately
                // (otherwise a LinkAuthRequestMessage needs to be sent and executed with ExternalUser.checkLinkAuthRequirements())
                // when a transaction attempt is made in the app
                return _temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp);
              });
            }
            var localSigner = createKeyManagerSigner(_this2.keyManager, KeyManagerLevel.LOCAL);
            var linkAuth = false;
            var _temp3 = _catch$1(function () {
              return Promise.resolve(getAccountInfo(myAccount)).then(function (_getAccountInfo) {
                _getAccountInfo.getPermission(app.accountName);
              });
            }, function (e) {
              if (e.message === "Unknown permission " + app.accountName.toString() + " on account " + myAccount.toString() + ".") {
                linkAuth = true;
              }
            });
            return _temp3 && _temp3.then ? _temp3.then(_temp4) : _temp4(_temp3);
          });
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.acceptLoginRequest = function acceptLoginRequest(responsesManager, platform, options) {
    try {
      var _this3 = this;
      debug$2('acceptLoginRequest() options', options);
      return Promise.resolve(responsesManager.createResponses(_this3)).then(function (finalResponses) {
        var responsePayload = {
          success: true,
          response: finalResponses
        };
        return function () {
          if (platform === 'mobile') {
            if (!options.callbackPath || !options.callbackOrigin) throwError('Missing callback origin or path', SdkErrors.MissingParams);
            var callbackUrl = options.callbackOrigin + options.callbackPath + '?';
            callbackUrl += 'payload=' + objToBase64Url(responsePayload);
            return callbackUrl;
          } else {
            if (!options.messageRecipient) throwError('Missing message recipient', SdkErrors.MissingParams);
            return Promise.resolve(_this3.getIssuer()).then(function (issuer) {
              return Promise.resolve(LoginRequestResponseMessage.signMessage(responsePayload, issuer, options.messageRecipient)).then(function (message) {
                return Promise.resolve(_this3.sendMessage(message)).then(function () {});
              });
            });
          }
        }();
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.checkLoginRequests = function checkLoginRequests(requests) {
    try {
      var _this4 = this;
      var managedRequests = new RequestsManager(requests);
      return Promise.resolve(managedRequests.verify()).then(function () {
        var _exit;
        var response = [];
        var _temp7 = _forOf(managedRequests.getLoginRequestsOrThrow(), function (request) {
          var payload = request.getPayload();
          return Promise.resolve(App.getApp(payload.origin)).then(function (app) {
            var _exit2;
            function _temp6(_result3) {
              if (_exit2) ;
              response.push({
                request: request,
                app: app,
                requiresLogin: requiresLogin,
                ssoApp: payload.origin === getSettings().ssoWebsiteOrigin,
                requestDid: request.getIssuer()
              });
            }
            var requiresLogin = true;
            var _temp5 = _catch$1(function () {
              return Promise.resolve(_this4.getAccountName()).then(function (_this4$getAccountName) {
                return Promise.resolve(verifyKeyExistsForApp(_this4$getAccountName, {
                  publicKey: payload.publicKey
                })).then(function () {
                  requiresLogin = false;
                });
              });
            }, function (e) {
              if (e instanceof SdkError && e.code === SdkErrors.UserNotLoggedInWithThisApp) {
                // Never consented
                requiresLogin = true;
              } else {
                throw e;
              }
            });
            return _temp5 && _temp5.then ? _temp5.then(_temp6) : _temp6(_temp5);
          });
        }, function () {
          return _exit;
        });
        return _temp7 && _temp7.then ? _temp7.then(function (_result4) {
          return _exit ? _result4 : response;
        }) : _exit ? _temp7 : response;
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return UserRequestsManager;
}(UserCommunication);

var User = /*#__PURE__*/function (_Mixin) {
  function User() {
    return _Mixin.apply(this, arguments) || this;
  }
  _inheritsLoose(User, _Mixin);
  return User;
}(Mixin(UserBase, UserAuthorization, UserCaptcha, UserOnboarding, UserCommunication, UserRequestsManager));

var getDidKeyIssuerFromStorage = function getDidKeyIssuerFromStorage(keyManager) {
  try {
    if (keyManager === undefined) keyManager = new JsKeyManager();
    return Promise.resolve(keyManager.getKey({
      level: KeyManagerLevel.BROWSER_LOCAL_STORAGE
    })).then(function (publicKey) {
      var signer = createVCSigner(keyManager, KeyManagerLevel.BROWSER_LOCAL_STORAGE);
      return Promise.resolve(toDidKey(publicKey)).then(function (did) {
        return {
          did: did,
          signer: signer.sign,
          alg: 'ES256K-R'
        };
      });
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var createDidKeyIssuerAndStore = function createDidKeyIssuerAndStore(keyManager) {
  try {
    if (keyManager === undefined) keyManager = new JsKeyManager();
    var _generateRandomKeyPai = generateRandomKeyPair(),
      privateKey = _generateRandomKeyPai.privateKey;
    return Promise.resolve(toDidKeyIssuer(privateKey)).then(function (issuer) {
      return Promise.resolve(keyManager.storeKey({
        level: KeyManagerLevel.BROWSER_LOCAL_STORAGE,
        privateKey: privateKey
      })).then(function () {
        return issuer;
      });
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

/**
 * Extracts the WalletRequests from the URL
 *
 * @returns {LoginRequestsMessagePayload} the requests, username and accountName
 */

/**
 * Verifies the WalletRequests received in the URL were successfully authorized by Tonomy ID
 *
 * @description should be called in the callback page of the Tonomy Accounts (SSO) website
 *
 * @returns {Promise<RequestsManager>} - the managed verified WalletRequests
 */
var onRedirectLogin = function onRedirectLogin() {
  try {
    var _getLoginRequestFromU = getLoginRequestFromUrl(),
      requests = _getLoginRequestFromU.requests;
    var requestsManager = new RequestsManager(requests);
    return Promise.resolve(requestsManager.verify()).then(function () {
      return Promise.resolve(requestsManager.checkReferrerOrigin()).then(function () {
        return requestsManager;
      });
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
function getLoginRequestFromUrl() {
  var params = new URLSearchParams(window.location.search);
  var base64UrlPayload = params.get('payload');
  if (!base64UrlPayload) throwError("payload parameter doesn't exist", SdkErrors.MissingParams);
  var unparsedLoginRequestMessagePayload = base64UrlToObj(base64UrlPayload);
  var requests = new RequestsManager(unparsedLoginRequestMessagePayload.requests);
  return {
    requests: requests.getRequests()
  };
}
/**
 * Extracts the login requests, username and accountName from the URL
 *
 * @returns {LoginRequestResponseMessagePayload} the requests, username and accountName
 */
function getLoginRequestResponseFromUrl() {
  var params = new URLSearchParams(window.location.search);
  var base64UrlPayload = params.get('payload');
  if (!base64UrlPayload) throwError("payload parameter doesn't exists", SdkErrors.MissingParams);
  var parsedPayload = base64UrlToObj(base64UrlPayload);
  if (parsedPayload.success !== true && parsedPayload.success !== false) throwError("success parameter doesn't exists", SdkErrors.MissingParams);
  if (parsedPayload.success) {
    if (!parsedPayload.response) {
      throw new Error('LoginRequestsResponseMessage must have a responses property');
    }
    var responses = parsedPayload.response.map(function (response) {
      return new WalletRequestAndResponseObject(response).getRequestAndResponse();
    });
    return _extends({}, parsedPayload, {
      response: responses
    });
  } else {
    if (!parsedPayload.error) {
      throw new Error('LoginRequestsResponseMessage must have an error property');
    }
    var error = parsedPayload.error;
    var requests = error.requests.map(function (request) {
      return new WalletRequest(request);
    });
    var requestsManager = new RequestsManager(requests);
    return _extends({}, parsedPayload, {
      error: _extends({}, error, {
        requests: requestsManager.getRequests()
      })
    });
  }
}

var veramo2 = function veramo2() {
  try {
    var kid = 'testing';
    var key = Wallet.createRandom().privateKey;
    debug$1('Creating key', kid, key);
    var keyManager = new KeyManager({
      store: new KeyStore(dbConnection),
      kms: {
        local: new KeyManagementSystem(new PrivateKeyStore(dbConnection, new SecretBox(KMS_SECRET_KEY)))
      }
    });
    debug$1('Setup for key import');
    keyManager.keyManagerCreate({
      type: 'Secp256k1',
      kms: 'local',
      meta: {
        encryption: ['ECDH-ES']
      }
    });
    debug$1('Importing key');
    keyManager.keyManagerImport({
      type: 'Secp256k1',
      kms: 'local',
      privateKeyHex: key,
      kid: kid
    });
    return Promise.resolve();
  } catch (e) {
    return Promise.reject(e);
  }
};
var verifyCredential = function verifyCredential(agent, verifiableCredential) {
  try {
    return Promise.resolve(agent.verifyCredential({
      credential: verifiableCredential
    })).then(function (result) {
      debug$1("Credential verified", result.verified);
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var createCredential = function createCredential(agent) {
  try {
    return Promise.resolve(agent.didManagerGetByAlias({
      alias: 'default'
    })).then(function (identifier) {
      return Promise.resolve(agent.createVerifiableCredential({
        credential: {
          issuer: {
            id: identifier.did
          },
          credentialSubject: {
            id: 'did:web:example.com',
            you: 'Rock'
          }
        },
        proofFormat: 'jwt'
      })).then(function (verifiableCredential) {
        debug$1("New credential created", verifiableCredential.id);
        debug$1(JSON.stringify(verifiableCredential, null, 2));
        return verifiableCredential;
      });
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var createIdentifier = function createIdentifier(agent) {
  try {
    return Promise.resolve(agent.didManagerCreate({
      alias: 'default'
    })).then(function (identifier) {
      debug$1("New identifier created", identifier.did);
      debug$1(JSON.stringify(identifier, null, 2));
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var listIdentifiers = function listIdentifiers(agent) {
  try {
    return Promise.resolve(agent.didManagerFind({
      alias: 'default'
    })).then(function (identifiers) {
      debug$1("There are " + identifiers.length + " identifiers");
      if (identifiers.length > 0) {
        identifiers.map(function (id) {
          debug$1(id);
        });
      }
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var setup = function setup() {
  try {
    var agent = createAgent({
      plugins: [new KeyManager({
        store: new KeyStore(dbConnection),
        kms: {
          local: new KeyManagementSystem(new PrivateKeyStore(dbConnection, new SecretBox(KMS_SECRET_KEY)))
        }
      }), new DIDManager({
        store: new DIDStore(dbConnection),
        defaultProvider: 'did:ethr:goerli',
        providers: {
          'did:ethr:goerli': new EthrDIDProvider({
            defaultKms: 'local',
            network: 'goerli',
            rpcUrl: 'https://goerli.infura.io/v3/' + INFURA_PROJECT_ID
          })
        }
      }), new DIDResolverPlugin({
        resolver: new Resolver(_extends({}, getResolver$1({
          infuraProjectId: INFURA_PROJECT_ID
        }), getResolver$2()))
      }), new CredentialPlugin()]
    });
    return Promise.resolve(agent);
  } catch (e) {
    return Promise.reject(e);
  }
};
var veramo = function veramo() {
  try {
    debug$1('Running veramo');
    return Promise.resolve(setup()).then(function (agent) {
      debug$1('Listing identifiers');
      return Promise.resolve(listIdentifiers(agent)).then(function () {
        return Promise.resolve(createIdentifier(agent)).then(function () {
          return Promise.resolve(createCredential(agent)).then(function (verifiableCredential) {
            return Promise.resolve(verifyCredential(agent, verifiableCredential)).then(function () {});
          });
        });
      });
    });
  } catch (e) {
    return Promise.reject(e);
  }
};
var setupDatabase = function setupDatabase(datasource) {
  try {
    var _temp2 = function _temp2(_result) {
      return _exit ? _result : Promise.resolve(new DataSource({
        type: 'sqlite',
        database: DATABASE_FILE,
        synchronize: false,
        migrations: migrations,
        migrationsRun: true,
        logging: ['error', 'info', 'warn'],
        entities: Entities
      }).initialize()).then(function (_DataSource$initializ) {
        dbConnection = _DataSource$initializ;
      });
    };
    var _exit;
    debug$1('Setting up database');
    var _temp = function () {
      if (datasource) {
        debug$1('Using provided datasource');
        return Promise.resolve(datasource.initialize()).then(function (_datasource$initializ) {
          dbConnection = _datasource$initializ;
          _exit = 1;
        });
      }
    }();
    return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
  } catch (e) {
    return Promise.reject(e);
  }
};
var debug$1 = Debug('tonomy-sdk:util:ssi:veramo');
var DATABASE_FILE = '.database.sqlite.test';
var INFURA_PROJECT_ID = 'e19492ad3c7d409ca266f23af0a097d7';
var KMS_SECRET_KEY = 'a8add1db4f64e6117667708d261e6fd9f4de85209ba690ad254fa8ecb26ffe03';
var dbConnection;

var BrowserStorage = /*#__PURE__*/function () {
  function BrowserStorage(scope) {
    this._storage = {};
    this.scope = void 0;
    this.scope = scope;
    this._storage = {};
  }
  var _proto = BrowserStorage.prototype;
  _proto.retrieve = function retrieve(key) {
    try {
      var _this = this;
      if (key in _this._storage) return Promise.resolve(_this._storage[key]);
      if (localStorage) {
        var value = localStorage.getItem(key);
        if (value) {
          var returnValue = JSON.parse(value);
          _this._storage[key] = returnValue;
          return Promise.resolve(returnValue);
        }
      } else {
        return Promise.resolve(undefined);
      }
      return Promise.resolve();
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.store = function store(key, value) {
    try {
      var _this2 = this;
      if (localStorage) {
        localStorage.setItem(key, JSON.stringify(value));
      }
      _this2._storage[key] = value;
      return Promise.resolve();
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.clear = function clear() {
    try {
      var _this3 = this;
      _this3._storage = {};
      if (localStorage) {
        for (var i = 0; i < localStorage.length; i++) {
          var key = localStorage.key(i);
          if (typeof key === 'string' && key.startsWith(_this3.scope)) {
            localStorage.removeItem(key);
          }
        }
      }
      return Promise.resolve();
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return BrowserStorage;
}();
function browserStorageFactory(scope) {
  return new BrowserStorage(scope);
}

var KEY_STORAGE_NAMESPACE = STORAGE_NAMESPACE + 'key.';
var JsKeyManager = /*#__PURE__*/function () {
  function JsKeyManager() {
    this.keyStorage = {};
  }
  var _proto = JsKeyManager.prototype;
  // creates a new secure key and returns the public key
  _proto.storeKey = function storeKey(options) {
    try {
      var _this = this;
      StoreKeyOptions.validate(options);
      var keyStore = {
        privateKey: options.privateKey,
        publicKey: options.privateKey.toPublic()
      };
      switch (options.level) {
        case KeyManagerLevel.ACTIVE:
        case KeyManagerLevel.LOCAL:
        case KeyManagerLevel.BIOMETRIC:
          break;
        case KeyManagerLevel.PASSWORD:
        case KeyManagerLevel.PIN:
          if (!options.challenge) throwError('Challenge missing', SdkErrors.MissingChallenge);
          keyStore.salt = randomString(32);
          keyStore.hashedSaltedChallenge = sha256(options.challenge + keyStore.salt);
          break;
        case KeyManagerLevel.BROWSER_LOCAL_STORAGE:
          localStorage.setItem(KEY_STORAGE_NAMESPACE + options.level, JSON.stringify(keyStore));
          break;
        case KeyManagerLevel.BROWSER_SESSION_STORAGE:
          sessionStorage.setItem(KEY_STORAGE_NAMESPACE + options.level, JSON.stringify(keyStore));
          break;
        default:
          throwError('Invalid level', SdkErrors.InvalidKeyLevel);
      }
      _this.keyStorage[options.level] = keyStore;
      return Promise.resolve(keyStore.publicKey);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.fetchKey = function fetchKey(options) {
    GetKeyOptions.validate(options);
    var keyStore = this.keyStorage[options.level];
    if (keyStore) return keyStore;
    if (options.level === KeyManagerLevel.BROWSER_LOCAL_STORAGE || options.level === KeyManagerLevel.BROWSER_SESSION_STORAGE) {
      var storage = options.level === KeyManagerLevel.BROWSER_LOCAL_STORAGE ? localStorage.getItem(KEY_STORAGE_NAMESPACE + options.level) : sessionStorage.getItem(KEY_STORAGE_NAMESPACE + options.level);
      if (!storage) throwError("No key for level " + options.level, SdkErrors.KeyNotFound);
      var _keyStore = JSON.parse(storage);
      this.keyStorage[options.level] = {
        privateKey: PrivateKey.from(_keyStore.privateKey),
        publicKey: PublicKey.from(_keyStore.publicKey)
      };
      if (_keyStore.hashedSaltedChallenge) this.keyStorage[options.level].hashedSaltedChallenge = _keyStore.hashedSaltedChallenge;
      if (_keyStore.salt) this.keyStorage[options.level].salt = _keyStore.salt;
      return this.keyStorage[options.level];
    }
    throwError("No key for level " + options.level, SdkErrors.KeyNotFound);
  };
  _proto.signData = function signData(options) {
    try {
      var _temp2 = function _temp2() {
        var privateKey = keyStore.privateKey;
        if (options.outputType === 'jwt') {
          if (typeof options.data !== 'string') throw throwError('Data must be a string', SdkErrors.InvalidData);
          var signer = createSigner$1(privateKey);
          return Promise.resolve(signer(options.data));
        } else {
          var digest;
          if (typeof options.data === 'string') {
            digest = Checksum256.hash(Buffer.from(options.data));
          } else {
            digest = options.data;
          }
          var signature = privateKey.signDigest(digest);
          return signature;
        }
      };
      var _this2 = this;
      SignDataOptions.validate(options);
      var keyStore = _this2.fetchKey(options);
      var _temp = function () {
        if (options.level === KeyManagerLevel.PASSWORD || options.level === KeyManagerLevel.PIN) {
          if (!options.challenge) throwError('Challenge missing', SdkErrors.MissingChallenge);
          return Promise.resolve(_this2.checkKey({
            level: options.level,
            challenge: options.challenge
          })).then(function (validChallenge) {
            if (!validChallenge && options.level === KeyManagerLevel.PASSWORD) throwError('Invalid password', SdkErrors.PasswordInvalid);
            if (!validChallenge && options.level === KeyManagerLevel.PIN) throwError('Invalid PIN', SdkErrors.PinInvalid);
          });
        }
      }();
      return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.getKey = function getKey(options) {
    try {
      var _this3 = this;
      GetKeyOptions.validate(options);
      var keyStore = _this3.fetchKey(options);
      return Promise.resolve(keyStore.publicKey);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.checkKey = function checkKey(options) {
    try {
      var _this4 = this;
      CheckKeyOptions.validate(options);
      var keyStore = _this4.fetchKey(options);
      if (options.level === KeyManagerLevel.PIN || options.level === KeyManagerLevel.PASSWORD) {
        if (!options.challenge) throwError('Challenge is missing', SdkErrors.MissingChallenge);
        var hashedSaltedChallenge = sha256((options == null ? void 0 : options.challenge) + keyStore.salt);
        return Promise.resolve(hashedSaltedChallenge === keyStore.hashedSaltedChallenge);
      } else throw throwError('Invalid Level', SdkErrors.InvalidKeyLevel);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.removeKey = function removeKey(options) {
    try {
      var _this5 = this;
      GetKeyOptions.validate(options);
      delete _this5.keyStorage[options.level];
      if (options.level === KeyManagerLevel.BROWSER_LOCAL_STORAGE || options.level === KeyManagerLevel.BROWSER_SESSION_STORAGE) {
        options.level === KeyManagerLevel.BROWSER_LOCAL_STORAGE ? localStorage.removeItem(KEY_STORAGE_NAMESPACE + options.level) : sessionStorage.removeItem(KEY_STORAGE_NAMESPACE + options.level);
      }
      return Promise.resolve();
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return JsKeyManager;
}();

function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
}
var debug = Debug('tonomy-sdk:externalUser');
var tonomyContract = TonomyContract.Instance;
/**
 * An external user on a website that is being logged into by a Tonomy ID user
 *
 */
var ExternalUser = /*#__PURE__*/function () {
  /**
   * Creates a new external user
   *
   * @param {KeyManager} _keyManager - the key manager to use for signing
   * @param {StorageFactory} _storageFactory - the storage factory to use for persistent storage
   */
  function ExternalUser(_keyManager, _storageFactory) {
    this.keyManager = void 0;
    this.storage = void 0;
    this.did = void 0;
    this.communication = void 0;
    this.keyManager = _keyManager;
    this.storage = createStorage(STORAGE_NAMESPACE + 'external.user.', _storageFactory);
    this.communication = new Communication(false);
  }
  /**
   * Removes the keys and clear storage
   *
   */
  var _proto = ExternalUser.prototype;
  _proto.logout = function logout() {
    try {
      var _this = this;
      _this.storage.clear();
      _this.keyManager.removeKey({
        level: KeyManagerLevel.BROWSER_LOCAL_STORAGE
      });
      _this.keyManager.removeKey({
        level: KeyManagerLevel.BROWSER_SESSION_STORAGE
      });
      return Promise.resolve();
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Retrieves the user from persistent storage if it exists and verifies the keys are valid
   *
   * @property {boolean} [options.autoLogout] - automatically logsout on error if this key is false
   * @property {StorageFactory} [options.storageFactory=browserStorageFactory] - the storage factory to use for persistent storage
   * @property {KeyManager} [options.keyManager=new JsKeyManager()] - the key manager to use for signing
   * @returns {Promise<ExternalUser>} - the user
   */
  ;
  ExternalUser.getUser = function getUser(options) {
    try {
      var _options$keyManager, _options$storageFacto, _options$autoLogout;
      var keyManager = (_options$keyManager = options == null ? void 0 : options.keyManager) != null ? _options$keyManager : new JsKeyManager();
      var storageFactory = (_options$storageFacto = options == null ? void 0 : options.storageFactory) != null ? _options$storageFacto : browserStorageFactory;
      var autoLogout = (_options$autoLogout = options == null ? void 0 : options.autoLogout) != null ? _options$autoLogout : true;
      var user = new ExternalUser(keyManager, storageFactory);
      return Promise.resolve(_catch(function () {
        return Promise.resolve(user.getAccountName()).then(function (accountName) {
          if (!accountName) {
            throw throwError('accountName not found', SdkErrors.AccountNotFound);
          }
          return Promise.resolve(verifyKeyExistsForApp(accountName, {
            keyManager: keyManager
          })).then(function (appPermission) {
            return Promise.resolve(user.getAppPermission()).then(function (appPermissionStorage) {
              if (appPermission.toString() !== appPermissionStorage.toString()) throwError('App permission has changed', SdkErrors.InvalidData);
              return Promise.resolve(user.getUsername()).then(function (username) {
                var _temp = function () {
                  if (username) {
                    return Promise.resolve(tonomyContract.getPerson(username)).then(function (personData) {
                      if (accountName.toString() !== personData.account_name.toString()) throwError('Username has changed', SdkErrors.InvalidData);
                    });
                  }
                }();
                return _temp && _temp.then ? _temp.then(function () {
                  return user;
                }) : user;
              });
            });
          });
        });
      }, function (e) {
        function _temp3() {
          if (e instanceof SdkError && (e.code === SdkErrors.KeyNotFound || e.code === SdkErrors.InvalidData)) throwError('User Not loggedIn', SdkErrors.UserNotLoggedIn);
          throw e;
        }
        var _temp2 = function () {
          if (autoLogout) return Promise.resolve(user.logout()).then(function () {});
        }();
        return _temp2 && _temp2.then ? _temp2.then(_temp3) : _temp3(_temp2);
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Returns the DID URL of the logged in user
   *
   * @returns {Promise<DIDurl>} - the DID of the user
   */
  ;
  _proto.getDid = function getDid() {
    try {
      var _this2 = this;
      var did = _this2.did;
      var _temp4 = function () {
        if (!did) {
          return Promise.resolve(_this2.getAccountName()).then(function (_this2$getAccountName) {
            return Promise.resolve(_this2$getAccountName.toString()).then(function (accountName) {
              return Promise.resolve(getChainInfo()).then(function (_getChainInfo) {
                var chainID = _getChainInfo.chain_id.toString();
                return Promise.resolve(_this2.getAppPermission()).then(function (appPermission) {
                  did = "did:antelope:" + chainID + ":" + accountName + "#" + appPermission;
                  _this2.did = did;
                  return Promise.resolve(_this2.did).then(function () {});
                });
              });
            });
          });
        }
      }();
      return Promise.resolve(_temp4 && _temp4.then ? _temp4.then(function () {
        return did;
      }) : did);
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * @returns {Promise{DIDurl}} the DID URL of the Tonomy ID wallet with #local fragment
   */
  ;
  _proto.getWalletDid = function getWalletDid() {
    try {
      var _this3 = this;
      return Promise.resolve(_this3.getDid()).then(function (did) {
        return Promise.resolve(_this3.getAppPermission()).then(function (appPermission) {
          return did.replace("#" + appPermission, '#local');
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Sets the account name of the user
   *
   * @param {Name} accountName - the account name of the user
   */
  ;
  _proto.setAccountName = function setAccountName(accountName) {
    try {
      var _this4 = this;
      _this4.storage.accountName = accountName;
      return Promise.resolve(_this4.storage.accountName).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Sets the username of the user
   *
   * @param {string} username - the username of the user
   */
  ;
  _proto.setUsername = function setUsername(username) {
    try {
      var _this5 = this;
      _this5.storage.username = username;
      return Promise.resolve(_this5.storage.username).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Sets the permission name of the app the user is logged into
   *
   * @param {Name} appPermission - the account name of the app
   */
  ;
  _proto.setAppPermission = function setAppPermission(appPermission) {
    try {
      var _this6 = this;
      _this6.storage.appPermission = appPermission;
      return Promise.resolve(_this6.storage.appPermission).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Gets the username of the user
   *
   * @returns {Promise<TonomyUsername>} - the username of the user
   */
  ;
  _proto.getUsername = function getUsername() {
    try {
      var _this7 = this;
      return Promise.resolve(_this7.storage.username).then(function (storage) {
        if (!storage) return;
        if (!storage) throwError('Username not set', SdkErrors.InvalidData);else if (storage instanceof TonomyUsername) {
          return storage;
        } else if (typeof storage === 'string') {
          return new TonomyUsername(storage);
        } else {
          throwError('Username not in expected format', SdkErrors.InvalidData);
        }
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Gets the account name of the user
   *
   * @returns {Promise<Name>} - the account name of the user
   */
  ;
  _proto.getAccountName = function getAccountName() {
    try {
      var _this8 = this;
      return Promise.resolve(_this8.storage.accountName);
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Gets the permission name of the app the user is logged into
   *
   * @returns {Promise<Name>} - the account name of the app
   */
  ;
  _proto.getAppPermission = function getAppPermission() {
    try {
      var _this9 = this;
      return Promise.resolve(_this9.storage.appPermission);
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Redirects the user to login to the app with their Tonomy ID account
   *
   * @description should be called when the user clicks on the login button
   *
   * @param {IOnPressLoginOptions} onPressLoginOptions - options for the login
   * @property {boolean} onPressLoginOptions.redirect - if true, redirects the user to the login page, if false, returns the token
   * @property {string} onPressLoginOptions.callbackPath - the path to redirect the user to after login
   * @param {KeyManager} [keyManager] - the key manager to use to store the keys
   * @returns {Promise<LoginWithTonomyMessages | void>} - if redirect is true, returns void, if redirect is false, returns the login request in the form of a JWT token
   */
  ;
  ExternalUser.loginWithTonomy = function loginWithTonomy(_ref, keyManager) {
    var _ref$redirect = _ref.redirect,
      redirect = _ref$redirect === void 0 ? true : _ref$redirect,
      callbackPath = _ref.callbackPath,
      dataRequest = _ref.dataRequest;
    try {
      if (keyManager === undefined) keyManager = new JsKeyManager();
      return Promise.resolve(createDidKeyIssuerAndStore(keyManager)).then(function (issuer) {
        return Promise.resolve(keyManager.getKey({
          level: KeyManagerLevel.BROWSER_LOCAL_STORAGE
        })).then(function (publicKey) {
          function _temp6() {
            var payload = {
              randomString: randomString(32),
              origin: window.location.origin,
              publicKey: publicKey,
              callbackPath: callbackPath
            };
            return Promise.resolve(LoginRequest.signRequest(payload, issuer)).then(function (loginRequest) {
              if (redirect) {
                var _payload = {
                  requests: [loginRequest]
                };
                if (dataSharingRequest) {
                  _payload.requests.push(dataSharingRequest);
                }
                var base64UrlPayload = objToBase64Url(_payload);
                window.location.href = getSettings().ssoWebsiteOrigin + "/login?payload=" + base64UrlPayload;
              } else {
                return Promise.resolve(AuthenticationMessage.signMessageWithoutRecipient({}, issuer)).then(function (loginToCommunication) {
                  return {
                    loginRequest: loginRequest,
                    dataSharingRequest: dataSharingRequest,
                    loginToCommunication: loginToCommunication
                  };
                });
              }
            });
          }
          var dataSharingRequest;
          var _temp5 = function () {
            if (dataRequest) {
              var dataSharingPayload = {
                username: (dataRequest == null ? void 0 : dataRequest.username) || false,
                origin: window.location.origin
              };
              return Promise.resolve(DataSharingRequest.signRequest(dataSharingPayload, issuer)).then(function (_DataSharingRequest$s) {
                dataSharingRequest = _DataSharingRequest$s;
              });
            }
          }();
          return _temp5 && _temp5.then ? _temp5.then(_temp6) : _temp6(_temp5);
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Returns the issuer of the user for use with did-jwt and VCs
   *
   * @returns {Promise<Issuer>} - the issuer of the user
   */
  ;
  _proto.getIssuer = function getIssuer() {
    try {
      var _this10 = this;
      return Promise.resolve(_this10.getDid()).then(function (did) {
        var signer = createVCSigner(_this10.keyManager, KeyManagerLevel.BROWSER_LOCAL_STORAGE);
        return {
          did: did,
          signer: signer.sign,
          alg: 'ES256K-R'
        };
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Receives the login request from Tonomy ID and verifies the login was successful
   *
   * @description should be called in the callback page
   *
   * @param {VerifyLoginOptions} [options] - options for the login
   * @property {boolean} [options.checkKeys = true] - if true, checks the keys in the keyManager against the blockchain
   * @property {KeyManager} [options.keyManager] - the key manager to use to storage and manage keys
   * @property {StorageFactory} [options.storageFactory] - the storage factory to use to store data
   *
   * @returns {Promise<ExternalUser>} an external user object ready to use
   */
  ;
  ExternalUser.verifyLoginRequest = function verifyLoginRequest(options) {
    try {
      if (!options) options = {};
      if (!options.checkKeys) options.checkKeys = true;
      var keyManager = options.keyManager || new JsKeyManager();
      var _getLoginRequestRespo = getLoginRequestResponseFromUrl(),
        success = _getLoginRequestRespo.success,
        error = _getLoginRequestRespo.error,
        response = _getLoginRequestRespo.response;
      return Promise.resolve(function () {
        if (success === true) {
          if (!response) throwError('No response found in url', SdkErrors.MissingParams);
          var managedResponses = new ResponsesManager(response);
          return Promise.resolve(managedResponses.verify()).then(function () {
            return Promise.resolve(managedResponses.fetchMeta()).then(function () {
              var loginResponse = managedResponses.getLoginResponsesWithSameOriginOrThrow();
              return Promise.resolve(keyManager.getKey({
                level: KeyManagerLevel.BROWSER_LOCAL_STORAGE
              })).then(function (keyFromStorage) {
                function _temp9() {
                  return Promise.resolve(externalUser.setAccountName(accountName)).then(function () {
                    var dataSharingResponse = managedResponses.getDataSharingResponseWithSameOrigin();
                    var _temp7 = function () {
                      if (dataSharingResponse && dataSharingResponse.getResponse().getPayload().data.username) {
                        return Promise.resolve(externalUser.setUsername(dataSharingResponse.getResponse().getPayload().data.username)).then(function () {});
                      }
                    }();
                    return _temp7 && _temp7.then ? _temp7.then(function () {
                      return externalUser;
                    }) : externalUser;
                  });
                }
                var payload = loginResponse.getRequest().getPayload();
                if (payload.publicKey.toString() !== keyFromStorage.toString()) {
                  throwError('Key in request does not match', SdkErrors.KeyNotFound);
                }
                var myStorageFactory = options.storageFactory || browserStorageFactory;
                var externalUser = new ExternalUser(keyManager, myStorageFactory);
                var accountName = loginResponse.getResponse().getPayload().accountName;
                var _temp8 = function () {
                  if (options.checkKeys) {
                    return Promise.resolve(verifyKeyExistsForApp(accountName, {
                      keyManager: keyManager
                    })).then(function (permission) {
                      return Promise.resolve(externalUser.setAppPermission(permission)).then(function () {});
                    });
                  }
                }();
                return _temp8 && _temp8.then ? _temp8.then(_temp9) : _temp9(_temp8);
              });
            });
          });
        } else {
          if (!error) throwError('No error found in url', SdkErrors.MissingParams);
          throwError(error.reason, error.code);
        }
      }());
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Signs a Verifiable Credential
   *
   * @param {string} id - the id of the VC
   * @param {string | string[]} type - the type of the VC
   * @param {object} data - the data of the VC
   * @property {string} [options.subject] - the subject of the VC
   *
   * @returns {Promise<VerifiableCredential>} - the signed VC
   */
  ;
  _proto.signVc = function signVc(id, type, data, options) {
    if (options === void 0) {
      options = {};
    }
    try {
      var _this11 = this;
      return Promise.resolve(_this11.getIssuer()).then(function (issuer) {
        return Promise.resolve(VerifiableCredential.sign(id, type, data, issuer, options));
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Return a signer to use to sign transactions
   *
   * @returns {Promise<Signer>} - the signer to use to sign transactions
   */
  ;
  _proto.getTransactionSigner = function getTransactionSigner() {
    return createKeyManagerSigner(this.keyManager, KeyManagerLevel.BROWSER_LOCAL_STORAGE);
  }
  /**
   * Signs a transaction and send it to the blockchain
   *
   * Note: It is signed with the permission of the current app
   * e.g. if user signed into app "marketcom", this will be the name of the permission used to sign the transaction
   *
   * Note: This is a convenience method that signs one action on one smart contract with the current
   * user's account and app permission. To sign a more complex transaction, get a signer with
   * getTransactionSigner() and use eosjs or @wharfkit/antelope directly
   *
   * @param {Name} contract - the smart contract account name
   * @param {Name} action - the action to sign (function of the smart contract)
   * @param {object} data - the data to sign
   *
   * @returns {Promise<API.v1.PushTransactionResponse>} - the signed transaction
   */;
  _proto.signTransaction = function signTransaction(contract, action, data) {
    try {
      var _this12 = this;
      return Promise.resolve(_this12.getAccountName()).then(function (account) {
        return Promise.resolve(_this12.getAppPermission()).then(function (permission) {
          function _temp11() {
            // This is a hack to get around linked_auth requirements on custom permissions
            // see https://github.com/Tonomy-Foundation/Tonomy-ID/issues/636#issuecomment-1508887362
            // and https://github.com/AntelopeIO/leap/issues/1131
            return Promise.resolve(_this12.checkLinkAuthRequirements(account, permission, contractAccount, action)).then(function () {
              // Setup the action to sign
              var newAction = {
                name: action.toString(),
                authorization: [{
                  actor: account.toString(),
                  permission: permission.toString()
                }],
                data: data
              };
              var signer = _this12.getTransactionSigner();
              debug("signTransaction() called by " + account.toString() + " with permission " + permission.toString() + " to contract " + contractAccount.toString(), JSON.stringify(newAction, null, 2));
              return Promise.resolve(transact(Name.from(contractAccount), [newAction], signer));
            });
          }
          var contractAccount;
          var _temp10 = function () {
            if (contract instanceof TonomyUsername) {
              return Promise.resolve(tonomyContract.getApp(contract)).then(function (app) {
                contractAccount = app.account_name;
              });
            } else {
              contractAccount = Name.from(contract);
            }
          }();
          return _temp10 && _temp10.then ? _temp10.then(_temp11) : _temp11(_temp10);
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.checkLinkAuthRequirements = function checkLinkAuthRequirements(actor, permission, contract, action) {
    try {
      var _this13 = this;
      // Check that the permission is linked to the contract
      return Promise.resolve(getAccount(actor)).then(function (account) {
        var _authorizingPermissio;
        var authorizingPermission = account.permissions.find(function (p) {
          return p.perm_name.equals(permission);
        });
        var linkedAuth = authorizingPermission == null || (_authorizingPermissio = authorizingPermission.linked_actions) == null ? void 0 : _authorizingPermissio.find(
        // a.action is undefined for all actions, or the specific action
        function (a) {
          return a.account.equals(contract) && (!a.action || a.action.equals(action));
        });
        // If not then link it
        var _temp12 = function () {
          if (!linkedAuth) {
            var _signMessage = LinkAuthRequestMessage.signMessage,
              _contract$action = {
                contract: Name.from(contract),
                action: Name.from('') // empty action name means all actions on this contract
              };
            return Promise.resolve(_this13.getIssuer()).then(function (_this13$getIssuer) {
              return Promise.resolve(_this13.getWalletDid()).then(function (_this13$getWalletDid) {
                return Promise.resolve(_signMessage.call(LinkAuthRequestMessage, _contract$action, _this13$getIssuer, _this13$getWalletDid)).then(function (linkAuthRequestMessage) {
                  var subscriberId;
                  // TODO: abstract the request response dynamic into a function...
                  var waitForResponse = new Promise(function (resolve, reject) {
                    subscriberId = _this13.communication.subscribeMessage(function (message) {
                      try {
                        var _temp13 = _catch(function () {
                          var _message$getSender = message.getSender();
                          return Promise.resolve(_this13.getWalletDid()).then(function (_this13$getWalletDid2) {
                            if (_message$getSender !== _this13$getWalletDid2) {
                              throwError('LinkAuthRequestResponse sender is not wallet', SdkErrors.SenderNotAuthorized);
                            }
                            var linkedAuthMsg = new LinkAuthRequestResponseMessage(message);
                            if (linkAuthRequestMessage.getVc().getId() === linkedAuthMsg.getPayload().requestId && linkedAuthMsg.getPayload().success) {
                              resolve();
                            } else {
                              throwError("Couldn't link permission", SdkErrors.LinkAuthFailed);
                            }
                          });
                        }, function (e) {
                          reject(e);
                        });
                        return Promise.resolve(_temp13 && _temp13.then ? _temp13.then(function () {}) : void 0);
                      } catch (e) {
                        return Promise.reject(e);
                      }
                    }, LinkAuthRequestResponseMessage.getType());
                    setTimeout(function () {
                      reject(createSdkError('LinkAuthRequestResponse timeout', SdkErrors.MessageSendError));
                    }, 5000);
                  });
                  return Promise.resolve(_this13.sendMessage(linkAuthRequestMessage)).then(function () {
                    return Promise.resolve(waitForResponse).then(function () {
                      // @ts-expect-error subscriberId is used before it is defined
                      _this13.communication.unsubscribeMessage(subscriberId);
                    });
                  });
                });
              });
            });
          }
        }();
        if (_temp12 && _temp12.then) return _temp12.then(function () {});
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }
  /**
   * Sends a message to another DID
   *
   * @param {Message} message - the message to send
   */
  ;
  _proto.sendMessage = function sendMessage(message) {
    try {
      var _this14 = this;
      return Promise.resolve(_this14.loginToCommunication()).then(function () {
        return Promise.resolve(_this14.communication.sendMessage(message)).then(function (res) {
          if (!res) throwError('Failed to send message', SdkErrors.MessageSendError);
        });
      });
    } catch (e) {
      return Promise.reject(e);
    }
  };
  _proto.loginToCommunication = function loginToCommunication() {
    try {
      var _this15 = this;
      var _temp14 = function () {
        if (!_this15.communication.isLoggedIn()) {
          return Promise.resolve(_this15.getIssuer()).then(function (issuer) {
            return Promise.resolve(AuthenticationMessage.signMessageWithoutRecipient({}, issuer)).then(function (authMessage) {
              return Promise.resolve(_this15.communication.login(authMessage)).then(function () {});
            });
          });
        }
      }();
      return Promise.resolve(_temp14 && _temp14.then ? _temp14.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };
  return ExternalUser;
}();

export { AccountType, AccountTypeEnum, AntelopePushTransactionError, App, AppStatusEnum, AuthenticationMessage, Authority, BrowserStorage, CheckKeyOptions, Communication, CommunicationError, DataSharingRequest, DemoTokenContract, EosioContract, EosioMsigContract, EosioTokenContract, index as EosioUtil, ExternalUser, GOVERNANCE_ACCOUNT_NAME, GetKeyOptions, HttpError, IdentifyMessage, JsKeyManager, KeyManagerLevel, LEOS_CURRENT_PRICE, LEOS_PUBLIC_SALE_PRICE, LEOS_SEED_LATE_ROUND_PRICE, LEOS_SEED_ROUND_PRICE, LinkAuthRequestMessage, LinkAuthRequestResponseMessage, LoginRequest, LoginRequestResponseMessage, LoginRequestsMessage, Message, RAM_FEE, RAM_PRICE, RequestsManager, ResponsesManager, SOCKET_TIMEOUT, STORAGE_NAMESPACE, SdkError, SdkErrors, SignDataOptions, StoreKeyOptions, TOTAL_RAM_AVAILABLE, TonomyContract, TonomyEosioProxyContract, TonomyUsername, User, UserStatusEnum, VestingContract, WalletRequest, WalletRequestAndResponse, WalletRequestAndResponseObject, WalletRequestAndResponseStrings, assetToAmount, base64UrlToObj, browserStorageFactory, bytesToTokens, castToWalletRequestResponseSubclass, castToWalletRequestSubclass, createDidKeyIssuerAndStore, createLoginQrCode, createSdkError, createSigner$1 as createSigner, createStorage, createUserObject, createVCSigner, dbConnection, defaultBlockchainParams, encodeHex, generateRandomKeyPair, getAccountInfo, getAccountNameFromDid, getAccountNameFromUsername, getDidKeyIssuerFromStorage, getFetch, getLoginRequestFromUrl, getLoginRequestResponseFromUrl, getSettings, int2hex, isProduction, objToBase64Url, onRedirectLogin, parseDid, randomBytes, randomNumber, randomString, setFetch, setSettings, setupDatabase, sha256, storageProxyHandler, terminateLoginRequest, throwError, index$1 as util, validateQrCode, veramo, veramo2, verifyKeyExistsForApp };
//# sourceMappingURL=index.module.js.map
